@@ -124,18 +124,32 @@ class Plot(object):
         except:
             yerr = None
 
+        try:
+            xerrp = float(parser.getAttribute(node, "xerrp"))
+        except:
+            xerrp = None
+
+        try:
+            yerrp = float(parser.getAttribute(node, "yerrp"))
+        except:
+            yerrp = None
+
         self.f.close()
 
         # Error Bar
         self.f = open(file, 'r')
-        self.xerr = self.uploadErrorBar(xerr)
-        self.yerr = self.uploadErrorBar(yerr)
+        self.xerr = self.uploadErrorBar(xerr, xerrp, xcol)
+        self.f.close()
+
+        self.f = open(file, 'r')
+        self.yerr = self.uploadErrorBar(yerr, yerrp, ycol)
         self.f.close()
 
         # List of additional matplotlib commands
         for k, v in parser.getAttributes(node).items():
             if k not in ('fig', 'fmt', 'legend', 'xcol', 'ycol', \
-                         'xplus', 'yplus', 'xfois', 'yfois', 'xerr', 'yerr'):
+                         'xplus', 'yplus', 'xfois', 'yfois', \
+                         'xerr', 'yerr', 'xerrp', 'yerrp'):
                 self.cmd.append("plt.setp(lines, " + k + "=" + v + ")")
 
         self.cmd += parser.getPltCommands(node)
@@ -162,39 +176,57 @@ class Plot(object):
             if line and line[0] != '#':
                 j += 1
                 if xcol:
-                    self.xspan.append(float(split(line)[xcol-1])*xfois + xplus)
+                    self.xspan.append(float(line.split()[xcol-1])*xfois + xplus)
                 else:
                     self.xspan.append(j)
 
-                self.yspan.append(float(split(line)[ycol-1])*yfois + yplus)
+                self.yspan.append(float(line.split()[ycol-1])*yfois + yplus)
 
 
-    def uploadErrorBar(self, errorbar):
+    def uploadErrorBar(self, errorbar, errorp, col):
         """
-        load and parse data for Measurement incertitude
+        load and parse data for Measurement uncertainty
         """
-        if errorbar == None:
+        if errorbar == None and errorp == None:
             return None
 
-        elif len(errorbar) == 2:
-            error = [ [], [] ]
-            for line in self.f.readlines():
-                line = line.lstrip()
-                if line and line[0] != '#':
-                    error[0].append(float(split(line)[errorbar[0]-1]))
-                    error[1].append(float(split(line)[errorbar[1]-1]))
-            return error
+        elif errorbar:
+            if errorp:
+                print("Warning: ambiguous definitions of error bars for "
+                      "one data set, percentage and set of error values.\n"
+                      "The error definition by percentage will be ignored.")
 
-        elif len(errorbar) == 1:
-            error = []
-            for line in self.f.readlines():
-                line = line.lstrip()
-                if line and line[0] != '#':
-                    error.append(float(split(line)[errorbar[0]-1]))
-            return error
+            if len(errorbar) == 2:
+                error = [ [], [] ]
+                for line in self.f.readlines():
+                    line = line.lstrip()
+                    if line and line[0] != '#':
+                        error[0].append(float(line.split()[errorbar[0]-1]))
+                        error[1].append(float(line.split()[errorbar[1]-1]))
+                return error
+
+            elif len(errorbar) == 1:
+                error = []
+                for line in self.f.readlines():
+                    line = line.lstrip()
+                    if line and line[0] != '#':
+                        error.append(float(line.split()[errorbar[0]-1]))
+                return error
+        elif errorp:
+            if col == 0:
+                print("Error: can not compute errors by percentage of an "
+                      "unspecified data set (column number missing).\n")
+                sys.exit(1)
+            else:
+                error = []
+                for line in self.f.readlines():
+                    line = line.lstrip()
+                    if line and line[0] != '#':
+                        error.append(errorp/100.*float(line.split()[col-1]))
+                return error
 
 #-------------------------------------------------------------------------------
-# Curve or plot for monitorig point (probe)
+# Curve or plot for monitoring point (probe)
 #-------------------------------------------------------------------------------
 
 class Probes(object):
@@ -212,6 +244,8 @@ class Probes(object):
         self.legend   = "Probe " + str(ycol - 1)
         self.fmt      = ""
         self.ismesure = False
+        self.xerr    = None
+        self.yerr    = None
 
         xcol = 1
 
@@ -220,8 +254,8 @@ class Probes(object):
         for line in f.readlines():
             line = line.lstrip()
             if line and line[0] != '#':
-                self.xspan.append(float(split(line)[xcol - 1]))
-                self.yspan.append(float(split(line)[ycol - 1]))
+                self.xspan.append(float(line.split()[xcol - 1]))
+                self.yspan.append(float(line.split()[ycol - 1]))
 
         f.close()
 
@@ -419,7 +453,7 @@ class Plotter(object):
         for line in f.readlines():
             line = line.lstrip()
             if line and line[0] != '#':
-                nbr = len(split(line))
+                nbr = len(line.split())
                 break
         f.close()
         return nbr
@@ -456,10 +490,10 @@ class Plotter(object):
 
                     f = os.path.join(self.parser.getDestination(),
                                      study_label,
-                                     case.label, "RESU",
+                                     case.label, case.resu,
                                      dest, "monitoring", file_name)
                     if not os.path.isfile(f):
-                        raise ValueError, "\n\nThis file does not exist: %s\n (call with path: %s)\n" % (file_name, f)
+                        raise ValueError("\n\nThis file does not exist: %s\n (call with path: %s)\n" % (file_name, f))
 
                     for ycol in range(2, self.__number_of_column(f) + 1):
                         curve = Probes(f, fig, ycol)
@@ -478,19 +512,29 @@ class Plotter(object):
                         d = repo
                         dd = self.parser.getRepository()
 
-                    f = os.path.join(dd,
-                                     study_label,
-                                     case.label, "RESU",
-                                     d, file_name)
+                    if case.subdomains:
+                        dom_list = case.subdomains
+                    else:
+                        dom_list = [""]
+
+                    iok = False
+                    for ddd in dom_list:
 
-                    if not os.path.isfile(f):
                         f = os.path.join(dd,
                                          study_label,
-                                         case.label, "RESU",
-                                         d, "monitoring", file_name)
+                                         case.label, case.resu,
+                                         d, ddd, file_name)
 
                         if not os.path.isfile(f):
-                            raise ValueError, "\n\nThis file does not exist: %s\n (call with path: %s)\n" % (file_name, f)
+                            f = os.path.join(dd,
+                                             study_label,
+                                             case.label, case.resu,
+                                             d, ddd, "monitoring", file_name)
+
+                        iok = iok or os.path.isfile(f)
+
+                    if not iok:
+                        raise ValueError("\n\nThis file does not exist: %s\n (last call with path: %s)\n" % (file_name, f))
 
                     for nn in plots:
                         curve = Plot(nn, self.parser, f)
@@ -508,7 +552,7 @@ class Plotter(object):
                     f = os.path.join(dd, study_label, "POST", file_name)
 
                     if not os.path.isfile(f):
-                        raise ValueError, "\n\nThis file does not exist: %s\n (call with path: %s)\n" % (file_name, f)
+                        raise ValueError("\n\nThis file does not exist: %s\n (call with path: %s)\n" % (file_name, f))
 
                     for nn in plots:
                         curve = Plot(nn, self.parser, f)
@@ -544,40 +588,34 @@ class Plotter(object):
         """
         Draw a single curve.
         """
+
+        # data sets x and y
         xspan = curve.xspan
         yspan = curve.yspan
 
-        if curve.measurement():
-            if curve.xerr:
-                lines = ax.errorbar(xspan, yspan,
-                                    xerr=curve.xerr,
-                                    fmt=curve.fmt,
-                                    label=curve.legend)
-            if curve.yerr:
-                lines = ax.errorbar(xspan, yspan,
-                                    yerr=curve.yerr,
-                                    fmt=curve.fmt,
-                                    label=curve.legend)
-            else:
-                lines = ax.plot(xspan, yspan, curve.fmt, label=curve.legend)
+        # data sets errors on x and y
+        xerr = curve.xerr
+        yerr = curve.yerr
+
+        # draw curve with error bars
+        if xerr or yerr:
+            lines = ax.errorbar(xspan, yspan,
+                                xerr=xerr,
+                                yerr=yerr,
+                                fmt=curve.fmt,
+                                label=curve.legend)
+        # draw curve only
         else:
-            if curve.fmt:
-                lines = ax.plot(xspan, yspan, curve.fmt, label=curve.legend)
-            else:
-                lines = ax.plot(xspan, yspan, label=curve.legend)
+            lines = ax.plot(xspan, yspan, curve.fmt, label=curve.legend)
 
 
         # additional matplotlib raw commands for line2D
         line = lines[0]
         for cmd in curve.cmd:
-            c = open("./tmp.py", "w")
-            c.write(cmd)
-            c.close()
             try:
-                execfile("./tmp.py")
+                eval(cmd)
             except:
                 print("Error with the matplotlib command: %s" % cmd)
-            os.remove("./tmp.py")
 
         plt.hold(True)
 
@@ -647,14 +685,10 @@ class Plotter(object):
 
         # additional matplotlib raw commands for figure
         for cmd in figure.cmd:
-            c = open("./tmp.py", "w")
-            c.write(cmd)
-            c.close()
             try:
-                execfile("./tmp.py")
+                eval(cmd)
             except:
                 print("Error with the matplotlib command: %s" % cmd)
-            os.remove("./tmp.py")
 
         # Layout
         nbrow, nbcol, hs, ri, le, ws = figure.layout()
@@ -696,20 +730,16 @@ class Plotter(object):
             idx = figure.subplots.index(p)
             ax = plt.subplot(nbrow, nbcol, idx + 1)
             for cmd in p.cmd:
-                c = open("./tmp.py", "w")
-                c.write(cmd)
-                c.close()
                 try:
-                    execfile("./tmp.py")
+                    eval(cmd)
                 except:
                     print("Error with the matplotlib command: %s" % cmd)
-                os.remove("./tmp.py")
 
 
     def __save(self, f, fmt):
         """method used to save the figure"""
         f = f + "." + fmt
-        plt.savefig(f, format=fmt)
+        plt.savefig(f, format=fmt, bbox_inches="tight", pad_inches=0.)
         plt.close()
 
 #-------------------------------------------------------------------------------
