@@ -82,6 +82,7 @@ class Scalar(object):
         self.size = map(int, parser.getAttributeTuple(node, "size", (500, 400)))
         self.zoom = float(parser.getAttribute(node, "zoom", 1.))
         self.wireframe = parser.getAttribute(node, "wireframe", "off")
+        self.smult = float(parser.getAttribute(node, "smult", 1.))
 
         # color scale and color legend
         #-----------------------------
@@ -222,7 +223,7 @@ class PlotVTK(object):
                                      d, "postprocessing", file_name)
 
                     if not os.path.isfile(f):
-                        raise ValueError, "\n\nThis file does not exist: %s\n\n" % f
+                        raise ValueError("\n\nThis file does not exist: %s\n\n" % f)
 
                     for nn in plots:
                         self.figures.append(Scalar(nn, self.parser, f))
@@ -252,13 +253,39 @@ class Builder(object):
         self.opt  = options
 
         ds = self.readData(self.opt.time_step)
+        cellData = ds.GetCellData()
 
-        if not ds.GetCellData().HasArray(self.opt.variable):
+        if not cellData.HasArray(self.opt.variable):
             print("Error: variable %s not found." % self.opt.variable)
             sys.exit(1)
 
+        # get dimension of data field
+        dim = cellData.GetArray(self.opt.variable).GetNumberOfComponents()
+
         convert = self.convertCell2Point(ds)
 
+        # Multiply given variable by a real number using vtk array calculator
+        calc = vtk.vtkArrayCalculator()
+        calc.SetInputConnection(convert.GetOutputPort())
+        if dim == 1:
+            calc.AddScalarVariable("var", self.opt.variable, 0)
+            attribute = "SCALARS"
+        else:
+            calc.AddVectorVariable("var", self.opt.variable, 0 , 1, 2)
+            attribute = "VECTORS"
+
+        calc.SetFunction("var*%f"%self.opt.smult)
+        resultName = self.opt.variable+"transf"
+        calc.SetResultArrayName(resultName)
+
+        aa = vtk.vtkAssignAttribute()
+        aa.SetInputConnection(calc.GetOutputPort())
+        aa.Assign(resultName, attribute, "POINT_DATA")
+        aa.Update()
+
+        convert = aa
+        self.opt.variable = resultName
+
         self.ren = vtk.vtkRenderer()
         self.ren.SetBackground(1., 1., 1.)
         self.cam = self.ren.GetActiveCamera()
@@ -291,6 +318,9 @@ class Builder(object):
         else:
             lut = eval("self." + self.opt.color_map + "()")
 
+        # scalar map of the magnitude of vector fields
+        lut.SetVectorModeToMagnitude()
+
         self.colorDataSetByArray(convert.GetOutput(), lut, self.cutMapper)
         grid = vtk.vtkLODActor()
 
@@ -305,7 +335,7 @@ class Builder(object):
             # mapper for the contours
             self.contoursMapper = vtk.vtkPolyDataMapper()
             # define contours on cut plane
-            contours = self.contoursFilterOnCutPlane(convert, cut)
+            contours = self.contoursFilterOnCutPlane(convert, cut, dim)
 
             # apply same transformation as to the cut
             if self.opt.stretch:
@@ -457,14 +487,24 @@ class Builder(object):
         #cut.SetSortByToSortByCell()
         return cut
 
-    def contoursFilterOnCutPlane(self, convert, cut):
+    def contoursFilterOnCutPlane(self, convert, cut, dim):
         """Create contours on a slice from the 3D computational domain."""
         # create the contour filter
         contours = vtk.vtkContourFilter()
-        # set the plane as input
-        contours.SetInputConnection(cut.GetOutputPort())
-        # select the variable
-        contours.SetInputArrayToProcess(0,0,0,0,self.opt.variable)
+
+        # scalar field
+        if dim == 1:
+            # set the plane as input
+            contours.SetInputConnection(cut.GetOutputPort())
+            # select the variable
+            contours.SetInputArrayToProcess(0,0,0,0,self.opt.variable)
+        # contours of the magnitude of vector fields
+        elif dim > 1:
+            vectorNorm = vtk.vtkVectorNorm()
+            vectorNorm.SetInputConnection(cut.GetOutputPort())
+            vectorNorm.SetInputArrayToProcess(0,0,0,0,self.opt.variable)
+            contours.SetInputConnection(vectorNorm.GetOutputPort())
+
         # define the iso values
         self.isoValuesByArray(convert.GetOutput(), contours)
 
@@ -605,7 +645,8 @@ class Builder(object):
                 mapper.SetScalarRange(self.opt.color_srange[0],
                                       self.opt.color_srange[1])
             else:
-                mapper.SetScalarRange(array.GetRange())
+                comp = -1
+                mapper.SetScalarRange(array.GetRange(comp))
             mapper.SetInterpolateScalarsBeforeMapping(1)
             mapper.SelectColorArray(array.GetName())
 
@@ -627,13 +668,14 @@ class Builder(object):
         if self.opt.cont_range:
             contours.GenerateValues(self.opt.cont_nval, self.opt.cont_range)
         else:
-            contours.GenerateValues(self.opt.cont_nval, array.GetRange())
+            comp = -1
+            contours.GenerateValues(self.opt.cont_nval, array.GetRange(comp))
 
 
     def screenshot(self, f, mode = "PNG"):
         """Save the image to png format."""
         if mode not in ["PostScript", "JPEG", "PNG", "TIFF"]:
-            raise ValueError, "format unknown: %s" % mode
+            raise ValueError("format unknown: %s" % mode)
 
         # capture what is being shown on self.renderer
         scr = vtk.vtkWindowToImageFilter()
