@@ -97,17 +97,38 @@ class Case(object):
         self.is_compare = "not done"
         self.threshold  = "default"
         self.diff_value = []
+        self.subdomains = None
         self.run_dir    = ""
 
-        self.exe, self.pkg = self.__get_exe(pkg)
+        self.resu = 'RESU'
+
+        # Specific case for coupling
+
+        coupling = os.path.join(self.__repo, self.label, "coupling_parameters.py")
+        if os.path.isfile(coupling):
+            import cs_case_coupling
+            try:
+                exec(compile(open(coupling).read(), '<string>', 'exec'))
+            except Exception:
+                execfile(coupling)
+            run_ref = os.path.join(self.__repo, self.label, "runcase")
+            self.exe, self.pkg = self.__get_exe(pkg, run_ref)
+            self.subdomains = []
+            for d in locals()['domains']:
+                if d['solver'] == self.pkg.code_name:
+                    self.subdomains.append(d['domain'])
+            self.resu = 'RESU_COUPLING'
+
+        else:
+            run_ref = os.path.join(self.__repo, self.label, "SCRIPTS", "runcase")
+            self.exe, self.pkg = self.__get_exe(pkg, run_ref)
 
 
-    def __get_exe(self, old_pkg):
+    def __get_exe(self, old_pkg, run_ref):
         """
         Return the name of the exe of the case, in order to mix
         Code_Saturne and NEPTUNE_CFD test cases in the same study.
         """
-        run_ref = os.path.join(self.__repo, self.label, "SCRIPTS", "runcase")
 
         # Read the runcase script from the Repository
 
@@ -125,7 +146,7 @@ class Case(object):
         return runcase.cmd_name, pkg
 
 
-    def update(self, xmlonly=False):
+    def __update_domain(self, subdir, xmlonly=False):
         """
         Update path for the script in the Repository.
         """
@@ -142,10 +163,8 @@ class Case(object):
         elif self.exe == "neptune_cfd":
             from core.XMLinitialize import XMLinit
 
-        n_procs = {}
-
-        for fn in os.listdir(os.path.join(self.__repo, self.label, "DATA")):
-            fp = os.path.join(self.__repo, self.label, "DATA", fn)
+        for fn in os.listdir(os.path.join(self.__repo, subdir, "DATA")):
+            fp = os.path.join(self.__repo, subdir, "DATA", fn)
             if os.path.isfile(fp):
                 fd = os.open(fp , os.O_RDONLY)
                 f = os.fdopen(fd)
@@ -163,23 +182,20 @@ class Case(object):
                     case['xmlfile'] = fp
                     case.xmlCleanAllBlank(case.xmlRootNode())
                     XMLinit(case).initialize()
-                    smdl = ScriptRunningModel(case)
-                    n_procs[str(fn)] = smdl.getString('n_procs')
-                    smdl.setString('n_procs', None)
                     case.xmlSaveDocument()
 
         # 2) Create RESU directory if needed
         if not xmlonly:
-            r = os.path.join(self.__repo, self.label, "RESU")
+            r = os.path.join(self.__repo, subdir, "RESU")
             if not os.path.isdir(r):
                 os.makedirs(r)
 
         # 3) Update the GUI script from the Repository
-        ref = os.path.join(self.__repo, self.label, "DATA", self.pkg.guiname)
+        ref = os.path.join(self.__repo, subdir, "DATA", self.pkg.guiname)
 
         have_gui = 1
         try:
-            f = file(ref, mode = 'r')
+            f = open(ref, mode = 'r')
         except IOError:
            print("Warning SaturneGUI does not exist: %s\n" % ref)
            have_gui = 0
@@ -199,15 +215,25 @@ class Case(object):
                        lines[i] = 'export PATH="":$PATH\n'
                    else:
                        lines[i] = 'export PATH="' + self.pkg.get_dir('bindir') +'":$PATH\n'
-           f = file(ref, mode = 'w')
+           f = open(ref, mode = 'w')
            f.writelines(lines)
            f.close()
 
         # 4) Update the runcase script from the Repository
-        ref = os.path.join(self.__repo, self.label, "SCRIPTS", "runcase")
+        self.update_runcase_path(os.path.join(self.__repo, subdir, "SCRIPTS"), None, xmlonly)
+
+
+    def update_runcase_path(self, subdir, destdir=None, xmlonly=False):
+        """
+        Update path for the script in the Repository.
+        """
+        if not destdir:
+            ref = os.path.join(self.__repo, subdir, "runcase")
+        else:
+            ref = os.path.join(destdir, subdir, "runcase")
 
         try:
-            f = file(ref, mode = 'r')
+            f = open(ref, mode = 'r')
         except IOError:
             print("Error: can not open %s\n" % ref)
             sys.exit(1)
@@ -225,45 +251,96 @@ class Case(object):
                 if re.search(r'^export PATH=', lines[i]):
                     lines[i] = 'export PATH="' + self.pkg.get_dir('bindir') +'":$PATH\n'
                 j = lines[i].find(self.pkg.name)
-                if j > -1:
-                    j = lines[i].find('run')
-                    args = separate_args(lines[i].rstrip())
-                    param = get_command_single_value(args, ('--param', '--param=', '-p'))
-                    try:
-                        if n_procs[param]:
-                            args = update_command_single_value(args,
-                                                               ('--nprocs', '--nprocs=', '-n'),
-                                                               n_procs[param])
-                            lines[i] = assemble_args(args) + '\n'
-                    except Exception:
-                        pass
 
-        f = file(ref, mode = 'w')
+        f = open(ref, mode = 'w')
         f.writelines(lines)
         f.close()
 
 
+    def update(self, xmlonly=False):
+        """
+        Update path for the script in the Repository.
+        """
+        # 1) Load the xml file of parameters in order to update it
+        #    with the __backwardCompatibility method.
+
+        from Base.XMLengine import Case
+        from Pages.ScriptRunningModel import ScriptRunningModel
+        from cs_exec_environment import \
+            separate_args, get_command_single_value, update_command_single_value, assemble_args, enquote_arg
+
+        if self.exe == "code_saturne":
+            from Base.XMLinitialize import XMLinit
+        elif self.exe == "neptune_cfd":
+            from core.XMLinitialize import XMLinit
+
+        if self.subdomains:
+            self.update_runcase_path(d, self.label, xmlonly)
+            cdirs = []
+            for d in self.subdomains:
+                cdirs.append(os.path.join(self.label, d))
+        else:
+            cdirs = (self.label,)
+
+        for d in cdirs:
+            self.__update_domain(d, xmlonly)
+
+        # Update the runcase script from the Repository in case of coupling
+
+        if self.subdomains:
+            ref = os.path.join(self.__repo, self.label, "runcase")
+            try:
+                f = open(ref, mode = 'r')
+                lines = f.readlines()
+                f.close()
+                for i in range(len(lines)):
+                    if lines[i].strip()[0:1] == '#':
+                        continue
+                    if xmlonly:
+                        if re.search(r'^export PATH=', lines[i]):
+                            lines[i] = 'export PATH="":$PATH\n'
+                    else:
+                        if re.search(r'^export PATH=', lines[i]):
+                            lines[i] = 'export PATH="' + self.pkg.get_dir('bindir') +'":$PATH\n'
+                f = open(ref, mode = 'w')
+                f.writelines(lines)
+                f.close()
+            except IOError:
+                pass
+
+
     def compile(self, d):
         """
         Just compile user sources if exist.
         @rtype: C{String}
         @return: the status of the succes of the compilation.
         """
-        home = os.getcwd()
-        os.chdir(os.path.join(d, self.label, 'SRC'))
-        cmd = os.path.join(self.pkg.get_dir('bindir'), self.exe) + " compile -t"
 
-        p = subprocess.Popen(cmd,
-                             shell=True,
-                             executable=get_shell_type(),
-                             stdout=subprocess.PIPE,
-                             stderr=subprocess.PIPE)
-        output = p.communicate()
-        o = output[1]
-        if o.find('erreur') != -1 or o.find('error') != -1:
-            self.is_compil = "KO"
+        if self.subdomains:
+            sdirs = []
+            for sd in self.subdomains:
+                sdirs.append(os.path.join(d, self.label, sd, 'SRC'))
         else:
-            self.is_compil = "OK"
+            sdirs = (os.path.join(d, self.label, 'SRC'),)
+
+        home = os.getcwd()
+
+        self.is_compil = "OK"
+
+        for s in sdirs:
+
+            os.chdir(s)
+            cmd = os.path.join(self.pkg.get_dir('bindir'), self.exe) + " compile -t"
+            p = subprocess.Popen(cmd,
+                                 shell=True,
+                                 executable=get_shell_type(),
+                                 stdout=subprocess.PIPE,
+                                 stderr=subprocess.PIPE,
+                                 universal_newlines=True)
+            output = p.communicate()
+            o = output[1]
+            if o.find('erreur') != -1 or o.find('error') != -1:
+                self.is_compil = "KO"
 
         os.chdir(home)
 
@@ -273,6 +350,8 @@ class Case(object):
     def __suggest_run_id(self):
 
         cmd = enquote_arg(os.path.join(self.pkg.get_dir('bindir'), self.exe)) + " run --suggest-id"
+        if self.subdomains:
+            cmd += " --coupling=coupling_parameters.py"
         p = subprocess.Popen(cmd,
                              shell=True,
                              executable=get_shell_type(),
@@ -280,9 +359,9 @@ class Case(object):
                              stderr=subprocess.PIPE,
                              universal_newlines=True)
         i = p.communicate()[0]
-        run_id = string.join(i.split())
+        run_id = " ".join(i.split())
 
-        return run_id, os.path.join(self.__dest, self.label, "RESU", run_id)
+        return run_id, os.path.join(self.__dest, self.label, self.resu, run_id)
 
 
     def __updateRuncase(self, run_id):
@@ -291,20 +370,29 @@ class Case(object):
         """
         from cs_exec_environment import separate_args, \
                                  get_command_single_value
-        run_ref     = os.path.join(self.__repo, self.label, "SCRIPTS", "runcase")
-        run_ref_win = os.path.join(self.__repo, self.label, "SCRIPTS", "runcase.bat")
-        if sys.platform.startswith('win'):
-            run_new = os.path.join(self.__dest, self.label, "SCRIPTS", "runcase.bat")
+
+        if self.subdomains:
+            run_ref = os.path.join(self.__repo, self.label, "runcase")
+            run_new = os.path.join(self.__dest, self.label, "runcase")
+            run_ref_win = os.path.join(self.__repo, self.label, "runcase.bat")
         else:
+            run_ref = os.path.join(self.__repo, self.label, "SCRIPTS", "runcase")
             run_new = os.path.join(self.__dest, self.label, "SCRIPTS", "runcase")
+            run_ref_win = os.path.join(self.__repo, self.label, "SCRIPTS", "runcase.bat")
+
+        if sys.platform.startswith('win'):
+            if self.subdomains:
+                run_new = os.path.join(self.__dest, self.label, "runcase.bat")
+            else:
+                run_new = os.path.join(self.__dest, self.label, "SCRIPTS", "runcase.bat")
 
         # Read the runcase from the Repository
 
         try:
-            f = file(run_ref, mode = 'r')
+            f = open(run_ref, mode = 'r')
         except:
             try:
-                f = file(run_ref_win, mode = 'r')
+                f = open(run_ref_win, mode = 'r')
             except IOError:
                 print("Error: can not open %s\n" % run_ref)
                 sys.exit(1)
@@ -316,16 +404,16 @@ class Case(object):
                     content = line.split()
                     if re.search(r'^\\' + self.exe, line):
                         content[0] = self.exe
-                    run_cmd = string.join(content)
+                    run_cmd = " ".join(content)
             else:
                 if re.search(r'^\\' + self.exe, line):
-                    run_cmd = string.join(line.split())
+                    run_cmd = " ".join(line.split())
         f.close()
 
         # Write the new runcase
 
         try:
-            f = file(run_new, mode = 'r')
+            f = open(run_new, mode = 'r')
         except IOError:
             print("Error: can not open %s\n" % run_new)
             sys.exit(1)
@@ -350,7 +438,7 @@ class Case(object):
                 elif re.search(r' cd ', lines[i]): # do not switch to batch submit directory
                     lines[i] = '# ' + lines[i]
 
-        f = file(run_new, mode = 'w')
+        f = open(run_new, mode = 'w')
         f.writelines(lines)
         f.close()
 
@@ -360,11 +448,14 @@ class Case(object):
         Run the case a thread.
         """
         home = os.getcwd()
-        os.chdir(os.path.join(self.__dest, self.label, 'SCRIPTS'))
+        if self.subdomains:
+            os.chdir(os.path.join(self.__dest, self.label))
+        else:
+            os.chdir(os.path.join(self.__dest, self.label, 'SCRIPTS'))
 
         if self.run_id:
             run_id = self.run_id
-            run_dir = os.path.join(self.__dest, self.label, "RESU", run_id)
+            run_dir = os.path.join(self.__dest, self.label, self.resu, run_id)
 
             if os.path.isdir(run_dir):
                 print("Warning: the directory %s already exists in the destination." % run_dir)
@@ -414,13 +505,13 @@ class Case(object):
         node = None
 
         if reference:
-            result = os.path.join(reference, self.label, 'RESU')
+            result = os.path.join(reference, self.label, self.resu)
         else:
-            result = os.path.join(self.__repo, self.label, 'RESU')
+            result = os.path.join(self.__repo, self.label, self.resu)
         repo = self.check_dir(studies, node, result, r, "repo")
         repo = os.path.join(result, repo, 'checkpoint', 'main')
 
-        result = os.path.join(self.__dest, self.label, 'RESU')
+        result = os.path.join(self.__dest, self.label, self.resu)
         dest = self.check_dir(studies, node, result, d, "dest")
         dest = os.path.join(result, dest, 'checkpoint', 'main')
 
@@ -433,25 +524,35 @@ class Case(object):
 
         if args != None:
             cmd += (" " + args)
-            l = string.split(args)
+            l = args.split()
             try:
                 i = l.index('--threshold')
                 self.threshold = l[i+1]
             except:
                 pass
 
-        l = subprocess.Popen(cmd, shell=True, executable=get_shell_type(), stdout=subprocess.PIPE).stdout
-        info = l.read().replace("\"", " ").replace(";", " ").replace(":", " ").split()
+        l = subprocess.Popen(cmd,
+                             shell=True,
+                             executable=get_shell_type(),
+                             stdout=subprocess.PIPE,
+                             universal_newlines=True).stdout
+        lines = l.readlines()
 
         tab = []
-
-        for i in range(len(info)):
-            if info[i][:4] == 'Diff':
-                if info[i-3] not in ['i4', 'u4']:
-                    tab.append( [info[i-7].replace("_", "\_"),
-                                 info[i+3],
-                                 info[i+5],
-                                 self.threshold] )
+        for i in range(len(lines)):
+            if lines[i].find("Support") != -1:
+                line = [x.replace("\""," ").strip() for x in lines[i].split(";")]
+                name = line[0]
+                info = [x.split(":") for x in line[1:]]
+                info = [[x[0].strip(),x[1].strip()] for x in info]
+                if info[1][1] not in ['i4', 'u4', 'c']:
+                    line = [x.strip() for x in lines[i+1].split(";")]
+                    vals = [x.split(":") for x in line]
+                    vals = [[x[0].strip(),x[1].strip()] for x in vals]
+                    tab.append([name.replace("_", "\_"),
+                                vals[1][1],
+                                vals[2][1],
+                                self.threshold])
 
         os.chdir(home)
 
@@ -484,7 +585,7 @@ class Case(object):
         # 2. The result directory must be read automatically;
         #    check if there is a single result directory.
         elif rep == "":
-            if len(filter(nodot, os.listdir(result))) == 0:
+            if len(list(filter(nodot, os.listdir(result)))) == 0:
                 msg = "Study %s case %s:\nthere is no result directory in %s\nStop.\n" % \
                     (self.__study, self.label, result)
                 studies.reporting(msg)
@@ -492,7 +593,7 @@ class Case(object):
 
             # if no run_id is specified in the xml file
             # only one result directory allowed in RESU
-            if len(filter(nodot, os.listdir(result))) > 1 and self.run_id == "":
+            if len(list(filter(nodot, os.listdir(result)))) > 1 and self.run_id == "":
                 msg = "Study %s case %s:\nthere are several directories in %s\nStop.\n" % \
                     (self.__study, self.label, result)
                 studies.reporting(msg)
@@ -502,7 +603,7 @@ class Case(object):
             # if no run_id is specified in the xml file
             # the only result directory present in RESU is taken
             if rep == "":
-                rep = filter(nodot, os.listdir(result))[0]
+                rep = list(filter(nodot, os.listdir(result)))[0]
 
             rep_f = os.path.join(result, rep)
             if not os.path.isdir(rep_f):
@@ -535,14 +636,14 @@ class Case(object):
         if repo != None:
             # build path to RESU directory with path to study and case label in the repo
             if reference:
-                result = os.path.join(reference, self.label, 'RESU')
+                result = os.path.join(reference, self.label, self.resu)
             else:
-                result = os.path.join(self.__repo, self.label, 'RESU')
+                result = os.path.join(self.__repo, self.label, self.resu)
             self.check_dir(studies, node, result, repo, "repo")
 
         if dest != None:
             # build path to RESU directory with path to study and case label in the dest
-            result = os.path.join(self.__dest, self.label, 'RESU')
+            result = os.path.join(self.__dest, self.label, self.resu)
             self.check_dir(studies, node, result, dest, "dest")
 
 #-------------------------------------------------------------------------------
@@ -631,7 +732,6 @@ class Study(object):
                 for cpr in ["", ".gz"]:
                     for fmt in ["unv",
                                 "med",
-                                "ngeom",
                                 "ccm",
                                 "cgns",
                                 "neu",
@@ -665,10 +765,28 @@ class Study(object):
         for c in self.Cases:
             if not os.path.isdir(c.label):
                 e = os.path.join(c.pkg.get_dir('bindir'), c.exe)
-                cmd = e + " create --case " + c.label  \
-                      + " --quiet --noref --copy-from "    \
-                      + os.path.join(self.__repo, c.label)
-                retval, t = run_autovnv_command(cmd, self.__log)
+                if c.subdomains:
+                    os.mkdir(c.label)
+                    os.chdir(c.label)
+                    refdir = os.path.join(self.__repo, c.label)
+                    for node in os.listdir(refdir):
+                        ref = os.path.join(self.__repo, c.label, node)
+                        if node in c.subdomains:
+                            cmd = e + " create --case " + node \
+                                  + " --quiet --noref --copy-from " \
+                                  + ref
+                            retval, t = run_autovnv_command(cmd, self.__log)
+                        elif os.path.isdir(ref):
+                            shutil.copytree(ref, node, symlinks=True)
+                        else:
+                            shutil.copy2(ref, node)
+                    c.update_runcase_path(c.label, destdir=self.__dest)
+                    os.chdir(self.__dest)
+                else:
+                    cmd = e + " create --case " + c.label  \
+                          + " --quiet --noref --copy-from "    \
+                          + os.path.join(self.__repo, c.label)
+                    retval, t = run_autovnv_command(cmd, self.__log)
             else:
                 print("Warning: the case %s already exists in the destination." % c.label)
 
@@ -684,7 +802,7 @@ class Study(object):
                 list_cases.append(case.label)
                 list_dir.append(case.run_dir)
 
-        return string.join(list_cases), string.join(list_dir)
+        return " ".join(list_cases), " ".join(list_dir)
 
 #-------------------------------------------------------------------------------
 
@@ -692,7 +810,7 @@ class Studies(object):
     """
     Manage all Studies and all Cases described in the files of parameters.
     """
-    def __init__(self, pkg, f, v, x, r, n, c, d, p, exe, dif, log):
+    def __init__(self, pkg, f, v, x, r, n, c, d, p, exe, dif, log, dis_tex):
         """
         Constructor.
           1. create if necessary the destination directory,
@@ -778,6 +896,7 @@ class Studies(object):
         self.__compare = c
         self.__ref     = d
         self.__postpro = p
+        self.__dis_tex = dis_tex
 
         # in case of restart
         iok = 0
@@ -942,7 +1061,11 @@ class Studies(object):
                     if case.compute == 'on' and case.is_compil != "KO":
 
                         if self.__n_iter:
-                            case_dir = os.path.join(self.dest, s.label, case.label, "DATA")
+                            if case.subdomains:
+                                case_dir = os.path.join(self.dest, s.label, case.label,
+                                                        case.subdomains[0], "DATA")
+                            else:
+                                case_dir = os.path.join(self.dest, s.label, case.label, "DATA")
                             os.chdir(case_dir)
                             # Create a control_file in each case DATA
                             if not os.path.exists('control_file'):
@@ -952,14 +1075,12 @@ class Studies(object):
                                 # when control_file is copied to the run directory on all systems
                                 control_file.flush()
                                 control_file.close
-                            else:
-                                print("Warning: there is already a control_file in the DATA directory of case %s." % case.label)
 
                         self.reporting('    - running %s ...' % case.label, True)
                         error = case.run()
                         if not error:
                             if not case.run_id:
-                                self.reporting('    - run %s --> Warning suffixe is not read' % case.label)
+                                self.reporting('    - run %s --> Warning suffix is not read' % case.label)
 
                             self.reporting('    - run %s --> OK (%s s) in %s' % (case.label, case.is_time, case.run_id))
                             self.__parser.setAttribute(case.node, "compute", "off")
@@ -986,6 +1107,12 @@ class Studies(object):
         Stop if you try to make a comparison with a file which does not exist.
         """
         for l, s in self.studies:
+            # reference directory passed in autovnv command line overwrites
+            # destination in all cases (even if compare is defined by a compare
+            # markup with a non empty destination)
+            ref = None
+            if self.__ref:
+                ref = os.path.join(self.__ref, s.label)
             for case in s.Cases:
                 if case.compare == 'on' and case.is_run != "KO":
                     compare, nodes, repo, dest, threshold, args = self.__parser.getCompare(case.node)
@@ -996,16 +1123,13 @@ class Studies(object):
                                 is_checked = True
                                 if destination == False:
                                     dest[i]= None
-                                case.check_dirs(self, nodes[i], repo[i], dest[i])
+                                case.check_dirs(self, nodes[i], repo[i], dest[i], reference=ref)
                     if not compare or not is_checked:
                         node = None
                         repo = ""
                         dest = ""
                         if destination == False:
                             dest = None
-                        ref = None
-                        if self.__ref:
-                            ref = os.path.join(self.__ref, s.label)
                         case.check_dirs(self, node, repo, dest, reference=ref)
 
 
@@ -1016,6 +1140,12 @@ class Studies(object):
         if self.__compare:
             for l, s in self.studies:
                 self.reporting('  o Compare study: ' + l)
+                # reference directory passed in autovnv command line overwrites
+                # destination in all cases (even if compare is defined by a
+                # compare markup with a non empty destination)
+                ref = None
+                if self.__ref:
+                    ref = os.path.join(self.__ref, s.label)
                 for case in s.Cases:
                     if case.compare == 'on' and case.is_run != "KO":
                         is_compare, nodes, repo, dest, t, args = self.__parser.getCompare(case.node)
@@ -1023,17 +1153,18 @@ class Studies(object):
                             for i in range(len(nodes)):
                                 if is_compare[i]:
                                     case.is_compare = "done"
-                                    self.reporting('    - compare %s (with args: %s)' % (case.label, args[i]))
-                                    case.diff_value += case.runCompare(self, repo[i], dest[i], t[i], args[i])
+                                    diff_value = case.runCompare(self, repo[i], dest[i], t[i], args[i], reference=ref)
+                                    case.diff_value += diff_value
+                                    if diff_value:
+                                        self.reporting('    - compare %s (with args: %s) --> DIFFERENCES FOUND' % (case.label, args[i]))
+                                    else:
+                                        self.reporting('    - compare %s (with args: %s) --> NO DIFFERENCES FOUND' % (case.label, args[i]))
                         if not is_compare or case.is_compare != "done":
                             repo = ""
                             dest = ""
                             t    = None
                             args = None
                             case.is_compare = "done"
-                            ref = None
-                            if self.__ref:
-                                ref = os.path.join(self.__ref, s.label)
                             case.diff_value += case.runCompare(self, repo, dest, t, args, reference=ref)
                             if case.diff_value:
                                 self.reporting('    - compare %s (default mode) --> DIFFERENCES FOUND' % (case.label))
@@ -1092,7 +1223,7 @@ class Studies(object):
             for case in s.Cases:
                 if case.is_run != "KO":
                     if case.run_dir == "":
-                        resu = os.path.join(self.dest, l, case.label, 'RESU')
+                        resu = os.path.join(self.dest, l, case.label, case.resu)
                         rep = case.check_dir(self, None, resu, "", "dest")
                         case.run_id = rep
                         case.run_dir = os.path.join(resu, rep)
@@ -1152,7 +1283,7 @@ class Studies(object):
         if self.__plotter:
             for l, s in self.studies:
                 self.reporting('  o Plot study: ' + l)
-                self.__plotter.plot_study(l, s)
+                self.__plotter.plot_study(l, s, self.__dis_tex)
 
         if self.__plotvtk:
             for l, s in self.studies:
