@@ -92,6 +92,10 @@ class case:
         else:
             self.package_compute = self.package
 
+        # Determine caller script path (which may contain batch directives)
+
+        self.parent_script = cs_exec_environment.get_parent_process_path()
+
         # Set environment modules if present
 
         cs_exec_environment.set_modules(self.package_compute)
@@ -119,8 +123,8 @@ class case:
         self.fsi_coupler = fsi_coupler
 
         # Mark fluid domains as coupled with Code_Aster if coupling is present.
-        # This should be improved by migrating tests to the executable, to better
-        # handle cases were only some domains are coupled.
+        # This should be improved by migrating tests to the executable,
+        # to better handle cases were only some domains are coupled.
         # For now, we assume that the first CFD domain is the coupled one.
 
         if fsi_coupler:
@@ -281,9 +285,9 @@ class case:
 
         # Code_Aster is handled in a specific manner: processes are counted
         # against the total, but the coupler is not, and processes will not by
-        # run by the same mpiexec instance (TODO: check/improve how this interacts
-        # with resource managers, so that some nodes are not oversubscribed while
-        # others are unused).
+        # run by the same mpiexec instance (TODO: check/improve how this
+        # interacts with resource managers, so that some nodes are not
+        # oversubscribed while others are unused).
 
         for d in self.ast_domains:
             np_list.append(d.get_n_procs())
@@ -408,9 +412,9 @@ class case:
 
     #---------------------------------------------------------------------------
 
-    def define_exec_dir(self, exec_basename):
+    def define_exec_dir(self):
         """
-        Create execution directory.
+        Define execution directory.
         """
 
         if self.exec_prefix != None:
@@ -419,42 +423,24 @@ class case:
                 exec_dir_name = study_name + '.' + self.name
             else:
                 exec_dir_name = self.name
-            exec_dir_name += '.' + exec_basename
+            exec_dir_name += '.' + self.run_id
             self.exec_dir = os.path.join(self.exec_prefix, exec_dir_name)
         else:
             r = os.path.join(self.case_dir, 'RESU')
             if len(self.domains) + len(self.syr_domains) + len(self.ast_domains) > 1:
                 r += '_COUPLING'
-            self.exec_dir = os.path.join(r, exec_basename)
+            self.exec_dir = os.path.join(r, self.run_id)
 
     #---------------------------------------------------------------------------
 
-    def set_exec_dir(self, path):
-        """
-        Set execution directory.
-        """
-
-        # Set execution directory
-
-        self.exec_dir = path
-
-        for d in self.domains:
-            d.set_exec_dir(self.exec_dir)
-        for d in self.syr_domains:
-            d.set_exec_dir(self.exec_dir)
-        for d in self.ast_domains:
-            d.set_exec_dir(self.exec_dir)
-
-    #---------------------------------------------------------------------------
-
-    def mk_exec_dir(self, exec_basename, force=False):
+    def set_exec_dir(self, force=False):
         """
         Create execution directory.
         """
 
         # Define execution directory name
 
-        self.define_exec_dir(exec_basename)
+        self.define_exec_dir()
 
         # Check that directory does not exist.
 
@@ -471,28 +457,38 @@ class case:
 
         # Set execution directory
 
-        self.set_exec_dir(self.exec_dir)
+        for d in self.domains:
+            d.set_exec_dir(self.exec_dir)
+        for d in self.syr_domains:
+            d.set_exec_dir(self.exec_dir)
+        for d in self.ast_domains:
+            d.set_exec_dir(self.exec_dir)
 
     #---------------------------------------------------------------------------
 
-    def set_result_dir(self, name, force=True):
+    def define_result_dir(self):
 
         r = os.path.join(self.case_dir, 'RESU')
 
-        if os.path.isdir(r):
-            self.result_dir = os.path.join(r, name)
-        else:
+        # Coupled case
+        if len(self.domains) + len(self.syr_domains) + len(self.ast_domains) > 1:
             r += '_COUPLING'
-            if os.path.isdir(r):
-                self.result_dir = os.path.join(r, name)
-            else:
-                r = os.path.join(self.case_dir, 'RESU')
-                err_str = \
+
+        if os.path.isdir(r):
+            self.result_dir = os.path.join(r, self.run_id)
+        else:
+            r = os.path.join(self.case_dir, 'RESU')
+            err_str = \
                     '\nResults directory: ' + r + '\n' \
-                    + '               or: ' + r + '_COUPLING' + '\n' \
                     + 'does not exist.\n' \
                     + 'Calculation will not be run.\n'
-                raise RunCaseError(err_str)
+            raise RunCaseError(err_str)
+
+    #---------------------------------------------------------------------------
+
+    def set_result_dir(self, force=True):
+
+        self.define_result_dir()
 
         if os.path.isdir(self.result_dir):
             if not force:
@@ -506,13 +502,13 @@ class case:
             os.mkdir(self.result_dir)
 
         for d in self.domains:
-            d.set_result_dir(name, self.result_dir)
+            d.set_result_dir(self.run_id, self.result_dir)
 
         for d in self.syr_domains:
-            d.set_result_dir(name, self.result_dir)
+            d.set_result_dir(self.run_id, self.result_dir)
 
         for d in self.ast_domains:
-            d.set_result_dir(name, self.result_dir)
+            d.set_result_dir(self.run_id, self.result_dir)
 
     #---------------------------------------------------------------------------
 
@@ -648,14 +644,14 @@ class case:
         src = sys.argv[0]
 
         if os.path.basename(src) == self.package.name:
-            return
-
-        dest = os.path.join(self.result_dir, os.path.basename(src))
+            src = self.parent_script
 
         # Copy single file
 
-        if os.path.isfile(src) and src != dest:
-            shutil.copy2(src, dest)
+        if src:
+            dest = os.path.join(self.result_dir, os.path.basename(src))
+            if os.path.isfile(src) and src != dest:
+                shutil.copy2(src, dest)
 
     #---------------------------------------------------------------------------
 
@@ -1226,6 +1222,16 @@ $appli/runSession $appli/bin/salome/driver -e -d 0 fsi_yacs_scheme.xml
             cs_exec_environment.write_prepend_path(s,
                                                    'LD_LIBRARY_PATH',
                                                    mpi_libdir)
+
+        # Add path for SALOME in case of coupling with YACS
+
+        if self.ast_domains:
+            salome_libdir = os.path.join(self.package_compute.get_dir("libdir"),
+                                         'salome')
+            cs_exec_environment.write_prepend_path(s,
+                                                   'LD_LIBRARY_PATH',
+                                                   salome_libdir)
+
         s.write('\n')
 
         # Handle rcfile and environment modules if used
@@ -1347,39 +1353,37 @@ $appli/runSession $appli/bin/salome/driver -e -d 0 fsi_yacs_scheme.xml
 
     #---------------------------------------------------------------------------
 
+    def set_run_id(self,
+                   run_id = None):
+
+        """
+        Set run id for calculation.
+        """
+
+        if run_id != None:
+            self.run_id = run_id
+            self.define_result_dir()
+
+        # When id not assigned, choose an id not already present
+
+        if self.run_id == None:
+            self.run_id = self.suggest_id()
+            self.define_result_dir()
+            j = 1
+            run_id_base = self.run_id
+            while os.path.isdir(self.result_dir):
+                self.run_id = run_id_base + '_' + str(j)
+                self.define_result_dir()
+
+    #---------------------------------------------------------------------------
+
     def prepare_data(self,
-                     n_procs = None,
-                     n_threads = None,
-                     mpiexec_options=None,
-                     run_id = None,
                      force_id = False):
 
         """
         Prepare data for calculation.
         """
 
-        # General values
-
-        if run_id != None:
-            self.run_id = run_id
-
-        if self.run_id == None:
-            now = datetime.datetime.now()
-            self.run_id = now.strftime('%Y%m%d-%H%M')
-
-        for d in self.domains:
-            if hasattr(d, 'adaptation'):
-                if d.adaptation:
-                    adaptation(d.adaptation, saturne_script, self.case_dir)
-
-        # Now that all domains are defined, set result copy mode
-
-        self.set_result_dir(self.run_id, force_id)
-
-        # Create working directory (reachable by all the processors)
-
-        self.mk_exec_dir(self.run_id)
-
         # Before creating or generating file, create stage 'marker' file.
 
         self.update_scripts_tmp(None, 'preparing')
@@ -1391,9 +1395,121 @@ $appli/runSession $appli/bin/salome/driver -e -d 0 fsi_yacs_scheme.xml
 
         os.chdir(self.exec_dir)
 
-        # Determine execution environment.
+        # Compile user subroutines if necessary
+        # (for some domain types, such as for Syrthes, this may be done later,
+        # during the general prepare_data stage).
+
+        need_compile = False
+
+        for d in self.domains:
+            if not hasattr(d, 'needs_compile'):
+                continue
+            if d.needs_compile() == True:
+                if need_compile == False: # Print banner on first pass
+                    need_compile = True
+                    msg = \
+                        " ****************************************\n" \
+                        "  Compiling user subroutines and linking\n" \
+                        " ****************************************\n\n"
+                    sys.stdout.write(msg)
+                    sys.stdout.flush()
+                d.compile_and_link()
+
+        # Setup data
+        #===========
+
+        sys.stdout.write('\n'
+                         ' ****************************\n'
+                         '  Preparing calculation data\n'
+                         ' ****************************\n\n')
+        sys.stdout.flush()
+
+        for d in self.domains:
+            d.prepare_data()
+            if len(d.error) > 0:
+                self.error = d.error
+        for d in self.syr_domains:
+            d.prepare_data()
+            if len(d.error) > 0:
+                self.error = d.error
+        for d in self.ast_domains:
+            d.prepare_data()
+            if len(d.error) > 0:
+                self.error = d.error
+
+        # Rename temporary file to indicate new status
+
+        # Remove the Salome temporary file
+
+        self.update_scripts_tmp('preparing', None)
+
+        # Rename temporary file to indicate new status
+
+        if len(self.error) == 0:
+            status = 'prepared'
+        else:
+            status = 'failed'
+
+        self.update_scripts_tmp('preparing', status)
+
+        # Standard or error exit
+
+        if len(self.error) > 0:
+            err_str = ' Error in ' + self.error + ' stage.\n\n'
+            sys.stderr.write(err_str)
+            return 1
+        else:
+            return 0
+
+    #---------------------------------------------------------------------------
+
+    def init_prepared_data(self):
+
+        """
+        Initialize prepared data for calculation.
+        """
+
+        self.copy_script()
+
+        os.chdir(self.exec_dir)
+
+        for d in self.domains:
+            if os.path.isfile(os.path.join(d.exec_dir,
+                                           d.package_compute.solver)):
+               d.solver_path = os.path.join('.',
+                                            d.package_compute.solver)
+
+        for d in self.syr_domains:
+            d.solver_path = os.path.join('.', 'syrthes')
+
+    #---------------------------------------------------------------------------
+
+    def preprocess(self,
+                   n_procs = None,
+                   n_threads = None,
+                   mpiexec_options=None):
+
+        """
+        Preprocess data for and generate run script
+        """
+
+        os.chdir(self.exec_dir)
+
+        # Adaptation should go in the future
+
+        for d in self.domains:
+            if hasattr(d, 'adaptation'):
+                if d.adaptation:
+                    adaptation(d.adaptation, saturne_script, self.case_dir)
+
+        # Before creating or generating file, create stage 'marker' file.
+
+        self.update_scripts_tmp('prepared', 'preprocessing')
+
+        # Determine execution environment
+        #================================
         # (priority for n_procs, in increasing order:
-        # XML file, resource manager, method argument, user Python script).
+        # resource manager, method argument).
 
         n_procs_default = None
         if len(self.domains) == 1 and len(self.syr_domains) == 0:
@@ -1429,64 +1545,10 @@ $appli/runSession $appli/bin/salome/driver -e -d 0 fsi_yacs_scheme.xml
         if n_procs_tot > 1:
             exec_env.resources.n_procs = n_procs_tot
 
-        # Greeting message.
-
-        msg = \
-            '\n' \
-            + '                      ' + self.package.code_name + ' is running\n' \
-            + '                      ***********************\n' \
-            + '\n' \
-            + ' Version: ' + self.package.version + '\n' \
-            + ' Path:    ' + self.package.get_dir('exec_prefix') + '\n\n' \
-            + ' Result directory:\n' \
-            + '   ' +  str(self.result_dir) + '\n\n'
-
-        if self.exec_dir != self.result_dir:
-            msg += ' Working directory (to be periodically cleaned):\n' \
-                + '   ' +  str(self.exec_dir) + '\n'
-
-        msg += '\n'
-
-        sys.stdout.write(msg)
-        sys.stdout.flush()
-
         self.print_procs_distribution()
 
-        # Compile user subroutines if necessary
-        # (for some domain types, such as for Syrthes, this may be done later,
-        # during the general prepare_data stage).
-
-        need_compile = False
-
-        for d in self.domains:
-            if not hasattr(d, 'needs_compile'):
-                continue
-            if d.needs_compile() == True:
-                if need_compile == False: # Print banner on first pass
-                    need_compile = True
-                    msg = \
-                        " ****************************************\n" \
-                        "  Compiling user subroutines and linking\n" \
-                        " ****************************************\n\n"
-                    sys.stdout.write(msg)
-                    sys.stdout.flush()
-                d.compile_and_link()
-
-        # Setup data
-        #===========
-
-        sys.stdout.write('\n'
-                         ' ****************************\n'
-                         '  Preparing calculation data\n'
-                         ' ****************************\n\n')
-        sys.stdout.flush()
-
-        for d in self.domains:
-            d.prepare_data()
-        for d in self.syr_domains:
-            d.prepare_data()
-        for d in self.ast_domains:
-            d.prepare_data()
+        # Preprocessing
+        #==============
 
         sys.stdout.write('\n'
                          ' ***************************\n'
@@ -1515,14 +1577,13 @@ $appli/runSession $appli/bin/salome/driver -e -d 0 fsi_yacs_scheme.xml
         else:
             status = 'failed'
 
-        self.update_scripts_tmp('preparing', status)
+        self.update_scripts_tmp('preprocessing', status)
 
         # Standard or error exit
 
         if len(self.error) > 0:
-            stage = {'preprocess':'preprocessing'}
-            if self.error in stage:
-                error_stage = stage[self.error]
+            if self.error == 'preprocess':
+                error_stage = 'preprocessing'
             else:
                 error_stage = self.error
             err_str = ' Error in ' + error_stage + ' stage.\n\n'
@@ -1542,13 +1603,6 @@ $appli/runSession $appli/bin/salome/driver -e -d 0 fsi_yacs_scheme.xml
         if not self.exec_solver:
             return 0
 
-        if run_id != None:
-            self.run_id = run_id
-
-        if self.exec_dir == None:
-            self.define_exec_dir(self.run_id)
-            self.set_exec_dir(self.exec_dir)
-
         os.chdir(self.exec_dir)
 
         # Indicate status using temporary file for SALOME.
@@ -1569,7 +1623,7 @@ $appli/runSession $appli/bin/salome/driver -e -d 0 fsi_yacs_scheme.xml
         b = cs_exec_environment.batch_info()
         max_time = b.get_remaining_time()
         if max_time != None:
-            os.putenv('CS_MAXTIME', max_time)
+            os.putenv('CS_MAXTIME', str(max_time))
 
         # Tell the script it is being called through the main script
         # (implying environment modules are set and the environment loaded)
@@ -1638,15 +1692,6 @@ $appli/runSession $appli/bin/salome/driver -e -d 0 fsi_yacs_scheme.xml
         directory.
         """
 
-        if run_id != None:
-            self.run_id = run_id
-
-        if self.exec_dir == None:
-            self.define_exec_dir(self.run_id)
-            self.set_exec_dir(self.exec_dir)
-
-        self.set_result_dir(self.run_id)
-
         os.chdir(self.exec_dir)
 
         self.update_scripts_tmp(('ready', 'failed', 'finished'), 'saving')
@@ -1702,14 +1747,20 @@ $appli/runSession $appli/bin/salome/driver -e -d 0 fsi_yacs_scheme.xml
             scratchdir = None,
             run_id = None,
             force_id = False,
-            prepare_data = True,
-            run_solver = True,
-            save_results = True):
+            stages = None):
 
         """
         Main script.
         """
 
+        # Define run stages if not provided
+
+        if not stages:
+            stages = {'prepare_data':True,
+                      'initialize':True,
+                      'run_solver':True,
+                      'save_results':True}
+
         # Define scratch directory
         # priority: argument, environment variable, preference setting.
 
@@ -1747,21 +1798,73 @@ $appli/runSession $appli/bin/salome/driver -e -d 0 fsi_yacs_scheme.xml
         if mpiexec_options == None:
             mpiexec_options = os.getenv('CS_MPIEXEC_OPTIONS')
 
-        if run_id != None:
-            self.run_id = run_id
+        # If preparation stage is not requested, it must have been done
+        # previously, and the id must be forced.
+
+        if not stages['prepare_data']:
+            force_id = True
+
+        # Run id and associated directories
+
+        self.set_run_id(run_id)
+
+        # If preparation stage is missing, force it
+        if stages['initialize'] and not stages['prepare_data']:
+            self.define_exec_dir()
+            if not os.path.isdir(self.exec_dir):
+                stages['prepare_data'] = True
+
+        # Set result copy mode
+
+        self.set_result_dir(force_id)
+
+        # Set working directory
+        # (nonlocal filesystem, reachable by all the processes)
+
+        self.set_exec_dir(force_id)
+
+        # Greeting message.
+
+        msg = \
+            '\n' \
+            + '                      ' + self.package.code_name + '\n' \
+            + '                      ************\n' \
+            + '\n' \
+            + ' Version:   ' + self.package.version + '\n' \
+            + ' Path:      ' + self.package.get_dir('exec_prefix') + '\n'
+        if self.package_compute != self.package:
+            msg += '   compute: ' + self.package_compute.get_dir('exec_prefix') + '\n\n'
+        else:
+            msg += '\n'
+        msg += ' Result directory:\n' \
+               + '   ' +  str(self.result_dir) + '\n\n'
+
+        if self.exec_dir != self.result_dir:
+            msg += ' Working directory (to be periodically cleaned):\n' \
+                + '   ' +  str(self.exec_dir) + '\n'
+
+        msg += '\n'
+
+        sys.stdout.write(msg)
+        sys.stdout.flush()
+
+        # Now run
 
         try:
             retcode = 0
-            if prepare_data == True:
-                retcode = self.prepare_data(n_procs,
-                                            n_threads,
-                                            mpiexec_options,
-                                            run_id,
-                                            force_id)
-            if run_solver == True and retcode == 0:
+            if stages['prepare_data']:
+                retcode = self.prepare_data(force_id)
+            else:
+                self.init_prepared_data()
+
+            if stages['initialize'] and  retcode == 0:
+                retcode = self.preprocess(n_procs,
+                                          n_threads,
+                                          mpiexec_options)
+            if stages['run_solver'] == True and retcode == 0:
                 self.run_solver()
 
-            if save_results == True:
+            if stages['save_results'] == True:
                 self.save_results()
 
         finally:
@@ -1776,10 +1879,10 @@ $appli/runSession $appli/bin/salome/driver -e -d 0 fsi_yacs_scheme.xml
         # Standard or error exit
 
         if len(self.error) > 0:
-            stage = {'preprocess':'preprocessing',
-                     'solver':'calculation'}
-            if self.error in stage:
-                error_stage = stage[self.error]
+            check_stage = {'preprocess':'preprocessing',
+                           'solver':'calculation'}
+            if self.error in check_stage:
+                error_stage = check_stage[self.error]
             else:
                 error_stage = self.error
             err_str = ' Error in ' + error_stage + ' stage.\n\n'
@@ -1788,6 +1891,48 @@ $appli/runSession $appli/bin/salome/driver -e -d 0 fsi_yacs_scheme.xml
         else:
             return 0
 
+    #---------------------------------------------------------------------------
+
+    def suggest_id(self,
+                   run_id_prefix = None,
+                   run_id_suffix = None):
+
+        """
+        Suggest run id.
+        """
+
+        now = datetime.datetime.now()
+        run_id_base = now.strftime('%Y%m%d-%H%M')
+
+        r = os.path.join(self.case_dir, 'RESU')
+
+        if len(self.domains) + len(self.syr_domains) + len(self.ast_domains) > 1:
+            r += '_COUPLING'
+
+        # Make sure directory does not exist already
+
+        j = 0
+
+        while True:
+
+            run_id = run_id_base
+            if j > 0:
+                run_id += '_' + str(j)
+
+            if run_id_prefix:
+                run_id = run_id_prefix + run_id
+            if run_id_suffix:
+                run_id = run_id_suffix + run_id
+
+            result_dir = os.path.join(r, run_id)
+
+            if os.path.isdir(result_dir):
+                j += 1
+            else:
+                break
+
+        return run_id
+
 #-------------------------------------------------------------------------------
 # End
 #-------------------------------------------------------------------------------
