@@ -39,6 +39,8 @@ and the following classes:
 # Library modules import
 #-------------------------------------------------------------------------------
 
+from __future__ import print_function
+
 import os, sys, shutil, stat
 import types, string, re, fnmatch
 from optparse import OptionParser
@@ -145,8 +147,12 @@ def make_executable(filename):
     """
 
     st   = os.stat(filename)
-    mode = st[stat.ST_MODE]
-    os.chmod(filename, mode | stat.S_IEXEC)
+    mode = st[stat.ST_MODE] | stat.S_IXUSR
+    if mode & stat.S_IRGRP:
+        mode = mode | stat.S_IXGRP
+    if mode & stat.S_IROTH:
+        mode = mode | stat.S_IXOTH
+    os.chmod(filename, mode)
 
     return
 
@@ -476,8 +482,7 @@ domains = [
             os.mkdir(ref)
             for f in ['dp_C3P', 'dp_C3PSJ', 'dp_C4P', 'dp_ELE',
                       'dp_FCP.xml',
-                      'dp_FUE', 'dp_FUE_new', 'dp_transfo',
-                      'meteo']:
+                      'dp_FUE', 'dp_transfo', 'meteo']:
                 abs_f = os.path.join(thch_distpath, f)
                 if os.path.isfile(abs_f):
                     shutil.copy(abs_f, ref)
