@@ -39,6 +39,8 @@ import tempfile
 
 python_version = sys.version[:3]
 
+import cs_batch
+
 #===============================================================================
 # Utility functions
 #===============================================================================
@@ -713,6 +715,26 @@ def source_syrthes_env(pkg):
 
 #-------------------------------------------------------------------------------
 
+def get_parent_process_path():
+    """
+    Retrieve parent script path, when possible
+    """
+
+    path = None
+
+    if sys.platform.startswith('win'):
+        try:
+            f = open("/proc/" + str(os.getppid()) + "/cmdline")
+            l = f.readlines()
+            l = f.read()
+            path = l.split('\x00')[1]
+        except Exception:
+            pass
+
+    return path
+
+#-------------------------------------------------------------------------------
+
 class batch_info:
 
     #---------------------------------------------------------------------------
@@ -794,7 +816,7 @@ class batch_info:
             rtime = get_command_output(cmd)
         elif self.batch_type == 'SLURM':
             cmd = "squeue -h -j $SLURM_JOBID -o %L"
-            # TODO parse this
+            rtime = cs_batch.parse_wall_time_slurm(get_command_output(cmd))
 
         return rtime
 
@@ -817,6 +839,13 @@ class resource_info(batch_info):
         self.n_nodes = None
         self.n_threads = None
 
+        # Pre-set the number of threads if OMP_NUM_THREADS given
+
+        if n_threads == None:
+            s = os.getenv('OMP_NUM_THREADS')
+            if s != None:
+                n_threads = int(s)
+
         # If obtained from an environment variable, express
         # the hosts file using a shell variable rather than
         # an absolute name (for use in generated scripts).
@@ -827,8 +856,6 @@ class resource_info(batch_info):
         # Check for resource manager
 
         # Test for SLURM (Simple Linux Utility for Resource Management).
-        # Note that we could also use SLURM_CPUS_PER_TASK to
-        # determine Open MP behavior when that is ready.
 
         s = os.getenv('SLURM_NPROCS')
         if s != None:
@@ -884,17 +911,27 @@ class resource_info(batch_info):
 
         if self.manager == None and self.batch_type == 'LOADL':
             s = os.getenv('LOADL_TOTAL_TASKS')
-            if s == None:
-                s = os.getenv('LOADL_BG_SIZE')
             if s != None:
                 self.manager = 'LOADL'
                 self.n_procs = int(s)
-            else:
+            s = os.getenv('LOADL_BG_SIZE')
+            if s != None:
+                self.manager = 'LOADL'
+                self.n_nodes = int(s)
+            if not self.n_procs:
                 s = os.getenv('LOADL_PROCESSOR_LIST')
                 if s != None:
                     self.manager = 'LOADL'
                     hl = s.strip().split(' ')
                     self.n_procs_from_hosts_list(hl, True)
+            if self.n_nodes and not self.n_procs:
+                if n_procs:
+                    self.n_procs = n_procs
+                elif os.getenv('LOADL_BG_SIZE'): # Blue Gene/Q
+                    self.n_procs = self.n_nodes*16
+                    if n_threads:
+                        if n_threads > 4:
+                            self.n_procs = self.n_nodes*16*4/n_threads
             s = os.getenv('LOADL_HOSTFILE')
             if s != None:
                 self.manager = 'LOADL'
@@ -971,11 +1008,6 @@ class resource_info(batch_info):
 
         # Check and possibly set number of threads
 
-        if n_threads == None:
-            s = os.getenv('OMP_NUM_THREADS')
-            if s != None:
-                n_threads = int(s)
-
         if n_threads != None:
             if self.n_threads != None and n_threads != self.n_threads:
                 sys.stderr.write('Warning:\n'
@@ -1246,9 +1278,7 @@ class mpi_environment:
 
         if resource_info and self.mpiexec and not self.mpiexec_n_per_node:
             if os.path.basename(self.mpiexec)[:4] == 'srun':
-                ppn = resource_info.n_procs_per_node()
-                if ppn:
-                    self.mpiexec_n_per_node = ' --ntasks-per-node=' + str(ppn)
+                self.mpiexec_n_per_node = ' --ntasks-per-node='
 
         # Initialize based on known MPI types, or default.
 
@@ -1287,6 +1317,18 @@ class mpi_environment:
                else:
                    self.__dict__[k] = v
 
+        # Now adjust mpiexec_n_per_node base on available info:
+        # leave value alone if digit (ppn value) already present,
+        # complete or remove string otherwise.
+
+        if self.mpiexec_n_per_node:
+            if not self.mpiexec_n_per_node[-1:].isdigit():
+                ppn = resource_info.n_procs_per_node()
+                if ppn:
+                    self.mpiexec_n_per_node += str(ppn)
+                else:
+                    self.mpiexec_n_per_node = None
+
     #---------------------------------------------------------------------------
 
     def __get_mpiexec_absname__(self, p):
@@ -1332,6 +1374,12 @@ class mpi_environment:
             if suffix in ['hydra', 'gforker', 'remshell', 'smpd', 'mpd']:
                 return suffix
 
+        # If command is an external wrapper, use its base name
+
+        cmd = os.path.basename(mpiexec_path)
+        if cmd not in ['mpiexec', 'mpirun']:
+            return cmd
+
         # Use mpichversion/mpich2version preferentially
 
         infoname = os.path.join(os.path.split(mpiexec_path)[0],
@@ -1401,7 +1449,7 @@ class mpi_environment:
           a single machine (the equivalent seem possible with HYDRA
           using "mpiexec -bootstrap fork")
 
-        - remsh is a very simple version of mpiexec which makes use of
+        - remshell is a very simple version of mpiexec which makes use of
           the ssh command to start processes on a collection of
           machines. It ignores the command line options which control
           the environment variables given to MPI programs.
@@ -1499,7 +1547,7 @@ class mpi_environment:
                 if ppn:
                     self.mpiexec_n_per_node = ' -ppn ' + str(ppn)
 
-        elif pm == 'smpd':
+        elif pm == 'remshell':
             hostsfile = resource_info.get_hosts_file(wdir)
             if hostsfile != None:
                 self.mpiboot += ' --file=' + hostsfile
@@ -1564,7 +1612,7 @@ class mpi_environment:
             info_name = os.path.join(os.path.dirname(absname),
                                      'ompi_info')
         else:
-            info_name = ''
+            info_name = 'ompi_info'
 
         # Determine processor count and MPMD handling
 
@@ -1589,16 +1637,15 @@ class mpi_environment:
 
         if resource_info != None:
             known_manager = False
-            if os.path.isfile(info_name):
-                rc_mca_by_type = {'SLURM':' slurm ',
-                                  'LSF':' lsf ',
-                                  'LOADL':' loadleveler ',
-                                  'PBS':' tm ',
-                                  'SGE':' gridengine '}
-                if resource_info.manager in rc_mca_by_type:
-                    info = get_command_output(info_name)
-                    if info.find(rc_mca_by_type[resource_info.manager]) > -1:
-                        known_manager = True
+            rc_mca_by_type = {'SLURM':' slurm ',
+                              'LSF':' lsf ',
+                              'LOADL':' loadleveler ',
+                              'PBS':' tm ',
+                              'SGE':' gridengine '}
+            if resource_info.manager in rc_mca_by_type:
+                info = get_command_output(info_name)
+                if info.find(rc_mca_by_type[resource_info.manager]) > -1:
+                    known_manager = True
             if known_manager == False:
                 hostsfile = resource_info.get_hosts_file(wdir)
                 if hostsfile != None:
@@ -1782,7 +1829,18 @@ class exec_environment:
         if sys.platform.startswith('win'):
             self.user = os.getenv('USERNAME')
         else:
-            self.user = os.getenv('USER')
+            self.user = os.getenv('LOGNAME')
+            if not self.user:
+                self.user = os.getenv('USER')
+            if not self.user:
+                try:
+                    from pwd import getpwuid
+                    getpwuid(os.getuid())[0]
+                except Exception:
+                    pass
+
+        if not self.user:
+            self.user = 'unknown'
 
         self.wdir = wdir
         if self.wdir == None:
