@@ -144,8 +144,6 @@ if test "x$GCC" = "xyes"; then
     cs_gcc=clang
   elif test -n "`$CC --version 2>&1 | grep PathScale`" ; then
     cs_gcc=pathcc
-  elif test -n "`$CC --version 2>&1 | grep Open64`" ; then
-    cs_gcc=open64
   else
     cs_gcc=gcc
   fi
@@ -280,7 +278,7 @@ elif test "x$cs_gcc" = "xclang"; then
   cflags_default_opt="-O2"
   cflags_default_hot="-O3"
   cflags_default_prf="-p"
-  cflags_default_omp="-openmp"
+  cflags_default_omp="-fopenmp=libomp"
 
 # Otherwise, are we using pathcc ?
 #---------------------------------
@@ -308,32 +306,6 @@ elif test "x$cs_gcc" = "xpathcc"; then
 
   fi
 
-# Otherwise, are we using open64 ?
-#---------------------------------
-
-elif test "x$cs_gcc" = "xopen64"; then
-
-  $CC --version 2>&1 | grep 'Open64' > /dev/null
-  if test "$?" = "0" ; then
-
-    echo "compiler '$CC' is Open64 C compiler"
-
-    # Version strings for logging purposes and known compiler flag
-    $CC --version > $outfile 2>&1
-    cs_ac_cc_version=`grep -i Compiler $outfile`
-    cs_cc_compiler_known=yes
-
-    # Default compiler flags
-    cflags_default="-std=c99"
-    cflags_default="-std=c99 -funsigned-char -W -Wall -Wshadow -Wpointer-arith -Wcast-qual -Wcast-align -Wwrite-strings -Wstrict-prototypes -Wmissing-prototypes -Wmissing-declarations -Wnested-externs -Wunused -Wunused-value"
-    cflags_default_dbg="-g"
-    cflags_default_opt="-O2"
-    cflags_default_hot="-Ofast"
-    cflags_default_prf=""
-    cflags_default_omp="-openmp"
-
-  fi
-
 fi
 
 # Otherwise, are we using pgcc ?
@@ -619,7 +591,7 @@ elif test "x$cs_gxx" = "xclang"; then
   cxxflags_default_opt="-O2"
   cxxflags_default_hot="-O3"
   cxxflags_default_prf="-p"
-  cxxflags_default_omp="-openmp"
+  cxxflags_default_omp="-fopenmp=libomp"
 
 # Otherwise, are we using pgcc ?
 #-------------------------------
@@ -739,33 +711,6 @@ if test "x$cs_cxx_compiler_known" != "xyes" ; then
 
 fi
 
-# Otherwise, are we using openCC ?
-#---------------------------------
-
-if test "x$cs_cxx_compiler_known" != "xyes" ; then
-
-  $CXX --version 2>&1 | grep 'Open64' > /dev/null
-  if test "$?" = "0" ; then
-
-    echo "compiler '$CXX' is Open64"
-
-    # Version strings for logging purposes and known compiler flag
-    $CXX --version > $outfile 2>&1
-    cs_ac_cxx_version=`grep -i Compiler $outfile`
-    cs_cxx_compiler_known=yes
-
-    # Default compiler flags
-    cxxflags_default="-ansi -W -Wall -Wshadow -Wpointer-arith -Wcast-qual -Wcast-align -Wwrite-strings -Wstrict-prototypes -Wmissing-prototypes -Wmissing-declarations -Wnested-externs -Wunused -Wunused-value"
-    cxxflags_default_dbg="-g"
-    cxxflags_default_opt="-O2"
-    cxxflags_default_hot="-Ofast"
-    cxxflags_default_prf=""
-    cxxflags_default_omp="-openmp"
-
-  fi
-
-fi
-
 # Compiler still not identified
 #------------------------------
 
@@ -1016,32 +961,6 @@ if test "x$cs_fc_compiler_known" != "xyes" ; then
   fi
 fi
 
-if test "x$cs_fc_compiler_known" != "xyes" ; then
-
-  # Are we using openf95?
-  #---------------------
-
-  $FC --version 2>&1 | grep 'Open64' > /dev/null
-
-  if test "$?" = "0" ; then
-
-    echo "compiler '$FC' is Open64 Fortran compiler"
-
-    # Version strings for logging purposes and known compiler flag
-    $FC --version > $outfile 2>&1
-    cs_ac_fc_version=`grep 'Open64' $outfile`
-    cs_fc_compiler_known=yes
-
-    fcflags_default="-Wall -Wno-unused -cpp -fno-second-underscore"
-    fcflags_default_dbg="-g -ffortran-bounds-check"
-    fcflags_default_opt="-O"
-    fcflags_default_hot="-fast"
-    fcflags_default_prf=""
-    fcflags_default_omp="-openmp"
-
-  fi
-fi
-
 if test "x$cs_fc_compiler_known" != "xyes" ; then
 
   case "$host_os" in
