@@ -30,7 +30,7 @@
 Here is a list of user examples. Thorougly documented snippets are provided.
 
    - \subpage cs_user_initialization "Physical fields user initialization"
-   - \subpage cs_user_boundary_conditions_examples "User boundary conditions definitions"
+   - \subpage cs_user_boundary_conditions_examples "User boundary condition definitions"
    - \subpage les_inflow "Inflow Boundary conditions for LES"
    - \subpage f_parameters
    - \subpage parameters
@@ -48,4 +48,5 @@ Here is a list of user examples. Thorougly documented snippets are provided.
    - \subpage cs_user_extra_operations_examples "User extra operations"
    - \subpage cs_user_extra_operations-nusselt_calculation
    - \subpage cs_user_source_terms-scalar_in_a_channel
+   - \subpage richards
 */
