@@ -57,6 +57,7 @@ from PyQt4.QtGui  import *
 import cs_case
 import cs_exec_environment
 import cs_runcase
+import cs_submit
 
 #-------------------------------------------------------------------------------
 # Application modules import
@@ -64,6 +65,7 @@ import cs_runcase
 
 from code_saturne.Pages.BatchRunningForm import Ui_BatchRunningForm
 from code_saturne.Pages.BatchRunningAdvancedOptionsDialogForm import Ui_BatchRunningAdvancedOptionsDialogForm
+from code_saturne.Pages.BatchRunningDebugOptionsHelpDialogForm import Ui_BatchRunningDebugOptionsHelpDialogForm
 from code_saturne.Pages.BatchRunningStopByIterationDialogForm import Ui_BatchRunningStopByIterationDialogForm
 
 from code_saturne.Base.Toolbox import GuiParam
@@ -86,6 +88,41 @@ log.setLevel(GuiParam.DEBUG)
 # Popup advanced options
 #-------------------------------------------------------------------------------
 
+class BatchRunningDebugOptionsHelpDialogView(QDialog, Ui_BatchRunningDebugOptionsHelpDialogForm):
+    """
+    Help dialog
+    """
+    def __init__(self, parent):
+        """
+        Constructor
+        """
+        QDialog.__init__(self, parent)
+
+        Ui_BatchRunningAdvancedOptionsDialogForm.__init__(self)
+        self.setupUi(self)
+        self.retranslateUi(self)
+
+        self.setWindowTitle(self.tr("Debugger syntax help"))
+        self.parent = parent
+
+        # Connections
+        self.connect(self.pushButtonClose, SIGNAL("clicked()"), self.slotDebugclose)
+
+
+    @pyqtSignature("")
+    def slotDebugclose(self):
+        """
+        Close debugging page
+        """
+
+        QDialog.accept(self)
+        return
+
+
+#-------------------------------------------------------------------------------
+# Popup advanced options
+#-------------------------------------------------------------------------------
+
 
 class BatchRunningAdvancedOptionsDialogView(QDialog, Ui_BatchRunningAdvancedOptionsDialogForm):
     """
@@ -116,25 +153,25 @@ class BatchRunningAdvancedOptionsDialogView(QDialog, Ui_BatchRunningAdvancedOpti
         self.modelCSOUT2.addItem(self.tr("to listing_r<r>"), 'listing')
 
         # Connections
-        self.connect(self.toolButton_2, SIGNAL("clicked()"), self.slotSearchFile)
-        self.connect(self.lineEdit_3, SIGNAL("textChanged(const QString &)"), self.slotValgrind)
+        self.connect(self.toolButton_2, SIGNAL("clicked()"), self.slotDebugHelp)
+        self.connect(self.lineEdit_3, SIGNAL("textChanged(const QString &)"), self.slotDebug)
         self.connect(self.comboBox_6, SIGNAL("activated(const QString&)"), self.slotLogType)
         self.connect(self.comboBox_7, SIGNAL("activated(const QString&)"), self.slotLogType)
 
         # Previous values
-        self.valgrind = self.parent.mdl.getString('valgrind')
-        if self.valgrind is not None:
-            self.lineEdit_3.setText(str(self.valgrind))
+        self.debug = self.parent.mdl.getString('debug')
+        if self.debug is not None:
+            self.lineEdit_3.setText(str(self.debug))
 
         self.setLogType()
 
 
     @pyqtSignature("const QString &")
-    def slotValgrind(self, text):
+    def slotDebug(self, text):
         """
-        Input for Valgrind.
+        Input for Debug.
         """
-        self.valgrind = str(text)
+        self.debug = str(text)
 
 
     def setLogType(self):
@@ -156,31 +193,15 @@ class BatchRunningAdvancedOptionsDialogView(QDialog, Ui_BatchRunningAdvancedOpti
 
 
     @pyqtSignature("")
-    def slotSearchFile(self):
+    def slotDebugHelp(self):
         """
-        Choice temporary directory for batch
+        Show help page for debugging
         """
-        file_name = ""
 
-        title = self.tr("Select file for use VALGRIND option")
-        path  = os.getcwd()
-        filetypes = self.tr("All Files (*)")
-        file_name = QFileDialog.getOpenFileName(self, title, path, filetypes)
-        file_name = str(file_name)
+        dialog = BatchRunningDebugOptionsHelpDialogView(self)
+        dialog.show()
 
-        # TO CHECK ...
-        if file_name:
-            self.valgrind = str(self.lineEdit_3.text())
-            if not self.valgrind:
-                new = file_name + " --tool=memcheck"
-            else:
-                new = ""
-                for i in self.valgrind.split():
-                    if i == self.valgrind.split()[0]:
-                        i = file_name
-                        new = new + i + ' '
-            self.valgrind = new
-            self.lineEdit_3.setText(str(self.valgrind))
+        return
 
 
     def get_result(self):
@@ -195,7 +216,7 @@ class BatchRunningAdvancedOptionsDialogView(QDialog, Ui_BatchRunningAdvancedOpti
         Method called when user clicks 'OK'
         """
 
-        self.parent.mdl.setString('valgrind', self.valgrind.strip())
+        self.parent.mdl.setString('debug', self.debug.strip())
 
         self.parent.mdl.setLogType(self.log_type)
 
@@ -221,7 +242,7 @@ class BatchRunningAdvancedOptionsDialogView(QDialog, Ui_BatchRunningAdvancedOpti
 
 class BatchRunningStopByIterationDialogView(QDialog, Ui_BatchRunningStopByIterationDialogForm):
     """
-    Advanced dialog for stop the computation at a given iteration
+    Advanced dialog to stop the computation at a given iteration
     """
     def __init__(self, parent, default):
         """
@@ -253,7 +274,7 @@ class BatchRunningStopByIterationDialogView(QDialog, Ui_BatchRunningStopByIterat
     @pyqtSignature("const QString &")
     def __slotStopIter(self, text):
         """
-        Private slot to set a iteration number to stop the code.
+        Private slot to set an iteration number to stop the code.
         """
         if self.sender().validator().state == QValidator.Acceptable:
             iter = from_qvariant(text, int)
@@ -286,10 +307,10 @@ class BatchRunningStopByIterationDialogView(QDialog, Ui_BatchRunningStopByIterat
 #-------------------------------------------------------------------------------
 
 class ListingDialogView(CommandMgrDialogView):
-    def __init__(self, parent, case, title, cmd_list):
+    def __init__(self, parent, case, title, cmd):
         self.case = case
 
-        CommandMgrDialogView.__init__(self, parent, title, cmd_list, self.case['scripts_path'], self.case['salome'])
+        CommandMgrDialogView.__init__(self, parent, title, cmd, self.case['scripts_path'], self.case['salome'])
 
         self.connect(self.pushButtonStop,   SIGNAL('clicked()'), self.__slotStop)
         self.connect(self.pushButtonStopAt, SIGNAL('clicked()'), self.__slotStopAt)
@@ -300,7 +321,7 @@ class ListingDialogView(CommandMgrDialogView):
         self.listing  = "listing"
         self.n_lines = 0
 
-        self.slotProcess()
+        self.proc.start(self.cmd)
 
 
     def slotReadFromStdout(self):
@@ -317,18 +338,16 @@ class ListingDialogView(CommandMgrDialogView):
             s = (ba.data()).decode("utf-8")[:-1]
             self.logText.append(s)
             self.n_lines += 1
-            self.__execDir(s)
+
+            # Work and result directories printed in first lines of log.
+            if self.n_lines < 16:
+                self.__execDir(s)
 
 
     def __execDir(self, s):
         """
         Private method. Find the directory of the code execution.
         """
-        # Work and result directories printed in first lines of log.
-
-        if self.n_lines > 15:
-            return
-
         # Read directly the run directory from the sdtout of the code.
 
         if "Working directory" in s:
@@ -441,26 +460,15 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
                     self.case['runcase'] = cs_runcase.runcase(runcase_path,
                                                               package=self.case['package'])
 
-        # Get batch type
-
-        config = configparser.ConfigParser()
-        config.read(self.case['package'].get_configfiles())
-
-        cs_batch_type = None
-        if config.has_option('install', 'batch'):
-            cs_batch_type = config.get('install', 'batch')
-            if os.path.isabs(cs_batch_type):
-                i = cs_batch_type.rfind(".")
-                if i > -1:
-                    cs_batch_type = cs_batch_type[i+1:]
-
-        self.case['batch_type'] = cs_batch_type
-
         # Get MPI and OpenMP features
 
         self.have_mpi = False
         self.have_openmp = False
         config_features = self.case['package'].config.features
+
+        config = configparser.ConfigParser()
+        config.read(self.case['package'].get_configfiles())
+
         if config.has_option('install', 'compute_versions'):
             compute_versions = config.get('install', 'compute_versions').split(':')
             if compute_versions[0]:
@@ -485,7 +493,7 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
 
         self.class_list = None
 
-        if self.case['batch_type'] != None:
+        if self.jmdl.batch.rm_type != None:
 
             self.groupBoxArchi.setTitle("Job and script files")
             self.labelBatch.show()
@@ -515,7 +523,7 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
 
         # Connections
 
-        if self.case['batch_type'] != None:
+        if self.jmdl.batch.rm_type != None:
             self.connect(self.lineEditJobName, SIGNAL("textChanged(const QString &)"),
                          self.slotJobName)
             self.connect(self.spinBoxNodes, SIGNAL("valueChanged(int)"),
@@ -558,7 +566,11 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         self.modelArg_cs_verif.addItem(self.tr("Mesh preprocessing"), 'mesh preprocess')
         self.modelArg_cs_verif.addItem(self.tr("Mesh quality criteria"), 'mesh quality')
         self.modelArg_cs_verif.addItem(self.tr("Standard"), 'standard')
-        self.modelArg_cs_verif.setItem(str_model=self.mdl.getRunType())
+        if self.case['prepro'] == False:
+            self.modelArg_cs_verif.enableItem(3)
+        else:
+            self.modelArg_cs_verif.disableItem(3)
+        self.modelArg_cs_verif.setItem(str_model=self.mdl.getRunType(self.case['prepro']))
 
         # initialize Widgets
 
@@ -571,7 +583,7 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         else:
             setGreenColor(self.toolButtonSearchBatch, True)
 
-        if self.case['batch_type'] != None and self.case['runcase']:
+        if self.jmdl.batch.rm_type != None and self.case['runcase']:
             self.displayBatchInfo()
 
         # Script info is based on the XML model
@@ -587,8 +599,8 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         Increment, decrement and colorize the input argument entry
         """
         if self.lineEditJobName.validator().state == QValidator.Acceptable:
-            self.jmdl.dictValues['job_name'] = str(v)
-            self.jmdl.updateBatchFile('job_name')
+            self.jmdl.batch.params['job_name'] = str(v)
+            self.jmdl.batch.update_lines(self.case['runcase'].lines, 'job_name')
 
 
     @pyqtSignature("int")
@@ -596,8 +608,8 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         """
         Increment, decrement and colorize the input argument entry
         """
-        self.jmdl.dictValues['job_nodes'] = str(self.spinBoxNodes.text())
-        self.jmdl.updateBatchFile('job_nodes')
+        self.jmdl.batch.params['job_nodes'] = str(self.spinBoxNodes.text())
+        self.jmdl.batch.update_lines(self.case['runcase'].lines, 'job_nodes')
 
 
     @pyqtSignature("int")
@@ -605,8 +617,8 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         """
         Increment, decrement and colorize the input argument entry
         """
-        self.jmdl.dictValues['job_ppn']  = str(self.spinBoxPpn.text())
-        self.jmdl.updateBatchFile('job_ppn')
+        self.jmdl.batch.params['job_ppn']  = str(self.spinBoxPpn.text())
+        self.jmdl.batch.update_lines(self.case['runcase'].lines, 'job_ppn')
 
 
     @pyqtSignature("int")
@@ -614,8 +626,8 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         """
         Increment, decrement and colorize the input argument entry
         """
-        self.jmdl.dictValues['job_procs']  = str(self.spinBoxProcs.text())
-        self.jmdl.updateBatchFile('job_procs')
+        self.jmdl.batch.params['job_procs']  = str(self.spinBoxProcs.text())
+        self.jmdl.batch.update_lines(self.case['runcase'].lines, 'job_procs')
 
 
     @pyqtSignature("int")
@@ -623,8 +635,8 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         """
         Increment, decrement and colorize the input argument entry
         """
-        self.jmdl.dictValues['job_threads']  = str(self.spinBoxThreads.text())
-        self.jmdl.updateBatchFile('job_threads')
+        self.jmdl.batch.params['job_threads']  = str(self.spinBoxThreads.text())
+        self.jmdl.batch.update_lines(self.case['runcase'].lines, 'job_threads')
 
 
     @pyqtSignature("")
@@ -633,16 +645,16 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         h_cput = self.spinBoxDays.value()*24 + self.spinBoxHours.value()
         m_cput = self.spinBoxMinutes.value()
         s_cput = self.spinBoxSeconds.value()
-        self.jmdl.dictValues['job_walltime'] = h_cput*3600 + m_cput*60 + s_cput
-        self.jmdl.updateBatchFile('job_walltime')
+        self.jmdl.batch.params['job_walltime'] = h_cput*3600 + m_cput*60 + s_cput
+        self.jmdl.batch.update_lines(self.case['runcase'].lines, 'job_walltime')
 
 
     @pyqtSignature("")
     def slotClass(self):
 
-        self.jmdl.dictValues['job_class'] = str(self.comboBoxClass.currentText())
-        if len(self.jmdl.dictValues['job_class']) > 0:
-            self.jmdl.updateBatchFile('job_class')
+        self.jmdl.batch.params['job_class'] = str(self.comboBoxClass.currentText())
+        if len(self.jmdl.batch.params['job_class']) > 0:
+            self.jmdl.batch.update_lines(self.case['runcase'].lines, 'job_class')
 
 
     @pyqtSignature("const QString &")
@@ -651,8 +663,8 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         Increment, decrement and colorize the input argument entry
         """
         if self.lineEditJobAccount.validator().state == QValidator.Acceptable:
-            self.jmdl.dictValues['job_account'] = str(v)
-            self.jmdl.updateBatchFile('job_account')
+            self.jmdl.batch.params['job_account'] = str(v)
+            self.jmdl.batch.update_lines(self.case['runcase'].lines, 'job_account')
 
 
     @pyqtSignature("const QString &")
@@ -661,8 +673,8 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         Increment, decrement and colorize the input argument entry
         """
         if self.lineEditJobWCKey.validator().state == QValidator.Acceptable:
-            self.jmdl.dictValues['job_wckey'] = str(v)
-            self.jmdl.updateBatchFile('job_wckey')
+            self.jmdl.batch.params['job_wckey'] = str(v)
+            self.jmdl.batch.update_lines(self.case['runcase'].lines, 'job_wckey')
 
 
     @pyqtSignature("const QString &")
@@ -670,8 +682,8 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         """
         Input run type option.
         """
-        self.run_type = self.modelArg_cs_verif.dicoV2M[str(text)]
-        self.mdl.setRunType(self.run_type)
+        run_type = self.modelArg_cs_verif.dicoV2M[str(text)]
+        self.mdl.setRunType(run_type)
 
 
     @pyqtSignature("int")
@@ -747,46 +759,36 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
             return
 
         # Verify if boundary condition definitions exist
-
-        bd = LocalizationModel('BoundaryZone', self.case)
-        if not bd.getZones():
-            if self.case['no_boundary_conditions'] == False:
-                title = self.tr("Warning")
-                msg   = self.tr("No boundary definition declared.\n\n")
-                QMessageBox.warning(self, title, msg)
-                self.case['no_boundary_conditions'] = True
+        if self.case['prepro'] == False:
+            bd = LocalizationModel('BoundaryZone', self.case)
+            if not bd.getZones():
+                if self.case['no_boundary_conditions'] == False:
+                    title = self.tr("Warning")
+                    msg   = self.tr("No boundary definition declared.\n\n")
+                    QMessageBox.warning(self, title, msg)
+                    self.case['no_boundary_conditions'] = True
 
         # Build command line
 
-        key = self.case['batch_type']
+        rm_type = self.jmdl.batch.rm_type
 
         batch = self.case['runcase'].path
+        cmd = None
+        run_title = None
 
-        if key == None:
+        if rm_type == None:
             run_id, run_title = self.__suggest_run_id()
             self.__updateRuncase(run_id)
             cmd = batch
-            key = 'localhost'
-        elif key[0:3] == 'CCC':
-            cmd = 'msub ' + batch
-        elif key[0:5] == 'LOADL':
-            cmd = 'llsubmit ' + batch
-        elif key[0:3] == 'LSF':
-            cmd = 'bsub < ' + batch
-        elif key[0:3] == 'PBS' or key[0:3] == 'SGE':
-            cmd = 'qsub ' + batch
-        elif key[0:5] == 'SLURM':
-            cmd = 'sbatch ' + batch
         else:
-            pass
+            run_title = self.case['package'].code_name + ' - Job Submission'
+            cmd = cs_exec_environment.enquote_arg(sys.argv[0]) \
+                  + ' submit ' +  cs_exec_environment.enquote_arg(batch)
 
-        if self.case['salome'] or key == 'localhost':
-            dlg = ListingDialogView(self.parent, self.case, run_title, [cmd])
-            dlg.show()
-        else:
-            cs_exec_environment.run_command(cmd)
+        dlg = ListingDialogView(self.parent, self.case, run_title, cmd)
+        dlg.show()
 
-        if self.case['salome'] or key == 'localhost':
+        if rm_type == None:
             self.__updateRuncase('')  # remove --id <id> from runcase
 
         os.chdir(prv_dir)
@@ -799,6 +801,9 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         cmd = os.path.join(self.case['package'].get_dir('bindir'),
                            self.case['package'].name)
         cmd = cs_exec_environment.enquote_arg(cmd) + " run --suggest-id"
+        if self.mdl.getRunType() != "standard":
+            cmd += " --id-prefix=preprocess"
+
         r_title = subprocess.Popen(cmd,
                                    shell=True,
                                    stdout=subprocess.PIPE,
@@ -807,11 +812,6 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
 
         run_id = r_id
         run_title = r_title
-        j = 1
-        while os.path.isdir(run_id):
-            j += 1
-            run_id = r_id + "_" + str(j)
-            run_title = r_title + "(" + str(j) + ")"
 
         return os.path.basename(run_id), run_title
 
@@ -826,92 +826,6 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         runcase.save()
 
 
-    def getCommandOutput(self, cmd):
-        """
-        Run a command and return it's standard output.
-        """
-        p = subprocess.Popen(cmd,
-                             shell=True,
-                             stdout=subprocess.PIPE,
-                             stderr=subprocess.PIPE,
-                             universal_newlines=True)
-        lines = []
-        while True:
-            l = p.stdout.readline()
-            lines.append(l.strip())
-            if len(l) == 0 and p.poll() != None:
-                break
-        output = p.communicate()
-
-        if p.returncode == 0:
-            return lines
-
-
-    def getClassList(self):
-        """
-        Layout of the second part of this page.
-        """
-
-        self.class_list = []
-
-        try:
-
-            if self.case['batch_type'][0:3] == 'CCC':
-                output = self.getCommandOutput('class')
-                for l in output[1:]:
-                    if len(l) == 0:
-                        break
-                    else:
-                        self.class_list.append(l.split(' ')[0])
-
-            elif self.case['batch_type'][0:5] == 'LOADL':
-                output = self.getCommandOutput('llclass')
-                ignore = True
-                for l in output:
-                    if l[0:3] == '---':
-                        ignore = not ignore
-                    elif ignore == False:
-                        self.class_list.append(l.split(' ')[0])
-
-            elif self.case['batch_type'][0:3] == 'LSF':
-                output = self.getCommandOutput('bqueues')
-                ignore = True
-                for l in output[1:]:
-                    if len(l) == 0:
-                        break
-                    else:
-                        self.class_list.append(l.split(' ')[0])
-
-            elif self.case['batch_type'][0:3] == 'PBS':
-                output = self.getCommandOutput('qstat -q')
-                ignore = True
-                for l in output:
-                    if l[0:3] == '---':
-                        ignore = not ignore
-                    elif ignore == False:
-                        self.class_list.append(l.split(' ')[0])
-
-            elif self.case['batch_type'][0:3] == 'SGE':
-                output = self.getCommandOutput('qconf -sc')
-                for l in output:
-                    if l[0:1] != '#':
-                        self.class_list.append(l.split(' ')[0])
-
-            elif self.case['batch_type'][0:5] == 'SLURM':
-                output = self.getCommandOutput('sinfo -s')
-                for l in output[1:]:
-                    if len(l) == 0:
-                        break
-                    else:
-                        name = l.split(' ')[0]
-                        if name[-1:] == '*':
-                            name = name[:-1]
-                        self.class_list.append(name)
-
-        except Exception:
-            pass
-
-
     def hideBatchInfo(self):
         """
         hide all batch info before displaying a selected subset
@@ -951,15 +865,15 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
         Layout of the second part of this page.
         """
 
-        self.job_name  = self.jmdl.dictValues['job_name']
-        self.job_nodes = self.jmdl.dictValues['job_nodes']
-        self.job_ppn  = self.jmdl.dictValues['job_ppn']
-        self.job_procs = self.jmdl.dictValues['job_procs']
-        self.job_threads = self.jmdl.dictValues['job_threads']
-        self.job_walltime = self.jmdl.dictValues['job_walltime']
-        self.job_class  = self.jmdl.dictValues['job_class']
-        self.job_account  = self.jmdl.dictValues['job_account']
-        self.job_wckey  = self.jmdl.dictValues['job_wckey']
+        self.job_name  = self.jmdl.batch.params['job_name']
+        self.job_nodes = self.jmdl.batch.params['job_nodes']
+        self.job_ppn  = self.jmdl.batch.params['job_ppn']
+        self.job_procs = self.jmdl.batch.params['job_procs']
+        self.job_threads = self.jmdl.batch.params['job_threads']
+        self.job_walltime = self.jmdl.batch.params['job_walltime']
+        self.job_class  = self.jmdl.batch.params['job_class']
+        self.job_account  = self.jmdl.batch.params['job_account']
+        self.job_wckey  = self.jmdl.batch.params['job_wckey']
 
         if self.job_name != None:
             self.labelJobName.show()
@@ -1012,7 +926,7 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
 
             # Only one pass here
             if self.class_list == None:
-                self.getClassList()
+                self.class_list = self.jmdl.batch.get_class_list()
                 if len(self.class_list) > 0:
                     for c in self.class_list:
                         self.comboBoxClass.addItem(self.tr(c), to_qvariant(c))
@@ -1031,9 +945,9 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
             self.comboBoxClass.show()
 
             # update runcase (compute class specific to ivanoe)
-            self.jmdl.dictValues['job_class'] = str(self.comboBoxClass.currentText())
-            if len(self.jmdl.dictValues['job_class']) > 0:
-                self.jmdl.updateBatchFile('job_class')
+            self.jmdl.batch.params['job_class'] = str(self.comboBoxClass.currentText())
+            if len(self.jmdl.batch.params['job_class']) > 0:
+                self.jmdl.batch.update_lines(self.case['runcase'].lines, 'job_class')
 
         if self.job_account != None:
             self.labelJobAccount.show()
@@ -1047,17 +961,17 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
 
         # Show Job management box
 
-        if self.case['batch_type'][0:5] == 'LOADL':
+        if self.jmdl.batch.rm_type == 'LOADL':
             self.groupBoxJob.setTitle("Load Leveler job parameters")
             self.labelJobAccount.setText(str("Group"))
             self.lineEditJobAccount.setToolTip("To obtain a list of defined groups, run <b><tt>xloadl</tt></b>, then select <i>File -> Build a Job</i>, and check the group names in the <i>Group</i> field")
-        elif self.case['batch_type'][0:3] == 'LSF':
+        elif self.jmdl.batch.rm_type == 'LSF':
             self.groupBoxJob.setTitle("LSF job parameters")
-        elif self.case['batch_type'][0:3] == 'PBS':
+        elif self.jmdl.batch.rm_type == 'PBS':
             self.groupBoxJob.setTitle("PBS job parameters")
-        elif self.case['batch_type'][0:3] == 'SGE':
+        elif self.jmdl.batch.rm_type == 'SGE':
             self.groupBoxJob.setTitle("Sun Grid Engine job parameters")
-        if self.case['batch_type'][0:5] == 'SLURM':
+        if self.jmdl.batch.rm_type == 'SLURM':
             self.groupBoxJob.setTitle("SLURM job parameters")
         else:
             self.groupBoxJob.setTitle("Batch job parameters")
@@ -1066,7 +980,7 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
 
         # Update file
 
-        self.jmdl.updateBatchFile()
+        self.jmdl.batch.update_lines(self.case['runcase'].lines)
 
 
     def displayScriptInfo(self):
@@ -1133,7 +1047,7 @@ class BatchRunningView(QWidget, Ui_BatchRunningForm):
                                                           package=self.case['package'])
                 self.labelBatchName.setText(str(launcher))
                 self.hideBatchInfo()
-                if self.case['batch_type'] != None:
+                if self.jmdl.batch.rm_type != None:
                     self.displayBatchInfo()
             else:
                 title = self.tr("Warning")
