@@ -48,6 +48,70 @@ except:
 else :
    import eosAva
 
+#-------------------------------------------------------------------------------
+# Coolprop
+#-------------------------------------------------------------------------------
+
+import cs_config
+
+coolprop_fluids = []
+coolprop_warn = False
+
+if cs_config.config().libs['coolprop'].have != "no" and not coolprop_fluids:
+
+   try:
+      import sys
+      sys.path.insert(0, cs_config.config().libs['coolprop'].flags['pythonpath'])
+      import CoolProp
+      sys.pop(0)
+      seld.coolprop_fluids = []
+      for f in CoolProp.__fluids__:
+         coolprop_fluids.append(f)
+      coolprop_fluids.sort()
+
+   except Exception:  # CoolProp might be available but not its Python bindings
+
+      if cs_config.config().libs['coolprop'].have != "gui_only":
+         import traceback
+         exc_info = sys.exc_info()
+         bt = traceback.format_exception(*exc_info)
+         for l in bt:
+            print(l)
+         del exc_info
+         print("Warning: CoolProp Python bindings not available or usable")
+         print("         list of fluids based on CoolProp 5.1.1")
+      else:
+         coolprop_warn = True
+
+      coolprop_fluids = ['1-Butene', 'Acetone', 'Air', 'Ammonia', 'Argon',
+                         'Benzene', 'CarbonDioxide', 'CarbonMonoxide',
+                         'CarbonylSulfide', 'CycloHexane', 'CycloPropane',
+                         'Cyclopentane', 'D4', 'D5', 'D6', 'Deuterium',
+                         'DimethylCarbonate', 'DimethylEther', 'Ethane',
+                         'Ethanol', 'EthylBenzene', 'Ethylene', 'Fluorine',
+                         'HFE143m', 'HeavyWater', 'Helium', 'Hydrogen',
+                         'HydrogenSulfide', 'IsoButane', 'IsoButene',
+                         'Isohexane', 'Isopentane', 'Krypton', 'MD2M', 'MD3M',
+                         'MD4M', 'MDM', 'MM', 'Methane', 'Methanol',
+                         'MethylLinoleate', 'MethylLinolenate', 'MethylOleate',
+                         'MethylPalmitate', 'MethylStearate', 'Neon',
+                         'Neopentane', 'Nitrogen', 'NitrousOxide', 'Novec649',
+                         'OrthoDeuterium', 'OrthoHydrogen', 'Oxygen',
+                         'ParaDeuterium', 'ParaHydrogen', 'Propylene',
+                         'Propyne', 'R11', 'R113', 'R114', 'R115', 'R116',
+                         'R12', 'R123', 'R1233zd(E)', 'R1234yf', 'R1234ze(E)',
+                         'R1234ze(Z)', 'R124', 'R125', 'R13', 'R134a', 'R13I1',
+                         'R14', 'R141b', 'R142b', 'R143a', 'R152A', 'R161',
+                         'R21', 'R218', 'R22', 'R227EA', 'R23', 'R236EA',
+                         'R236FA', 'R245fa', 'R32', 'R365MFC', 'R404A',
+                         'R407C', 'R41', 'R410A', 'R507A', 'RC318', 'SES36',
+                         'SulfurDioxide', 'SulfurHexafluoride', 'Toluene',
+                         'Water', 'Xenon', 'cis-2-Butene', 'm-Xylene',
+                         'n-Butane', 'n-Decane', 'n-Dodecane', 'n-Heptane',
+                         'n-Hexane', 'n-Nonane', 'n-Octane', 'n-Pentane',
+                         'n-Propane', 'n-Undecane', 'o-Xylene', 'p-Xylene',
+                         'trans-2-Butene']
+
 #-------------------------------------------------------------------------------
 # Third-party modules
 #-------------------------------------------------------------------------------
@@ -180,7 +244,6 @@ temperature = enthalpy / 1040.;
 thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
 """
 
-
     def __init__(self, parent, case):
         """
         Constructor
@@ -245,21 +308,21 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
 
         # Combo models
 
-        self.modelRho      = ComboModel(self.comboBoxRho, 3, 1)
-        self.modelMu       = ComboModel(self.comboBoxMu, 3, 1)
-        self.modelCp       = ComboModel(self.comboBoxCp, 3, 1)
-        self.modelAl       = ComboModel(self.comboBoxAl, 3, 1)
-        self.modelDiff     = ComboModel(self.comboBoxDiff, 2, 1)
-        self.modelNameDiff = ComboModel(self.comboBoxNameDiff,1,1)
-        self.modelViscv0   = ComboModel(self.comboBoxViscv0, 3, 1)
-        self.modelDiftl0   = ComboModel(self.comboBoxDiftl0, 3, 1)
+        self.modelRho      = ComboModel(self.comboBoxRho,      3, 1)
+        self.modelMu       = ComboModel(self.comboBoxMu,       3, 1)
+        self.modelCp       = ComboModel(self.comboBoxCp,       3, 1)
+        self.modelAl       = ComboModel(self.comboBoxAl,       3, 1)
+        self.modelDiff     = ComboModel(self.comboBoxDiff,     2, 1)
+        self.modelNameDiff = ComboModel(self.comboBoxNameDiff, 1, 1)
+        self.modelViscv0   = ComboModel(self.comboBoxViscv0,   3, 1)
+        self.modelDiftl0   = ComboModel(self.comboBoxDiftl0,   3, 1)
         self.modelMaterial = ComboModel(self.comboBoxMaterial, 1, 1)
-        self.modelMethod   = ComboModel(self.comboBoxMethod, 1, 1)
-        self.modelPhas     = ComboModel(self.comboBoxPhas, 2, 1)
+        self.modelMethod   = ComboModel(self.comboBoxMethod,   1, 1)
+        self.modelPhas     = ComboModel(self.comboBoxPhas,     2, 1)
 
         self.modelRho.addItem(self.tr('constant'), 'constant')
         self.modelRho.addItem(self.tr('variable'), 'variable')
-        self.modelRho.addItem(self.tr('thermal law'), 'thermal_law')
+        self.modelRho.addItem(self.tr('material law'), 'thermal_law')
         if mdl_atmo != 'off':
             self.modelRho.addItem(self.tr('defined in atphyv'), 'variable')
         elif mdl_joule == 'arc':
@@ -267,19 +330,19 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
 
         self.modelMu.addItem(self.tr('constant'), 'constant')
         self.modelMu.addItem(self.tr('variable'), 'variable')
-        self.modelMu.addItem(self.tr('thermal law'), 'thermal_law')
+        self.modelMu.addItem(self.tr('material law'), 'thermal_law')
         if mdl_joule == 'arc':
             self.modelMu.addItem(self.tr('defined in elphyv'), 'variable')
 
         self.modelCp.addItem(self.tr('constant'), 'constant')
         self.modelCp.addItem(self.tr('variable'), 'variable')
-        self.modelCp.addItem(self.tr('thermal law'), 'thermal_law')
+        self.modelCp.addItem(self.tr('material law'), 'thermal_law')
         if mdl_joule == 'arc':
             self.modelCp.addItem(self.tr('defined in elphyv'), 'variable')
 
         self.modelAl.addItem(self.tr('constant'), 'constant')
         self.modelAl.addItem(self.tr('variable'), 'variable')
-        self.modelAl.addItem(self.tr('thermal law'), 'thermal_law')
+        self.modelAl.addItem(self.tr('material law'), 'thermal_law')
         if mdl_joule == 'arc':
             self.modelAl.addItem(self.tr('defined in elphyv'), 'variable')
 
@@ -288,37 +351,15 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
 
         self.modelViscv0.addItem(self.tr('constant'), 'constant')
         self.modelViscv0.addItem(self.tr('variable'), 'variable')
-        self.modelViscv0.addItem(self.tr('thermal law'), 'thermal_law')
+        self.modelViscv0.addItem(self.tr('material law'), 'thermal_law')
 
         self.modelDiftl0.addItem(self.tr('constant'), 'constant')
         self.modelDiftl0.addItem(self.tr('variable'), 'variable')
-        self.modelDiftl0.addItem(self.tr('thermal law'), 'thermal_law')
+        self.modelDiftl0.addItem(self.tr('material law'), 'thermal_law')
 
         self.modelPhas.addItem(self.tr('liquid'), 'liquid')
         self.modelPhas.addItem(self.tr('gas'), 'gas')
 
-        if (self.freesteam == 0 and EOS == 0) or \
-            self.m_th.getThermalScalarModel() == "off" or \
-            mdl_joule != 'off' or mdl_comp != 'off':
-            self.groupBoxTableChoice.hide()
-        else:
-            self.groupBoxTableChoice.show()
-            self.lineEditReference.setEnabled(False)
-            # suppress perfect gas
-            self.modelMaterial.addItem(self.tr('user material'), 'user_material')
-            tmp = ["Argon", "Nitrogen", "Hydrogen", "Oxygen", "Helium", "Air"]
-            if EOS == 1:
-                fls = self.ava.whichFluids()
-                for fli in fls:
-                    if fli not in tmp:
-                        tmp.append(fli)
-                        self.modelMaterial.addItem(self.tr(fli), fli)
-            if self.freesteam == 1 and EOS == 0:
-                self.modelMaterial.addItem(self.tr('Water'), 'Water')
-            material = self.mdl.getMaterials()
-            self.modelMaterial.setItem(str_model=material)
-            self.updateMethod()
-
         self.scalar = ""
         scalar_list = self.m_sca.getUserScalarNameList()
         for s in self.m_sca.getScalarsVarianceList():
@@ -329,8 +370,68 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
             for scalar in scalar_list:
                 self.modelNameDiff.addItem(scalar)
 
-        # Connections
+        # Validators
+        validatorRho    = DoubleValidator(self.lineEditRho,    min = 0.0)
+        validatorMu     = DoubleValidator(self.lineEditMu,     min = 0.0)
+        validatorCp     = DoubleValidator(self.lineEditCp,     min = 0.0)
+        validatorAl     = DoubleValidator(self.lineEditAl,     min = 0.0)
+        validatorDiff   = DoubleValidator(self.lineEditDiff,   min = 0.0)
+        validatorViscv0 = DoubleValidator(self.lineEditViscv0, min = 0.0)
+        validatorDiftl0 = DoubleValidator(self.lineEditDiftl0, min = 0.0)
 
+        validatorRho.setExclusiveMin(True)
+        validatorMu.setExclusiveMin(True)
+        validatorCp.setExclusiveMin(True)
+        validatorAl.setExclusiveMin(True)
+        validatorDiff.setExclusiveMin(True)
+        validatorDiftl0.setExclusiveMin(True)
+
+        self.lineEditRho.setValidator(validatorRho)
+        self.lineEditMu.setValidator(validatorMu)
+        self.lineEditCp.setValidator(validatorCp)
+        self.lineEditAl.setValidator(validatorAl)
+        self.lineEditDiff.setValidator(validatorDiff)
+        self.lineEditViscv0.setValidator(validatorViscv0)
+        self.lineEditDiftl0.setValidator(validatorDiftl0)
+
+        if (self.freesteam == 1 or EOS == 1 or coolprop_fluids):
+            self.tables = True
+        else:
+            self.tables = False
+
+        if self.tables == False or mdl_joule != 'off' or mdl_comp != 'off':
+            self.groupBoxTableChoice.hide()
+        else:
+            self.groupBoxTableChoice.show()
+            self.lineEditReference.setEnabled(False)
+
+            # suppress perfect gas
+            self.modelMaterial.addItem(self.tr('user material'), 'user_material')
+            tmp = ["Argon", "Nitrogen", "Hydrogen", "Oxygen", "Helium", "Air"]
+            if EOS == 1:
+                fls = self.ava.whichFluids()
+                for fli in fls:
+                    if fli not in tmp:
+                        tmp.append(fli)
+                        self.modelMaterial.addItem(self.tr(fli), fli)
+
+            if self.freesteam == 1 and EOS == 0:
+                self.modelMaterial.addItem(self.tr('Water'), 'Water')
+
+            if coolprop_fluids and EOS == 0:
+                have_coolprop = False
+                if cs_config.config().libs['coolprop'].have != "no":
+                    have_coolprop = True
+                for fli in coolprop_fluids:
+                    if self.freesteam == 1 and fli == 'Water':
+                        continue
+                    self.modelMaterial.addItem(self.tr(fli), fli, coolprop_warn)
+
+            material = self.mdl.getMaterials()
+            self.modelMaterial.setItem(str_model=material)
+            self.updateMethod()
+
+        # Connections
         self.connect(self.comboBoxRho,      SIGNAL("activated(const QString&)"), self.slotStateRho)
         self.connect(self.comboBoxMu,       SIGNAL("activated(const QString&)"), self.slotStateMu)
         self.connect(self.comboBoxCp,       SIGNAL("activated(const QString&)"), self.slotStateCp)
@@ -355,32 +456,23 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         self.connect(self.pushButtonDiff,   SIGNAL("clicked()"), self.slotFormulaDiff)
         self.connect(self.pushButtonViscv0, SIGNAL("clicked()"), self.slotFormulaViscv0)
 
-        # Validators
+        self.initializeWidget()
 
-        validatorRho    = DoubleValidator(self.lineEditRho, min = 0.0)
-        validatorMu     = DoubleValidator(self.lineEditMu, min = 0.0)
-        validatorCp     = DoubleValidator(self.lineEditCp, min = 0.0)
-        validatorAl     = DoubleValidator(self.lineEditAl, min = 0.0)
-        validatorDiff   = DoubleValidator(self.lineEditDiff, min = 0.0)
-        validatorViscv0 = DoubleValidator(self.lineEditViscv0, min = 0.0)
-        validatorDiftl0 = DoubleValidator(self.lineEditDiftl0, min = 0.0)
+        self.case.undoStartGlobal()
 
-        validatorRho.setExclusiveMin(True)
-        validatorMu.setExclusiveMin(True)
-        validatorCp.setExclusiveMin(True)
-        validatorAl.setExclusiveMin(True)
-        validatorDiff.setExclusiveMin(True)
-        validatorDiftl0.setExclusiveMin(True)
 
-        self.lineEditRho.setValidator(validatorRho)
-        self.lineEditMu.setValidator(validatorMu)
-        self.lineEditCp.setValidator(validatorCp)
-        self.lineEditAl.setValidator(validatorAl)
-        self.lineEditDiff.setValidator(validatorDiff)
-        self.lineEditViscv0.setValidator(validatorViscv0)
-        self.lineEditDiftl0.setValidator(validatorDiftl0)
+    def initializeWidget(self):
+        """
+        """
+        mdl_atmo, mdl_joule, mdl_thermal, mdl_gas, mdl_coal, mdl_comp = self.mdl.getThermoPhysicalModel()
 
-        if scalar_list == []:
+        #compressible
+        self.groupBoxViscv0.hide()
+
+        # combustion
+        self.groupBoxDiftl0.hide()
+
+        if self.scalar == "":
             self.groupBoxDiff.hide()
         else :
             self.groupBoxDiff.show()
@@ -396,14 +488,7 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
                 self.pushButtonDiff.setEnabled(True)
                 setGreenColor(self.pushButtonDiff, True)
 
-        #compressible
-        self.groupBoxViscv0.hide()
-
-        # combustion
-        self.groupBoxDiftl0.hide()
-
         # Standard Widget initialization
-
         for tag, symbol in self.lst:
             __model  = getattr(self, "model"      + symbol)
             __line   = getattr(self, "lineEdit"   + symbol)
@@ -525,12 +610,10 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
                 if tag == 'specific_heat':
                     self.groupBoxCp.setTitle('Specific heat')
 
-        self.case.undoStartGlobal()
 
-
-    def updateTypeChoice(self):
+    def updateTypeChoice(self, old_choice):
         """
-        add/suppress thermo tables for each proprties
+        add/suppress thermo tables for each properties
         """
         for tag, symbol in self.lst:
             __model  = getattr(self, "model" + symbol)
@@ -538,6 +621,9 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
                 __model.disableItem(str_model='thermal_law')
             else:
                 __model.enableItem(str_model='thermal_law')
+                if old_choice == "user_material":
+                    self.mdl.setPropertyMode(tag, 'thermal_law')
+                self.__changeChoice(str("material law"), symbol, tag)
             c = self.mdl.getPropertyMode(tag)
             __model.setItem(str_model=c)
 
@@ -561,12 +647,15 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
                 fls = self.ava.whichMethods()
                 for fli in fls:
                     self.modelMethod.addItem(self.tr(fli),fli)
-                if self.mdl.getMethod() != "freesteam":
+                if self.mdl.getMethod() != "freesteam" and self.mdl.getMethod() != "CoolProp":
                     self.comboBoxPhas.show()
                     self.labelPhas.show()
             if self.freesteam == 1 and self.mdl.getMaterials() == "Water":
                 self.modelMethod.addItem(self.tr("freesteam"), "freesteam")
 
+            if self.mdl.getMaterials() in coolprop_fluids:
+                self.modelMethod.addItem(self.tr("CoolProp"), "CoolProp")
+
         # update comboBoxMethod
         method = self.mdl.getMethod()
         self.modelMethod.setItem(str_model=method)
@@ -588,9 +677,10 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         Method to call 'setMaterial'
         """
         choice = self.modelMaterial.dicoV2M[str(text)]
+        old_choice = self.mdl.getMaterials()
         self.mdl.setMaterials(choice)
         self.updateMethod()
-        self.updateTypeChoice()
+        self.updateTypeChoice(old_choice)
 
 
     @pyqtSignature("const QString &")
@@ -615,7 +705,8 @@ thermal_conductivity = 6.2e-5 * temperature + 8.1e-3;
         self.comboBoxPhas.hide()
         self.labelPhas.hide()
         if self.mdl.getMaterials() != "user_material" and \
-           self.mdl.getMethod() != "freesteam":
+           self.mdl.getMethod() != "freesteam" and \
+           self.mdl.getMethod() != "CoolProp":
             self.comboBoxPhas.show()
             self.labelPhas.show()
 
