@@ -210,7 +210,7 @@ class StandardItemModelBoundariesNames(QStandardItemModel):
 
     def data(self, index, role):
 
-        self.kwords = [ "INBRBD",   "IFLMBD",   "IANGBD",   "IVITBD",
+        self.kwords = [ "IFLMBD",   "INBRBD",   "IANGBD",   "IVITBD",
                         "IENCNBBD", "IENCMABD", "IENCDIBD", "IENCCKBD"]
         if not index.isValid():
             return
