@@ -377,6 +377,7 @@ void CS_PROCF (perinr, PERINR)
                        1,               /* n_r_sweeps */
                        tr_dim,
                        false,           /* hyd_p_flag, */
+                       1,               /* w_stride */
                        *iwarnp,
                        -1,              /* clip_mode */
                        *epsrgp,
@@ -563,6 +564,105 @@ cs_gradient_perio_init_rij(const cs_field_t  *f,
   }
 }
 
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Initialize ghost cell values for Reynolds stress tensor gradient.
+ *
+ * We retrieve the gradient given by perinr (phyvar) for the Reynolds
+ * stress tensor in a buffer on ghost cells. then we define
+ * dpdx, dpdy and dpdz gradient (1 -> n_cells_with_ghosts).
+ *
+ * We can't implicitly take into account rotation of a gradient of a tensor
+ * variable because we have to know all components.
+ *
+ * We set idimtr to 2 for the Reynolds stress tensor.
+ *
+ * We assume that is correct to treat periodicities implicitly for the other
+ * variables when reconstructing gradients.
+ *
+ * \param[in]       f        pointer to field
+ * \param[out]      tr_dim   2 for tensor (Rij) in case of rotation, 0 otherwise
+ * \param[in, out]  grad     gradient of field
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_gradient_perio_init_rij_tensor(const cs_field_t  *f,
+                                  int               *tr_dim,
+                                  cs_real_63_t        grad[])
+{
+  cs_mesh_t  *mesh = cs_glob_mesh;
+  int isou;
+
+  if (mesh->halo == NULL ) {
+    *tr_dim = 0;
+    return;
+  }
+  else
+    *tr_dim = 2;
+
+  /*
+    When there is periodicity of rotation :
+      - Retrieve gradient values for ghost cells and for the previous
+        time step without reconstruction
+      - Ghost cells without rotation keep their value.
+  */
+
+  if (_drdxyz != NULL) {
+
+    int  rank_id, t_id;
+    cs_lnum_t  i, shift, start_std, end_std, start_ext, end_ext;
+
+    cs_halo_t  *halo = mesh->halo;
+
+    const cs_lnum_t  n_cells   = mesh->n_cells;
+    const cs_lnum_t  n_transforms = mesh->n_transforms;
+    const fvm_periodicity_t  *periodicity = mesh->periodicity;
+
+    for (t_id = 0; t_id < n_transforms; t_id++) {
+
+      if (   fvm_periodicity_get_type(periodicity, t_id)
+          >= FVM_PERIODICITY_ROTATION) {
+
+        shift = 4 * halo->n_c_domains * t_id;
+
+        for (rank_id = 0; rank_id < halo->n_c_domains; rank_id++) {
+
+          start_std = halo->perio_lst[shift + 4*rank_id];
+          end_std = start_std + halo->perio_lst[shift + 4*rank_id + 1];
+
+          for (i = start_std; i < end_std; i++) {
+            for (isou = 0; isou < 6 ; isou++){
+              grad[n_cells + i][isou][0] = _drdxyz[0 + isou*3 + 18*i];
+              grad[n_cells + i][isou][1] = _drdxyz[1 + isou*3 + 18*i];
+              grad[n_cells + i][isou][2] = _drdxyz[2 + isou*3 + 18*i];
+            }
+          }
+
+          if (mesh->halo_type == CS_HALO_EXTENDED) {
+
+            start_ext = halo->perio_lst[shift + 4*rank_id + 2];
+            end_ext = start_ext + halo->perio_lst[shift + 4*rank_id + 3];
+
+            for (i = start_ext; i < end_ext; i++) {
+              for (isou = 0; isou < 6 ; isou++){
+                grad[n_cells + i][isou][0] = _drdxyz[0 + isou*3 + 18*i];
+                grad[n_cells + i][isou][1] = _drdxyz[1 + isou*3 + 18*i];
+                grad[n_cells + i][isou][2] = _drdxyz[2 + isou*3 + 18*i];
+              }
+            }
+
+          } /* End if extended halo */
+
+        } /* End of loop on ranks */
+
+      } /* End of test on rotation */
+
+    } /* End of loop on transformations */
+
+  }
+}
+
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief  Process grad buffers in case of rotation on Reynolds stress tensor.
