@@ -67,12 +67,15 @@ typedef enum {
 
   CS_MATRIX_SCALAR,           /* Simple scalar matrix */
   CS_MATRIX_SCALAR_SYM,       /* Simple scalar symmetric matrix */
-  CS_MATRIX_33_BLOCK_D,       /* Matrix with 3x3 diagonal blocks
-                                 (and 3.I extradiagonal blocks) */
-  CS_MATRIX_33_BLOCK_D_SYM,   /* Symmetric matrix with 3x3 diagonal blocks
-                                 (and 3.I extradiagonal blocks) */
-  CS_MATRIX_33_BLOCK,         /* Matrix with 3x3 blocks
-                                 (diagonal and extra-diagonal) */
+  CS_MATRIX_BLOCK_D,          /* Matrix with diagonal blocks
+                                 (and m.I extradiagonal blocks) */
+  CS_MATRIX_BLOCK_D_66,       /* Matrix with 6x6 diagonal blocks
+                                 (and 6.I extradiagonal blocks;
+                                 subcase of CS_MATRIX_BLOCK_D, allows
+                                 separate tuning) */
+  CS_MATRIX_BLOCK_D_SYM,      /* Symmetric matrix with diagonal blocks
+                                 (and m.I extradiagonal blocks) */
+  CS_MATRIX_BLOCK,            /* Block matrix */
   CS_MATRIX_N_FILL_TYPES      /* Number of possible matrix fill types */
 
 } cs_matrix_fill_type_t;
@@ -545,7 +548,7 @@ cs_matrix_get_extra_diagonal(const cs_matrix_t  *matrix);
  * Initialize row info for a given matrix.
  *
  * parameters:
- *   row_info --> row info structure
+ *   r --> row info structure
  *----------------------------------------------------------------------------*/
 
 void
@@ -555,7 +558,7 @@ cs_matrix_row_init(cs_matrix_row_info_t  *r);
  * Finalize row info for a given matrix.
  *
  * parameters:
- *   row_info <-> row info structure
+ *   r <-> row info structure
  *----------------------------------------------------------------------------*/
 
 void
@@ -577,7 +580,7 @@ cs_matrix_row_finalize(cs_matrix_row_info_t  *r);
  * parameters:
  *   matrix    <-- pointer to matrix structure
  *   row_id    <-- id of row to query
- *   row_info  <-> row info structure
+ *   r         <-> row info structure
  *----------------------------------------------------------------------------*/
 
 void
@@ -766,13 +769,12 @@ cs_matrix_variant_destroy(cs_matrix_variant_t  **mv);
  *
  *   CS_MATRIX_NATIVE  (all fill types)
  *     standard
- *     3_3_diag        (for CS_MATRIX_33_BLOCK_D or CS_MATRIX_33_BLOCK_D_SYM)
+ *     fixed           (for CS_MATRIX_??_BLOCK_D or CS_MATRIX_??_BLOCK_D_SYM)
  *     omp             (for OpenMP with compatible numbering)
  *     vector          (For vector machine with compatible numbering)
  *
  *   CS_MATRIX_CSR     (for CS_MATRIX_SCALAR or CS_MATRIX_SCALAR_SYM)
  *     standard
- *     prefetch
  *     mkl             (with MKL)
  *
  *   CS_MATRIX_CSR_SYM (for CS_MATRIX_SCALAR_SYM)
@@ -781,7 +783,7 @@ cs_matrix_variant_destroy(cs_matrix_variant_t  **mv);
  *
  *   CS_MATRIX_MSR     (all fill types except CS_MATRIX_33_BLOCK)
  *     standard
- *     prefetch
+ *     generic         (for CS_MATRIX_??_BLOCK_D or CS_MATRIX_??_BLOCK_D_SYM)
  *     mkl             (with MKL, for CS_MATRIX_SCALAR or CS_MATRIX_SCALAR_SYM)
  *
  * parameters:
@@ -812,7 +814,7 @@ cs_matrix_variant_set_func(cs_matrix_variant_t     *mv,
  * parameters:
  *   mv        <-> pointer to matrix variant
  *   mv_merge  <-- pointer to matrix variant to merge
- *   fill type <-- matrix fill type to merge from
+ *   fill_type <-- matrix fill type to merge from
  *----------------------------------------------------------------------------*/
 
 void
