@@ -119,11 +119,18 @@ static int _tuned_matrix_id[CS_MATRIX_N_FILL_TYPES];
 static cs_matrix_structure_t *_matrix_struct_msr = NULL;
 static cs_matrix_t *_matrix_msr = NULL;
 
+/* Native matrix structure, if needed */
+
+static cs_matrix_structure_t *_matrix_struct_native = NULL;
+static cs_matrix_t *_matrix_native = NULL;
+
+/* Tuning options */
+
 static double _t_measure = 0.5;
 static int _n_min_products = 10;
 
 /* Pointer to global (block-based) numbering, if used */
-
+static cs_lnum_t  _row_num_size = 0;
 static cs_gnum_t  *_global_row_num = NULL;
 
 /*============================================================================
@@ -146,6 +153,8 @@ _initialize_api(void)
     }
     _matrix_struct_msr = NULL;
     _matrix_msr = NULL;
+    _matrix_struct_native = NULL;
+    _matrix_native = NULL;
     _initialized = true;
   }
 }
@@ -165,6 +174,7 @@ _build_block_row_num(cs_lnum_t         n_rows,
   cs_lnum_t _n_rows = n_rows;
   cs_gnum_t row_start = 1;
 
+  _row_num_size = n_rows;
   if (halo != NULL) {
     assert(n_rows == halo->n_local_elts);
     _n_rows += halo->n_elts[CS_HALO_EXTENDED];
@@ -191,6 +201,68 @@ _build_block_row_num(cs_lnum_t         n_rows,
                          _global_row_num);
 }
 
+/*----------------------------------------------------------------------------
+ * Return native matrix for a given fill type
+ *
+ * parameters:
+ *   symmetric              <-- Indicates if matrix coefficients are symmetric
+ *   diag_block_size        <-- Block sizes for diagonal, or NULL
+ *   extra_diag_block_size  <-- Block sizes for extra diagonal, or NULL
+ *
+ * returns:
+ *   pointer to native matrix adapted to fill type
+ *----------------------------------------------------------------------------*/
+
+static cs_matrix_t  *
+_p_matrix_native(bool        symmetric,
+                 const int  *diag_block_size,
+                 const int  *extra_diag_block_size)
+{
+  cs_matrix_t *m = NULL;
+
+  /* If default matrix for fill type is already native, return that */
+
+  cs_matrix_fill_type_t mft = cs_matrix_get_fill_type(symmetric,
+                                                      diag_block_size,
+                                                      extra_diag_block_size);
+
+  if (_matrix_tuned[mft] != NULL) {
+    if ((_matrix_tuned[mft])->type == CS_MATRIX_NATIVE)
+      m = cs_matrix_default(symmetric,
+                            diag_block_size,
+                            extra_diag_block_size);
+  }
+
+  if (m == NULL) {
+
+    /* Create matrix if not done yet */
+
+    if (_matrix_native == NULL) {
+
+      cs_mesh_t  *mesh = cs_glob_mesh;
+
+      _matrix_struct_native
+        = cs_matrix_structure_create(CS_MATRIX_NATIVE,
+                                     true,
+                                     mesh->n_cells,
+                                     mesh->n_cells_with_ghosts,
+                                     mesh->n_i_faces,
+                                     mesh->global_cell_num,
+                                     (const cs_lnum_2_t *)(mesh->i_face_cells),
+                                     mesh->halo,
+                                     mesh->i_face_numbering);
+
+      _matrix_native = cs_matrix_create(_matrix_struct_native);
+
+    }
+
+    m = _matrix_native;
+
+  }
+
+  return m;
+}
+
 /*! (DOXYGEN_SHOULD_SKIP_THIS) \endcond */
 
 /*============================================================================
@@ -228,23 +300,21 @@ void CS_PROCF(promav, PROMAV)
     int _diag_block_size[4] = {1, 1, 1, 1};
     int _extra_diag_block_size[4] = {1, 1, 1, 1};
 
-    /* TODO: update diag_block_size[] values for the general case */
     _diag_block_size[0] = *ibsize;
     _diag_block_size[1] = *ibsize;
     _diag_block_size[2] = *ibsize;
     _diag_block_size[3] = (*ibsize)*(*ibsize);
 
     if (*iesize > 1) {
-      /* TODO: update extra_diag_block_size[] values for the general case */
       _extra_diag_block_size[0] = *iesize;
       _extra_diag_block_size[1] = *iesize;
       _extra_diag_block_size[2] = *iesize;
       _extra_diag_block_size[3] = (*iesize)*(*iesize);
     }
 
-    a = cs_matrix_default(symmetric,
-                          _diag_block_size,
-                          _extra_diag_block_size);
+    a = _p_matrix_native(symmetric,
+                         _diag_block_size,
+                         _extra_diag_block_size);
 
     cs_matrix_set_coefficients(a,
                                symmetric,
@@ -257,7 +327,7 @@ void CS_PROCF(promav, PROMAV)
   }
   else {
 
-    a = cs_matrix_default(symmetric, NULL, NULL);
+    a = _p_matrix_native(symmetric, NULL, NULL);
 
     cs_matrix_set_coefficients(a, false, NULL, NULL,
                                m->n_i_faces,
@@ -422,6 +492,11 @@ cs_matrix_finalize(void)
   if (_matrix_struct_msr != NULL)
     cs_matrix_structure_destroy(&(_matrix_struct_msr));
 
+  if (_matrix_native != NULL)
+    cs_matrix_destroy(&(_matrix_native));
+  if (_matrix_struct_native != NULL)
+    cs_matrix_structure_destroy(&(_matrix_struct_native));
+
   _initialized = false;
   _initialize_api();
   _initialized = false;
@@ -491,6 +566,28 @@ cs_matrix_update_mesh(void)
 
   }
 
+  /* Same for native... */
+
+  if (_matrix_native != NULL) {
+
+    cs_matrix_destroy(&(_matrix_native));
+    cs_matrix_structure_destroy(&(_matrix_struct_native));
+
+    _matrix_struct_native
+      = cs_matrix_structure_create(CS_MATRIX_NATIVE,
+                                   true,
+                                   mesh->n_cells,
+                                   mesh->n_cells_with_ghosts,
+                                   mesh->n_i_faces,
+                                   mesh->global_cell_num,
+                                   (const cs_lnum_2_t *)(mesh->i_face_cells),
+                                   mesh->halo,
+                                   mesh->i_face_numbering);
+
+    _matrix_native = cs_matrix_create(_matrix_struct_native);
+
+  }
+
 }
 
 /*----------------------------------------------------------------------------
@@ -510,34 +607,14 @@ cs_matrix_default(bool        symmetric,
                   const int  *diag_block_size,
                   const int  *extra_diag_block_size)
 {
-  cs_matrix_fill_type_t fill_type = CS_MATRIX_SCALAR;
-  int db_size = 1, eb_size = 1;
-
   cs_matrix_t *m = NULL;
 
-  if (extra_diag_block_size != NULL)
-    eb_size = extra_diag_block_size[0];
-  if (diag_block_size != NULL)
-    db_size = diag_block_size[0];
-  /* Set fill type */
+  cs_matrix_fill_type_t mft = cs_matrix_get_fill_type(symmetric,
+                                                      diag_block_size,
+                                                      extra_diag_block_size);
 
-  if (eb_size == 3)
-    fill_type = CS_MATRIX_33_BLOCK;
-  else if (db_size == 3) {
-    if (symmetric)
-      fill_type = CS_MATRIX_33_BLOCK_D_SYM;
-    else
-      fill_type = CS_MATRIX_33_BLOCK_D;
-  }
-  else if (db_size == 1) {
-    if (symmetric)
-      fill_type = CS_MATRIX_SCALAR_SYM;
-    else
-      fill_type = CS_MATRIX_SCALAR;
-  }
-
-  if (_tuned_matrix_id[fill_type] > -1)
-    m = _matrix_tuned[_tuned_matrix_id[fill_type]];
+  if (_tuned_matrix_id[mft] > -1)
+    m = _matrix_tuned[_tuned_matrix_id[mft]];
 
   return m;
 }
@@ -750,7 +827,7 @@ cs_matrix_get_block_row_gnum(cs_lnum_t         n_rows,
 {
   const cs_gnum_t  *g_row_num = _global_row_num;
 
-  if (_global_row_num == NULL) {
+  if (_global_row_num == NULL || n_rows > _row_num_size) {
     _build_block_row_num(n_rows, halo);
     g_row_num = _global_row_num;
   }
