@@ -61,11 +61,13 @@ BEGIN_C_DECLS
  *----------------------------------------------------------------------------*/
 
 typedef void
-(cs_matrix_set_coeffs_t) (cs_matrix_t      *matrix,
-                          bool              symmetric,
-                          bool              copy,
-                          const cs_real_t  *restrict da,
-                          const cs_real_t  *restrict xa);
+(cs_matrix_set_coeffs_t) (cs_matrix_t        *matrix,
+                          bool                symmetric,
+                          bool                copy,
+                          cs_lnum_t           n_edges,
+                          const cs_lnum_2_t  *restrict edges,
+                          const cs_real_t    *restrict da,
+                          const cs_real_t    *restrict xa);
 
 typedef void
 (cs_matrix_release_coeffs_t) (cs_matrix_t  *matrix);
@@ -94,15 +96,15 @@ typedef void
 
 typedef struct _cs_matrix_struct_native_t {
 
-  cs_lnum_t          n_cells;       /* Local number of cells */
-  cs_lnum_t          n_cells_ext;   /* Local number of participating cells
-                                       (cells + ghost cells sharing a face) */
-  cs_lnum_t          n_faces;       /* Local number of faces
-                                       (for extra-diagonal terms */
+  cs_lnum_t          n_rows;        /* Local number of rows */
+  cs_lnum_t          n_cols_ext;    /* Local number of columns + ghosts */
+  cs_lnum_t          n_edges;       /* Local number of graph edges
+                                       (for extra-diagonal terms) */
 
   /* Pointers to shared arrays */
 
-  const cs_lnum_2_t  *face_cell;    /* Face -> cells connectivity (0 to n-1) */
+  const cs_lnum_2_t  *edges;        /* Edges (symmetric row <-> column)
+                                       connectivity */
 
 } cs_matrix_struct_native_t;
 
@@ -133,8 +135,7 @@ typedef struct _cs_matrix_coeff_native_t {
 typedef struct _cs_matrix_struct_csr_t {
 
   cs_lnum_t         n_rows;           /* Local number of rows */
-  cs_lnum_t         n_cols;           /* Local number of columns
-                                         (> n_rows in case of ghost cells) */
+  cs_lnum_t         n_cols_ext;       /* Local number of columns + ghosts */
   cs_lnum_t         n_cols_max;       /* Maximum number of nonzero values
                                          on a given row */
 
@@ -146,8 +147,11 @@ typedef struct _cs_matrix_struct_csr_t {
                                          faces contribute to the same
                                          value (i.e. we have split faces) */
 
-  cs_lnum_t        *row_index;        /* Row index (0 to n-1) */
-  cs_lnum_t        *col_id;           /* Column id (0 to n-1) */
+  const cs_lnum_t  *row_index;        /* Pointer to row index (0 to n-1) */
+  const cs_lnum_t  *col_id;           /* Pointer to column id (0 to n-1) */
+
+  cs_lnum_t        *_row_index;       /* Row index (0 to n-1), if owner */
+  cs_lnum_t        *_col_id;          /* Column id (0 to n-1), if owner */
 
 } cs_matrix_struct_csr_t;
 
@@ -156,13 +160,13 @@ typedef struct _cs_matrix_struct_csr_t {
 
 typedef struct _cs_matrix_coeff_csr_t {
 
-  int               n_prefetch_rows;  /* Number of rows at a time for which
-                                         the x values in y = Ax should be
-                                         prefetched (0 if no prefetch) */
+  /* Pointers to possibly shared arrays */
 
-  cs_real_t        *val;              /* Matrix coefficients */
+  const cs_real_t  *val;              /* Matrix coefficients */
 
-  cs_real_t        *x_prefetch;       /* Prefetch array for x in y = Ax */
+  /* Pointers to private arrays (NULL if shared) */
+
+  cs_real_t        *_val;             /* Diagonal matrix coefficients */
 
   /* Pointers to auxiliary arrays used for queries */
 
@@ -180,7 +184,7 @@ typedef struct _cs_matrix_struct_csr_sym_t {
 
   cs_lnum_t         n_rows;           /* Local number of rows */
   cs_lnum_t         n_cols;           /* Local number of columns
-                                         (> n_rows in case of ghost cells) */
+                                         (> n_rows in case of ghost columns) */
   cs_lnum_t         n_cols_max;       /* Maximum number of nonzero values
                                          on a given row */
 
@@ -218,22 +222,18 @@ typedef struct _cs_matrix_coeff_csr_sym_t {
 
 typedef struct _cs_matrix_coeff_msr_t {
 
-  int              n_prefetch_rows;   /* Number of rows at a time for which
-                                         the x values in y = Ax should be
-                                         prefetched (0 if no prefetch) */
   int              max_db_size;       /* Current max allocated block size */
   int              max_eb_size;       /* Current max allocated extradiag block size */
 
   /* Pointers to possibly shared arrays */
 
   const cs_real_t  *d_val;            /* Diagonal matrix coefficients */
+  const cs_real_t  *x_val;            /* Extra-diagonal matrix coefficients */
 
   /* Pointers to private arrays (NULL if shared) */
 
   cs_real_t        *_d_val;           /* Diagonal matrix coefficients */
-  cs_real_t        *x_val;            /* Extra-diagonal matrix coefficients */
-
-  cs_real_t        *x_prefetch;       /* Prefetch array for x in y = Ax */
+  cs_real_t        *_x_val;           /* Extra-diagonal matrix coefficients */
 
 } cs_matrix_coeff_msr_t;
 
@@ -244,11 +244,8 @@ struct _cs_matrix_structure_t {
 
   cs_matrix_type_t       type;         /* Matrix storage and definition type */
 
-  cs_lnum_t              n_cells;      /* Local number of cells */
-  cs_lnum_t              n_cells_ext;  /* Local number of participating cells
-                                          (cells + ghost cells sharing a face) */
-  cs_lnum_t              n_faces;      /* Local Number of mesh faces
-                                          (necessary to affect coefficients) */
+  cs_lnum_t              n_rows;       /* Local number of rows */
+  cs_lnum_t              n_cols_ext;   /* Local number of columns + ghosts */
 
   void                  *structure;    /* Matrix structure */
 
@@ -257,8 +254,7 @@ struct _cs_matrix_structure_t {
      local->local cell numbering for future info or renumbering,
      and halo) */
 
-  const cs_lnum_2_t     *face_cell;    /* Face -> cells connectivity */
-  const cs_gnum_t       *cell_num;     /* Global cell numbers */
+  const cs_gnum_t       *row_num;      /* Global row numbers */
   const cs_halo_t       *halo;         /* Parallel or periodic halo */
   const cs_numbering_t  *numbering;    /* Vectorization or thread-related
                                           numbering information */
@@ -271,14 +267,13 @@ struct _cs_matrix_t {
 
   cs_matrix_type_t       type;         /* Matrix storage and definition type */
 
-  cs_lnum_t              n_cells;      /* Local number of cells */
-  cs_lnum_t              n_cells_ext;  /* Local number of participating cells
-                                          (cells + ghost cells sharing a face) */
-  cs_lnum_t              n_faces;      /* Local Number of mesh faces
-                                          (necessary to affect coefficients) */
+  cs_lnum_t              n_rows;       /* Local number of rows */
+  cs_lnum_t              n_cols_ext;   /* Local number of columns + ghosts */
 
   cs_matrix_fill_type_t  fill_type;    /* Matrix fill type */
 
+  bool                   symmetric;    /* true if coefficients are symmetric */
+
   int                    db_size[4];   /* Diag Block size, including padding:
                                           0: useful block size
                                           1: vector block extents
@@ -295,21 +290,19 @@ struct _cs_matrix_t {
 
   const void            *structure;    /* Matrix structure */
 
-  /* Pointers to shared arrays from mesh structure
-     (face->cell connectivity for coefficient assignment,
-     local->local cell numbering for future info or renumbering,
+  /* Pointers to arrays possibly shared from mesh structure
+     (graph edges: face->cell connectivity for coefficient assignment,
+     rows: local->local cell numbering for future info or renumbering,
      and halo) */
 
-  const cs_lnum_2_t     *face_cell;    /* Face -> cells connectivity */
-  const cs_gnum_t       *cell_num;     /* Global cell numbers */
   const cs_halo_t       *halo;         /* Parallel or periodic halo */
   const cs_numbering_t  *numbering;    /* Vectorization or thread-related
                                           numbering information */
 
-  /* Pointers to shared arrays from coefficient assignment
-     these may become NULL in the future if coefficients are passed
-     directly from non "native" types, so precautions may need to be
-     taken when accessing those */
+  /* Pointer to shared arrays from coefficient assignment from
+     "native" type. This should be removed in the future, but requires
+     removing the dependency to the native structure in the multigrid
+     code first. */
 
   const cs_real_t      *xa;            /* Extra-diagonal terms */
 
@@ -328,10 +321,6 @@ struct _cs_matrix_t {
 
   cs_matrix_vector_product_t        *vector_multiply[CS_MATRIX_N_FILL_TYPES][2];
 
-  /* Loop length parameter for some SpMv algorithms */
-
-  int                                loop_length[CS_MATRIX_N_FILL_TYPES][2];
-
 };
 
 /* Structure used for tuning variants */
@@ -343,10 +332,6 @@ struct _cs_matrix_variant_t {
 
   cs_matrix_type_t       type;         /* Matrix storage and definition type */
 
-  /* Loop length parameter for some SpMv algorithms */
-
-  int                    loop_length[CS_MATRIX_N_FILL_TYPES][2];
-
   /* Function pointer arrays, with variants:
      fill_type + exclude_diagonal_flag */
 
@@ -363,7 +348,7 @@ struct _cs_matrix_variant_t {
   /* Measured operation costs for each available operation, or -1 otherwise
      fill_type*2 + exclude_diagonal_flag */
 
-  double  matrix_vector_cost[CS_MATRIX_N_FILL_TYPES][2];
+  double  matrix_vector_cost[CS_MATRIX_N_FILL_TYPES][2][2];
 
 };
 
@@ -373,6 +358,159 @@ struct _cs_matrix_variant_t {
  * Semi-private function prototypes
  *============================================================================*/
 
+/*----------------------------------------------------------------------------
+ * Create CSR matrix coefficients.
+ *
+ * returns:
+ *   pointer to allocated CSR coefficients structure.
+ *----------------------------------------------------------------------------*/
+
+cs_matrix_coeff_csr_t *
+cs_matrix_create_coeff_csr(void);
+
+/*----------------------------------------------------------------------------
+ * Destroy CSR matrix coefficients.
+ *
+ * parameters:
+ *   coeff  <->  Pointer to CSR matrix coefficients pointer
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_destroy_coeff_csr(cs_matrix_coeff_csr_t **coeff);
+
+/*----------------------------------------------------------------------------
+ * Release shared CSR matrix coefficients.
+ *
+ * parameters:
+ *   matrix <-- Pointer to matrix structure
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_release_coeffs_csr(cs_matrix_t  *matrix);
+
+/*----------------------------------------------------------------------------
+ * Copy diagonal of CSR matrix.
+ *
+ * parameters:
+ *   matrix <-- Pointer to matrix structure
+ *   da     --> Diagonal (pre-allocated, size: n_rows)
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_copy_diagonal_csr(const cs_matrix_t  *matrix,
+                            cs_real_t          *restrict da);
+
+/*----------------------------------------------------------------------------
+ * Destroy CSR matrix structure.
+ *
+ * parameters:
+ *   matrix  <->  Pointer to CSR matrix structure pointer
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_destroy_struct_csr(cs_matrix_struct_csr_t  **matrix);
+
+/*----------------------------------------------------------------------------
+ * Local matrix.vector product y = A.x with CSR matrix.
+ *
+ * parameters:
+ *   exclude_diag <-- exclude diagonal if true
+ *   matrix       <-- Pointer to matrix structure
+ *   x            <-- Multipliying vector values
+ *   y            --> Resulting vector
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_vec_p_l_csr(bool                exclude_diag,
+                      const cs_matrix_t  *matrix,
+                      const cs_real_t    *restrict x,
+                      cs_real_t          *restrict y);
+
+#if defined (HAVE_MKL)
+/*----------------------------------------------------------------------------
+ * Local matrix.vector product y = A.x with MSR matrix, using MKL
+ *
+ * parameters:
+ *   exclude_diag <-- exclude diagonal if true
+ *   matrix       <-- Pointer to matrix structure
+ *   x            <-- Multipliying vector values
+ *   y            --> Resulting vector
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_vec_p_l_csr_mkl(bool                exclude_diag,
+                          const cs_matrix_t  *matrix,
+                          const cs_real_t    *restrict x,
+                          cs_real_t          *restrict y);
+
+#endif /* defined (HAVE_MKL) */
+
+/*----------------------------------------------------------------------------
+ * Copy diagonal of native or MSR matrix.
+ *
+ * parameters:
+ *   matrix <-- Pointer to matrix structure
+ *   da     --> Diagonal (pre-allocated, size: n_cols)
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_copy_diagonal_separate(const cs_matrix_t  *matrix,
+                                 cs_real_t          *restrict da);
+
+/*----------------------------------------------------------------------------
+ * Create MSR matrix coefficients.
+ *
+ * returns:
+ *   pointer to allocated MSR coefficients structure.
+ *----------------------------------------------------------------------------*/
+
+cs_matrix_coeff_msr_t *
+cs_matrix_create_coeff_msr(void);
+
+/*----------------------------------------------------------------------------
+ * Release shared MSR matrix coefficients.
+ *
+ * parameters:
+ *   matrix <-- Pointer to matrix structure
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_release_coeffs_msr(cs_matrix_t  *matrix);
+
+/*----------------------------------------------------------------------------
+ * Local matrix.vector product y = A.x with MSR matrix.
+ *
+ * parameters:
+ *   exclude_diag <-- exclude diagonal if true
+ *   matrix       <-- Pointer to matrix structure
+ *   x            <-- Multipliying vector values
+ *   y            --> Resulting vector
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_vec_p_l_msr(bool                exclude_diag,
+                      const cs_matrix_t  *matrix,
+                      const cs_real_t    *restrict x,
+                      cs_real_t          *restrict y);
+
+#if defined (HAVE_MKL)
+/*----------------------------------------------------------------------------
+ * Local matrix.vector product y = A.x with MSR matrix, using MKL
+ *
+ * parameters:
+ *   exclude_diag <-- exclude diagonal if true
+ *   matrix       <-- Pointer to matrix structure
+ *   x            <-- Multipliying vector values
+ *   y            --> Resulting vector
+ *----------------------------------------------------------------------------*/
+
+void
+cs_matrix_vec_p_l_msr_mkl(bool                exclude_diag,
+                          const cs_matrix_t  *matrix,
+                          const cs_real_t    *restrict x,
+                          cs_real_t          *restrict y);
+#endif /* defined (HAVE_MKL) */
+
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
