@@ -306,50 +306,52 @@ typedef int
  *============================================================================*/
 
 /*----------------------------------------------------------------------------
- * Initialize sparse linear equation solver API.
+ * \brief Initialize sparse linear equation solver API.
  *----------------------------------------------------------------------------*/
 
 void
 cs_sles_initialize(void);
 
 /*----------------------------------------------------------------------------
- * Finalize sparse linear equation solver API.
+ * \brief Finalize sparse linear equation solver API.
  *----------------------------------------------------------------------------*/
 
 void
 cs_sles_finalize(void);
 
-/*----------------------------------------------------------------------------
- * Log sparse linear equation solver info
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Log sparse linear equation solver info
  *
- * parameters:
- *   log_type <-- log type (CS_LOG_SETUP or CS_LOG_PERFORMANCE)
- *----------------------------------------------------------------------------*/
+ * \param[in]  log_type  log type (CS_LOG_SETUP or CS_LOG_PERFORMANCE)
+ */
+/*----------------------------------------------------------------------------*/
 
 void
 cs_sles_log(cs_log_t  log_type);
 
-/*----------------------------------------------------------------------------
- * Return pointer to linear system object, based on matching field id or
- * system name.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Return pointer to linear system object, based on matching field id or
+ *        system name.
  *
  * If this system did not previously exist, NULL is returned.
  *
- * parameters:
- *   f_id <-- associated field id, or < 0
- *   name <-- associated name if f_id < 0, or NULL
+ * \param[in]  f_id  associated field id, or < 0
+ * \param[in]  name  associated name if f_id < 0, or NULL
  *
- * returns:
- *   pointer to associated linear system object, or NULL
- *----------------------------------------------------------------------------*/
+ * \return  pointer to associated linear system object, or NULL
+ */
+/*----------------------------------------------------------------------------*/
 
 cs_sles_t *
 cs_sles_find(int          f_id,
              const char  *name);
 
-/*----------------------------------------------------------------------------
- * Return pointer to linear system object, based on matching field id or
- * system name.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Return pointer to linear system object, based on matching field id or
+ *        system name.
  *
  * If this system did not previously exist, it is created and added to
  * to the list of "known" systems. In this case, it will be usable
@@ -358,34 +360,32 @@ cs_sles_find(int          f_id,
  * cs_sles_set_sefault_define() has been previously used to define
  * the default solver policy.
  *
- * parameters:
- *   f_id <-- associated field id, or < 0
- *   name <-- associated name if f_id < 0, or NULL
+ * \param[in]  f_id  associated field id, or < 0
+ * \param[in]  name  associated name if f_id < 0, or NULL
  *
- * returns:
- *   pointer to associated linear system object.
- *----------------------------------------------------------------------------*/
+ * \return  pointer to associated linear system object, or NULL
+ */
+/*----------------------------------------------------------------------------*/
 
 cs_sles_t *
 cs_sles_find_or_add(int          f_id,
                     const char  *name);
 
-/*----------------------------------------------------------------------------
- * Temporarily replace field id with name for matching calls
- * to cs_sles_setup(), cs_sles_solve(), cs_sles_free(), and other operations
- * involving access through a field id.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Temporarily replace field id with name for matching calls
+ * to \ref cs_sles_setup, \ref cs_sles_solve, \ref cs_sles_free, and other
+ * operations involving access through a field id.
  *
- * Deprecated.
- *   This function is provided to allow some peculiar
- *   calling sequences, in which codits is called with a nonzero
- *   ivar value, but specific solver options must still be set.
- *   In the future, a more consistent mechanism (using a zero ivar
- *   value or designing a cleaner method to handle those exceptional cases)
- *   is preferred. As such, only a stack depth of 1 is allowed.
+ * \deprecated This function is provided to allow some peculiar
+ * calling sequences, in which \ref codits is called with a nonzero
+ * \c ivar value, but specific solver options must still be set.
+ * In the future, a more consistent mechanism (using a zero \c ivar
+ * value or designing a cleaner method to handle those exceptional cases)
+ * is preferred. As such, only a stack depth of 1 is allowed.
  *
- * parameters:
- *   f_id  associated field id, or < 0
- *   name  associated name if f_id < 0, or NULL
+ * \param[in]  f_id  associated field id, or < 0
+ * \param[in]  name  associated name if f_id < 0, or NULL
  */
 /*----------------------------------------------------------------------------*/
 
@@ -393,24 +393,26 @@ void
 cs_sles_push(int          f_id,
              const char  *name);
 
-/*----------------------------------------------------------------------------
- * Restore behavior temporarily modified by cs_slesh_push().
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Restore behavior temporarily modified by \ref cs_sles_push.
  *
- * Deprecated.
- *   This function matches cs_sles_push(), which is deprecated.
+ * \deprecated This function matches \ref cs_sles_push, which is deprecated.
  *
- * parameters:
- *   f_id  associated field id, or < 0
- *----------------------------------------------------------------------------*/
+ * \param[in]  f_id  associated field id, or < 0
+ */
+/*----------------------------------------------------------------------------*/
 
 void
 cs_sles_pop(int  f_id);
 
-/*----------------------------------------------------------------------------
- * Define sparse linear equation solver for a given field or equation name.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Define sparse linear equation solver for a given field or
+ *        equation name.
  *
  * If this system did not previously exist, it is added to the list of
- * "known" systems. If it existed previously,
+ * "known" systems.
  *
  * The context pointer is used to point to a structure adapted to the function
  * pointers given here, and combined with those functions, allows using
@@ -420,27 +422,26 @@ cs_sles_pop(int  f_id);
  * to the associated structure type (for example, "cs_sles_it_t" or
  * "cs_multigrid_t").
  *
- * parameters:
- *   f_id         <-- associated field id, or < 0
- *   name         <-- associated name if f_id < 0, or NULL
- *   context      <-> pointer to solver context management structure
- *                    (cs_sles subsystem becomes owner)
- *   setup_func   <-- pointer to system setup function
- *   solve_func   <-- pointer to system solution function
- *                    (also calls setup_func if not done yet
- *                    or free_func called since last solve)
- *   free_func    <-- pointer function freeing system setup
- *   log_func     <-- pointer to system info logging function
- *                    (optional, but recommended)
- *   copy_func    <-- pointer to settings copy function (optional)
- *   destroy_func <-- pointer to function destroying solver context
- *                                (called with cs_sles_finalize() or with
- *                                a new call to this function for the same
- *                                system)
+ * \param[in]       f_id          associated field id, or < 0
+ * \param[in]       name          associated name if f_id < 0, or NULL
+ * \param[in, out]  context       pointer to solver context management
+ *                                structure (cs_sles subsystem becomes owner)
+ * \param[in]       type_name     context structure or object type name
+ * \param[in]       setup_func    pointer to system setup function
+ * \param[in]       solve_func    pointer to system solution function (also
+ *                                calls setup_func if not done yet or free_func
+ *                                called since last solve)
+ * \param[in]       free_func     pointer function freeing system setup
+ * \param[in]       log_func      pointer to system info logging function
+                                  (optional, but recommended)
+ * \param[in]       copy_func     pointer to settings copy function (optional)
+ * \param[in]       destroy_func  pointer to function destroying solver context
+ *                                (called with \ref cs_sles_finalize or with a
+ *                                new call to this function for the same system)
  *
- * returns:
- *   pointer to associated linear system object
- *----------------------------------------------------------------------------*/
+ * \return  pointer to associated linear system object
+ */
+/*----------------------------------------------------------------------------*/
 
 cs_sles_t *
 cs_sles_define(int                 f_id,
@@ -454,90 +455,94 @@ cs_sles_define(int                 f_id,
                cs_sles_copy_t     *copy_func,
                cs_sles_destroy_t  *destroy_func);
 
-/*----------------------------------------------------------------------------
- * Set the verbosity for a given linear equation solver.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Set the verbosity for a given linear equation solver.
  *
- * This verbosity will be used by cs_sles_setup() and cs_sles_solve().
+ * This verbosity will be used by cs_sles_setup and cs_sles_solve.
  *
  * By default, the verbosity is set to 0, or the value returned by the
  * function set with cs_sles_set_default_define().
  *
- * parameters
- *   sles      <-> pointer to solver object
- *   verbosity <-- verbosity level
- *----------------------------------------------------------------------------*/
+ * \param[in, out]  sles       pointer to solver object
+ * \param[in]       verbosity  verbosity level
+ */
+/*----------------------------------------------------------------------------*/
 
 void
 cs_sles_set_verbosity(cs_sles_t  *sles,
                       int         verbosity);
 
-/*----------------------------------------------------------------------------
- * Return type name of solver context.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Return type name of solver context.
  *
  * The returned string is intended to help determine which type is associated
- * with the void * pointer returned by cs_sles_get_context() for a given
+ * with the void * pointer returned by \ref cs_sles_get_context for a given
  * solver definition, so as to be able to call additional specific functions
  * beyond the generic functions assigned to a cs_sles_t object.
  *
  * If no type_name string was associated to the solver upon its definition by
- * cs_sles_define(), or it has not been defined yet, the string returned
+ * \ref cs_sles_define, or it has not been defined yet, the string returned
  * is "<undefined>". It is recommended the type name provided
- * cs_sles_define() directly relate to the associated structure type
+ * \ref cs_sles_define directly relate to the associated structure type
  * (for example, "cs_sles_it_t" or "cs_multigrid_t").
  *
- * parameters
- *   sles  pointer to solver object
+ * \param[in]  sles  pointer to solver object
  *
- * returns:
- *   pointer to linear system solver specific type name
- *----------------------------------------------------------------------------*/
+ * \return  pointer to linear system solver specific type name
+ */
+/*----------------------------------------------------------------------------*/
 
 const char *
 cs_sles_get_type(cs_sles_t  *sles);
 
-/*----------------------------------------------------------------------------
- * Return pointer to solver context structure pointer.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Return pointer to solver context structure pointer.
  *
  * The context structure depends on the type of solver used, which may in
  * turn be determined by the string returned by cs_sles_get_type().
  * If may be used by appropriate functions specific to that type.
  *
- * parameters
- *   sles  pointer to solver object
+ * \param[in]  sles  pointer to solver object
  *
- * returns:
- *   pointer to solver-specific linear system info and context
-*----------------------------------------------------------------------------*/
+ * \return  pointer to solver-specific linear system info and context
+ */
+/*----------------------------------------------------------------------------*/
 
 void *
 cs_sles_get_context(cs_sles_t  *sles);
 
-/*----------------------------------------------------------------------------
- * Setup sparse linear equation solver.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Setup sparse linear equation solver.
+ *
+ * Use of this function is optional: if a \ref cs_sles_solve is called
+ * for the same system before this function is called, the latter will be
+ * called automatically.
  *
  * If no options were previously provided for the matching system,
  * default options will be used.
  *
- * parameters:
- *   sles <-> pointer to solver object
- *   a    <-- matrix
- *
- * returns:
- *   convergence state
- *----------------------------------------------------------------------------*/
+ * \param[in, out]  sles  pointer to solver object
+ * \param[in]       a     matrix
+ */
+/*----------------------------------------------------------------------------*/
 
 void
 cs_sles_setup(cs_sles_t          *sles,
               const cs_matrix_t  *a);
 
-/*----------------------------------------------------------------------------
- * General sparse linear system resolution.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief General sparse linear system resolution.
  *
  * If no options were previously provided for the matching system,
  * default options will be used.
  *
- * Note that if cs_sles_setup() was previously called for this
- * system, and cs_sles_free() has not been called since, the matrix
+ * Note that if \ref cs_sles_setup was previously called for this
+ * system, and \ref cs_sles_free has not been called since, the matrix
  * provided should be the same. The optional separation between the
  * two stages is intended to allow amortizing the cost of setup
  * over multiple solutions.
@@ -545,22 +550,22 @@ cs_sles_setup(cs_sles_t          *sles,
  * The system is considered to have converged when
  * residue/r_norm <= precision, residue being the L2 norm of a.vx-rhs.
  *
- * parameters:
- *   sles          <-> pointer to solver object
- *   a             <-- matrix
- *   rotation_mode <-- halo update option for rotational periodicity
- *   precision     <-- solver precision
- *   r_norm        <-- residue normalization
- *   n_iter        --> number of "equivalent" iterations
- *   residue       --> residue
- *   rhs           <-- right hand side
- *   vx            <-> system solution
- *   aux_size      <-- size of aux_vectors (in bytes)
- *   aux_vectors   --- optional working area (internal allocation if NULL)
+ * \param[in, out]  sles           pointer to solver object
+ * \param[in]       a              matrix
+ * \param[in]       rotation_mode  halo update option for rotational periodicity
+ * \param[in]       precision      solver precision
+ * \param[in]       r_norm         residue normalization
+ * \param[out]      n_iter         number of "equivalent" iterations
+ * \param[out]      residue        residue
+ * \param[in]       rhs            right hand side
+ * \param[in, out]  vx             system solution
+ * \param[in]       aux_size       size of aux_vectors (in bytes)
+ * \param           aux_vectors    optional working area
+ *                                 (internal allocation if NULL)
  *
- * returns:
- *   convergence state
- *----------------------------------------------------------------------------*/
+ * \return  convergence state
+ */
+/*----------------------------------------------------------------------------*/
 
 cs_sles_convergence_state_t
 cs_sles_solve(cs_sles_t           *sles,
@@ -575,50 +580,52 @@ cs_sles_solve(cs_sles_t           *sles,
               size_t               aux_size,
               void                *aux_vectors);
 
-/*----------------------------------------------------------------------------
- * Free sparse linear equation solver setup.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Free sparse linear equation solver setup.
  *
  * This function frees resolution-related data, such as multigrid hierarchy,
  * preconditioning, and any other temporary arrays or objects required for
  * resolution, but maintains context information such as that used for
  * logging (especially performance data).
  *
- * parameters:
- *   sles <-> pointer to solver object
- *----------------------------------------------------------------------------*/
+ * \param[in, out]  sles  pointer to solver object
+ */
+/*----------------------------------------------------------------------------*/
 
 void
 cs_sles_free(cs_sles_t  *sles);
 
-/*----------------------------------------------------------------------------
- * Copy the definition of a sparse linear equation solver to another.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Copy the definition of a sparse linear equation solver to another.
  *
  * The intended use of this function is to allow associating different
  * solvers to related systems, so as to differentiate logging, while using
- * the same setttings by default.
+ * the same settings by default.
  *
- * If the source solver does not provide a cs_sles_copy_t function,
+ * If the source solver does not provide a \ref cs_sles_copy_t function,
  * No modification is done to the solver. If the copy function is available,
  * the context is copied, as are the matching function pointers.
  *
  * If previous settings have been defined and used, they are saved as
- * per cs_sles_define().
+ * per \ref cs_sles_define.
  *
- * parameters:
- *   dest <-> pointer to destination solver object
- *   src  <-- pointer to source solver object
+ * \param[in, out]  dest  pointer to destination solver object
+ * \param[in]       src   pointer to source solver object
  *
- * returns:
- *   0 in case of success, 1 in case of failure
- *----------------------------------------------------------------------------*/
+ * \return  0 in case of success, 1 in case of failure
+ */
+/*----------------------------------------------------------------------------*/
 
 int
 cs_sles_copy(cs_sles_t        *dest,
              const cs_sles_t  *src);
 
-/*----------------------------------------------------------------------------
- * Associate a convergence error handler to a given sparse linear
- * equation solver.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Associate a convergence error handler to a given sparse linear
+ *        equation solver.
  *
  * The error will be called whenever convergence fails. To dissassociate
  * the error handler, this function may be called with \p handler = NULL.
@@ -626,78 +633,57 @@ cs_sles_copy(cs_sles_t        *dest,
  * The association will only be successful if the matching solver
  * has already been defined.
  *
- * parameters:
- *   sles               <-> pointer to solver object
- *   error_handler_func <-- pointer to convergence error handler function
- *----------------------------------------------------------------------------*/
+ * \param[in, out]  sles                pointer to solver object
+ * \param[in]       error_handler_func  pointer to convergence error
+ *                                      handler function
+ */
+/*----------------------------------------------------------------------------*/
 
 void
 cs_sles_set_error_handler(cs_sles_t                *sles,
                           cs_sles_error_handler_t  *error_handler_func);
 
-/*----------------------------------------------------------------------------
- * Set default sparse linear solver definition function.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Set default sparse linear solver definition function.
  *
  * The provided function will be used to provide a definition when
- * cs_sles_setup() or cs_sles_solve() is used for a system for which no
- * matching call to cs_sles_define() has been done.
+ * \ref cs_sles_setup or \ref cs_sles_solve is used for a system for which no
+ * matching call to \ref cs_sles_define has been done.
  *
- * parameters:
- *   define_func <-- pointer to default definition function
- *----------------------------------------------------------------------------*/
+ * \param[in]  define_func pointer to default definition function
+ */
+/*----------------------------------------------------------------------------*/
 
 void
 cs_sles_set_default_define(cs_sles_define_t  *define_func);
 
-/*----------------------------------------------------------------------------
- * Set default verbosity definition function.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Set default verbosity definition function.
  *
  * The provided function will be used to define the verbosity when
- * cs_sles_default_verbosity() is called.
+ * \ref cs_sles_find_or_add is called.
  *
- * parameters:
- *   verbosity_func <-- pointer to default verbosity function
- *----------------------------------------------------------------------------*/
+ * \param[in]  verbosity_func pointer to default verbosity function
+ */
+/*----------------------------------------------------------------------------*/
 
 void
 cs_sles_set_default_verbosity(cs_sles_verbosity_t  *verbosity_func);
 
-/*----------------------------------------------------------------------------
- * Test if a linear system needs solving or if the residue is already
- * within convergence criteria.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Output default post-processing data for failed system convergence.
  *
- * parameters:
- *   solver_name <-- name of the solver calling the test
- *   system_name <-- name of the linear system tested
- *   verbosity   <-- verbosity level
- *   precision   <-- solver precision
- *   r_norm      <-- residue normalization
- *   residue     <-- residue
- *
- * returns:
- *   1 if solving is required, 0 if the residue is already zero within
- *   tolerance criteria (precision of residue normalization)
- *----------------------------------------------------------------------------*/
-
-int
-cs_sles_needs_solving(const char  *solver_name,
-                      const char  *system_name,
-                      int          verbosity,
-                      double       precision,
-                      double       r_norm,
-                      double       residue);
-
-/*----------------------------------------------------------------------------
- * Output default post-processing data for failed system convergence.
- *
- * parameters:
- *   name             <-- variable name
- *   mesh_id          <-- id of error output mesh, or 0 if none
- *   rotation_mode    <-- halo update option for rotational periodicity
- *   a                <-- linear equation matrix
- *   rhs              <-- right hand side
- *   vx               <-> current system solution
- *----------------------------------------------------------------------------*/
+ * \param[in]       name           variable name
+ * \param[in]       mesh_id        id of error output mesh, or 0 if none
+ * \param[in]       rotation_mode  halo update option for rotational periodicity
+ * \param[in]       a              linear equation matrix
+ * \param[in]       rhs            right hand side
+ * \param[in, out]  vx             current system solution
+ */
+/*----------------------------------------------------------------------------*/
 
 void
 cs_sles_post_error_output_def(const char          *name,
@@ -707,15 +693,16 @@ cs_sles_post_error_output_def(const char          *name,
                               const cs_real_t     *rhs,
                               cs_real_t           *vx);
 
-/*----------------------------------------------------------------------------
- * Output post-processing variable for failed system convergence.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Output post-processing variable for failed system convergence.
  *
- * parameters:
- *   name            <-- variable name
- *   diag_block_size <-- block size for diagonal
- *   mesh_id         <-- id of error output mesh, or 0 if none
- *   var             <-> variable values
- *----------------------------------------------------------------------------*/
+ * \param[in]       name             variable name
+ * \param[in]       mesh_id          id of error output mesh, or 0 if none
+ * \param[in]       diag_block_size  block size for diagonal
+ * \param[in, out]  var              variable values
+ */
+/*----------------------------------------------------------------------------*/
 
 void
 cs_sles_post_error_output_var(const char  *name,
@@ -723,19 +710,19 @@ cs_sles_post_error_output_var(const char  *name,
                               int          diag_block_size,
                               cs_real_t   *var);
 
-/*----------------------------------------------------------------------------*
- * Return base name associated to a field id, name couple.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Return base name associated to a field id, name couple.
  *
  * This is simply a utility function which will return its name argument
  * if f_id < 0, and the associated field's name or label otherwise.
  *
- * parameters:
- *   f_id <-- associated field id, or < 0
- *   name <-- associated name if f_id < 0, or NULL
+ * \param[in]  f_id  associated field id, or < 0
+ * \param[in]  name  associated name if f_id < 0, or NULL
  *
- * returns:
- *   pointer to associated linear system object, or NULL
- *----------------------------------------------------------------------------*/
+ * \return  pointer to associated linear system object, or NULL
+ */
+/*----------------------------------------------------------------------------*/
 
 const char *
 cs_sles_base_name(int          f_id,
