@@ -390,9 +390,8 @@ _cs_ksp_converged(KSP                  ksp,
  * of the option used.
  *
  * Note that this function returns a pointer directly to the iterative solver
- * management structure. This may be used to set further options,
- * for example using \ref cs_sles_petsc_set_plot_options. If needed,
- * \ref cs_sles_find may be used to obtain a pointer to the matching
+ * management structure. This may be used to set further options.
+ * If needed, \ref cs_sles_find may be used to obtain a pointer to the matching
  * \ref cs_sles_t container.
  *
  * \param[in]      f_id          associated field id, or < 0
@@ -466,10 +465,12 @@ cs_sles_petsc_create(MatType                      matrix_type,
 
   PetscInitialized(&is_initialized);
   if (is_initialized == PETSC_FALSE) {
+#if defined(HAVE_MPI)
     if (cs_glob_n_ranks > 1)
       PETSC_COMM_WORLD = cs_glob_mpi_comm;
     else
       PETSC_COMM_WORLD = MPI_COMM_SELF;
+#endif
     PetscInitializeNoArguments();
   }
 
@@ -1103,7 +1104,7 @@ cs_sles_petsc_setup(void               *context,
 
   /* KSPSetup could be called here for better separation of setup/solve
      logging, but calling it systematically seems to cause issues
-     at least with the performance of the GAMG preconditionner
+     at least with the performance of the GAMG preconditioner
      (possibly calling unneed operations). So we avoid it for now,
      noting that the user always has to option of calling it at the
      end of the setup hook. */
