@@ -206,6 +206,8 @@ cs_run(void)
 
   cs_preprocessor_data_read_headers(cs_glob_mesh,
                                     cs_glob_mesh_builder);
+  if (!opts.cdo)
+    opts.cdo = cs_user_cdo_activated();
 
   /* Initialize Fortran API and calculation setup */
 
@@ -308,13 +310,7 @@ cs_run(void)
     cs_gradient_initialize();
     cs_gradient_perio_initialize();
 
-    if (opts.cdo) { /* CDO kernel mode */
-
-      cs_cdo_main(cs_glob_mesh,
-                  cs_glob_mesh_quantities);
-
-    }
-    else if (opts.verif == false) {
+    if (opts.verif == false) {
 
       /* Initialize sparse linear systems resolution */
 
@@ -331,25 +327,38 @@ cs_run(void)
 
       if (cs_user_solver_set() == 0) {
 
-        /* Additional initializations required by some models */
+        if (opts.cdo) {
 
-        cs_fan_build_all(cs_glob_mesh, cs_glob_mesh_quantities);
+          /*----------------------------------------------
+           * Call main calculation function (CDO Kernel)
+           *----------------------------------------------*/
 
-        /*----------------------------------------------
-         * Call main calculation function (code Kernel)
-         *----------------------------------------------*/
+          cs_cdo_main(cs_glob_mesh, cs_glob_mesh_quantities);
 
-        CS_PROCF(caltri, CALTRI)();
+        }
+        else {
+
+          /* Additional initializations required by some models */
+
+          cs_fan_build_all(cs_glob_mesh, cs_glob_mesh_quantities);
+
+          /*----------------------------------------------
+           * Call main calculation function (code Kernel)
+           *----------------------------------------------*/
+
+          CS_PROCF(caltri, CALTRI)();
+
+        }
 
       }
       else {
 
-        /*--------------------------------
-         * Call user calculation function
-         *--------------------------------*/
+          /*--------------------------------
+           * Call user calculation function
+           *--------------------------------*/
 
-        cs_user_solver(cs_glob_mesh,
-                       cs_glob_mesh_quantities);
+          cs_user_solver(cs_glob_mesh,
+                         cs_glob_mesh_quantities);
 
       }
 
