@@ -71,6 +71,7 @@ use ihmpre
 use cplsat
 use mesh
 use field
+use cs_c_bindings
 
 !===============================================================================
 
@@ -81,11 +82,11 @@ implicit none
 ! Local variables
 
 integer          ii
-integer          ifcvsl, kislts, ifctsl
-integer          iflid, iflidp, iopchr, ivar
-integer          itycat, ityloc, idim1, idim3, idimf
+integer          ifcvsl, kislts, ifctsl, kbfid
+integer          iflid, iopchr
+integer          itycat, ityloc, idim1, idim3
 logical          ilved, iprev, inoprv, is_set
-integer          f_id, f_loc
+integer          f_id
 
 character(len=80) :: name, f_name, f_label, s_label, s_name
 
@@ -109,37 +110,14 @@ inoprv = .false.   ! variables have no previous value
 iopchr = 1         ! Postprocessing level for variables
 
 !===============================================================================
-! 1. Initialisation
+! 1. Initialization
 !===============================================================================
 
-! Add weight field for variable to compute gradient
-iflidp = -1
-itycat = FIELD_PROPERTY
-ityloc = 1         ! variables defined on cells
-ilved  = .true.    ! interleaved by default
-inoprv = .false.   ! variables have no previous value
-iopchr = 0         ! Postprocessing level for variables
-idimf  = -1        ! Field dimension
+call field_get_key_id("boundary_value_id", kbfid)
 
-do ivar = 1, nvar
-  if (iwgrec(ivar).eq.1) then
-
-    if (idiff(ivar).lt.1) cycle
-    iflid = ivarfl(ivar)
-    if (iflid.eq.iflidp) cycle
-    iflidp = iflid
-    call field_get_name(iflid, name)
-    f_name = 'gradient_weighting_'//trim(name)
-    if (idften(ivar).eq.1) then
-      idimf = 1
-    elseif (idften(ivar).eq.6) then
-      idimf = 6
-    endif
-    call field_create(f_name, itycat, ityloc, idimf, ilved, inoprv, f_id)
-    call field_set_key_int(iflid, kwgrec, f_id)
-
-  endif
-enddo
+call field_get_key_id('log', keylog)
+call field_get_key_id('post_vis', keyvis)
+call field_get_key_id('label', keylbl)
 
 !===============================================================================
 ! 2. Additional property fields
@@ -205,24 +183,30 @@ do ii = 1, nscal
   endif
 enddo
 
+! Boundary roughness
+if (iwallf.ge.5) then
+  call add_boundary_property_field_owner('boundary_roughness', 'Boundary Roughness', &
+                                         iflid)
+endif
+
 !===============================================================================
 ! 3. Additional postprocessing fields
 !===============================================================================
 
 ! Fields used to save postprocessing data
 
-itycat = FIELD_INTENSIVE + FIELD_PROPERTY
 ityloc = 3 ! boundary faces
 
-! If postprocessing of boundary temperature or boundary layer Nusselt required,
+itycat = FIELD_INTENSIVE + FIELD_PROPERTY
+
+! If postprocessing of boundary layer Nusselt required,
 ! create appropriate fields; check that a thermal variable is present first
 
 if (iscalt.le.0) then
-  ipstdv(ipsttb) = 0
   ipstdv(ipstnu) = 0
 endif
 
-if (ipstdv(ipsttb).gt.0 .or. ipstdv(ipstnu).gt.0) then
+if (ipstdv(ipstnu).gt.0) then
   call field_find_or_create('tplus', itycat, ityloc, idim1, ilved, iflid)
   call field_find_or_create('tstar', itycat, ityloc, idim1, ilved, iflid)
 endif
@@ -275,6 +259,21 @@ do ii = 1, nvar
   endif
 enddo
 
+! Some mappings
+
+call cs_field_pointer_map_boundary
+
+call field_get_id_try('boundary_temperature', itempb)
+
+if (itempb .ge. 0) then
+  call field_get_id_try('temperature', f_id)
+  if (f_id .lt. 0) call field_get_id_try('t_gas', f_id)
+  if (f_id .ge. 0) then
+    call field_get_label(f_id, f_label)
+    call field_set_key_str(itempb, keylbl, f_label)
+  endif
+endif
+
 !---
 ! Formats
 !---
