@@ -111,7 +111,6 @@ integer          nent
 integer          stats_id, restart_stats_id, lagr_stats_id, post_stats_id
 
 double precision titer1, titer2
-double precision tecrf1, tecrf2
 
 integer          ivoid(1)
 double precision rvoid(1)
@@ -251,7 +250,7 @@ allocate(izft1d(nfabor))
 if (iihmpr.eq.1) then
   call uikpdc &
 ( iappel ,          &
-  ncelet , ncepdc , &
+  ncepdc ,          &
   ivoid  ,          &
   rvoid  )
 endif
@@ -483,6 +482,8 @@ endif
 ! Memory reservation for Lagrangian module
 if (iilagr.gt.0) then
 
+  call init_lagr_arrays
+
   allocate(icocel(lndnod), itycel(ncelet+1))
   allocate(ifrlag(nfabor))
 
@@ -511,7 +512,7 @@ call iniva0(nvar, nscal, dt, propce, frcxt, prhyd)
 if (iporos.ge.1) then
 
   if (iihmpr.eq.1) then
-    call uiporo(ncelet, iporos)
+    call uiporo(iporos)
   endif
   call usporo
 
@@ -765,7 +766,7 @@ if (ncpdct.gt.0) then
   endif
 
   if (iihmpr.eq.1) then
-    call uikpdc(iappel, ncelet, ncepdc, icepdc, ckupdc)
+    call uikpdc(iappel, ncepdc, icepdc, ckupdc)
   endif
 
   call cs_user_head_losses &
@@ -968,10 +969,7 @@ if (itrale.gt.0) then
   ! Sortie postprocessing de profils 1D
 
   if (iihmpr.eq.1) then
-    call uiprof                                                   &
-  ( ncelet , ncel,                                                &
-    ntmabs, ntcabs, ttcabs, ttmabs, ttpabs,                       &
-    xyzcen)
+    call uiprof()
   endif
 
   call cs_f_user_extra_operations &
@@ -1254,6 +1252,8 @@ if (iilagr.gt.0) then
 
   if (associated(dlgeo)) deallocate(dlgeo)
 
+  call finalize_lagr_arrays
+
 endif
 
 call turbomachinery_finalize
