@@ -155,7 +155,6 @@ integer          iscal
 integer          modntl
 integer          iuntur, iuiptn
 integer          ifccp
-integer          yplus_id
 
 double precision rnx, rny, rnz, rxnn
 double precision tx, ty, tz, txn, txn0, t2x, t2y, t2z
@@ -182,7 +181,7 @@ double precision fcoefa(6), fcoefb(6), fcofaf(6), fcofbf(6), fcofad(6), fcofbd(6
 
 double precision, dimension(:), pointer :: crom
 double precision, dimension(:), pointer :: viscl, visct, cpro_cp, yplbr
-double precision, dimension(:), allocatable :: byplus, buk, buet, buplus, bcfnns
+double precision, dimension(:), allocatable :: byplus, buk, buet, bcfnns
 
 double precision, dimension(:), pointer :: cvar_k
 double precision, dimension(:), pointer :: cvar_r11, cvar_r22, cvar_r33
@@ -205,6 +204,8 @@ double precision, dimension(:), pointer :: coefa_r13, coefaf_r13, coefad_r13
 double precision, dimension(:), pointer :: coefb_r13, coefbf_r13, coefbd_r13
 double precision, dimension(:), pointer :: coefa_r23, coefaf_r23, coefad_r23
 double precision, dimension(:), pointer :: coefb_r23, coefbf_r23, coefbd_r23
+double precision, dimension(:,:), pointer :: coefa_rij, coefaf_rij, coefad_rij
+double precision, dimension(:,:,:), pointer :: coefb_rij, coefbf_rij, coefbd_rij
 double precision, dimension(:), pointer :: coefa_omg, coefaf_omg
 double precision, dimension(:), pointer :: coefb_omg, coefbf_omg
 double precision, dimension(:), pointer :: coefa_al, coefaf_al
@@ -255,9 +256,8 @@ deuxd0 = 2.d0
 
 yplbr => null()
 
-call field_get_id_try('yplus', yplus_id)
-if (yplus_id.ge.0) then
-  call field_get_val_s(yplus_id, yplbr)
+if (iyplbr.ge.0) then
+  call field_get_val_s(iyplbr, yplbr)
 endif
 
 ! --- Gradient and flux Boundary Conditions
@@ -291,99 +291,109 @@ else
   coefbf_ep => null()
 endif
 
-if (ir11.gt.0) then ! Also have boundary conditions for the momentum equation
+if (itytur.eq.3) then! Also have boundary conditions for the momentum equation
 
-  call field_get_coefa_s(ivarfl(ir11), coefa_r11)
-  call field_get_coefb_s(ivarfl(ir11), coefb_r11)
-  call field_get_coefaf_s(ivarfl(ir11), coefaf_r11)
-  call field_get_coefbf_s(ivarfl(ir11), coefbf_r11)
-  call field_get_coefad_s(ivarfl(ir11), coefad_r11)
-  call field_get_coefbd_s(ivarfl(ir11), coefbd_r11)
+  if (irijco.eq.1) then
+    call field_get_coefa_v(ivarfl(irij), coefa_rij)
+    call field_get_coefb_v(ivarfl(irij), coefb_rij)
+    call field_get_coefaf_v(ivarfl(irij), coefaf_rij)
+    call field_get_coefbf_v(ivarfl(irij), coefbf_rij)
+    call field_get_coefad_v(ivarfl(irij), coefad_rij)
+    call field_get_coefbd_v(ivarfl(irij), coefbd_rij)
 
-  call field_get_coefa_s(ivarfl(ir22), coefa_r22)
-  call field_get_coefb_s(ivarfl(ir22), coefb_r22)
-  call field_get_coefaf_s(ivarfl(ir22), coefaf_r22)
-  call field_get_coefbf_s(ivarfl(ir22), coefbf_r22)
-  call field_get_coefad_s(ivarfl(ir22), coefad_r22)
-  call field_get_coefbd_s(ivarfl(ir22), coefbd_r22)
+    coefb_r11 => null()
+    coefaf_r11 => null()
+    coefbf_r11 => null()
+    coefad_r11 => null()
+    coefbd_r11 => null()
 
-  call field_get_coefa_s(ivarfl(ir33), coefa_r33)
-  call field_get_coefb_s(ivarfl(ir33), coefb_r33)
-  call field_get_coefaf_s(ivarfl(ir33), coefaf_r33)
-  call field_get_coefbf_s(ivarfl(ir33), coefbf_r33)
-  call field_get_coefad_s(ivarfl(ir33), coefad_r33)
-  call field_get_coefbd_s(ivarfl(ir33), coefbd_r33)
+    coefa_r22 => null()
+    coefb_r22 => null()
+    coefaf_r22 => null()
+    coefbf_r22 => null()
+    coefad_r22 => null()
+    coefbd_r22 => null()
 
-  call field_get_coefa_s(ivarfl(ir12), coefa_r12)
-  call field_get_coefb_s(ivarfl(ir12), coefb_r12)
-  call field_get_coefaf_s(ivarfl(ir12), coefaf_r12)
-  call field_get_coefbf_s(ivarfl(ir12), coefbf_r12)
-  call field_get_coefad_s(ivarfl(ir12), coefad_r12)
-  call field_get_coefbd_s(ivarfl(ir12), coefbd_r12)
+    coefa_r33 => null()
+    coefb_r33 => null()
+    coefaf_r33 => null()
+    coefbf_r33 => null()
+    coefad_r33 => null()
+    coefbd_r33 => null()
 
-  call field_get_coefa_s(ivarfl(ir13), coefa_r13)
-  call field_get_coefb_s(ivarfl(ir13), coefb_r13)
-  call field_get_coefaf_s(ivarfl(ir13), coefaf_r13)
-  call field_get_coefbf_s(ivarfl(ir13), coefbf_r13)
-  call field_get_coefad_s(ivarfl(ir13), coefad_r13)
-  call field_get_coefbd_s(ivarfl(ir13), coefbd_r13)
+    coefa_r12 => null()
+    coefb_r12 => null()
+    coefaf_r12 => null()
+    coefbf_r12 => null()
+    coefad_r12 => null()
+    coefbd_r12 => null()
 
-  call field_get_coefa_s(ivarfl(ir23), coefa_r23)
-  call field_get_coefb_s(ivarfl(ir23), coefb_r23)
-  call field_get_coefaf_s(ivarfl(ir23), coefaf_r23)
-  call field_get_coefbf_s(ivarfl(ir23), coefbf_r23)
-  call field_get_coefad_s(ivarfl(ir23), coefad_r23)
-  call field_get_coefbd_s(ivarfl(ir23), coefbd_r23)
+    coefa_r13 => null()
+    coefb_r13 => null()
+    coefaf_r13 => null()
+    coefbf_r13 => null()
+    coefad_r13 => null()
+    coefbd_r13 => null()
 
-  call field_get_coefa_s(ivarfl(iep), coefa_ep)
-  call field_get_coefb_s(ivarfl(iep), coefb_ep)
-  call field_get_coefaf_s(ivarfl(iep), coefaf_ep)
-  call field_get_coefbf_s(ivarfl(iep), coefbf_ep)
+    coefa_r23 => null()
+    coefb_r23 => null()
+    coefaf_r23 => null()
+    coefbf_r23 => null()
+    coefad_r23 => null()
+    coefbd_r23 => null()
 
-else
 
-  coefa_r11 => null()
-  coefb_r11 => null()
-  coefaf_r11 => null()
-  coefbf_r11 => null()
-  coefad_r11 => null()
-  coefbd_r11 => null()
+  else
 
-  coefa_r22 => null()
-  coefb_r22 => null()
-  coefaf_r22 => null()
-  coefbf_r22 => null()
-  coefad_r22 => null()
-  coefbd_r22 => null()
+    call field_get_coefa_s(ivarfl(ir11), coefa_r11)
+    call field_get_coefb_s(ivarfl(ir11), coefb_r11)
+    call field_get_coefaf_s(ivarfl(ir11), coefaf_r11)
+    call field_get_coefbf_s(ivarfl(ir11), coefbf_r11)
+    call field_get_coefad_s(ivarfl(ir11), coefad_r11)
+    call field_get_coefbd_s(ivarfl(ir11), coefbd_r11)
 
-  coefa_r33 => null()
-  coefb_r33 => null()
-  coefaf_r33 => null()
-  coefbf_r33 => null()
-  coefad_r33 => null()
-  coefbd_r33 => null()
+    call field_get_coefa_s(ivarfl(ir22), coefa_r22)
+    call field_get_coefb_s(ivarfl(ir22), coefb_r22)
+    call field_get_coefaf_s(ivarfl(ir22), coefaf_r22)
+    call field_get_coefbf_s(ivarfl(ir22), coefbf_r22)
+    call field_get_coefad_s(ivarfl(ir22), coefad_r22)
+    call field_get_coefbd_s(ivarfl(ir22), coefbd_r22)
 
-  coefa_r12 => null()
-  coefb_r12 => null()
-  coefaf_r12 => null()
-  coefbf_r12 => null()
-  coefad_r12 => null()
-  coefbd_r12 => null()
+    call field_get_coefa_s(ivarfl(ir33), coefa_r33)
+    call field_get_coefb_s(ivarfl(ir33), coefb_r33)
+    call field_get_coefaf_s(ivarfl(ir33), coefaf_r33)
+    call field_get_coefbf_s(ivarfl(ir33), coefbf_r33)
+    call field_get_coefad_s(ivarfl(ir33), coefad_r33)
+    call field_get_coefbd_s(ivarfl(ir33), coefbd_r33)
 
-  coefa_r13 => null()
-  coefb_r13 => null()
-  coefaf_r13 => null()
-  coefbf_r13 => null()
-  coefad_r13 => null()
-  coefbd_r13 => null()
+    call field_get_coefa_s(ivarfl(ir12), coefa_r12)
+    call field_get_coefb_s(ivarfl(ir12), coefb_r12)
+    call field_get_coefaf_s(ivarfl(ir12), coefaf_r12)
+    call field_get_coefbf_s(ivarfl(ir12), coefbf_r12)
+    call field_get_coefad_s(ivarfl(ir12), coefad_r12)
+    call field_get_coefbd_s(ivarfl(ir12), coefbd_r12)
 
-  coefa_r23 => null()
-  coefb_r23 => null()
-  coefaf_r23 => null()
-  coefbf_r23 => null()
-  coefad_r23 => null()
-  coefbd_r23 => null()
+    call field_get_coefa_s(ivarfl(ir13), coefa_r13)
+    call field_get_coefb_s(ivarfl(ir13), coefb_r13)
+    call field_get_coefaf_s(ivarfl(ir13), coefaf_r13)
+    call field_get_coefbf_s(ivarfl(ir13), coefbf_r13)
+    call field_get_coefad_s(ivarfl(ir13), coefad_r13)
+    call field_get_coefbd_s(ivarfl(ir13), coefbd_r13)
 
+    call field_get_coefa_s(ivarfl(ir23), coefa_r23)
+    call field_get_coefb_s(ivarfl(ir23), coefb_r23)
+    call field_get_coefaf_s(ivarfl(ir23), coefaf_r23)
+    call field_get_coefbf_s(ivarfl(ir23), coefbf_r23)
+    call field_get_coefad_s(ivarfl(ir23), coefad_r23)
+    call field_get_coefbd_s(ivarfl(ir23), coefbd_r23)
+
+    coefa_rij => null()
+    coefb_rij => null()
+    coefaf_rij => null()
+    coefbf_rij => null()
+    coefad_rij => null()
+    coefbd_rij => null()
+  endif
 endif
 
 if (ial.gt.0) then
@@ -508,7 +518,6 @@ endif
 allocate(byplus(nfabor))
 allocate(buk(nfabor))
 allocate(buet(nfabor))
-allocate(buplus(nfabor))
 allocate(bcfnns(nfabor))
 
 ! --- Loop on boundary faces
@@ -696,7 +705,7 @@ do ifac = 1, nfabor
     rugd=rcodcl(ifac,iu,3)
 
     ! NB: for rough walls, yplus is computed from the roughness and not uk.
-    yplus=distbf/rugd
+    yplus = distbf/rugd
 
     ! Pseudo shift of wall by rugd ((distbf+rugd)/rugd)
     uet = utau/log(yplus+1.d0)*xkappa
@@ -704,10 +713,10 @@ do ifac = 1, nfabor
     ! Dimensionless velocity
     uplus = log(yplus+1.d0)/xkappa
 
-    if (ideuch.eq.0) then
+    if (iwallf.le.2) then
       uk = uet
 
-    ! Si ideuch=1 ou 2 on calcule uk et uet
+    ! Si iwallf= 3, 4 ou 5 on calcule uk et uet
     else
 
       if (itytur.eq.2 .or. itytur.eq.5 .or. iturb.eq.60) then
@@ -736,7 +745,7 @@ do ifac = 1, nfabor
 
     endif
 
-    if (ideuch.eq.0) then
+    if (iwallf.le.2) then
       uk = uet
     endif
 
@@ -768,7 +777,7 @@ do ifac = 1, nfabor
     endif
 
     ! Save yplus if post-processed
-    if (yplus_id.ge.0) then
+    if (iyplbr.ge.0) then
       yplbr(ifac) = yplus
     endif
 
@@ -793,9 +802,8 @@ do ifac = 1, nfabor
         distb0=distbf+rugd
         xmutlm = xkappa*uk*distb0*romc
 
-        rcprod = max(distbf/distb0,                                &
-                     deuxd0*distbf/distb0*sqrt(xmutlm/visctc)      &
-                     - 1.d0/(2.d0+rugd/distb0))
+        rcprod = distbf/distb0*max(1.d0,                                &
+                     2.d0*sqrt(xmutlm/visctc) - distb0/distbf/(2.d0+rugd/distb0))
 
         rcflux = max(xmutlm,visctc)/(visclc+visctc)*distbf/distb0
 
@@ -971,10 +979,10 @@ do ifac = 1, nfabor
           jj = 1
           kk = 2
         else if (isou.eq.5) then
-          jj = 1
+          jj = 2
           kk = 3
         else if (isou.eq.6) then
-          jj = 2
+          jj = 1
           kk = 3
         endif
 
@@ -1002,51 +1010,60 @@ do ifac = 1, nfabor
         ! Translate into Diffusive flux BCs
         fcofaf(isou) = -hint*fcoefa(isou)
         fcofbf(isou) = hint*(1.d0-fcoefb(isou))
-
-        if (isou.eq.1) then
-          coefa_r11(ifac) = fcoefa(isou)
-          coefb_r11(ifac) = fcoefb(isou)
-          coefaf_r11(ifac) = fcofaf(isou)
-          coefbf_r11(ifac) = fcofbf(isou)
-          coefad_r11(ifac) = fcofad(isou)
-          coefbd_r11(ifac) = fcofbd(isou)
-        else if (isou.eq.2) then
-          coefa_r22(ifac) = fcoefa(isou)
-          coefb_r22(ifac) = fcoefb(isou)
-          coefaf_r22(ifac) = fcofaf(isou)
-          coefbf_r22(ifac) = fcofbf(isou)
-          coefad_r22(ifac) = fcofad(isou)
-          coefbd_r22(ifac) = fcofbd(isou)
-        else if (isou.eq.3) then
-          coefa_r33(ifac) = fcoefa(isou)
-          coefb_r33(ifac) = fcoefb(isou)
-          coefaf_r33(ifac) = fcofaf(isou)
-          coefbf_r33(ifac) = fcofbf(isou)
-          coefad_r33(ifac) = fcofad(isou)
-          coefbd_r33(ifac) = fcofbd(isou)
-        else if (isou.eq.4) then
-          coefa_r12(ifac) = fcoefa(isou)
-          coefb_r12(ifac) = fcoefb(isou)
-          coefaf_r12(ifac) = fcofaf(isou)
-          coefbf_r12(ifac) = fcofbf(isou)
-          coefad_r12(ifac) = fcofad(isou)
-          coefbd_r12(ifac) = fcofbd(isou)
-        else if (isou.eq.5) then
-          coefa_r13(ifac) = fcoefa(isou)
-          coefb_r13(ifac) = fcoefb(isou)
-          coefaf_r13(ifac) = fcofaf(isou)
-          coefbf_r13(ifac) = fcofbf(isou)
-          coefad_r13(ifac) = fcofad(isou)
-          coefbd_r13(ifac) = fcofbd(isou)
-        else if (isou.eq.6) then
-          coefa_r23(ifac) = fcoefa(isou)
-          coefb_r23(ifac) = fcoefb(isou)
-          coefaf_r23(ifac) = fcofaf(isou)
-          coefbf_r23(ifac) = fcofbf(isou)
-          coefad_r23(ifac) = fcofad(isou)
-          coefbd_r23(ifac) = fcofbd(isou)
+      enddo
+      do isou = 1, 6
+        if (irijco.eq.1) then
+          coefa_rij(isou, ifac)       = fcoefa(isou)
+          coefb_rij(isou,isou, ifac)  = fcoefb(isou)
+          coefaf_rij(isou, ifac)      = fcofaf(isou)
+          coefbf_rij(isou,isou, ifac) = fcofbf(isou)
+          coefad_rij(isou, ifac)      = fcofad(isou)
+          coefbd_rij(isou,isou, ifac) = fcofbd(isou)
+        else
+          if (isou.eq.1) then
+            coefa_r11(ifac) = fcoefa(isou)
+            coefb_r11(ifac) = fcoefb(isou)
+            coefaf_r11(ifac) = fcofaf(isou)
+            coefbf_r11(ifac) = fcofbf(isou)
+            coefad_r11(ifac) = fcofad(isou)
+            coefbd_r11(ifac) = fcofbd(isou)
+          else if (isou.eq.2) then
+            coefa_r22(ifac) = fcoefa(isou)
+            coefb_r22(ifac) = fcoefb(isou)
+            coefaf_r22(ifac) = fcofaf(isou)
+            coefbf_r22(ifac) = fcofbf(isou)
+            coefad_r22(ifac) = fcofad(isou)
+            coefbd_r22(ifac) = fcofbd(isou)
+          else if (isou.eq.3) then
+            coefa_r33(ifac) = fcoefa(isou)
+            coefb_r33(ifac) = fcoefb(isou)
+            coefaf_r33(ifac) = fcofaf(isou)
+            coefbf_r33(ifac) = fcofbf(isou)
+            coefad_r33(ifac) = fcofad(isou)
+            coefbd_r33(ifac) = fcofbd(isou)
+          else if (isou.eq.4) then
+            coefa_r12(ifac) = fcoefa(isou)
+            coefb_r12(ifac) = fcoefb(isou)
+            coefaf_r12(ifac) = fcofaf(isou)
+            coefbf_r12(ifac) = fcofbf(isou)
+            coefad_r12(ifac) = fcofad(isou)
+            coefbd_r12(ifac) = fcofbd(isou)
+          else if (isou.eq.5) then
+            coefa_r23(ifac) = fcoefa(isou)
+            coefb_r23(ifac) = fcoefb(isou)
+            coefaf_r23(ifac) = fcofaf(isou)
+            coefbf_r23(ifac) = fcofbf(isou)
+            coefad_r23(ifac) = fcofad(isou)
+            coefbd_r23(ifac) = fcofbd(isou)
+          else if (isou.eq.6) then
+            coefa_r13(ifac) = fcoefa(isou)
+            coefb_r13(ifac) = fcoefb(isou)
+            coefaf_r13(ifac) = fcofaf(isou)
+            coefbf_r13(ifac) = fcofbf(isou)
+            coefad_r13(ifac) = fcofad(isou)
+            coefbd_r13(ifac) = fcofbd(isou)
+          endif
         endif
-
       enddo
 
       ! ---> Epsilon
@@ -1238,7 +1255,6 @@ do ifac = 1, nfabor
     byplus(ifac) = yplus
     buk(ifac) = uk
     buet(ifac) = uet
-    buplus(ifac) = uplus
     bcfnns(ifac) = cfnns
 
   endif
@@ -1261,7 +1277,7 @@ do iscal = 1, nscal
     !=================
  ( iscal  , isvhb  , icodcl ,                                     &
    rcodcl ,                                                       &
-   byplus , buk    , buet   , buplus , bcfnns ,                   &
+   byplus , buk    , buet   , bcfnns ,                            &
    hbord  , theipb ,                                              &
    tetmax , tetmin , tplumx , tplumn )
 
@@ -1290,7 +1306,6 @@ endif
 deallocate(byplus)
 deallocate(buk)
 deallocate(buet)
-deallocate(buplus)
 deallocate(bcfnns)
 
 !===============================================================================
@@ -1453,7 +1468,6 @@ end subroutine
 !> \param[in]     byplus        dimensionless distance to the wall
 !> \param[in]     buk           dimensionless velocity
 !> \param[in]     buet          boundary ustar value
-!> \param[in]     buplus        boundary uplus value
 !> \param[in]     bcfnns        boundary correction factor
 !> \param[in,out] hbord         exchange coefficient at boundary
 !> \param[in]     theipb        boundary temperature in \f$ \centip \f$
@@ -1467,7 +1481,7 @@ end subroutine
 subroutine clptrg_scalar &
  ( iscal  , isvhb  , icodcl ,                                     &
    rcodcl ,                                                       &
-   byplus , buk    , buet   , buplus , bcfnns ,                   &
+   byplus , buk    , buet   , bcfnns ,                            &
    hbord  , theipb ,                                              &
    tetmax , tetmin , tplumx , tplumn )
 
@@ -1507,12 +1521,12 @@ integer          icodcl(nfabor,nvarcl)
 double precision rcodcl(nfabor,nvarcl,3)
 double precision byplus(nfabor)
 double precision hbord(nfabor), theipb(nfabor)
-double precision buk(nfabor), buet(nfabor), buplus(nfabor), bcfnns(nfabor)
+double precision buk(nfabor), buet(nfabor), bcfnns(nfabor)
 double precision tetmax, tetmin, tplumx, tplumn
 
 ! Local variables
 
-integer          ivar, f_id, isvhbl
+integer          ivar, f_id, b_f_id, isvhbl
 integer          ifac, iel, isou, jsou
 integer          ifccp, ifccv, ifcvsl, itplus, itstar
 
@@ -1526,7 +1540,7 @@ double precision visci(3,3), hintt(6)
 
 character(len=80) :: fname
 
-double precision, dimension(:), pointer :: val_s, crom, viscls
+double precision, dimension(:), pointer :: val_s, bval_s, crom, viscls
 double precision, dimension(:), pointer :: viscl, visct, cpro_cp, cv
 
 double precision, dimension(:), pointer :: bfconv, bhconv
@@ -1535,6 +1549,8 @@ double precision, dimension(:), pointer :: coefap, coefbp, cofafp, cofbfp
 double precision, dimension(:,:), pointer :: coefaut, cofafut, cofarut, visten
 double precision, dimension(:,:,:), pointer :: coefbut, cofbfut, cofbrut
 
+integer, save :: kbfid = -1
+
 !===============================================================================
 
 ivar = isca(iscal)
@@ -1613,6 +1629,9 @@ endif
 
 ! pointers to T+ and T* if saved
 
+itplus = -1
+itstar = -1
+
 tplusp => null()
 tstarp => null()
 
@@ -1631,6 +1650,21 @@ endif
 if (ifconv.ge.0) call field_get_val_s(ifconv, bfconv)
 if (ihconv.ge.0) call field_get_val_s(ihconv, bhconv)
 
+if (kbfid.lt.0) call field_get_key_id("boundary_value_id", kbfid)
+
+call field_get_key_int(f_id, kbfid, b_f_id)
+
+if (b_f_id .ge. 0) then
+  call field_get_val_s(b_f_id, bval_s)
+else
+  bval_s => null()
+  ! if thermal variable has no boundary but temperature does, use it
+  if (itherm.eq.2 .and. itempb.ge.0) then
+    b_f_id = itempb
+    call field_get_val_s(b_f_id, bval_s)
+  endif
+endif
+
 ! --- Loop on boundary faces
 do ifac = 1, nfabor
 
@@ -1927,7 +1961,9 @@ do ifac = 1, nfabor
     endif ! End if icodcl=6
 
     ! Save the value of T^star and T^+ for post-processing
-    if (iscal.eq.iscalt) then
+
+    if (b_f_id.ge.0 .or. iscal.eq.iscalt) then
+
       ! Rough wall function
       if (icodcl(ifac,ivar).eq.6) then
         phit = cofafp(ifac)+cofbfp(ifac)*theipb(ifac)
@@ -1940,13 +1976,18 @@ do ifac = 1, nfabor
 
       tet = phit/(romc*cpp*max(buet(ifac)*bcfnns(ifac),epzero))
 
+      if (b_f_id .ge. 0) bval_s(ifac) = bval_s(ifac) - tplus*tet
+
       if (itplus .ge. 0) tplusp(ifac) = tplus
       if (itstar .ge. 0) tstarp(ifac) = tet
 
-      tetmax = max(tet, tetmax)
-      tetmin = min(tet, tetmin)
-      tplumx = max(tplus,tplumx)
-      tplumn = min(tplus,tplumn)
+      if (iscal.eq.iscalt) then
+        tetmax = max(tet, tetmax)
+        tetmin = min(tet, tetmin)
+        tplumx = max(tplus,tplumx)
+        tplumn = min(tplus,tplumn)
+      endif
+
     endif
 
   endif ! rough wall condition
