@@ -156,8 +156,7 @@ integer          modntl
 integer          iuntur
 integer          nlogla, nsubla, iuiptn
 integer          ifccp
-integer          iwallf
-integer          yplus_id
+integer          f_id_rough
 
 double precision rnx, rny, rnz, rxnn
 double precision tx, ty, tz, txn, txn0, t2x, t2y, t2z
@@ -172,19 +171,24 @@ double precision rcprod
 double precision hflui, hint, pimp, qimp
 double precision eloglo(3,3), alpha(6,6)
 double precision rcodcx, rcodcy, rcodcz, rcodcn
-double precision visclc, visctc, romc  , distbf, srfbnf
+double precision visclc, visctc, romc  , distbf, srfbnf, efvisc
 double precision cofimp, ypup
 double precision bldr12
 double precision xkip
 double precision rinfiv(3)
 double precision visci(3,3), fikis, viscis, distfi
 double precision fcoefa(6), fcoefb(6), fcofaf(6), fcofbf(6), fcofad(6), fcofbd(6)
+double precision rxx, rxy, rxz, ryy, ryz, rzz, rnnb
+double precision roughness
 
 double precision, dimension(:), pointer :: crom
 double precision, dimension(:), pointer :: viscl, visct, cpro_cp, yplbr
+double precision, dimension(:), pointer :: bfpro_roughness
 double precision, dimension(:), allocatable :: byplus, bdplus, buk
 double precision, dimension(:), pointer :: cvar_k, cvar_ep
 double precision, dimension(:), pointer :: cvar_r11, cvar_r22, cvar_r33
+double precision, dimension(:), pointer :: cvar_r12, cvar_r13, cvar_r23
+double precision, dimension(:,:), pointer :: cvar_rij
 
 double precision, dimension(:,:), pointer :: coefau, cofafu, visten
 double precision, dimension(:,:,:), pointer :: coefbu, cofbfu
@@ -214,6 +218,9 @@ double precision, dimension(:), pointer :: coefb_fb, coefbf_fb
 double precision, dimension(:), pointer :: coefa_nu, coefaf_nu
 double precision, dimension(:), pointer :: coefb_nu, coefbf_nu
 
+double precision, dimension(:,:), pointer :: coefa_rij, coefaf_rij, coefad_rij
+double precision, dimension(:,:,:), pointer :: coefb_rij, coefbf_rij, coefbd_rij
+
 integer          ntlast , iaff
 data             ntlast , iaff /-1 , 0/
 save             ntlast , iaff
@@ -230,20 +237,25 @@ cofimp  = 0.d0
 ek = 0.d0
 rcprod = 0.d0
 uiptn = 0.d0
+rnnb = 0.d0
 
 rinfiv(1) = rinfin
 rinfiv(2) = rinfin
 rinfiv(3) = rinfin
 
-! --- Constants
 uet = 1.d0
 utau = 1.d0
+
+! --- Constants
 sqrcmu = sqrt(cmu)
 
 yplbr => null()
+bfpro_roughness => null()
 
-call field_get_id_try('yplus', yplus_id)
-if (yplus_id.ge.0) call field_get_val_s(yplus_id, yplbr)
+call field_get_id_try("boundary_roughness", f_id_rough)
+if (f_id_rough.ge.0) call field_get_val_s(f_id_rough, bfpro_roughness)
+
+if (iyplbr.ge.0) call field_get_val_s(iyplbr, yplbr)
 if (itytur.eq.3 .and. idirsm.eq.1) call field_get_val_v(ivsten, visten)
 
 ! --- Gradient and flux boundary conditions
@@ -277,99 +289,109 @@ else
   coefbf_ep => null()
 endif
 
-if (ir11.gt.0) then ! Also have boundary conditions for the momentum equation
+if (itytur.eq.3) then! Also have boundary conditions for the momentum equation
 
-  call field_get_coefa_s(ivarfl(ir11), coefa_r11)
-  call field_get_coefb_s(ivarfl(ir11), coefb_r11)
-  call field_get_coefaf_s(ivarfl(ir11), coefaf_r11)
-  call field_get_coefbf_s(ivarfl(ir11), coefbf_r11)
-  call field_get_coefad_s(ivarfl(ir11), coefad_r11)
-  call field_get_coefbd_s(ivarfl(ir11), coefbd_r11)
+  if (irijco.eq.1) then
+    call field_get_coefa_v(ivarfl(irij), coefa_rij)
+    call field_get_coefb_v(ivarfl(irij), coefb_rij)
+    call field_get_coefaf_v(ivarfl(irij), coefaf_rij)
+    call field_get_coefbf_v(ivarfl(irij), coefbf_rij)
+    call field_get_coefad_v(ivarfl(irij), coefad_rij)
+    call field_get_coefbd_v(ivarfl(irij), coefbd_rij)
 
-  call field_get_coefa_s(ivarfl(ir22), coefa_r22)
-  call field_get_coefb_s(ivarfl(ir22), coefb_r22)
-  call field_get_coefaf_s(ivarfl(ir22), coefaf_r22)
-  call field_get_coefbf_s(ivarfl(ir22), coefbf_r22)
-  call field_get_coefad_s(ivarfl(ir22), coefad_r22)
-  call field_get_coefbd_s(ivarfl(ir22), coefbd_r22)
+    coefb_r11 => null()
+    coefaf_r11 => null()
+    coefbf_r11 => null()
+    coefad_r11 => null()
+    coefbd_r11 => null()
 
-  call field_get_coefa_s(ivarfl(ir33), coefa_r33)
-  call field_get_coefb_s(ivarfl(ir33), coefb_r33)
-  call field_get_coefaf_s(ivarfl(ir33), coefaf_r33)
-  call field_get_coefbf_s(ivarfl(ir33), coefbf_r33)
-  call field_get_coefad_s(ivarfl(ir33), coefad_r33)
-  call field_get_coefbd_s(ivarfl(ir33), coefbd_r33)
+    coefa_r22 => null()
+    coefb_r22 => null()
+    coefaf_r22 => null()
+    coefbf_r22 => null()
+    coefad_r22 => null()
+    coefbd_r22 => null()
 
-  call field_get_coefa_s(ivarfl(ir12), coefa_r12)
-  call field_get_coefb_s(ivarfl(ir12), coefb_r12)
-  call field_get_coefaf_s(ivarfl(ir12), coefaf_r12)
-  call field_get_coefbf_s(ivarfl(ir12), coefbf_r12)
-  call field_get_coefad_s(ivarfl(ir12), coefad_r12)
-  call field_get_coefbd_s(ivarfl(ir12), coefbd_r12)
+    coefa_r33 => null()
+    coefb_r33 => null()
+    coefaf_r33 => null()
+    coefbf_r33 => null()
+    coefad_r33 => null()
+    coefbd_r33 => null()
 
-  call field_get_coefa_s(ivarfl(ir13), coefa_r13)
-  call field_get_coefb_s(ivarfl(ir13), coefb_r13)
-  call field_get_coefaf_s(ivarfl(ir13), coefaf_r13)
-  call field_get_coefbf_s(ivarfl(ir13), coefbf_r13)
-  call field_get_coefad_s(ivarfl(ir13), coefad_r13)
-  call field_get_coefbd_s(ivarfl(ir13), coefbd_r13)
+    coefa_r12 => null()
+    coefb_r12 => null()
+    coefaf_r12 => null()
+    coefbf_r12 => null()
+    coefad_r12 => null()
+    coefbd_r12 => null()
 
-  call field_get_coefa_s(ivarfl(ir23), coefa_r23)
-  call field_get_coefb_s(ivarfl(ir23), coefb_r23)
-  call field_get_coefaf_s(ivarfl(ir23), coefaf_r23)
-  call field_get_coefbf_s(ivarfl(ir23), coefbf_r23)
-  call field_get_coefad_s(ivarfl(ir23), coefad_r23)
-  call field_get_coefbd_s(ivarfl(ir23), coefbd_r23)
+    coefa_r13 => null()
+    coefb_r13 => null()
+    coefaf_r13 => null()
+    coefbf_r13 => null()
+    coefad_r13 => null()
+    coefbd_r13 => null()
 
-  call field_get_coefa_s(ivarfl(iep), coefa_ep)
-  call field_get_coefb_s(ivarfl(iep), coefb_ep)
-  call field_get_coefaf_s(ivarfl(iep), coefaf_ep)
-  call field_get_coefbf_s(ivarfl(iep), coefbf_ep)
+    coefa_r23 => null()
+    coefb_r23 => null()
+    coefaf_r23 => null()
+    coefbf_r23 => null()
+    coefad_r23 => null()
+    coefbd_r23 => null()
 
-else
 
-  coefa_r11 => null()
-  coefb_r11 => null()
-  coefaf_r11 => null()
-  coefbf_r11 => null()
-  coefad_r11 => null()
-  coefbd_r11 => null()
+  else
 
-  coefa_r22 => null()
-  coefb_r22 => null()
-  coefaf_r22 => null()
-  coefbf_r22 => null()
-  coefad_r22 => null()
-  coefbd_r22 => null()
+    call field_get_coefa_s(ivarfl(ir11), coefa_r11)
+    call field_get_coefb_s(ivarfl(ir11), coefb_r11)
+    call field_get_coefaf_s(ivarfl(ir11), coefaf_r11)
+    call field_get_coefbf_s(ivarfl(ir11), coefbf_r11)
+    call field_get_coefad_s(ivarfl(ir11), coefad_r11)
+    call field_get_coefbd_s(ivarfl(ir11), coefbd_r11)
 
-  coefa_r33 => null()
-  coefb_r33 => null()
-  coefaf_r33 => null()
-  coefbf_r33 => null()
-  coefad_r33 => null()
-  coefbd_r33 => null()
+    call field_get_coefa_s(ivarfl(ir22), coefa_r22)
+    call field_get_coefb_s(ivarfl(ir22), coefb_r22)
+    call field_get_coefaf_s(ivarfl(ir22), coefaf_r22)
+    call field_get_coefbf_s(ivarfl(ir22), coefbf_r22)
+    call field_get_coefad_s(ivarfl(ir22), coefad_r22)
+    call field_get_coefbd_s(ivarfl(ir22), coefbd_r22)
 
-  coefa_r12 => null()
-  coefb_r12 => null()
-  coefaf_r12 => null()
-  coefbf_r12 => null()
-  coefad_r12 => null()
-  coefbd_r12 => null()
+    call field_get_coefa_s(ivarfl(ir33), coefa_r33)
+    call field_get_coefb_s(ivarfl(ir33), coefb_r33)
+    call field_get_coefaf_s(ivarfl(ir33), coefaf_r33)
+    call field_get_coefbf_s(ivarfl(ir33), coefbf_r33)
+    call field_get_coefad_s(ivarfl(ir33), coefad_r33)
+    call field_get_coefbd_s(ivarfl(ir33), coefbd_r33)
 
-  coefa_r13 => null()
-  coefb_r13 => null()
-  coefaf_r13 => null()
-  coefbf_r13 => null()
-  coefad_r13 => null()
-  coefbd_r13 => null()
+    call field_get_coefa_s(ivarfl(ir12), coefa_r12)
+    call field_get_coefb_s(ivarfl(ir12), coefb_r12)
+    call field_get_coefaf_s(ivarfl(ir12), coefaf_r12)
+    call field_get_coefbf_s(ivarfl(ir12), coefbf_r12)
+    call field_get_coefad_s(ivarfl(ir12), coefad_r12)
+    call field_get_coefbd_s(ivarfl(ir12), coefbd_r12)
 
-  coefa_r23 => null()
-  coefb_r23 => null()
-  coefaf_r23 => null()
-  coefbf_r23 => null()
-  coefad_r23 => null()
-  coefbd_r23 => null()
+    call field_get_coefa_s(ivarfl(ir13), coefa_r13)
+    call field_get_coefb_s(ivarfl(ir13), coefb_r13)
+    call field_get_coefaf_s(ivarfl(ir13), coefaf_r13)
+    call field_get_coefbf_s(ivarfl(ir13), coefbf_r13)
+    call field_get_coefad_s(ivarfl(ir13), coefad_r13)
+    call field_get_coefbd_s(ivarfl(ir13), coefbd_r13)
 
+    call field_get_coefa_s(ivarfl(ir23), coefa_r23)
+    call field_get_coefb_s(ivarfl(ir23), coefb_r23)
+    call field_get_coefaf_s(ivarfl(ir23), coefaf_r23)
+    call field_get_coefbf_s(ivarfl(ir23), coefbf_r23)
+    call field_get_coefad_s(ivarfl(ir23), coefad_r23)
+    call field_get_coefbd_s(ivarfl(ir23), coefbd_r23)
+
+    coefa_rij => null()
+    coefb_rij => null()
+    coefaf_rij => null()
+    coefbf_rij => null()
+    coefad_rij => null()
+    coefbd_rij => null()
+  endif
 endif
 
 if (ial.gt.0) then
@@ -452,9 +474,16 @@ if ((iturb.eq.30).or.(iturb.eq.31)) then
 endif
 
 if (itytur.eq.3) then
-  call field_get_val_s(ivarfl(ir11), cvar_r11)
-  call field_get_val_s(ivarfl(ir22), cvar_r22)
-  call field_get_val_s(ivarfl(ir33), cvar_r33)
+  if (irijco.eq.1) then
+    call field_get_val_v(ivarfl(irij), cvar_rij)
+  else
+    call field_get_val_s(ivarfl(ir11), cvar_r11)
+    call field_get_val_s(ivarfl(ir22), cvar_r22)
+    call field_get_val_s(ivarfl(ir33), cvar_r33)
+    call field_get_val_s(ivarfl(ir12), cvar_r12)
+    call field_get_val_s(ivarfl(ir13), cvar_r13)
+    call field_get_val_s(ivarfl(ir23), cvar_r23)
+  endif
 endif
 
 ! min. and max. of wall tangential velocity
@@ -680,26 +709,47 @@ do ifac = 1, nfabor
 
     if (itytur.eq.2 .or. itytur.eq.5 .or. iturb.eq.60) then
       ek = cvar_k(iel)
+      ! TODO: we could add 2*nu_T dv/dy to rnnb
+      rnnb = 2.d0 / 3.d0 * ek
     else if (itytur.eq.3) then
-      ek = 0.5d0*(cvar_r11(iel)+cvar_r22(iel)+cvar_r33(iel))
+      if (irijco.eq.1) then
+        ek = 0.5d0*(cvar_rij(1,iel)+cvar_rij(2,iel)+cvar_rij(3,iel))
+        if (iwallf == 5) then
+          rxx = cvar_rij(1,iel)
+          rxy = cvar_rij(4,iel)
+          rxz = cvar_rij(6,iel)
+          ryy = cvar_rij(2,iel)
+          ryz = cvar_rij(5,iel)
+          rzz = cvar_rij(3,iel)
+          rnnb =   rnx * (rxx * rnx + rxy * rny + rxz * rnz) &
+                 + rny * (rxy * rnx + ryy * rny + ryz * rnz) &
+                 + rnz * (rxz * rnx + ryz * rny + rzz * rnz)
+        endif
+      else
+        ek = 0.5d0*(cvar_r11(iel)+cvar_r22(iel)+cvar_r33(iel))
+        if (iwallf == 5) then
+          rxx = cvar_r11(iel)
+          rxy = cvar_r12(iel)
+          rxz = cvar_r13(iel)
+          ryy = cvar_r22(iel)
+          ryz = cvar_r23(iel)
+          rzz = cvar_r33(iel)
+          rnnb =   rnx * (rxx * rnx + rxy * rny + rxz * rnz) &
+                 + rny * (rxy * rnx + ryy * rny + ryz * rnz) &
+                 + rnz * (rxz * rnx + ryz * rny + rzz * rnz)
+        endif
+      endif
     endif
 
-
-    ! With power law (Werner & Wengle)
-    if (ideuch.eq.0.and.ilogpo.eq.0) then
-      iwallf = 3
+    if (f_id_rough.ge.0) then
+      roughness = bfpro_roughness(ifac)
     else
-      iwallf = ideuch
-    endif
-
-    ! No wall functions for low Reynolds models
-    if (iturb.eq.0.or.itytur.eq.5.or.iturb.eq.32) then
-      iwallf = 4
+      roughness = 0.d0
     endif
 
     call wallfunctions &
   ( iwallf, ifac  ,                                        &
-    xnuii , xnuit , utau  , distbf, ek    ,                &
+    xnuii , xnuit , utau  , distbf, roughness, rnnb, ek,   &
     iuntur, nsubla, nlogla,                                &
     uet   , uk    , yplus , ypup  , cofimp, dplus )
 
@@ -730,7 +780,7 @@ do ifac = 1, nfabor
     endif
 
     ! Save yplus if post-processed or condensation modelling
-    if (yplus_id.ge.0) then
+    if (iyplbr.ge.0) then
       yplbr(ifac) = yplus-dplus
     endif
 
@@ -739,8 +789,7 @@ do ifac = 1, nfabor
     !===========================================================================
 
     ! Deprecated power law (Werner & Wengle)
-    ! If ilogpo=0, then ideuch=0
-    if (ilogpo.eq.0) then
+    if (iwallf.eq.1) then
       uiptn  = utau + uet*apow*bpow*yplus**bpow*(2.d0**(bpow-1.d0)-2.d0)
 
     ! Dependant on the turbulence Model
@@ -914,9 +963,10 @@ do ifac = 1, nfabor
 
       ! If yplus=0, uiptn is set to 0 to avoid division by 0.
       ! By the way, in this case: iuntur=0
-      if (yplus.gt.epzero.and.iuntur.eq.1) then !FIXME use only iuntur
-        pimp = distbf*4.d0*uk**5*romc**2/           &
-            (xkappa*visclc**2*(yplus+dplus)**2)
+      if (yplus.gt.epzero) then !.and.iuntur.eq.1) then !FIXME use only iuntur
+        efvisc = visclc/romc + exp(-xkappa*(8.5-5.2)) * roughness * uk
+        pimp = distbf*4.d0*uk**5/           &
+            (xkappa*efvisc**2*(yplus+dplus)**2)
 
         qimp = -pimp*hint !TODO transform it, it is only to be fully equivalent
       else
@@ -963,10 +1013,10 @@ do ifac = 1, nfabor
           jj = 1
           kk = 2
         else if (isou.eq.5) then
-          jj = 1
+          jj = 2
           kk = 3
         else if (isou.eq.6) then
-          jj = 2
+          jj = 1
           kk = 3
         endif
 
@@ -1057,53 +1107,62 @@ do ifac = 1, nfabor
         ! Translate into Diffusive flux BCs
         fcofaf(isou) = -hint*fcoefa(isou)
         fcofbf(isou) = hint*(1.d0-fcoefb(isou))
-
-        if (isou.eq.1) then
-          coefa_r11(ifac) = fcoefa(isou)
-          coefb_r11(ifac) = fcoefb(isou)
-          coefaf_r11(ifac) = fcofaf(isou)
-          coefbf_r11(ifac) = fcofbf(isou)
-          coefad_r11(ifac) = fcofad(isou)
-          coefbd_r11(ifac) = fcofbd(isou)
-        else if (isou.eq.2) then
-          coefa_r22(ifac) = fcoefa(isou)
-          coefb_r22(ifac) = fcoefb(isou)
-          coefaf_r22(ifac) = fcofaf(isou)
-          coefbf_r22(ifac) = fcofbf(isou)
-          coefad_r22(ifac) = fcofad(isou)
-          coefbd_r22(ifac) = fcofbd(isou)
-        else if (isou.eq.3) then
-          coefa_r33(ifac) = fcoefa(isou)
-          coefb_r33(ifac) = fcoefb(isou)
-          coefaf_r33(ifac) = fcofaf(isou)
-          coefbf_r33(ifac) = fcofbf(isou)
-          coefad_r33(ifac) = fcofad(isou)
-          coefbd_r33(ifac) = fcofbd(isou)
-        else if (isou.eq.4) then
-          coefa_r12(ifac) = fcoefa(isou)
-          coefb_r12(ifac) = fcoefb(isou)
-          coefaf_r12(ifac) = fcofaf(isou)
-          coefbf_r12(ifac) = fcofbf(isou)
-          coefad_r12(ifac) = fcofad(isou)
-          coefbd_r12(ifac) = fcofbd(isou)
-        else if (isou.eq.5) then
-          coefa_r13(ifac) = fcoefa(isou)
-          coefb_r13(ifac) = fcoefb(isou)
-          coefaf_r13(ifac) = fcofaf(isou)
-          coefbf_r13(ifac) = fcofbf(isou)
-          coefad_r13(ifac) = fcofad(isou)
-          coefbd_r13(ifac) = fcofbd(isou)
-        else if (isou.eq.6) then
-          coefa_r23(ifac) = fcoefa(isou)
-          coefb_r23(ifac) = fcoefb(isou)
-          coefaf_r23(ifac) = fcofaf(isou)
-          coefbf_r23(ifac) = fcofbf(isou)
-          coefad_r23(ifac) = fcofad(isou)
-          coefbd_r23(ifac) = fcofbd(isou)
-        endif
-
       enddo
 
+      do isou = 1, 6
+        if (irijco.eq.1) then
+          coefa_rij(isou, ifac)       = fcoefa(isou)
+          coefb_rij(isou,isou, ifac)  = fcoefb(isou)
+          coefaf_rij(isou, ifac)      = fcofaf(isou)
+          coefbf_rij(isou,isou, ifac) = fcofbf(isou)
+          coefad_rij(isou, ifac)      = fcofad(isou)
+          coefbd_rij(isou,isou, ifac) = fcofbd(isou)
+        else
+          if (isou.eq.1) then
+            coefa_r11(ifac) = fcoefa(isou)
+            coefb_r11(ifac) = fcoefb(isou)
+            coefaf_r11(ifac) = fcofaf(isou)
+            coefbf_r11(ifac) = fcofbf(isou)
+            coefad_r11(ifac) = fcofad(isou)
+            coefbd_r11(ifac) = fcofbd(isou)
+          else if (isou.eq.2) then
+            coefa_r22(ifac) = fcoefa(isou)
+            coefb_r22(ifac) = fcoefb(isou)
+            coefaf_r22(ifac) = fcofaf(isou)
+            coefbf_r22(ifac) = fcofbf(isou)
+            coefad_r22(ifac) = fcofad(isou)
+            coefbd_r22(ifac) = fcofbd(isou)
+          else if (isou.eq.3) then
+            coefa_r33(ifac) = fcoefa(isou)
+            coefb_r33(ifac) = fcoefb(isou)
+            coefaf_r33(ifac) = fcofaf(isou)
+            coefbf_r33(ifac) = fcofbf(isou)
+            coefad_r33(ifac) = fcofad(isou)
+            coefbd_r33(ifac) = fcofbd(isou)
+          else if (isou.eq.4) then
+            coefa_r12(ifac) = fcoefa(isou)
+            coefb_r12(ifac) = fcoefb(isou)
+            coefaf_r12(ifac) = fcofaf(isou)
+            coefbf_r12(ifac) = fcofbf(isou)
+            coefad_r12(ifac) = fcofad(isou)
+            coefbd_r12(ifac) = fcofbd(isou)
+          else if (isou.eq.5) then
+            coefa_r23(ifac) = fcoefa(isou)
+            coefb_r23(ifac) = fcoefb(isou)
+            coefaf_r23(ifac) = fcofaf(isou)
+            coefbf_r23(ifac) = fcofbf(isou)
+            coefad_r23(ifac) = fcofad(isou)
+            coefbd_r23(ifac) = fcofbd(isou)
+          else if (isou.eq.6) then
+            coefa_r13(ifac) = fcoefa(isou)
+            coefb_r13(ifac) = fcoefb(isou)
+            coefaf_r13(ifac) = fcofaf(isou)
+            coefbf_r13(ifac) = fcofbf(isou)
+            coefad_r13(ifac) = fcofad(isou)
+            coefbd_r13(ifac) = fcofbd(isou)
+          endif
+        endif
+      enddo
       ! ---> Epsilon
       !      NB: no reconstruction, possibility of partial implicitation
 
@@ -1163,8 +1222,9 @@ do ifac = 1, nfabor
         ! Si yplus=0, on met coefa a 0 directement pour eviter une division
         ! par 0.
         if (yplus.gt.epzero.and.iuntur.eq.1) then
-          pimp = distbf*4.d0*uk**5*romc**2/           &
-                (xkappa*visclc**2*(yplus+dplus)**2)
+          efvisc = visclc/romc + exp(-xkappa*(8.5-5.2)) * roughness * uk
+          pimp = distbf*4.d0*uk**5/           &
+                (xkappa*efvisc**2*(yplus+dplus)**2)
         else
           pimp = 0.d0
         endif
@@ -1876,7 +1936,7 @@ double precision tetmax, tetmin, tplumx, tplumn
 
 ! Local variables
 
-integer          ivar, f_id, isvhbl
+integer          ivar, f_id, b_f_id, isvhbl
 integer          ifac, iel, isou, jsou
 integer          ifccp, ifccv, ifcvsl, itplus, itstar
 
@@ -1889,7 +1949,7 @@ double precision visci(3,3), hintt(6)
 
 character(len=80) :: fname
 
-double precision, dimension(:), pointer :: val_s, crom, viscls
+double precision, dimension(:), pointer :: val_s, bval_s, crom, viscls
 double precision, dimension(:), pointer :: viscl, visct, cpro_cp, cv
 
 double precision, dimension(:), pointer :: bfconv, bhconv
@@ -1898,6 +1958,8 @@ double precision, dimension(:), pointer :: coefap, coefbp, cofafp, cofbfp
 double precision, dimension(:,:), pointer :: coefaut, cofafut, cofarut, visten
 double precision, dimension(:,:,:), pointer :: coefbut, cofbfut, cofbrut
 
+integer, save :: kbfid = -1
+
 !===============================================================================
 
 ivar = isca(iscal)
@@ -1986,6 +2048,9 @@ endif
 
 ! pointers to T+ and T* if saved
 
+itplus = -1
+itstar = -1
+
 tplusp => null()
 tstarp => null()
 
@@ -2004,6 +2069,21 @@ endif
 if (ifconv.ge.0) call field_get_val_s(ifconv, bfconv)
 if (ihconv.ge.0) call field_get_val_s(ihconv, bhconv)
 
+if (kbfid.lt.0) call field_get_key_id("boundary_value_id", kbfid)
+
+call field_get_key_int(f_id, kbfid, b_f_id)
+
+if (b_f_id .ge. 0) then
+  call field_get_val_s(b_f_id, bval_s)
+else
+  bval_s => null()
+  ! if thermal variable has no boundary but temperature does, use it
+  if (itherm.eq.2 .and. itempb.ge.0) then
+    b_f_id = itempb
+    call field_get_val_s(b_f_id, bval_s)
+  endif
+endif
+
 ! --- Loop on boundary faces
 do ifac = 1, nfabor
 
@@ -2148,7 +2228,7 @@ do ifac = 1, nfabor
     ! Dirichlet on the scalar, with wall function
     if (iturb.ne.0.and.icodcl(ifac,ivar).eq.5) then
 
-      call hturbp (prdtl,sigmas(iscal),xkappa,yplus,dplus,hflui,ypth)
+      call hturbp(iwalfs,prdtl,sigmas(iscal),yplus,dplus,hflui,ypth)
 
       ! Compute (y+-d+)/T+ *PrT
       yptp = hflui/prdtl
@@ -2157,7 +2237,7 @@ do ifac = 1, nfabor
 
       ! Neumann on the scalar, with wall function (for post-processing)
     elseif (iturb.ne.0.and.icodcl(ifac,ivar).eq.3) then
-      call hturbp (prdtl,sigmas(iscal),xkappa,yplus,dplus,hflui,ypth)
+      call hturbp(iwalfs,prdtl,sigmas(iscal),yplus,dplus,hflui,ypth)
       ! y+/T+ *PrT
       yptp = hflui/prdtl
       hflui = hint
@@ -2314,7 +2394,7 @@ do ifac = 1, nfabor
             bhconv(ifac) = hflui*cp0
           endif
 
-          ! Energie (compressible module)
+          ! Energy (compressible module)
         elseif (itherm.eq.3) then
           ! If Cv is variable
           if (ifccv.ge.0) then
@@ -2336,13 +2416,13 @@ do ifac = 1, nfabor
 
     endif ! End if icodcl.eq.5
 
-    ! Save the value of T^star and T^+ for post-processing
-    if (iscal.eq.iscalt) then
+    ! Save the values of of T^star and T^+ for post-processing
+
+    if (b_f_id.ge.0 .or. iscal.eq.iscalt) then
 
       ! Wall function
       if (icodcl(ifac,ivar).eq.5) then
         phit = cofafp(ifac)+cofbfp(ifac)*theipb(ifac)
-
         ! Imposed flux with wall function for post-processing
       elseif (icodcl(ifac,ivar).eq.3) then
         phit = rcodcl(ifac,ivar,3)
@@ -2354,13 +2434,18 @@ do ifac = 1, nfabor
       ! T+ = (T_I - T_w) / Tet
       tplus = max((yplus-dplus), epzero)/yptp
 
+      if (b_f_id .ge. 0) bval_s(ifac) = bval_s(ifac) - tplus*tet
+
       if (itplus .ge. 0) tplusp(ifac) = tplus
       if (itstar .ge. 0) tstarp(ifac) = tet
 
-      tetmax = max(tet, tetmax)
-      tetmin = min(tet, tetmin)
-      tplumx = max(tplus,tplumx)
-      tplumn = min(tplus,tplumn)
+      if (iscal.eq.iscalt) then
+        tetmax = max(tet, tetmax)
+        tetmin = min(tet, tetmin)
+        tplumx = max(tplus,tplumx)
+        tplumn = min(tplus,tplumn)
+      endif
+
     endif
 
   endif ! smooth wall condition
@@ -2373,4 +2458,3 @@ enddo
 
 return
 end subroutine
-
