@@ -73,32 +73,33 @@ use entsor
 use optcal
 use cstphy
 use cstnum
-use pointe,only:thermal_condensation_flux,flthr,dflthr
+use pointe, only: thermal_condensation_flux, flthr, dflthr
 use parall
 use period
 use field
 use mesh
 use cs_c_bindings
 use cs_f_interfaces
-
-use cs_nz_condensation, only:nzones,izcophc,izcophg,iztag1d,ztpar
+use cs_nz_condensation, only: nzones, izcophc, izcophg, iztag1d, ztpar
 use cs_nz_tagmr, only: ztpar0, ztmur
+
+
 !===============================================================================
 
 implicit none
 
 ! Arguments
 
-integer          nvar , nfbpcd, ifbpcd(nfbpcd), izzftcd(nfbpcd)
+integer          nvar, nfbpcd, ifbpcd(nfbpcd), izzftcd(nfbpcd)
 
 double precision tpar
-double precision gam_s(nfbpcd, nvar)
+double precision gam_s(nfbpcd,nvar)
 double precision hpcond(nfbpcd)
 
 ! Local variables
 
 integer          ii, iz, iel, ifac, iesp
-integer          ivar, f_id, ifcvsl, yplus_id
+integer          ivar, f_id, ifcvsl
 
 double precision flux
 double precision sink_term, gamma_cond
@@ -150,8 +151,7 @@ sink_term = 0.d0
 
 yplbr => null()
 
-call field_get_id_try('yplus', yplus_id)
-if (yplus_id.ge.0) call field_get_val_s(yplus_id, yplbr)
+if (iyplbr.ge.0) call field_get_val_s(iyplbr, yplbr)
 
 call field_get_id("y_h2o_g", f_id)
 call field_get_key_struct_gas_mix_species_prop(f_id, s_h2o_g)
@@ -438,7 +438,7 @@ do ii = 1, nfbpcd
     dplus = 0.d0
     yplus = yplbr(ifac)
     sigmat = 0.9d0
-    call hturbp (schdt, sigmat, xkappa,yplus,dplus,hflui,ypth)
+    call hturbp(iwalfs,schdt,sigmat,yplus,dplus,hflui,ypth)
 
     hcdt =  cpro_viscl(iel)/distbf*hflui
 
@@ -533,7 +533,7 @@ do ii = 1, nfbpcd
   sigmat = 0.9d0
   Prdtl = cpro_viscl(iel)/cpro_venth(iel)
 
-  call hturbp (Prdtl, sigmat, xkappa,yplus,dplus,hpflui,ypth)
+  call hturbp(iwalfs,Prdtl,sigmat,yplus,dplus,hpflui,ypth)
   hw_enth = cpro_venth(iel)/distbf*hpflui
 
   h1max = max(h1max,hw_enth)
