@@ -146,7 +146,7 @@ logical          lprev
 character(len=80) :: chaine, fname
 integer          ivar
 integer          ii, ifac , iel, isou
-integer          iprev , inc   , iccocg, isqrt, iii, iiun, ibcl
+integer          iprev , inc   , iccocg, iii, iiun, ibcl
 integer          ivarsc
 integer          iiscav
 integer          ifcvsl, iflmas, iflmab
@@ -176,7 +176,7 @@ double precision, allocatable, dimension(:) :: w1, smbrs, rovsdt
 double precision, allocatable, dimension(:,:) :: viscce
 double precision, allocatable, dimension(:,:) :: weighf
 double precision, allocatable, dimension(:) :: weighb
-double precision, allocatable, dimension(:,:) :: grad, grdni
+double precision, allocatable, dimension(:,:) :: grad
 double precision, allocatable, dimension(:) :: coefa_p, coefb_p
 double precision, allocatable, dimension(:) :: dpvar
 double precision, allocatable, dimension(:) :: xcpp
@@ -193,6 +193,7 @@ double precision, dimension(:), pointer :: coefap, coefbp, cofafp, cofbfp
 double precision, dimension(:), pointer :: porosi
 double precision, dimension(:), pointer :: cvara_k, cvara_ep, cvara_omg
 double precision, dimension(:), pointer :: cvara_r11, cvara_r22, cvara_r33
+double precision, dimension(:,:), pointer :: cvara_rij
 double precision, dimension(:), pointer :: visct, cpro_cp, c_st_scal
 double precision, dimension(:), pointer :: cpro_viscls
 ! Darcy arrays
@@ -232,7 +233,7 @@ call field_get_val_s(iflmab, bmasfl)
 if (iwgrec(ivar).eq.1) then
   ! Id weighting field for gradient
   call field_get_key_int(iflid, kwgrec, iflwgr)
-  call field_get_dim(iflid, f_dim, interleaved)
+  call field_get_dim(iflwgr, f_dim, interleaved)
   if (f_dim.gt.1) then
     call field_get_val_v(iflwgr, cpro_wgrec_v)
   else
@@ -381,6 +382,13 @@ if ((ichemistry.ge.1).and.(isepchemistry.eq.2)                    &
   call chem_source_terms(iscal, smbrs, rovsdt)
 endif
 
+
+!Precipitation/dissolution
+! Calculation of source terms du to precipitation and dissolution phenomena
+if (ipreci .eq. 1) then
+  call precst(nvar, nscal, iscal, dt, smbrs)
+endif
+
 ! Si on extrapole les TS :
 !   SMBRS recoit -theta PROPCE du pas de temps precedent
 !     (on aurait pu le faire avant ustssc, mais avec le risque que
@@ -420,7 +428,7 @@ if (idilat.eq.3 .and. iscalt.gt.0) then
   if (ivar.eq.isca(iscalt)) then
     ! unsteady thermodynamic source term added
     do iel = 1, ncel
-      smbrs(iel) = smbrs(iel) + (pther - pthera)/dt(iel)*volume(iel)
+      smbrs(iel) = smbrs(iel) + (pther - pthera)/dt(iel)*cell_f_vol(iel)
     enddo
   endif
 endif
@@ -453,14 +461,14 @@ if (iirayo.ge.1) then
     call raysca &
     !==========
   ( iscalt,ncelet,ncel,     &
-    smbrs, rovsdt,volume)
+    smbrs, rovsdt,cell_f_vol)
 
     ! Store the explicit radiative source term
     if (idilat.ge.4) then
       do iel = 1, ncel
         propce(iel,ipproc(iustdy(iscalt))) = &
         propce(iel,ipproc(iustdy(iscalt)))   &
-        + propce(iel,ipproc(itsre(1)))*volume(iel)
+        + propce(iel,ipproc(itsre(1)))*cell_f_vol(iel)
       enddo
     endif
   endif
@@ -475,7 +483,7 @@ if (iirayo.ge.1) then
       call cs_coal_radst &
       !=================
       ( ivar   , ncelet , ncel  ,               &
-        volume , propce , smbrs , rovsdt )
+        cell_f_vol , propce , smbrs , rovsdt )
 
     endif
 
@@ -504,7 +512,7 @@ if (iirayo.ge.1) then
       call cs_fuel_radst &
      !==================
      ( ivar   , ncelet , ncel  ,                &
-       volume , propce , smbrs , rovsdt)
+       cell_f_vol , propce , smbrs , rovsdt)
 
     endif
   endif
@@ -549,7 +557,7 @@ if (ncesmp.gt.0) then
   !==========
  ( ncelet , ncel   , ncesmp , iiun   , isso2t(iscal) , thetv  ,   &
    icetsm , itypsm(1,ivar) ,                                      &
-   volume , cvara_var    , smacel(1,ivar) , srcmas   ,            &
+   cell_f_vol , cvara_var    , smacel(1,ivar) , srcmas   ,            &
    smbrs  , rovsdt , w1)
 
   deallocate(srcmas)
@@ -642,7 +650,7 @@ if (itspdv.eq.1) then
   if (itytur.eq.2 .or. itytur.eq.3 .or. itytur.eq.5 .or. iturb.eq.60) then
 
     ! Allocate a temporary array for the gradient reconstruction
-    allocate(grad(3,ncelet),grdni(ncelet,3))
+    allocate(grad(3,ncelet))
     allocate(coefa_p(nfabor), coefb_p(nfabor))
 
     ! Remarque : on a prevu la possibilite de scalaire associe non
@@ -682,20 +690,13 @@ if (itspdv.eq.1) then
     climgp = climgr(iii)
     extrap = extrag(iii)
 
-    call grdcel &
-    !==========
-     ( iii    , imrgra , inc    , iccocg , nswrgp , imligp ,          &
-       iwarnp , nfecra , epsrgp , climgp , extrap ,                   &
+    call gradient_s                                                   &
+     ( ivarfl(iii)     , imrgra , inc    , iccocg , nswrgp , imligp , &
+       iwarnp          , epsrgp , climgp , extrap ,                   &
        cvara_varsca    , coefa_p, coefb_p,                            &
-       grdni   )
+       grad )
 
-    do iel = 1, ncel
-      grad(1,iel) = grdni(iel,1)
-      grad(2,iel) = grdni(iel,2)
-      grad(3,iel) = grdni(iel,3)
-    enddo
-
-    deallocate (grdni, coefa_p, coefb_p)
+    deallocate (coefa_p, coefb_p)
 
     ! Traitement de la production
     ! On utilise MAX(PROPCE,ZERO) car en LES dynamique on fait un clipping
@@ -723,7 +724,7 @@ if (itspdv.eq.1) then
         call field_get_val_v(f_id, xut)
 
         do iel = 1, ncel
-          c_st_scal(iel) = c_st_scal(iel) -2.d0*xcpp(iel)*volume(iel) &
+          c_st_scal(iel) = c_st_scal(iel) -2.d0*xcpp(iel)*cell_f_vol(iel) &
                                           *(xut(1,iel)*grad(1,iel)    &
                                            +xut(2,iel)*grad(2,iel)    &
                                            +xut(3,iel)*grad(3,iel) )
@@ -733,7 +734,7 @@ if (itspdv.eq.1) then
         do iel = 1, ncel
           c_st_scal(iel) = c_st_scal(iel)                                     &
                + 2.d0*xcpp(iel)*max(propce(iel,ipcvso),zero)                  &
-               *volume(iel)/sigmas(iscal)                                     &
+               *cell_f_vol(iel)/sigmas(iscal)                                     &
                *(grad(1,iel)**2 + grad(2,iel)**2 + grad(3,iel)**2)
         enddo
       endif
@@ -755,7 +756,7 @@ if (itspdv.eq.1) then
         call field_get_val_v(f_id, xut)
 
         do iel = 1, ncel
-          smbrs(iel) = smbrs(iel) -2.d0*xcpp(iel)*volume(iel)   &
+          smbrs(iel) = smbrs(iel) -2.d0*xcpp(iel)*cell_f_vol(iel)   &
                                   *(xut(1,iel)*grad(1,iel)      &
                                    +xut(2,iel)*grad(2,iel)      &
                                    +xut(3,iel)*grad(3,iel) )
@@ -766,7 +767,7 @@ if (itspdv.eq.1) then
         do iel = 1, ncel
           smbrs(iel) = smbrs(iel)                                            &
                      + 2.d0*xcpp(iel)*max(propce(iel,ipcvso),zero)           &
-                     * volume(iel)/sigmas(iscal)                             &
+                     * cell_f_vol(iel)/sigmas(iscal)                             &
                      * (grad(1,iel)**2 + grad(2,iel)**2 + grad(3,iel)**2)
         enddo
       endif
@@ -777,7 +778,7 @@ if (itspdv.eq.1) then
           propce(iel,ipproc(iustdy(iscal))) =                     &
           propce(iel,ipproc(iustdy(iscal))) +                     &
                2.d0*xcpp(iel)*max(propce(iel,ipcvso),zero)        &
-             *volume(iel)/sigmas(iscal)                           &
+             *cell_f_vol(iel)/sigmas(iscal)                           &
              *(grad(1,iel)**2 + grad(2,iel)**2 + grad(3,iel)**2)
         enddo
       endif
@@ -798,9 +799,13 @@ if (itspdv.eq.1) then
       call field_get_val_prev_s(ivarfl(iep), cvara_ep)
     elseif (itytur.eq.3) then
       call field_get_val_prev_s(ivarfl(iep), cvara_ep)
-      call field_get_val_prev_s(ivarfl(ir11), cvara_r11)
-      call field_get_val_prev_s(ivarfl(ir22), cvara_r22)
-      call field_get_val_prev_s(ivarfl(ir33), cvara_r33)
+      if (irijco.eq.1) then
+        call field_get_val_prev_v(ivarfl(irij), cvara_rij)
+      else
+        call field_get_val_prev_s(ivarfl(ir11), cvara_r11)
+        call field_get_val_prev_s(ivarfl(ir22), cvara_r22)
+        call field_get_val_prev_s(ivarfl(ir33), cvara_r33)
+      endif
     elseif(iturb.eq.60) then
       call field_get_val_prev_s(ivarfl(ik), cvara_k)
       call field_get_val_prev_s(ivarfl(iomg), cvara_omg)
@@ -811,14 +816,19 @@ if (itspdv.eq.1) then
         xk = cvara_k(iel)
         xe = cvara_ep(iel)
       elseif (itytur.eq.3) then
-        xk = 0.5d0*(cvara_r11(iel)+cvara_r22(iel)+cvara_r33(iel))
-        xe = cvara_ep(iel)
+        if (irijco.eq.1) then
+          xk = 0.5d0*(cvara_rij(1,iel)+cvara_rij(2,iel)+cvara_rij(3,iel))
+          xe = cvara_ep(iel)
+        else
+          xk = 0.5d0*(cvara_r11(iel)+cvara_r22(iel)+cvara_r33(iel))
+          xe = cvara_ep(iel)
+        endif
       elseif(iturb.eq.60) then
         xk = cvara_k(iel)
         xe = cmu*xk*cvara_omg(iel)
       endif
       rhovst = xcpp(iel)*crom(iel)*xe/(xk * rvarfl(iscal))       &
-             *volume(iel)
+             *cell_f_vol(iel)
 
       ! La diagonale recoit eps/Rk, (*theta eventuellement)
       rovsdt(iel) = rovsdt(iel) + rhovst*thetap
@@ -880,6 +890,7 @@ if (idiff(ivar).ge.1) then
       do iel = 1, ncel
         cpro_wgrec_s(iel) = w1(iel)
       enddo
+      call synsca(cpro_wgrec_s)
     endif
 
     call viscfa &
@@ -937,6 +948,7 @@ if (idiff(ivar).ge.1) then
           cpro_wgrec_v(isou,iel) = viscce(isou,iel)
         enddo
       enddo
+      call syntis(cpro_wgrec_v)
     endif
 
     call vitens &
@@ -981,27 +993,13 @@ if (ippmod(idarcy).eq.1) then
   call field_get_val_s_by_name('saturation', cpro_sat)
 endif
 
-! Without porosity neither Darcy
-if ((iporos.eq.0).and.(ippmod(idarcy).eq.-1)) then
+! Not Darcy
+if (ippmod(idarcy).eq.-1) then
 
   ! --> Unsteady term and mass aggregation term
   do iel = 1, ncel
     rovsdt(iel) = rovsdt(iel)                                                 &
-                + istat(ivar)*xcpp(iel)*pcrom(iel)*volume(iel)/dt(iel)
-  enddo
-! With porosity but not Darcy
-elseif (ippmod(idarcy).eq.-1) then
-  call field_get_val_s(ipori, porosi)
-
-  do iel = 1, ncel
-    smbrs(iel) = smbrs(iel)*porosi(iel)
-  enddo
-
-  ! --> Unsteady term and mass aggregation term
-  do iel = 1, ncel
-    rovsdt(iel) = ( rovsdt(iel)                                             &
-                  + istat(ivar)*xcpp(iel)*pcrom(iel)*volume(iel)/dt(iel)    &
-                  ) * porosi(iel)
+                + istat(ivar)*xcpp(iel)*pcrom(iel)*cell_f_vol(iel)/dt(iel)
   enddo
 ! Darcy : we take into account the porosity and delay for underground transport
 else
@@ -1048,7 +1046,7 @@ if (ippmod(idarcy).eq.1) then
     call divmas(1, imasfl , bmasfl , diverg)
     do iel = 1, ncel
       smbrs(iel) = smbrs(iel) - diverg(iel)*cvar_var(iel)              &
-        + volume(iel)/dt(iel)*cvar_var(iel)                            &
+        + cell_f_vol(iel)/dt(iel)*cvar_var(iel)                            &
         *( cproa_delay(iel)*cproa_sat(iel)                             &
          - cpro_delay(iel)*cpro_sat(iel) )
     enddo
@@ -1119,14 +1117,19 @@ if (idilat.ge.4.and.itspdv.eq.1) then
       xk = cvara_k(iel)
       xe = cvara_ep(iel)
     elseif (itytur.eq.3) then
-      xk = 0.5d0*(cvara_r11(iel)+cvara_r22(iel)+cvara_r33(iel))
-      xe = cvara_ep(iel)
+        if (irijco.eq.1) then
+          xk = 0.5d0*(cvara_rij(1,iel)+cvara_rij(2,iel)+cvara_rij(3,iel))
+          xe = cvara_ep(iel)
+        else
+          xk = 0.5d0*(cvara_r11(iel)+cvara_r22(iel)+cvara_r33(iel))
+          xe = cvara_ep(iel)
+        endif
     elseif(iturb.eq.60) then
       xk = cvara_k(iel)
       xe = cmu*xk*cvara_omg(iel)
     endif
     rhovst = xcpp(iel)*crom(iel)*xe/(xk * rvarfl(iscal))       &
-           *volume(iel)
+           *cell_f_vol(iel)
 
     propce(iel,ipproc(iustdy(iscal))) =                               &
       propce(iel,ipproc(iustdy(iscal))) - rhovst*cvar_var(iel)
@@ -1142,7 +1145,7 @@ if (idilat.ge.4.and.iirayo.ge.1.and.iscal.eq.iscalt) then
     dvar = cvar_var(iel)-cvara_var(iel)
     propce(iel,ipproc(iustdy(iscalt))) = &
     propce(iel,ipproc(iustdy(iscalt)))   &
-    - propce(iel,ipproc(itsri(1)))*dvar*volume(iel)
+    - propce(iel,ipproc(itsri(1)))*dvar*cell_f_vol(iel)
   enddo
 endif
 
@@ -1157,11 +1160,10 @@ if (iwarni(ivar).ge.2) then
   endif
   do iel = 1, ncel
     smbrs(iel) = smbrs(iel)                                                 &
-            - istat(ivar)*xcpp(iel)*(pcrom(iel)/dt(iel))*volume(iel)        &
+            - istat(ivar)*xcpp(iel)*(pcrom(iel)/dt(iel))*cell_f_vol(iel)        &
                 *(cvar_var(iel)-cvara_var(iel))*ibcl
   enddo
-  isqrt = 1
-  call prodsc(ncel,isqrt,smbrs,smbrs,sclnor)
+  sclnor = sqrt(cs_gdot(ncel,smbrs,smbrs))
   write(nfecra,1200)chaine(1:16) ,sclnor
 endif
 
