@@ -42,7 +42,7 @@
 
 /* System type name */
 
-#if defined(__blrts__) || defined(__bg__)
+#if defined(__bg__)
 #define _CS_ARCH_Blue_Gene
 
 #elif defined(__linux__) || defined(__linux) || defined(linux)
@@ -57,9 +57,7 @@
  * be better optimized on memory-aligned data (if 0 here, no alignment
  * is leveraged). This alignment is not exploited yet in Code_Saturne. */
 
-#if defined(__blrts__) || defined(__bgp__)
-#define CS_MEM_ALIGN 16
-#elif defined(__bgq__)
+#if defined(__bgq__)
 #define CS_MEM_ALIGN 32
 #else
 #define CS_MEM_ALIGN 0
@@ -154,10 +152,13 @@ cs_exit(int  status);
 
 /*----------------------------------------------------------------------------
  * Initialize error and signal handlers.
+ *
+ * parameters:
+ *   signal_defaults <-- leave default signal handlers in place if true.
  *----------------------------------------------------------------------------*/
 
 void
-cs_base_error_init(void);
+cs_base_error_init(bool  signal_defaults);
 
 /*----------------------------------------------------------------------------
  * Initialize management of memory allocated through BFT.
