@@ -76,6 +76,15 @@
 
 BEGIN_C_DECLS
 
+/*=============================================================================
+ * Additional doxygen documentation
+ *============================================================================*/
+
+/*!
+  \file cs_boundary_conditions.c
+        Boundary condition handling.
+*/
+
 /*! \cond DOXYGEN_SHOULD_SKIP_THIS */
 
 /*=============================================================================
@@ -309,7 +318,7 @@ _inlet_sum(int                          var_id,
 {
   const int dim = f->dim;
   const cs_lnum_t n_b_faces = m->n_b_faces;
-  const cs_real_t *f_surf = mq->b_face_surf;
+  const cs_real_t *f_surf = mq->b_f_face_surf;
 
   /* Get field's variable id */
 
@@ -420,41 +429,14 @@ cs_f_boundary_conditions_mapped_set(int                        field_id,
 
 /*! (DOXYGEN_SHOULD_SKIP_THIS) \endcond */
 
-/*============================================================================
- * Public Fortran function definitions
- *============================================================================*/
-
-/*----------------------------------------------------------------------------
- * Handling of boundary condition definition errors and associated output.
- *
- * For each boundary face, itypfb defines the boundary condition type.
- * As a convention here, zero values correspond to undefined types,
- * positive values to defined types (with no error), and negative values
- * to defined types with inconsistent or incompatible values, the
- * absolute value indicating the original boundary condition type.
- *
- * Fortran Interface:
- *
- * SUBROUTINE BCDERR (ITYPFB)
- * *****************
- *
- * INTEGER          ITYPFB      : <-> : Array of BC type ids
- *----------------------------------------------------------------------------*/
-
-void CS_PROCF (bcderr, BCDERR)
-(
- cs_int_t        *itypfb
-)
-{
-  cs_boundary_conditions_error(itypfb);
-}
-
 /*============================================================================
  * Public function definitions
  *============================================================================*/
 
-/*----------------------------------------------------------------------------
- * Handling of boundary condition definition errors and associated output.
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Handling of boundary condition definition errors and
+ *        associated output.
  *
  * For each boundary face, bc_type defines the boundary condition type.
  * As a convention here, zero values correspond to undefined types,
@@ -462,10 +444,9 @@ void CS_PROCF (bcderr, BCDERR)
  * to defined types with inconsistent or incompatible values, the
  * absolute value indicating the original boundary condition type.
  *
- *
- * parameters:
- *   bc_type   <-- array of BC type ids
- *----------------------------------------------------------------------------*/
+ * \param[in]  bc_type  array of BC type ids
+ */
+/*----------------------------------------------------------------------------*/
 
 void
 cs_boundary_conditions_error(const cs_int_t  bc_type[])
