@@ -313,8 +313,13 @@ typedef cs_real_t  cs_real_66_t[6][6];  /* Matrix of 6x6 real values */
 
 typedef cs_real_t  cs_real_34_t[3][4];  /* Matrix of 3x4 real values */
 
+typedef cs_real_t  cs_real_63_t[6][3];  /* Matrix of 6x3 real values */
+
 typedef cs_real_33_t  cs_real_332_t[2];  /* vector of 2 3x3 matrices
                                             of real values */
+typedef cs_real_66_t  cs_real_662_t[2];  /* vector of 2 6x6 matrices
+                                            of real values */
+
 
 /* Mappings to MPI datatypes */
 /*---------------------------*/
@@ -384,6 +389,11 @@ typedef cs_real_33_t  cs_real_332_t[2];  /* vector of 2 3x3 matrices
 #  define CS_THR_MIN 128
 #endif
 
+/* Cache line size, or multiple thereof */
+/*--------------------------------------*/
+
+#define CS_CL_SIZE 64
+
 /*----------------------------------------------------------------------------
  * Type independent min an max (caution: the argument is evaluated)
  *----------------------------------------------------------------------------*/
@@ -420,6 +430,16 @@ typedef enum {
 #  define   END_C_DECLS
 #endif
 
+/*----------------------------------------------------------------------------
+ * Macros for scoping of examples
+ *----------------------------------------------------------------------------*/
+
+#undef BEGIN_EXAMPLE_SCOPE
+#undef END_EXAMPLE_SCOPE
+
+#define BEGIN_EXAMPLE_SCOPE  {
+#define   END_EXAMPLE_SCOPE  }
+
 /*----------------------------------------------------------------------------
  * Macros for Fortran interoperability
  *----------------------------------------------------------------------------*/
@@ -452,6 +472,13 @@ typedef enum {
  * Global variables
  *============================================================================*/
 
+/* Numerical constants */
+
+extern const cs_real_t cs_defs_epzero;
+extern const cs_real_t cs_defs_infinite_r;
+extern const cs_real_t cs_defs_big_r;
+extern const cs_real_t cs_defs_pi;
+
 /* Sizes and names associated with datatypes */
 
 extern const size_t   cs_datatype_size[];
