@@ -307,6 +307,7 @@ cs_field_pointer_map_base(void)
   cs_field_pointer_map(CS_ENUMF_(r12), cs_field_by_name_try("r12"));
   cs_field_pointer_map(CS_ENUMF_(r23), cs_field_by_name_try("r23"));
   cs_field_pointer_map(CS_ENUMF_(r13), cs_field_by_name_try("r13"));
+  cs_field_pointer_map(CS_ENUMF_(rij), cs_field_by_name_try("rij"));
 
   cs_field_pointer_map(CS_ENUMF_(phi), cs_field_by_name_try("phi"));
   cs_field_pointer_map(CS_ENUMF_(f_bar), cs_field_by_name_try("f_bar"));
@@ -328,8 +329,6 @@ cs_field_pointer_map_base(void)
 
   cs_field_pointer_map(CS_ENUMF_(rho),
                        cs_field_by_name_try("density"));
-  cs_field_pointer_map(CS_ENUMF_(rho_b),
-                       cs_field_by_name_try("boundary_density"));
 
   cs_field_pointer_map(CS_ENUMF_(cp),
                        cs_field_by_name_try("specific_heat"));
@@ -345,6 +344,22 @@ cs_field_pointer_map_base(void)
                        cs_field_by_name_try("tensorial_porosity"));
 }
 
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Map some boundary fields to enumerated pointers.
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_field_pointer_map_boundary(void)
+{
+  cs_field_pointer_map(CS_ENUMF_(t_b),
+                       cs_field_by_name_try("boundary_temperature"));
+
+  cs_field_pointer_map(CS_ENUMF_(rho_b),
+                       cs_field_by_name_try("boundary_density"));
+}
+
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief Map base fields to enumerated pointers for atmospheric models
@@ -461,6 +476,22 @@ cs_field_pointer_map_compressible(void)
 
   cs_field_pointer_map(CS_ENUMF_(t),
                        cs_field_by_name_try("temperature"));
+
+  cs_field_pointer_map(CS_ENUMF_(cv),
+                       cs_field_by_name_try("specific_heat_const_vol"));
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Map base fields to enumerated pointers for gas mix model
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_field_pointer_map_gas_mix(void)
+{
+  cs_field_pointer_map(CS_ENUMF_(mol_mass),
+                       cs_field_by_name_try("mix_mol_mas"));
 }
 
 /*----------------------------------------------------------------------------*/
@@ -569,9 +600,6 @@ cs_field_pointer_map_radiation(int  n_r_phases)
 
   }
 
-  cs_field_pointer_map(CS_ENUMF_(tparo),
-                       cs_field_by_name_try("wall_temperature"));
-
   cs_field_pointer_map(CS_ENUMF_(qinci),
                        cs_field_by_name_try("rad_incident_flux"));
 
