@@ -217,13 +217,19 @@ static cs_solving_info_t _solving_info =
 
 static cs_gas_mix_species_prop_t _gas_mix_species_prop =
 {
-  -1.,   /* molar mass             */
-  -1.,   /* specific heat          */
-  -1.,   /* volume diffusion       */
-  -1.,   /* dynamic viscosity a    */
-  -1.,   /* dynamic viscosity b    */
-  -1.,   /* thermal conductivity a */
-  -1.,   /* thermal conductivity b */
+  -1.,   /* molar mass                              */
+  -1.,   /* specific heat                           */
+  -1.,   /* volume diffusion                        */
+  -1.,   /* dynamic viscosity a                     */
+  -1.,   /* dynamic viscosity b                     */
+  -1.,   /* thermal conductivity a                  */
+  -1.,   /* thermal conductivity b                  */
+  -1.,   /* reference viscosity (Sutherland)        */
+  -1.,   /* reference conductivity (Sutherland)     */
+  -1.,   /* reference temperature for viscosity     */
+  -1.,   /* reference temperature for conductivity  */
+  -1.,   /* Sutherland temperature for viscosity    */
+  -1.,   /* Sutherland temperature for conductivity */
 };
 
 /*============================================================================
@@ -291,6 +297,13 @@ _log_func_gas_mix_species_prop(const void *t)
   cs_log_printf(CS_LOG_SETUP, _(fmt), "dynamic viscosity b   ", _t->mu_b);
   cs_log_printf(CS_LOG_SETUP, _(fmt), "thermal conductivity a", _t->lambda_a);
   cs_log_printf(CS_LOG_SETUP, _(fmt), "thermal conductivity b", _t->lambda_b);
+  cs_log_printf(CS_LOG_SETUP, _(fmt), "reference thermal viscosity (Sutherland)", _t->muref);
+  cs_log_printf(CS_LOG_SETUP, _(fmt), "reference thermal conductivity (Sutherland)", _t->lamref);
+  cs_log_printf(CS_LOG_SETUP, _(fmt), "reference temperature (Sutherland for viscosity)", _t->trefmu);
+  cs_log_printf(CS_LOG_SETUP, _(fmt), "reference temperature (Sutherland conductivity)", _t->treflam);
+  cs_log_printf(CS_LOG_SETUP, _(fmt), "Sutherland temperature for viscosity", _t->smu);
+  cs_log_printf(CS_LOG_SETUP, _(fmt), "Sutherland tempertaure for conductivity", _t->slam);
+
 }
 
 /*============================================================================
@@ -353,6 +366,19 @@ cs_f_piso_get_pointers(int     **nterup,
  * Public function definitions
  *============================================================================*/
 
+/*----------------------------------------------------------------------------
+ *!
+ * \brief Provide acces to cs_glob_piso
+ *
+ * needed to initialize structure with GUI
+ *----------------------------------------------------------------------------*/
+
+cs_piso_t *
+cs_get_glob_piso(void)
+{
+  return &_piso;
+}
+
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief Define general field keys.
@@ -392,6 +418,8 @@ cs_parameters_define_field_keys(void)
 
   cs_field_define_key_int("slope_test_upwind_id", -1, CS_FIELD_VARIABLE);
 
+  cs_field_define_key_int("boundary_value_id", -1, 0);
+
   cs_field_define_key_double("min_scalar_clipping", -1.e12, 0);
   cs_field_define_key_double("max_scalar_clipping", 1.e12, 0);
 
@@ -696,6 +724,200 @@ cs_parameters_create_added_properties(void)
   _n_user_properties = 0;
 }
 
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Define a boundary values field for a variable field.
+ *
+ * \param[in, out]  f  pointer to field structure
+ *
+ * \return  pointer to boundary values field, or NULL if not applicable
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_field_t *
+cs_parameters_add_boundary_values(cs_field_t  *f)
+{
+  cs_field_t *bf = NULL;
+
+  /* Check we are on cells and don't already have such value */
+
+  if (f->location_id != CS_MESH_LOCATION_CELLS)
+    return bf;
+
+  int kbf = cs_field_key_id_try("boundary_value_id");
+
+  int bf_id = cs_field_get_key_int(f, kbf);
+  if (bf_id > -1) {
+    bf = cs_field_by_id(bf_id);
+    return bf;
+  }
+
+  /* Currently only managed for scalars or temperature property */
+
+  int ks = cs_field_key_id_try("scalar_id");
+  if (ks < 0)
+    return bf;
+
+  int scalar_id = (f->type & CS_FIELD_VARIABLE) ?
+    cs_field_get_key_int(f, ks) : -1;
+
+  if (scalar_id < 0&& strcmp(f->name, "temperature") != 0)
+    return bf;
+
+  /* Build new field */
+
+  char *b_name;
+  size_t l = strlen("boundary_") + strlen(f->name) + 1;
+  BFT_MALLOC(b_name, l, char);
+  snprintf(b_name, l, "boundary_%s", f->name);
+
+  /* Field may already have been defined */
+
+  bf = cs_field_by_name_try(b_name);
+
+  if (bf == NULL) {
+
+    int type_flag =   (f->type & (CS_FIELD_INTENSIVE | CS_FIELD_EXTENSIVE))
+                    | CS_FIELD_POSTPROCESS;
+
+    bf = cs_field_create(b_name,
+                         type_flag,
+                         CS_MESH_LOCATION_BOUNDARY_FACES,
+                         f->dim,
+                         true,
+                         false);
+
+    /* Set same label as parent */
+
+    cs_field_set_key_str(bf,
+                         cs_field_key_id("label"),
+                         cs_field_get_label(f));
+
+    /* Set same postprocessing and logging defaults as parent */
+
+    int k_log = cs_field_key_id("log");
+    cs_field_set_key_int(bf,
+                         k_log,
+                         cs_field_get_key_int(f, k_log));
+
+    int k_vis = cs_field_key_id("post_vis");
+    int f_vis = cs_field_get_key_int(f, k_vis);
+    f_vis = CS_MAX(f_vis, 1);
+    cs_field_set_key_int(bf, k_vis, f_vis);
+
+  }
+  else {
+
+    if (   f->dim != bf->dim
+        || bf->location_id != CS_MESH_LOCATION_BOUNDARY_FACES)
+      bft_error(__FILE__, __LINE__, 0,
+                _("Error defining variable boundary field:\n"
+                  "  parent name:   \"%s\"\n"
+                  "  name:          \"%s\"\n"
+                  "  dimension:     %d\n\n"
+                  "An incompatible field with matching name already exists:\n"
+                  "  id:          %d\n"
+                  "  location_id: %d\n"
+                  "  dimension:   %d"),
+                f->name, bf->name, f->dim,
+                bf->id, bf->location_id, bf->dim);
+
+  }
+
+  BFT_FREE(b_name);
+
+  cs_field_set_key_int(f, kbf, bf->id);
+  cs_field_lock_key(f, kbf);
+
+  return bf;
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Define a boundary values field for temperature, if applicable.
+ *
+ * \return  pointer to boundary values field, or NULL if not applicable
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_field_t *
+cs_parameters_add_boundary_temperature(void)
+{
+  cs_field_t *bf = NULL;
+
+  /* Check if we already have a temperature variable field
+    (temperature or enthalpy */
+
+  cs_field_t *f = cs_field_by_name_try("temperature");
+
+  if (f != NULL)
+    bf = cs_parameters_add_boundary_values(f);
+
+  else {
+
+    f = cs_field_by_name_try("enthalpy");
+
+    if (f != NULL) {
+      if (   f->location_id != CS_MESH_LOCATION_CELLS
+          || (f->type & CS_FIELD_VARIABLE) == 0)
+        f = NULL;
+    }
+
+    /* If we have a compatible cell enthalpy field,
+       use if to define default output options */
+
+    if (f != NULL) {
+
+      char b_name[] = "boundary_temperature";
+
+      bf = cs_field_by_name_try(b_name);
+
+      if (bf == NULL) {
+
+        int type_flag =   (f->type & (CS_FIELD_INTENSIVE | CS_FIELD_EXTENSIVE))
+                           | CS_FIELD_POSTPROCESS;
+
+        bf = cs_field_create(b_name,
+                             type_flag,
+                             CS_MESH_LOCATION_BOUNDARY_FACES,
+                             f->dim,
+                             true,
+                             false);
+
+        /* Set same postprocessing and logging defaults as enthalpy */
+
+        int k_log = cs_field_key_id("log");
+        cs_field_set_key_int(bf,
+                             k_log,
+                             cs_field_get_key_int(f, k_log));
+
+        int k_vis = cs_field_key_id("post_vis");
+        int f_vis = cs_field_get_key_int(f, k_vis);
+        f_vis = CS_MAX(f_vis, 1);
+        cs_field_set_key_int(bf, k_vis, f_vis);
+
+      }
+      else {
+
+        if (   1 != bf->dim
+            || bf->location_id != CS_MESH_LOCATION_BOUNDARY_FACES)
+          bft_error(__FILE__, __LINE__, 0,
+                    _("Error defining variable \"boundary_temperature\" field:\n"
+                      "An incompatible field with matching name already exists:\n"
+                      "  id:          %d\n"
+                      "  location_id: %d\n"
+                      "  dimension:   %d"),
+                    bf->id, bf->location_id, bf->dim);
+
+      }
+
+    }
+
+  }
+
+  return bf;
+}
+
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
