@@ -103,16 +103,30 @@ BEGIN_C_DECLS
   \var  cs_fluid_properties_t::ieos
         indicator of equation of state
 
-        useful only for the compressible module. Only perfect gas with a
-        constant adiabatic coefficient, \ref ieos=1 is available, but the
-        user can complete the file \ref cs_cf_thermo.h, which is not a user
-        source, to add new equations of state.
+        useful only for the compressible module. Ideal gas with a constant
+        adiabatic coefficient (\ref ieos=1), stiffened gas (\ref ieos=2) and
+        mix of ideal gas (\ref ieos=3) are available, but the user can complete
+        the file \ref cs_cf_thermo.h, which is not a user source, to add new
+        equations of state.
   \var  cs_fluid_properties_t::icp
         property index of the isobaric specific heat
         - 0: uniform isobaric specific heat (no property field defined)
   \var  cs_fluid_properties_t::icv
         property index of the isochoric specific heat
         - 0: uniform isochoric specific heat (no property field defined)
+  \var  cs_fluid_properties_t::irovar
+        variable density field \f$ \rho \f$:
+        - 0: false
+        - 1: true
+  \var  cs_fluid_properties_t::ivivar
+        variable viscosity field \f$ \rho \f$:
+        - 0: false
+        - 1: true
+  \var  cs_fluid_properties_t::ivsuth
+        Sutherland law for laminar viscosity and thermal conductivity
+        Only useful in gas mix (igmix) specific physics
+        - 1: Sutherland law
+        - 0: low temperature law (linear except for helium)
   \var  cs_fluid_properties_t::ro0
         reference density
 
@@ -267,6 +281,9 @@ static cs_fluid_properties_t  _fluid_properties = {
   .ieos     = -1,
   .icp      = 0,
   .icv      = 0,
+  .irovar   = 0,
+  .ivivar   = 0,
+  .ivsuth   = 0,
   .ro0      = 1.17862,
   .viscl0   = 1.83337e-5,
   .p0       = 1.01325e5,
@@ -275,7 +292,7 @@ static cs_fluid_properties_t  _fluid_properties = {
   .t0       = 293.15,
   .cp0      = 1017.24,
   .cv0      = 0.,
-  .xmasmr   = 0.,
+  .xmasmr   = 0.028966, /* air molar mass */
   .psginf   = 0.,
   .gammasg  = 1.4,
   .pther    = 1.013e5,
@@ -288,10 +305,9 @@ static cs_fluid_properties_t  _fluid_properties = {
  * Global variables
  *============================================================================*/
 
-const
-cs_physical_constants_t  *cs_glob_physical_constants = &_physical_constants;
+const cs_physical_constants_t  *cs_glob_physical_constants = &_physical_constants;
 
-cs_fluid_properties_t  * const cs_glob_fluid_properties = &_fluid_properties;
+const cs_fluid_properties_t  *cs_glob_fluid_properties = &_fluid_properties;
 
 /*! \cond DOXYGEN_SHOULD_SKIP_THIS */
 
@@ -312,6 +328,9 @@ cs_f_fluid_properties_get_pointers(int     **ixyzp0,
                                    int     **ieos,
                                    int     **icp,
                                    int     **icv,
+                                   int     **irovar,
+                                   int     **ivivar,
+                                   int     **ivsuth,
                                    double  **ro0,
                                    double  **viscl0,
                                    double  **p0,
@@ -374,6 +393,9 @@ cs_f_physical_constants_get_pointers(double  **r,
  *   ieos     --> pointer to cs_glob_fluid_properties->ieos
  *   icp      --> pointer to cs_glob_fluid_properties->icp
  *   icv      --> pointer to cs_glob_fluid_properties->icv
+ *   irovar   --> pointer to cs_glob_fluid_properties->irovar
+ *   ivivar   --> pointer to cs_glob_fluid_properties->ivivar
+ *   ivsuth   --> pointer to cs_glob_fluid_properties->ivsuth
  *   ro0      --> pointer to cs_glob_fluid_properties->ro0
  *   viscl0   --> pointer to cs_glob_fluid_properties->viscl0
  *   p0       --> pointer to cs_glob_fluid_properties->p0
@@ -395,6 +417,9 @@ cs_f_fluid_properties_get_pointers(int     **ixyzp0,
                                    int     **ieos,
                                    int     **icp,
                                    int     **icv,
+                                   int     **irovar,
+                                   int     **ivivar,
+                                   int     **ivsuth,
                                    double  **ro0,
                                    double  **viscl0,
                                    double  **p0,
@@ -414,6 +439,9 @@ cs_f_fluid_properties_get_pointers(int     **ixyzp0,
   *ieos     = &(_fluid_properties.ieos);
   *icp      = &(_fluid_properties.icp);
   *icv      = &(_fluid_properties.icv);
+  *irovar   = &(_fluid_properties.irovar);
+  *ivivar   = &(_fluid_properties.ivivar);
+  *ivsuth   = &(_fluid_properties.ivsuth);
   *ro0      = &(_fluid_properties.ro0);
   *viscl0   = &(_fluid_properties.viscl0);
   *p0       = &(_fluid_properties.p0);
@@ -436,6 +464,32 @@ cs_f_fluid_properties_get_pointers(int     **ixyzp0,
  * Public function definitions
  *============================================================================*/
 
+/*----------------------------------------------------------------------------
+ *!
+ * \brief Provide acces to cs_glob_physical_constants
+ *
+ * needed to initialize structure with GUI
+ *----------------------------------------------------------------------------*/
+
+cs_physical_constants_t *
+cs_get_glob_physical_constants(void)
+{
+  return &_physical_constants;
+}
+
+/*----------------------------------------------------------------------------
+ *!
+ * \brief Provide acces to cs_glob_fluid_properties
+ *
+ * needed to initialize structure with GUI
+ *----------------------------------------------------------------------------*/
+
+cs_fluid_properties_t *
+cs_get_glob_fluid_properties(void)
+{
+  return &_fluid_properties;
+}
+
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
