@@ -63,6 +63,7 @@
 #include "cs_post.h"
 #include "cs_prototypes.h"
 #include "cs_preprocessor_data.h"
+#include "cs_timer_stats.h"
 
 /*----------------------------------------------------------------------------
  * Header for the current file
@@ -130,18 +131,24 @@ extern void cs_f_majgeo(const cs_int_t     *ncel,
                         const cs_int_t      ipnfbr[],
                         const cs_int_t      nodfbr[],
                         const cs_int_t      isympa[],
+                        const cs_int_t      isolid_0[],
                         const cs_real_t    *volmin,
                         const cs_real_t    *volmax,
                         const cs_real_t    *voltot,
                         const cs_real_t     xyzcen[],
                         const cs_real_t     surfac[],
                         const cs_real_t     surfbo[],
+                        const cs_real_t     suffac[],
+                        const cs_real_t     suffbo[],
                         const cs_real_t     cdgfac[],
                         const cs_real_t     cdgfbo[],
                         const cs_real_t     xyznod[],
                         const cs_real_t     volume[],
+                        const cs_real_t     cell_f_vol[],
                         const cs_real_t     surfan[],
                         const cs_real_t     surfbn[],
+                        const cs_real_t     suffan[],
+                        const cs_real_t     suffbn[],
                         const cs_real_t     dist[],
                         const cs_real_t     distb[],
                         const cs_real_t     pond[],
@@ -200,6 +207,10 @@ cs_preprocess_mesh(cs_halo_type_t   halo_type)
 {
   double  t1, t2;
 
+  int t_stat_id = cs_timer_stats_id_by_name("mesh_processing");
+
+  int t_top_id = cs_timer_stats_switch(t_stat_id);
+
   /* Set partitioning options */
 
   {
@@ -332,6 +343,8 @@ cs_preprocess_mesh(cs_halo_type_t   halo_type)
   cs_mesh_dump(cs_glob_mesh);
   cs_mesh_quantities_dump(cs_glob_mesh, cs_glob_mesh_quantities);
 #endif
+
+  cs_timer_stats_switch(t_top_id);
 }
 
 /*----------------------------------------------------------------------------*/
@@ -398,18 +411,24 @@ cs_preprocess_mesh_update_fortran(void)
               m->b_face_vtx_idx,
               m->b_face_vtx_lst,
               mq->b_sym_flag,
+              mq->c_solid_flag,
               &(mq->min_vol),
               &(mq->max_vol),
               &(mq->tot_vol),
               mq->cell_cen,
               mq->i_face_normal,
               mq->b_face_normal,
+              mq->i_f_face_normal,
+              mq->b_f_face_normal,
               mq->i_face_cog,
               mq->b_face_cog,
               m->vtx_coord,
               mq->cell_vol,
+              mq->cell_f_vol,
               mq->i_face_surf,
               mq->b_face_surf,
+              mq->i_f_face_surf,
+              mq->b_f_face_surf,
               mq->i_dist,
               mq->b_dist,
               mq->weight,
