@@ -36,8 +36,7 @@
 #include "cs_mesh_quantities.h"
 #include "cs_mesh_bad_cells.h"
 
-#include "cs_cdo_connect.h"
-#include "cs_cdo_quantities.h"
+#include "cs_domain.h"
 
 /*----------------------------------------------------------------------------*/
 
@@ -381,7 +380,7 @@ cs_user_matrix_tuning(void);
 /*----------------------------------------------------------------------------
  * Define or modify general numerical and physical user parameters.
  *
- * At the calling point of this function, most model-related most varibles
+ * At the calling point of this function, most model-related most variables
  * and other fields have been defined, so speciic settings related to those
  * fields may be set here.
  *----------------------------------------------------------------------------*/
@@ -492,12 +491,47 @@ cs_user_turbomachinery_rotor(void);
 
 /*----------------------------------------------------------------------------*/
 /*!
- * \brief  Initialize the specifications for the current simulation
+ * \brief  Activate or not the CDO module
+ */
+/*----------------------------------------------------------------------------*/
+
+bool
+cs_user_cdo_activated(void);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Specify additional mesh locations
  */
 /*----------------------------------------------------------------------------*/
 
 void
-cs_user_cdo_setup(void);
+cs_user_cdo_add_mesh_locations(void);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Specify for the computational domain:
+ *         -- which type of boundaries closed the computational domain
+ *         -- the settings for the time step
+ *
+ * \param[in, out]   domain    pointer to a cs_domain_t structure
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_user_cdo_init_domain(cs_domain_t   *domain);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Associate material property and/or convection field to user-defined
+ *         equations and specify boundary conditions, source terms, initial
+ *         values for these additional equations
+ *
+ * \param[in, out]   domain    pointer to a cs_domain_t structure
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_user_cdo_set_domain(cs_domain_t   *domain);
 
 /*----------------------------------------------------------------------------*/
 /*!
@@ -514,50 +548,26 @@ cs_user_cdo_geometric_settings(void);
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief  Setup advanced features concerning the numerical parameters
+ *         of the equation resolved during the computation
+ *
+ * \param[in, out]  domain  pointer to a cs_domain_t structure
  */
 /*----------------------------------------------------------------------------*/
 
 void
-cs_user_cdo_numeric_settings(void);
+cs_user_cdo_numeric_settings(cs_domain_t   *domain);
 
 /*----------------------------------------------------------------------------*/
 /*!
- * \brief  Setup advanced features concerning the discrete Hodge operators
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_user_cdo_hodge_settings(void);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Setup advanced features concerning the resolution of linear systems
- *         within the CDO framework
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_user_cdo_itsol_settings(void);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Additional operations on results produced by CDO schemes.
+ * \brief  Additional operations on results provided by CDO schemes.
  *         Define advanced post-processing and/or analysis for instance.
  *
- * \param[in]  m        pointer to a cs_mesh_t struct.
- * \param[in]  mq       pointer to a cs_quantities_t struct.
- * \param[in]  connect  pointer to a cs_cdo_connect_t structure
- * \param[in]  quant    pointer to a cs_cdo_quantities_t structure
- * \param[in]  tcur     current physical time of the simulation
+ * \param[in]  domain   pointer to a cs_domain_t structure
  */
 /*----------------------------------------------------------------------------*/
 
 void
-cs_user_cdo_extra_op(const cs_mesh_t             *m,
-                     const cs_mesh_quantities_t  *mq,
-                     const cs_cdo_connect_t      *connect,
-                     const cs_cdo_quantities_t   *quant,
-                     double                       tcur);
+cs_user_cdo_extra_op(const cs_domain_t     *domain);
 
 /*----------------------------------------------------------------------------*/
 
