@@ -99,8 +99,8 @@ BEGIN_C_DECLS
         - 0: false
   \var  cs_stokes_model_t::iccvfg
         calculation with a fixed velocity field
-        - 1: true (default)
-        - 0: false
+        - 1: true
+        - 0: false (default)
   \var  cs_stokes_model_t::idilat
         algorithm to take into account the density variation in time
         - 1: dilatable steady algorithm (default)
@@ -292,6 +292,19 @@ cs_f_stokes_options_get_pointers(int     **ivisse,
  * Public function definitions
  *============================================================================*/
 
+/*----------------------------------------------------------------------------
+ *!
+ * \brief Provide acces to cs_glob_stokes_model
+ *
+ * needed to initialize structure with GUI
+ *----------------------------------------------------------------------------*/
+
+cs_stokes_model_t *
+cs_get_glob_stokes_model(void)
+{
+  return &_stokes_model;
+}
+
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
