@@ -20,54 +20,48 @@
 
 !-------------------------------------------------------------------------------
 
-subroutine dttvar &
-!================
+!===============================================================================
+! Purpose:
+! -------
 
+!> \file dttvar.f90
+!> \brief Compute the local time step and add the Courant and Fourier number to
+!the log.
+!>
+!> This function has access to the boundary face type, except for the first time
+!> step.
+
+!-------------------------------------------------------------------------------
+
+!-------------------------------------------------------------------------------
+! Arguments
+!______________________________________________________________________________.
+!  mode           name          role                                           !
+!______________________________________________________________________________!
+!> \param[in]     nvar          total number of variables
+!> \param[in]     nscal         total number of scalars
+!> \param[in]     ncepdp        number of cells with head loss terms
+!> \param[in]     ncesmp        number of cells with mass source terms
+!> \param[in]     iwarnp        verbosity
+!> \param[in]     icepdc        index number of cells with head loss terms
+!> \param[in]     icetsm        index number of cells with mass source terms
+!> \param[in]     itypsm        type of mass source term for each variable
+!>                               (see \ref cs_user_mass_source_terms)
+!> \param[in]     dt            time step (per cell)
+!> \param[in]     ckupdc        head loss coefficient
+!> \param[in]     smacel        value associated to each variable in the mass
+!>                               source terms or mass rate (see
+!>                               \ref cs_user_mass_source_terms)
+!_______________________________________________________________________________
+
+subroutine dttvar &
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    iwarnp ,                                                       &
    icepdc , icetsm , itypsm ,                                     &
-   dt     , propce ,                                              &
+   dt     ,                                                       &
    ckupdc , smacel )
 
 !===============================================================================
-! FONCTION :
-! ----------
-
-! CALCUL DU PAS DE TEMPS LOCAL
-! AFFICHAGE DES NOMBRES DE COURANT + FOURIER MINIMUM, MAXIMUM
-! On dispose des types de faces de bord au pas de temps
-!   precedent (sauf au premier pas de temps, ou les tableaux
-!   ITYPFB et ITRIFB n'ont pas ete renseignes)
-
-! Sous programme utilise dans le cas une seule phase (ou
-! si seule la phase 1 pilote le pas de temps)
-!-------------------------------------------------------------------------------
-! Arguments
-!__________________.____._____.________________________________________________.
-! name             !type!mode ! role                                           !
-!__________________!____!_____!________________________________________________!
-! nvar             ! i  ! <-- ! total number of variables                      !
-! nscal            ! i  ! <-- ! total number of scalars                        !
-! ncepdp           ! i  ! <-- ! number of cells with head loss                 !
-! ncesmp           ! i  ! <-- ! number of cells with mass source term          !
-! iwarnp           ! i  ! <-- ! verbosity                                      !
-! icepdc(ncelet)   ! te ! <-- ! numero des ncepdp cellules avec pdc            !
-! icetsm(ncesmp)   ! te ! <-- ! numero des cellules a source de masse          !
-! itypsm           ! te ! <-- ! type de source de masse pour les               !
-! (ncesmp,nvar)    !    !     !  variables (cf. cs_user_mass_source_terms)     !
-! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
-! propce(ncelet, *)! ra ! <-- ! physical properties at cell centers            !
-! ckupdc           ! tr ! <-- ! tableau de travail pour pdc                    !
-!  (ncepdp,6)      !    !     !                                                !
-! smacel           ! tr ! <-- ! valeur des variables associee a la             !
-! (ncesmp,nvar)    !    !     !  source de masse                               !
-!                  !    !     ! pour ivar=ipr, smacel=flux de masse            !
-!__________________!____!_____!________________________________________________!
-
-!     Type: i (integer), r (real), s (string), a (array), l (logical),
-!           and composite types (ex: ra real array)
-!     mode: <-- input, --> output, <-> modifies data, --- work array
-!===============================================================================
 
 !===============================================================================
 ! Module files
@@ -103,14 +97,13 @@ integer          icepdc(ncepdp)
 integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
 
 double precision dt(ncelet)
-double precision propce(ncelet,*)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 
 ! Local variables
 
 character(len=8) :: cnom
 
-integer          ifac, iel, icfmax, icfmin, idiff0, iconv0, isym, flid
+integer          ifac, iel, icfmax(1), icfmin(1), idiff0, iconv0, isym, flid
 integer          modntl
 integer          iflmas, iflmab
 integer          icou, ifou , icoucf
@@ -122,7 +115,7 @@ integer          ipccou, ipcfou, ntcam1
 
 double precision epsrgp, climgp, extrap
 double precision cfmax,cfmin, w1min, w2min, w3min
-double precision unpvdt, rom, dtloc
+double precision unpvdt, dtloc
 double precision xyzmax(3), xyzmin(3), vmin(1), vmax(1)
 double precision dtsdtm
 double precision hint
@@ -142,7 +135,7 @@ double precision, dimension(:), pointer :: viscl, visct, cpro_cour, cpro_four
 !===============================================================================
 
 !===============================================================================
-! 0.  INITIALISATION
+! 0. Initialisation
 !===============================================================================
 
 ! Pointers to the mass fluxes
@@ -199,19 +192,17 @@ if (                                                             &
 endif
 
 !===============================================================================
-! 1.  CALCUL DE LA LIMITATION EN COMPRESSIBLE
+! 1. Compute CFL like condition on the time step for positive density for the
+!    compressible module
 !===============================================================================
 
-!     On commence par cela afin de disposer de VISCF VISCB comme
-!       tableaux de travail.
-
 if (ippmod(icompf).ge.0) then
 
   call cfdttv                                                   &
   !==========
  ( nvar   , nscal  , ncepdp , ncesmp ,                          &
    icepdc , icetsm , itypsm ,                                   &
-   dt     , propce ,                                            &
+   dt     ,                                                     &
    ckupdc , smacel ,                                            &
    wcf    ,                                                     &
    viscf  , viscb  , cofbft )
@@ -222,16 +213,12 @@ endif
 ! 2. Compute the diffusivity at the faces
 !===============================================================================
 
-!     On s'en sert dans les divers matrdt suivants
-
-!     "VITESSE" DE DIFFUSION FACETTE
-
 if (idiff(iu).ge. 1) then
   do iel = 1, ncel
     w1(iel) = viscl(iel) + idifft(iu)*visct(iel)
   enddo
   call viscfa(imvisf, w1, viscf, viscb)
-  !==========
+
 else
   do ifac = 1, nfac
     viscf(ifac) = 0.d0
@@ -242,7 +229,7 @@ else
 endif
 
 !===============================================================================
-! 3.  CONDITION LIMITE POUR MATRDT
+! 3. Boundary condition for matrdt
 !===============================================================================
 
 if (idtvar.ge.0) then
@@ -268,7 +255,7 @@ else
   !      (algorithm was probably broken since velocity components are
   !      coupled)
 
-  mult = 1.0d0 / 3.0d0
+  mult = 1.d0 / 3.d0
 
   call field_get_coefb_v (ivarfl(iu), coefbv)
   call field_get_coefbf_v(ivarfl(iu), cofbfv)
@@ -281,17 +268,17 @@ else
 endif
 
 !===============================================================================
-! 4.  ALGORITHME INSTATIONNAIRE
+! 4. Steady algorithme
 !===============================================================================
 
 if (idtvar.ge.0) then
 
 !===============================================================================
-! 4.1  PAS DE TEMPS VARIABLE A PARTIR DE COURANT ET FOURIER IMPOSES
+! 4.1 Variable time step from imposed Courant and Fourier
 !===============================================================================
 
   ! On calcule le pas de temps thermique max (meme en IDTVAR=0, pour affichage)
-  ! DTTMAX = 1/SQRT(MAX(0+,gradRO.g/RO) -> W3
+  ! dttmax = 1/sqrt(max(0+,gradRO.g/RO) -> w3
 
   if (iptlro.eq.1) then
 
@@ -314,7 +301,7 @@ if (idtvar.ge.0) then
     inc   = 1
     iccocg = 1
 
-    call gradient_s                                               &
+    call gradient_s &
  ( f_id   , imrgra , inc    , iccocg , nswrgp , imligp ,          &
    iwarnp , epsrgp , climgp , extrap ,                            &
    crom, brom, coefbr ,                                           &
@@ -322,7 +309,7 @@ if (idtvar.ge.0) then
 
     do iel = 1, ncel
       w3(iel) = (grad(1,iel)*gx + grad(2,iel)*gy + grad(3,iel)*gz)&
-           /crom(iel)
+              / crom(iel)
       w3(iel) = 1.d0/sqrt(max(epzero,w3(iel)))
 
     enddo
@@ -338,15 +325,15 @@ if (idtvar.ge.0) then
     icou = 0
     ifou = 0
 
-! 4.1.1 LIMITATION PAR LE COURANT
-! =============================
+    ! 4.1.1 Courant limitation
+    ! ========================
 
     if (coumax.gt.0.d0.and.iconv(iu).ge.1) then
 
       ! ICOU = 1 marque l'existence d'une limitation par le COURANT
       icou = 1
 
-      ! CONSTRUCTION DE U/DX           (COURANT       ) =W1
+      ! CONSTRUCTION DE U/DX (COURANT) = W1
 
       idiff0 = 0
 
@@ -354,19 +341,17 @@ if (idtvar.ge.0) then
       isym = 2
 
       call matrdt &
-      !==========
- (iconv(iu), idiff0, isym, coefbt, cofbft, imasfl, bmasfl, viscf, viscb, dam)
+     ( iconv(iu), idiff0, isym, coefbt, cofbft, imasfl, bmasfl, viscf, viscb, dam)
 
       do iel = 1, ncel
-        rom = crom(iel)
-        w1    (iel) = dam(iel)/(rom*volume(iel))
+        w1(iel) = dam(iel)/(crom(iel)*volume(iel))
       enddo
 
-      ! ---> CALCUL DE W1     = PAS DE TEMPS VARIABLE VERIFIANT
-      !       LE NOMBRE DE COURANT         MAXIMUM PRESCRIT PAR L'UTILISATEUR
+      ! ---> CALCUL DE W1 = PAS DE TEMPS VARIABLE VERIFIANT
+      !       LE NOMBRE DE COURANT MAXIMUM PRESCRIT PAR L'UTILISATEUR
 
       do iel = 1, ncel
-        w1    (iel) = coumax/max(w1    (iel), epzero)
+        w1(iel) = coumax/max(w1(iel), epzero)
       enddo
 
       ! PAS DE TEMPS UNIFORME : ON PREND LE MINIMUM DE LA CONTRAINTE
@@ -377,8 +362,7 @@ if (idtvar.ge.0) then
           w1min = min(w1min,w1(iel))
         enddo
         if (irangp.ge.0) then
-          call parmin (w1min)
-          !==========
+          call parmin(w1min)
         endif
         do iel = 1, ncel
           w1(iel) = w1min
@@ -387,8 +371,8 @@ if (idtvar.ge.0) then
 
     endif
 
-    ! 4.1.2 LIMITATION PAR LE FOURIER
-    ! =============================
+    ! 4.1.2 Fourier limitation
+    ! ========================
 
     if (foumax.gt.0.d0.and.idiff(iu).ge.1) then
 
@@ -398,7 +382,6 @@ if (idtvar.ge.0) then
       iconv0 = 0
       !                              2
       ! CONSTRUCTION DE      +2.NU/DX  (       FOURIER) =W2
-
       ! Matrice a priori symetrique
       isym = 1
 
@@ -407,15 +390,15 @@ if (idtvar.ge.0) then
  (iconv0, idiff(iu), isym, coefbt, cofbft, imasfl, bmasfl, viscf, viscb, dam)
 
       do iel = 1, ncel
-        rom = crom(iel)
-        w2    (iel) = dam(iel)/(rom*volume(iel))
+        w2(iel) = dam(iel)/(crom(iel)*volume(iel))
       enddo
 
+
       ! ---> CALCUL DE W2     = PAS DE TEMPS VARIABLE VERIFIANT
       !       LE NOMBRE DE         FOURIER MAXIMUM PRESCRIT PAR L'UTILISATEUR
 
       do iel = 1, ncel
-        w2    (iel) = foumax/max(w2    (iel), epzero)
+        w2(iel) = foumax/max(w2(iel), epzero)
       enddo
 
       ! ---> PAS DE TEMPS UNIFORME : ON PREND LE MINIMUM DE LA CONTRAINTE
@@ -462,7 +445,6 @@ if (idtvar.ge.0) then
         enddo
         if (irangp.ge.0) then
           call parmin (w3min)
-          !==========
         endif
         do iel = 1, ncel
           dam(iel) = w3min
@@ -502,7 +484,7 @@ if (idtvar.ge.0) then
     !              DESCENTE  IMMEDIATE   DU PAS DE TEMPS
 
     do iel = 1, ncel
-      if (w1    (iel).ge.dt(iel)) then
+      if (w1(iel).ge.dt(iel)) then
         unpvdt = 1.d0+varrdt
         dt(iel) = min(unpvdt*dt(iel), w1(iel))
       else
@@ -559,8 +541,8 @@ if (idtvar.ge.0) then
     ! 4.1.7 ON CLIPPE LE PAS DE TEMPS PAR RAPPORT A DTMIN ET DTMAX
     ! ==========================================================
 
-    icfmin = 0
-    icfmax = 0
+    icfmin(1) = 0
+    icfmax(1) = 0
 
     call field_get_id('dt', flid)
 
@@ -569,11 +551,11 @@ if (idtvar.ge.0) then
       dtloc = dt(1)
       if (dtloc.gt.dtmax) then
         dtloc = dtmax
-        icfmax = ncel
+        icfmax(1) = ncel
       endif
       if (dtloc.lt.dtmin) then
         dtloc = dtmin
-        icfmin = ncel
+        icfmin(1) = ncel
       endif
 
       ntcam1 = ntcabs - 1
@@ -583,7 +565,7 @@ if (idtvar.ge.0) then
         call csexit(1)
       endif
 
-      call log_iteration_clipping_field(flid, icfmin, icfmax, dt, dt)
+      call log_iteration_clipping_field(flid, icfmin(1), icfmax(1), dt, dt,icfmin(1), icfmax(1))
 
       ttcabs = ttcabs + (dtloc - dt(1))
       if (imobil.eq.1 .or. iturbo.eq.2) then
@@ -605,29 +587,29 @@ if (idtvar.ge.0) then
         vmax(1) = max(vmax(1),dt(iel))
 
         if (dt(iel).gt.dtmax) then
-          icfmax = icfmax +1
+          icfmax(1) = icfmax(1) +1
           dt(iel) = dtmax
         endif
         if (dt(iel).lt.dtmin) then
-          icfmin = icfmin +1
+          icfmin(1) = icfmin(1) +1
           dt(iel) = dtmin
         endif
 
       enddo
 
-      call log_iteration_clipping_field(flid, icfmin, icfmax, vmin, vmax)
+      call log_iteration_clipping_field(flid, icfmin(1), icfmax(1), vmin, vmax,icfmin(1), icfmax(1))
 
     endif
 
 
     if (iwarnp.ge.2) then
       if (irangp.ge.0) then
-        call parcpt (icfmin)
+        call parcpt (icfmin(1))
         !==========
-        call parcpt (icfmax)
+        call parcpt (icfmax(1))
         !==========
       endif
-      write (nfecra,1003) icfmin,dtmin,icfmax,dtmax
+      write (nfecra,1003) icfmin(1),dtmin,icfmax(1),dtmax
     endif
 
   endif
@@ -672,16 +654,15 @@ if (idtvar.ge.0) then
  (iconv(iu), idiff0, isym, coefbt, cofbft, imasfl, bmasfl, viscf, viscb, dam)
 
     do iel = 1, ncel
-      rom = crom(iel)
-      w1    (iel) = dam(iel)/(rom*volume(iel))
+      w1(iel) = dam(iel)/(crom(iel)*volume(iel))
     enddo
 
     ! CALCUL DU NOMBRE DE COURANT/FOURIER MAXIMUM ET MINIMUM
 
     cfmax = -grand
     cfmin =  grand
-    icfmax= 1
-    icfmin= 1
+    icfmax(1)= 1
+    icfmin(1)= 1
 
     do iel = 1, ncel
       cpro_cour(iel) = w1(iel)*dt(iel)
@@ -692,20 +673,20 @@ if (idtvar.ge.0) then
       do iel = 1, ncel
         if (cpro_cour(iel).le.cfmin) then
           cfmin  = cpro_cour(iel)
-          icfmin = iel
+          icfmin(1) = iel
         endif
         if (cpro_cour(iel).ge.cfmax) then
           cfmax  = cpro_cour(iel)
-          icfmax = iel
+          icfmax(1) = iel
         endif
       enddo
 
-      xyzmin(1) = xyzcen(1,icfmin)
-      xyzmin(2) = xyzcen(2,icfmin)
-      xyzmin(3) = xyzcen(3,icfmin)
-      xyzmax(1) = xyzcen(1,icfmax)
-      xyzmax(2) = xyzcen(2,icfmax)
-      xyzmax(3) = xyzcen(3,icfmax)
+      xyzmin(1) = xyzcen(1,icfmin(1))
+      xyzmin(2) = xyzcen(2,icfmin(1))
+      xyzmin(3) = xyzcen(3,icfmin(1))
+      xyzmax(1) = xyzcen(1,icfmax(1))
+      xyzmax(2) = xyzcen(2,icfmax(1))
+      xyzmax(3) = xyzcen(3,icfmax(1))
 
       if (irangp.ge.0) then
         nbrval = 3
@@ -743,16 +724,15 @@ if (idtvar.ge.0) then
  (iconv0, idiff(iu), isym, coefbt, cofbft, imasfl, bmasfl, viscf, viscb, dam)
 
     do iel = 1, ncel
-      rom = crom(iel)
-      w1    (iel) = dam(iel)/(rom*volume(iel))
+      w1(iel) = dam(iel)/(crom(iel)*volume(iel))
     enddo
 
     ! CALCUL DU NOMBRE DE COURANT/FOURIER MAXIMUM ET MINIMUM
 
     cfmax  = -grand
     cfmin  =  grand
-    icfmax = 0
-    icfmin = 0
+    icfmax(1) = 0
+    icfmin(1) = 0
 
     do iel = 1, ncel
       cpro_four(iel) = w1(iel)*dt(iel)
@@ -763,20 +743,20 @@ if (idtvar.ge.0) then
       do iel = 1, ncel
         if (cpro_four(iel).le.cfmin) then
           cfmin  = cpro_four(iel)
-          icfmin = iel
+          icfmin(1) = iel
         endif
         if (cpro_four(iel).ge.cfmax) then
           cfmax  = cpro_four(iel)
-          icfmax = iel
+          icfmax(1) = iel
         endif
       enddo
 
-      xyzmin(1) = xyzcen(1,icfmin)
-      xyzmin(2) = xyzcen(2,icfmin)
-      xyzmin(3) = xyzcen(3,icfmin)
-      xyzmax(1) = xyzcen(1,icfmax)
-      xyzmax(2) = xyzcen(2,icfmax)
-      xyzmax(3) = xyzcen(3,icfmax)
+      xyzmin(1) = xyzcen(1,icfmin(1))
+      xyzmin(2) = xyzcen(2,icfmin(1))
+      xyzmin(3) = xyzcen(3,icfmin(1))
+      xyzmax(1) = xyzcen(1,icfmax(1))
+      xyzmax(2) = xyzcen(2,icfmax(1))
+      xyzmax(3) = xyzcen(3,icfmax(1))
 
       if (irangp.ge.0) then
         nbrval = 3
@@ -817,16 +797,15 @@ if (idtvar.ge.0) then
  (iconv(iu), idiff(iu), isym, coefbt, cofbft, imasfl, bmasfl, viscf, viscb, dam)
 
     do iel = 1, ncel
-      rom = crom(iel)
-      w1    (iel) = dam(iel)/(rom*volume(iel))
+      w1(iel) = dam(iel)/(crom(iel)*volume(iel))
     enddo
 
     ! CALCUL DU NOMBRE DE COURANT/FOURIER MAXIMUM ET MINIMUM
 
     cfmax  = -grand
     cfmin  =  grand
-    icfmax = 0
-    icfmin = 0
+    icfmax(1) = 0
+    icfmin(1) = 0
 
     do iel = 1, ncel
       w2(iel) = w1(iel)*dt(iel)
@@ -841,20 +820,20 @@ if (idtvar.ge.0) then
       do iel = 1, ncel
         if (w2(iel).le.cfmin) then
           cfmin  = w2(iel)
-          icfmin = iel
+          icfmin(1) = iel
         endif
         if (w2(iel).ge.cfmax) then
           cfmax  = w2(iel)
-          icfmax = iel
+          icfmax(1) = iel
         endif
       enddo
 
-      xyzmin(1) = xyzcen(1,icfmin)
-      xyzmin(2) = xyzcen(2,icfmin)
-      xyzmin(3) = xyzcen(3,icfmin)
-      xyzmax(1) = xyzcen(1,icfmax)
-      xyzmax(2) = xyzcen(2,icfmax)
-      xyzmax(3) = xyzcen(3,icfmax)
+      xyzmin(1) = xyzcen(1,icfmin(1))
+      xyzmin(2) = xyzcen(2,icfmin(1))
+      xyzmin(3) = xyzcen(3,icfmin(1))
+      xyzmax(1) = xyzcen(1,icfmax(1))
+      xyzmax(2) = xyzcen(2,icfmax(1))
+      xyzmax(3) = xyzcen(3,icfmax(1))
 
       if (irangp.ge.0) then
         nbrval = 3
@@ -885,8 +864,8 @@ if (idtvar.ge.0) then
 
     cfmax  = -grand
     cfmin  =  grand
-    icfmax = 0
-    icfmin = 0
+    icfmax(1) = 0
+    icfmin(1) = 0
 
     do iel = 1, ncel
       w2(iel) = wcf(iel)*dt(iel)
@@ -901,20 +880,20 @@ if (idtvar.ge.0) then
       do iel = 1, ncel
         if (w2(iel).le.cfmin) then
           cfmin  = w2(iel)
-          icfmin = iel
+          icfmin(1) = iel
         endif
         if (w2(iel).ge.cfmax) then
           cfmax  = w2(iel)
-          icfmax = iel
+          icfmax(1) = iel
         endif
       enddo
 
-      xyzmin(1) = xyzcen(1,icfmin)
-      xyzmin(2) = xyzcen(2,icfmin)
-      xyzmin(3) = xyzcen(3,icfmin)
-      xyzmax(1) = xyzcen(1,icfmax)
-      xyzmax(2) = xyzcen(2,icfmax)
-      xyzmax(3) = xyzcen(3,icfmax)
+      xyzmin(1) = xyzcen(1,icfmin(1))
+      xyzmin(2) = xyzcen(2,icfmin(1))
+      xyzmin(3) = xyzcen(3,icfmin(1))
+      xyzmax(1) = xyzcen(1,icfmax(1))
+      xyzmax(2) = xyzcen(2,icfmax(1))
+      xyzmax(3) = xyzcen(3,icfmax(1))
 
       if (irangp.ge.0) then
         nbrval = 3
