@@ -25,11 +25,6 @@
 !> selected by the user.
 !
 !------------------------------------------------------------------------------
-!
-!> \brief Variables definition initialization, according to calculation type
-!> selected by the user.
-!
-!------------------------------------------------------------------------------
 ! Arguments
 !------------------------------------------------------------------------------
 !   mode          name          role
@@ -131,11 +126,20 @@ do ipp = 2, nmodmx
     ippok = ipp
   endif
 enddo
-if (nmodpp.gt.1) then
+if (nmodpp.gt.1.and.(ippmod(igmix).eq.-1.or.ippmod(icompf).eq.-1)) then
   write(nfecra,6000)
   iok = iok + 1
 endif
 
+! In case ideal gas mix specific physics was enabled by the user
+! together with the compressible module, the equation of state
+! indicator is reset to the approprate value automatically (ieos=3)
+! and the user is warned.
+if (ippmod(igmix).ge.0.and.ippmod(icompf).ge.0.and.ieos.ne.3) then
+  ieos = 3
+  write(nfecra,6002)
+endif
+
 if (nmodpp.eq.1) then
   if (ippmod(ippok).lt.0 .or. ippmod(ippok).gt.5) then
     write(nfecra,6001)
@@ -201,12 +205,26 @@ if (itytur.eq.2) then
   call add_variable_field('k', 'Turb Kinetic Energy', 1, ik)
   call add_variable_field('epsilon', 'Turb Dissipation', 1, iep)
 else if (itytur.eq.3) then
-  call add_variable_field('r11', 'R11', 1, ir11)
-  call add_variable_field('r22', 'R22', 1, ir22)
-  call add_variable_field('r33', 'R33', 1, ir33)
-  call add_variable_field('r12', 'R12', 1, ir12)
-  call add_variable_field('r23', 'R23', 1, ir23)
-  call add_variable_field('r13', 'R13', 1, ir13)
+  if (irijco.eq.1) then
+    call add_variable_field('rij', 'Rij', 6, irij)
+    call field_set_key_int(ivarfl(irij), keycpl, 1)
+
+    ! All rij components point to same field
+    ir11 = irij
+    ir22 = ir11 + 1
+    ir33 = ir22 + 1
+    ir12 = ir33 + 1
+    ir23 = ir12 + 1
+    ir13 = ir23 + 1
+  else
+    call add_variable_field('r11', 'R11', 1, ir11)
+    call add_variable_field('r22', 'R22', 1, ir22)
+    call add_variable_field('r33', 'R33', 1, ir33)
+    call add_variable_field('r12', 'R12', 1, ir12)
+    call add_variable_field('r23', 'R23', 1, ir23)
+    call add_variable_field('r13', 'R13', 1, ir13)
+  endif
+
   call add_variable_field('epsilon', 'Turb Dissipation', 1, iep)
   if (iturb.eq.32) then
     call add_variable_field('alpha', 'Alphap', 1, ial)
@@ -295,7 +313,11 @@ if (iihmpr.eq.1) then
 endif
 
 call add_user_scalar_fields
-!==========================
+
+! Map pointers
+
+call cs_field_pointer_map_base
+call cs_field_pointer_map_boundary
 
 ! ---> Verifications
 
@@ -335,10 +357,12 @@ return
 '@                                                            ',/,&
 '@ @@ ATTENTION : ARRET A L''ENTREE DES DONNEES               ',/,&
 '@    =========                                               ',/,&
-'@     PLUSIEURS MODELES PHYSIQUES PARTICULIERES ACTIVES      ',/,&
+'@     PLUSIEURS MODELES DE PHYSIQUES PARTICULIERES           ',/,&
+'@     INCOMPATIBLES SONT ACTIVES                             ',/,&
 '@                                                            ',/,&
-'@  Un seul modele physique particuliere peut etre active a la',/,&
-'@    fois.                                                   ',/,&
+'@  Seul les modeles de physiques particulieres compressible  ',/,&
+'@    et melange de gaz parfaits peuvent etre actives         ',/,&
+'@    simultanement.                                          ',/,&
 '@                                                            ',/,&
 '@  Le calcul ne sera pas execute.                            ',/,&
 '@                                                            ',/,&
@@ -362,6 +386,25 @@ return
 '@  Modifier les indicateurs de IPPMOD dans usppmo.           ',/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/)
+ 6002 format(                                                     &
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/,&
+'@ @@ ATTENTION :  A L''ENTREE DES DONNEES                    ',/,&
+'@    =========                                               ',/,&
+'@     EQUATION D''ETAT INCOMPATIBLE AVEC LES PHYSIQUES       ',/,&
+'@     PARTICULIERES SELECTIONNEES                            ',/,&
+'@                                                            ',/,&
+'@  Les modeles de physiques particulieres compressible et    ',/,&
+'@    et melange de gaz parfaits sont actives simultanement   ',/,&
+'@    mais l''equation d''etat selectionnee n''est pas melange',/,&
+'@    de gas parfait (ieos different de 3).                   ',/,&
+'@                                                            ',/,&
+'@  L''indicateur ieos a ete repositionne a 3 et le calcul    ',/,&
+'@  sera execute.                                             ',/,&
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
  6010 format(                                                     &
 '@                                                            ',/,&
@@ -439,10 +482,11 @@ return
 '@                                                            ',/,&
 '@ @@ WARNING   : STOP AT THE INITIAL DATA VERIFICATION       ',/,&
 '@    =========                                               ',/,&
-'@     TOO MANY SPECIFIC PHYSICS MODULES ACTIVATED            ',/,&
+'@     SEVERAL INCOMPATIBLE MODELS OF SPECIFIC PHYSICS ARE    ',/,&
+'@     ARE ENABLED.                                           ',/,&
 '@                                                            ',/,&
-'@  Only one specific physics module can be active for one    ',/,&
-'@    given calculation.                                      ',/,&
+'@  Only the compressible and gas mix specific physics can be ',/,&
+'@    enabled simultaneously.                                 ',/,&
 '@                                                            ',/,&
 '@  The calculation will not be run.                          ',/,&
 '@                                                            ',/,&
@@ -466,6 +510,24 @@ return
 '@  Modify the indices of       IPPMOD in   usppmo.           ',/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/)
+ 6002 format(                                                     &
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
+'@                                                            ',/,&
+'@ @@ WARNING   : AT THE INITIAL DATA VERIFICATION            ',/,&
+'@    =========                                               ',/,&
+'@     EQUATION OF STATE INCOMPATIBLE WITH SELECTED SPECIFIC  ',/,&
+'@     PHYSICS                                                ',/,&
+'@                                                            ',/,&
+'@  The specific physics compressible and gas mix are         ',/,&
+'@    simultaneously enabled but the selected equation of     ',/,&
+'@    state is not ideal gas mix (ieos different from 3).     ',/,&
+'@                                                            ',/,&
+'@  The indicator ieos has been reset to 3 and the calculation',/,&
+'@  will run.                                                 ',/,&
+'@                                                            ',/,&
+'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
  6010 format(                                                     &
 '@                                                            ',/,&
