@@ -424,6 +424,7 @@ ir33   = 0
 ir12   = 0
 ir13   = 0
 ir23   = 0
+irij   = 0
 iphi   = 0
 ifb    = 0
 ial    = 0
@@ -455,10 +456,12 @@ ifour  = 0
 icp    = 0
 iprtot = 0
 
+itemp  = 0
 ibeta  = 0
 
 iforbr = -1
 iyplbr = -1
+itempb = -1
 
 ! --- Ici tout numvar est initialise.
 
@@ -778,6 +781,7 @@ iwalfs = -999
 iwallt = 0
 iclkep = 0
 ikecou =-999
+irijco = 0
 irijnu = 0
 irijrb = 0
 irijec = 0
