@@ -85,8 +85,7 @@ double precision dt(ncelet), propce(ncelet,*)
 integer          iis   , iscal , iprop
 integer          iel   , ifac  , isou
 integer          iclip , ii    , jj    , idim
-integer          iivisa, iivism
-integer          iicpa
+integer          iivism
 integer          ifcvsl
 integer          nn
 integer          iflid, nfld, ifmaip, bfmaip, iflmas, iflmab
@@ -109,8 +108,11 @@ double precision, dimension(:), pointer :: cvar_k, cvar_ep, cvar_al
 double precision, dimension(:), pointer :: cvar_phi, cvar_fb, cvar_omg, cvar_nusa
 double precision, dimension(:), pointer :: cvar_r11, cvar_r22, cvar_r33
 double precision, dimension(:), pointer :: cvar_r12, cvar_r13, cvar_r23
+double precision, dimension(:,:), pointer :: cvar_rij
 double precision, dimension(:), pointer :: viscl, visct, cpro_cp, cpro_prtot
 double precision, dimension(:), pointer :: cpro_viscls, cproa_viscls, cvar_tempk
+double precision, dimension(:), pointer :: cproa_viscl, cproa_cp
+double precision, dimension(:), pointer :: mix_mol_mas
 
 !===============================================================================
 
@@ -229,9 +231,9 @@ do iel = 1, ncel
   viscl(iel) = viscl0
 enddo
 if(iviext.gt.0) then
-  iivisa = ipproc(ivisla)
+  call field_get_val_prev_s(iprpfl(iviscl), cproa_viscl)
   do iel = 1, ncel
-    propce(iel,iivisa) = viscl(iel)
+    cproa_viscl(iel) = viscl(iel)
   enddo
 endif
 
@@ -242,9 +244,9 @@ if(icp.gt.0) then
     cpro_cp(iel) = cp0
   enddo
   if(icpext.gt.0) then
-    iicpa  = ipproc(icpa)
+    call field_get_val_prev_s(iprpfl(icp), cproa_cp)
     do iel = 1, ncel
-      propce(iel,iicpa ) = cpro_cp(iel)
+      cproa_cp(iel) = cpro_cp(iel)
     enddo
   endif
 endif
@@ -259,6 +261,15 @@ if (ippmod(icompf).lt.0) then
   enddo
 endif
 
+! Initialization of mix_mol_mas with default values (air)
+! (used in cs_cf_thermo_default_init)
+if(ippmod(igmix).ge.0) then
+  call field_get_val_s(iprpfl(igmxml), mix_mol_mas)
+  do iel =1, ncel
+    mix_mol_mas(iel) = xmasmr
+  enddo
+endif
+
 ! Default initialisations for the compressible model
 if (ippmod(icompf).ge.0) then
   ! In compressible, for now, the temperature is not solved but is a field of
@@ -270,7 +281,7 @@ if (ippmod(icompf).ge.0) then
 
   ! Default isochoric specific heat (cv0),
   ! total energy and density
-  call cs_cf_thermo_default_init(isuite)
+  call cs_cf_thermo_default_init
 
   ! Default diffusivity for total energy
   visls0(ienerg) = visls0(itempk)/cv0
@@ -416,52 +427,86 @@ elseif(itytur.eq.3) then
 
   call field_get_val_s(ivarfl(iep), cvar_ep)
 
-  call field_get_val_s(ivarfl(ir11), cvar_r11)
-  call field_get_val_s(ivarfl(ir22), cvar_r22)
-  call field_get_val_s(ivarfl(ir33), cvar_r33)
-  call field_get_val_s(ivarfl(ir12), cvar_r12)
-  call field_get_val_s(ivarfl(ir23), cvar_r23)
-  call field_get_val_s(ivarfl(ir13), cvar_r13)
+  if (irijco.eq.1) then
+      call field_get_val_v(ivarfl(irij), cvar_rij)
 
-  if (uref.ge.0.d0) then
 
-    trii   = (0.02d0*uref)**2
+    if (uref.ge.0.d0) then
 
-    do iel = 1, ncel
-      cvar_r11(iel) = trii
-      cvar_r22(iel) = trii
-      cvar_r33(iel) = trii
-      cvar_r12(iel) = 0.d0
-      cvar_r13(iel) = 0.d0
-      cvar_r23(iel) = 0.d0
-      xxk = 0.5d0*(cvar_r11(iel)+                             &
-           cvar_r22(iel)+cvar_r33(iel))
-      cvar_ep(iel) = xxk**1.5d0*cmu/almax
-    enddo
-    iclip = 1
-    call clprij(ncelet , ncel   , nvar    ,     &
-                iclip  )
+      trii   = (0.02d0*uref)**2
 
-  else
-
-    do iel = 1, ncel
-      cvar_r11(iel) = -grand
-      cvar_r22(iel) = -grand
-      cvar_r33(iel) = -grand
-      cvar_r12(iel) = -grand
-      cvar_r13(iel) = -grand
-      cvar_r23(iel) = -grand
-      cvar_ep(iel)  = -grand
-    enddo
-
-    if(iturb.eq.32)then
-      call field_get_val_s(ivarfl(ial), cvar_al)
       do iel = 1, ncel
-        cvar_al(iel) = 1.d0
+        cvar_rij(1,iel) = trii
+        cvar_rij(2,iel) = trii
+        cvar_rij(3,iel) = trii
+        cvar_rij(4,iel) = 0.d0
+        cvar_rij(5,iel) = 0.d0
+        cvar_rij(6,iel) = 0.d0
+        xxk = 0.5d0*(cvar_rij(1,iel)+                             &
+             cvar_rij(2,iel)+cvar_rij(3,iel))
+        cvar_ep(iel) = xxk**1.5d0*cmu/almax
+      enddo
+      iclip = 1
+      call clprij2(ncelet, ncel, iclip)
+
+    else
+
+      do iel = 1, ncel
+        cvar_rij(1,iel) = -grand
+        cvar_rij(2,iel) = -grand
+        cvar_rij(3,iel) = -grand
+        cvar_rij(4,iel) = -grand
+        cvar_rij(5,iel) = -grand
+        cvar_rij(6,iel) = -grand
+        cvar_ep(iel)  = -grand
+      enddo
+
+    endif
+  else
+      call field_get_val_s(ivarfl(ir11), cvar_r11)
+      call field_get_val_s(ivarfl(ir22), cvar_r22)
+      call field_get_val_s(ivarfl(ir33), cvar_r33)
+      call field_get_val_s(ivarfl(ir12), cvar_r12)
+      call field_get_val_s(ivarfl(ir23), cvar_r23)
+      call field_get_val_s(ivarfl(ir13), cvar_r13)
+
+    if (uref.ge.0.d0) then
+
+      trii   = (0.02d0*uref)**2
+
+      do iel = 1, ncel
+        cvar_r11(iel) = trii
+        cvar_r22(iel) = trii
+        cvar_r33(iel) = trii
+        cvar_r12(iel) = 0.d0
+        cvar_r13(iel) = 0.d0
+        cvar_r23(iel) = 0.d0
+        xxk = 0.5d0*(cvar_r11(iel)+                             &
+             cvar_r22(iel)+cvar_r33(iel))
+        cvar_ep(iel) = xxk**1.5d0*cmu/almax
+      enddo
+      iclip = 1
+      call clprij(ncelet, ncel, iclip)
+
+    else
+
+      do iel = 1, ncel
+        cvar_r11(iel) = -grand
+        cvar_r22(iel) = -grand
+        cvar_r33(iel) = -grand
+        cvar_r12(iel) = -grand
+        cvar_r13(iel) = -grand
+        cvar_r23(iel) = -grand
+        cvar_ep(iel)  = -grand
       enddo
     endif
-
- endif
+  endif
+  if(iturb.eq.32)then
+    call field_get_val_s(ivarfl(ial), cvar_al)
+    do iel = 1, ncel
+      cvar_al(iel) = 1.d0
+    enddo
+  endif
 
 elseif(iturb.eq.60) then
 
@@ -606,20 +651,7 @@ do ii = 1, nfld
 enddo
 
 !===============================================================================
-! 9.  INITIALISATION DU NUMERO DE LA FACE DE PAROI 5 LA PLUS PROCHE
-!===============================================================================
-
-!     Si IFAPAT existe,
-!     on suppose qu'il faut le (re)calculer : on init le tab a -1.
-
-if (ineedy.gt.0 .and. abs(icdpar).eq.2) then
-  do iel = 1, ncel
-    ifapat(iel) = -1
-  enddo
-endif
-
-!===============================================================================
-! 10.  INITIALISATION DE LA FORCE EXTERIEURE QUAND IPHYDR=1
+! 8.  INITIALISATION DE LA FORCE EXTERIEURE QUAND IPHYDR=1
 !===============================================================================
 
 if(iphydr.eq.1) then
@@ -631,7 +663,7 @@ if(iphydr.eq.1) then
 endif
 
 !===============================================================================
-! 11.  INITIALISATION DE LA PRESSION HYDROSTATIQUE QUAND IPHYDR=2
+! 9.  INITIALISATION DE LA PRESSION HYDROSTATIQUE QUAND IPHYDR=2
 !===============================================================================
 
 if(iphydr.eq.2) then
@@ -641,7 +673,7 @@ if(iphydr.eq.2) then
 endif
 
 !===============================================================================
-! 12.  INITIALISATIONS EN ALE OU MAILLAGE MOBILE
+! 10.  INITIALISATIONS EN ALE OU MAILLAGE MOBILE
 !===============================================================================
 
 if (iale.eq.1) then
