@@ -81,7 +81,6 @@ character(len=80) :: chaine
 integer          ivar  , iscal
 integer          iel
 integer          iclip , iok   , ii
-integer          ifcven, ifclam
 integer          kscmin, kscmax, keyvar, n_fields
 integer          f_id, f_id_prv, c_id, f_dim
 integer          iflid, iflidp
@@ -108,8 +107,9 @@ double precision, dimension(:), pointer :: cvar_pr
 double precision, dimension(:), pointer :: cvar_k, cvar_ep, cvar_al
 double precision, dimension(:), pointer :: cvar_phi, cvar_omg, cvar_nusa
 double precision, dimension(:), pointer :: cvar_r11, cvar_r22, cvar_r33
-double precision, dimension(:), pointer :: cvar_tempk, cvar_var
-double precision, dimension(:), pointer :: cpro_prtot, cpro_venerg, cpro_lambda
+double precision, dimension(:,:), pointer :: cvar_rij
+double precision, dimension(:), pointer :: cvar_var
+double precision, dimension(:), pointer :: cpro_prtot
 
 !===============================================================================
 
@@ -155,22 +155,22 @@ do ivar = 1, nvar
       idimf = 6
     endif
     call field_get_key_int(iflid, kwgrec, f_id)
-  if (idimf.eq.6) then
-    call field_get_val_v(f_id, field_v_v)
-    do iel = 1, ncelet
-      field_v_v(1,iel) = 1.d0
-      field_v_v(2,iel) = 1.d0
-      field_v_v(3,iel) = 1.d0
-      field_v_v(4,iel) = 0.d0
-      field_v_v(5,iel) = 0.d0
-      field_v_v(6,iel) = 0.d0
-    enddo
-  else if (idimf.eq.1) then
-    call field_get_val_s(f_id, field_s_v)
-    do iel = 1, ncelet
-      field_s_v(iel) = 1.d0
-    enddo
-  endif
+    if (idimf.eq.6) then
+      call field_get_val_v(f_id, field_v_v)
+      do iel = 1, ncelet
+        field_v_v(1,iel) = 1.d0
+        field_v_v(2,iel) = 1.d0
+        field_v_v(3,iel) = 1.d0
+        field_v_v(4,iel) = 0.d0
+        field_v_v(5,iel) = 0.d0
+        field_v_v(6,iel) = 0.d0
+      enddo
+    else if (idimf.eq.1) then
+      call field_get_val_s(f_id, field_s_v)
+      do iel = 1, ncelet
+        field_s_v(iel) = 1.d0
+      enddo
+    endif
 
   endif
 enddo
@@ -180,10 +180,7 @@ enddo
 
 if (iihmpr.eq.1) then
 
-  call uiiniv (ncelet, isuite, ippmod(idarcy),     &
-               ithvar,                             &
-               ro0, cp0, viscl0, uref,             &
-               almax, xyzcen)
+  call uiiniv (isuite, ippmod(idarcy), ithvar)
 
 endif
 
@@ -379,37 +376,47 @@ if(iusini.eq.1.or.isuite.eq.1) then
   elseif(itytur.eq.3) then
 
     call field_get_val_s(ivarfl(iep), cvar_ep)
+    if (irijco.eq.1) then
+      call field_get_val_v(ivarfl(irij), cvar_rij)
 
-    call field_get_val_s(ivarfl(ir11), cvar_r11)
-    call field_get_val_s(ivarfl(ir22), cvar_r22)
-    call field_get_val_s(ivarfl(ir33), cvar_r33)
+      x11min = cvar_rij(1,1)
+      x22min = cvar_rij(2,1)
+      x33min = cvar_rij(3,1)
+      xepmin = cvar_ep(1)
+      do iel = 1, ncel
+        x11min = min(x11min,cvar_rij(1,iel))
+        x22min = min(x22min,cvar_rij(2,iel))
+        x33min = min(x33min,cvar_rij(3,iel))
+        xepmin = min(xepmin,cvar_ep(iel) )
+      enddo
+    else
+      call field_get_val_s(ivarfl(ir11), cvar_r11)
+      call field_get_val_s(ivarfl(ir22), cvar_r22)
+      call field_get_val_s(ivarfl(ir33), cvar_r33)
 
-    x11min = cvar_r11(1)
-    x22min = cvar_r22(1)
-    x33min = cvar_r33(1)
-    xepmin = cvar_ep(1)
-    do iel = 1, ncel
-      x11min = min(x11min,cvar_r11(iel))
-      x22min = min(x22min,cvar_r22(iel))
-      x33min = min(x33min,cvar_r33(iel))
-      xepmin = min(xepmin,cvar_ep(iel) )
-    enddo
+      x11min = cvar_r11(1)
+      x22min = cvar_r22(1)
+      x33min = cvar_r33(1)
+      xepmin = cvar_ep(1)
+      do iel = 1, ncel
+        x11min = min(x11min,cvar_r11(iel))
+        x22min = min(x22min,cvar_r22(iel))
+        x33min = min(x33min,cvar_r33(iel))
+        xepmin = min(xepmin,cvar_ep(iel) )
+      enddo
+    endif
     if (irangp.ge.0) then
       call parmin (x11min)
-      !==========
       call parmin (x22min)
-      !==========
       call parmin (x33min)
-      !==========
       call parmin (xepmin)
-      !==========
     endif
     if (x11min.ge.0.d0.and.x22min.ge.0.d0.and.                  &
          x33min.ge.0.d0.and.xepmin.ge.0.d0 ) then
       iclip = 1
-      call clprij( ncelet , ncel   , nvar   ,          &
-      !==========
-                   iclip  )
+      if (irijco.eq.0) then
+        call clprij(ncelet, ncel, iclip)
+      endif
     else
       write(nfecra,3030) x11min,x22min,x33min,xepmin
       iok = iok + 1
