@@ -762,7 +762,7 @@ endif
 ! Idem en Spalart-Allmaras.
 
 if (ypluli.lt.-grand) then
-  if (iwallf.eq.4 .or. itytur.eq.4 .or. iturb.eq.70) then
+  if (iwallf.eq.4 .or. itytur.eq.4 .or. iturb.eq.70.or.iwallf.eq.6) then
     ypluli = 10.88d0
   else
     ypluli = 1.d0/xkappa
@@ -838,6 +838,11 @@ if (nscal.gt.0) then
 
 endif
 
+! Temperature scale
+
+if (itherm.ge.1 .and. itpscl.le.0) then
+  itpscl = 1
+endif
 
 ! ---> ISCACP
 !      Si l'utilisateur n'a pas modifie ISCACP, on prend par defaut :
