@@ -100,6 +100,10 @@ module numvar
   !> Reynolds stress component \f$ R_{zz} \f$
   integer, save :: ir13
 
+  !> \anchor irij
+  !> Reynolds stress tenso \f$ R_{ij} \f$
+  integer, save :: irij
+
   !> \anchor iphi
   !> variable \f$ \phi \f$ of the \f$ \phi-f_b \f$ model
   integer, save :: iphi
@@ -249,12 +253,20 @@ module numvar
   !> pointer for thermal expansion coefficient
   integer, save :: ibeta
 
+  !> pointer for deduced mass fraction in case of gas mix
+  integer, save :: iddgas
+
+  !> pointer for gas mix molar mass
+  integer, save :: igmxml
+
   !> field id of the stresses at boundary  (if post-processed)
   integer, save :: iforbr
 
   !>  field id of \f$y^+\f$ at boundary (if post-processed)
   integer, save :: iyplbr
 
+  !>  field id of temperature at boundary
+  integer, save ::  itempb
   !> \}
   !----------------------------------------------------------------------------
   ! Numerical properties
