@@ -226,156 +226,6 @@ end subroutine post_boundary_thermal_flux
 ! Function:
 ! ---------
 
-!> \brief Compute temperature at boundary.
-
-!> If working with enthalpy, compute an enthalpy.
-
-!-------------------------------------------------------------------------------
-! Arguments
-!______________________________________________________________________________.
-!  mode           name          role                                           !
-!______________________________________________________________________________!
-!> \param[in]     nfbrps        number of boundary faces to postprocess
-!> \param[in]     lstfbr        list of boundary faces to postprocess
-!> \param[out]    btemp         boundary temperature at selected faces
-!_______________________________________________________________________________
-
-subroutine post_boundary_temperature &
- ( nfbrps , lstfbr ,                                               &
-   btemp )
-
-!===============================================================================
-
-!===============================================================================
-! Module files
-!===============================================================================
-
-use paramx
-use pointe
-use entsor
-use cstnum
-use cstphy
-use optcal
-use numvar
-use parall
-use period
-use mesh
-use field
-use field_operator
-
-!===============================================================================
-
-implicit none
-
-! Arguments
-
-integer, intent(in)                                :: nfbrps
-integer, dimension(nfbrps), intent(in)             :: lstfbr
-double precision, dimension(nfbrps), intent(out)   :: btemp
-
-! Local variables
-
-integer ::         inc, iccocg
-integer ::         iel, ifac, iloc, ivar
-integer ::         itplus, itstar
-
-double precision :: diipbx, diipby, diipbz
-double precision :: tcel
-
-double precision, allocatable, dimension(:,:) :: grad
-double precision, dimension(:), pointer :: tplusp, tstarp
-double precision, dimension(:), pointer :: tscalp
-
-!===============================================================================
-
-! pointers to T+ and T* if saved
-
-call field_get_id_try('tplus', itplus)
-call field_get_id_try('tstar', itstar)
-
-if (itstar.ge.0 .and. itplus.ge.0) then
-
-  ivar = isca(iscalt)
-
-  call field_get_val_prev_s(ivarfl(ivar), tscalp)
-
-  call field_get_val_s (itplus, tplusp)
-  call field_get_val_s (itstar, tstarp)
-
-  ! Compute variable values at boundary faces
-
-  ! Reconstructed fluxes
-  if (ircflu(ivar) .gt. 0 .and. itbrrb.eq.1) then
-
-    ! Allocate a temporary array for the gradient calculation
-    allocate(grad(3,ncelet))
-
-    inc = 1
-    iccocg = 1
-
-    ! Compute gradient of temperature / enthalpy
-
-    call field_gradient_scalar &
-      (ivarfl(ivar), 1, imrgra, inc, iccocg,                               &
-       grad)
-
-    ! Compute reconstructed value in boundary cells
-
-    do iloc = 1, nfbrps
-
-      ifac = lstfbr(iloc)
-      iel = ifabor(ifac)
-
-      diipbx = diipb(1,ifac)
-      diipby = diipb(2,ifac)
-      diipbz = diipb(3,ifac)
-      tcel =   tscalp(iel)                                                  &
-             + diipbx*grad(1,iel) + diipby*grad(2,iel) + diipbz*grad(3,iel)
-
-      btemp(iloc) = tcel - tplusp(ifac)*tstarp(ifac)
-
-    enddo
-
-    deallocate(grad)
-
-  else ! If flux is not reconstructed
-
-    do iloc = 1, nfbrps
-
-      ifac = lstfbr(iloc)
-      iel = ifabor(ifac)
-
-      tcel = tscalp(iel)
-
-      btemp(iloc) = tcel - tplusp(ifac)*tstarp(ifac)
-
-    enddo
-
-  endif
-
-else ! default if not computable
-
-  do iloc = 1, nfbrps
-    btemp(iloc) = -1.d0
-  enddo
-
-endif
-
-!--------
-! Formats
-!--------
-
-!----
-! End
-!----
-
-return
-end subroutine post_boundary_temperature
-
-!===============================================================================
-! Function:
-! ---------
-
 !> \brief Compute Nusselt number near boundary.
 
 !-------------------------------------------------------------------------------
