@@ -26,7 +26,7 @@
 
 !> \file predvv.f90
 !>
-!> \brief This subroutine perform the velocity prediction step of the Navier
+!> \brief This subroutine performs the velocity prediction step of the Navier
 !> Stokes equations for incompressible or slightly compressible flows for
 !> the coupled velocity components solver.
 !>
@@ -56,7 +56,6 @@
 !> \param[in]     ifbpcd        index of faces with condensation source terms
 !> \param[in]     ltmast        index of cells with condensation source terms
 !> \param[in]     itypsm        type of mass source term for the variables
-!> \param[in]     itypcd        type of condensation source terms for the variables
 !> \param[in]     dt            time step (per cell)
 !> \param[in]     vel           velocity
 !> \param[in]     vela          velocity at the previous time step
@@ -105,7 +104,6 @@
 !> \param[in]     w7            working array
 !> \param[in]     w8            working array
 !> \param[in]     w9            working array
-!> \param[in]     xnormp        workig array for the norm of the pressure
 !_______________________________________________________________________________
 
 subroutine predvv &
@@ -113,7 +111,7 @@ subroutine predvv &
    nvar   , nscal  , iterns ,                                     &
    ncepdp , ncesmp , nfbpcd , ncmast ,                            &
    icepdc , icetsm , ifbpcd , ltmast ,                            &
-   itypsm , itypcd ,                                              &
+   itypsm ,                                                       &
    dt     , vel    , vela   ,                                     &
    propce ,                                                       &
    flumas , flumab ,                                              &
@@ -121,7 +119,7 @@ subroutine predvv &
    ckupdc , smacel , spcond , svcond , frcxt  , grdphd ,          &
    trava  , ximpa  , uvwk   , dfrcxt , tpucou , trav   ,          &
    viscf  , viscb  , viscfi , viscbi , secvif , secvib ,          &
-   w1     , w7     , w8     , w9     , xnormp )
+   w1     , w7     , w8     , w9     )
 
 !===============================================================================
 
@@ -169,7 +167,7 @@ integer          ncepdp , ncesmp , nfbpcd , ncmast
 
 integer          icepdc(ncepdp)
 integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
-integer          ifbpcd(nfbpcd), itypcd(nfbpcd,nvar)
+integer          ifbpcd(nfbpcd)
 integer          ltmast(ncelet)
 
 double precision dt(ncelet)
@@ -179,7 +177,7 @@ double precision tslagr(ncelet,*)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 double precision spcond(nfbpcd,nvar), svcond(ncelet,nvar)
 double precision frcxt(3,ncelet), dfrcxt(3,ncelet)
-double precision grdphd(ncelet,3)
+double precision grdphd(3, ncelet)
 double precision trava(ndim,ncelet)
 double precision ximpa(ndim,ndim,ncelet),uvwk(ndim,ncelet)
 double precision tpucou(6, ncelet)
@@ -189,7 +187,6 @@ double precision viscfi(*), viscbi(nfabor)
 double precision secvif(nfac), secvib(nfabor)
 double precision w1(ncelet)
 double precision w7(ncelet), w8(ncelet), w9(ncelet)
-double precision xnormp(ncelet)
 double precision coefav(3  ,ndimfb)
 double precision cofafv(3  ,ndimfb)
 double precision coefbv(3,3,ndimfb)
@@ -200,8 +197,8 @@ double precision vela  (3  ,ncelet)
 
 ! Local variables
 
-integer          f_id  , iel   , ielpdc, ifac  , isou  , itypfl
-integer          iccocg, inc   , iprev , init  , ii    , jj    , isqrt
+integer          f_id  , iel   , ielpdc, ifac  , isou  , itypfl, n_fans
+integer          iccocg, inc   , iprev , init  , ii    , jj
 integer          nswrgp, imligp, iwarnp
 integer          iswdyp, idftnp
 integer          iconvp, idiffp, ndircp, nswrsp
@@ -226,7 +223,7 @@ double precision rvoid(1)
 
 ! Working arrays
 double precision, allocatable, dimension(:,:) :: eswork
-double precision, allocatable, dimension(:,:) :: grad, gradni
+double precision, allocatable, dimension(:,:) :: grad
 double precision, dimension(:,:), allocatable :: smbr
 double precision, dimension(:,:,:), allocatable :: fimp
 double precision, dimension(:,:), allocatable :: gavinj
@@ -238,21 +235,21 @@ double precision, dimension(:), allocatable :: xinvro
 double precision, dimension(:), pointer :: brom, crom, croma, pcrom
 double precision, dimension(:), pointer :: coefa_k, coefb_k
 double precision, dimension(:), pointer :: coefa_p, coefb_p
-double precision, dimension(:), pointer :: porosi
-double precision, dimension(:), pointer :: volf
-double precision, allocatable, dimension(:), target :: xvolf
 double precision, dimension(:,:), allocatable :: rij
 double precision, dimension(:), pointer :: coef1, coef2, coef3, coef4, coef5, coef6
+double precision, dimension(:,:), pointer :: coefap
+double precision, dimension(:,:,:), pointer :: coefbp
 double precision, dimension(:,:), allocatable :: coefat
 double precision, dimension(:,:,:), allocatable :: coefbt
 double precision, dimension(:,:), allocatable :: tflmas, tflmab
 double precision, dimension(:,:), allocatable :: divt
+double precision, dimension(:), allocatable ::xnormp
 double precision, dimension(:,:), pointer :: forbr, c_st_vel
 double precision, dimension(:), pointer :: cvara_pr, cvara_k
 double precision, dimension(:), pointer :: cvara_r11, cvara_r22, cvara_r33
 double precision, dimension(:), pointer :: cvara_r12, cvara_r23, cvara_r13
+double precision, dimension(:,:), pointer :: cvara_rij
 double precision, dimension(:), pointer :: viscl, visct, c_estim
-
 double precision, allocatable, dimension(:) :: surfbm
 
 !===============================================================================
@@ -283,63 +280,48 @@ if (iroext.gt.0.or.idilat.gt.1) then
 endif
 
 if (iappel.eq.2) then
-  if (ineedf.eq.1 .and. iterns.eq.1 .or. icavit.ge.0) then
+  if (iforbr.ge.0 .and. iterns.eq.1 .or. icavit.ge.0) then
     call field_get_val_s(ivarfl(ipr), cvara_pr)
   endif
-  if(ineedf.eq.1 .and. iterns.eq.1                                          &
+  if(iforbr.ge.0 .and. iterns.eq.1                                          &
      .and. (itytur.eq.2 .or. itytur.eq.5 .or. iturb.eq.60) .and. igrhok.eq.1) then
     call field_get_val_s(ivarfl(ik), cvara_k)
   endif
   if (itytur.eq.3.and.iterns.eq.1) then
-    call field_get_val_s(ivarfl(ir11), cvara_r11)
-    call field_get_val_s(ivarfl(ir22), cvara_r22)
-    call field_get_val_s(ivarfl(ir33), cvara_r33)
-    call field_get_val_s(ivarfl(ir12), cvara_r12)
-    call field_get_val_s(ivarfl(ir23), cvara_r23)
-    call field_get_val_s(ivarfl(ir13), cvara_r13)
+    if (irijco.eq.1) then
+      call field_get_val_v(ivarfl(irij), cvara_rij)
+    else
+      call field_get_val_s(ivarfl(ir11), cvara_r11)
+      call field_get_val_s(ivarfl(ir22), cvara_r22)
+      call field_get_val_s(ivarfl(ir33), cvara_r33)
+      call field_get_val_s(ivarfl(ir12), cvara_r12)
+      call field_get_val_s(ivarfl(ir23), cvara_r23)
+      call field_get_val_s(ivarfl(ir13), cvara_r13)
+    endif
   endif
 else
-  if (ineedf.eq.1 .and. iterns.eq.1 .or. icavit.ge.0) then
+  if (iforbr.ge.0 .and. iterns.eq.1 .or. icavit.ge.0) then
     call field_get_val_prev_s(ivarfl(ipr), cvara_pr)
   endif
-  if(ineedf.eq.1 .and. iterns.eq.1                                          &
+  if(iforbr.ge.0 .and. iterns.eq.1                                          &
      .and. (itytur.eq.2 .or. itytur.eq.5 .or. iturb.eq.60) .and. igrhok.eq.1) then
       call field_get_val_prev_s(ivarfl(ik), cvara_k)
   endif
   if (itytur.eq.3.and.iterns.eq.1) then
-    call field_get_val_prev_s(ivarfl(ir11), cvara_r11)
-    call field_get_val_prev_s(ivarfl(ir22), cvara_r22)
-    call field_get_val_prev_s(ivarfl(ir33), cvara_r33)
-    call field_get_val_prev_s(ivarfl(ir12), cvara_r12)
-    call field_get_val_prev_s(ivarfl(ir23), cvara_r23)
-    call field_get_val_prev_s(ivarfl(ir13), cvara_r13)
+    if (irijco.eq.1) then
+      call field_get_val_v(ivarfl(irij), cvara_rij)
+    else
+      call field_get_val_s(ivarfl(ir11), cvara_r11)
+      call field_get_val_s(ivarfl(ir22), cvara_r22)
+      call field_get_val_s(ivarfl(ir33), cvara_r33)
+      call field_get_val_s(ivarfl(ir12), cvara_r12)
+      call field_get_val_s(ivarfl(ir23), cvara_r23)
+      call field_get_val_s(ivarfl(ir13), cvara_r13)
+    endif
   endif
 endif
 
-! Compute the Volume of fluid (in case of porosity)
-if (iporos.eq.0)  then
-  volf => volume(:)
-
-! With porosity
-else
-
-  call field_get_val_s(ipori, porosi)
-
-  allocate(xvolf(ncelet))
-
-  do iel = 1, ncel
-    xvolf(iel) = volume(iel) * porosi(iel)
-  enddo
-
-  if (irangp.ge.0.or.iperio.eq.1) then
-    call synsca(xvolf)
-  endif
-
-  volf => xvolf(:)
-
-endif
-
-if (ineedf.eq.1 .and. iterns.eq.1) call field_get_val_v(iforbr, forbr)
+if (iforbr.ge.0 .and. iterns.eq.1) call field_get_val_v(iforbr, forbr)
 
 ! Theta relatif aux termes sources explicites
 thets  = thetsn
@@ -354,7 +336,7 @@ endif
 if (icorio.eq.1) then
   ! Relative velocity formulation
   ccorio = 2.d0
-elseif (iturbo.eq.1) then
+else if (iturbo.eq.1) then
   ! Mixed relative/absolute velocity formulation
   ccorio = 1.d0
 else
@@ -396,7 +378,6 @@ else
   call field_get_coefa_s (ivarfl(ipr), coefa_p)
   call field_get_coefb_s (ivarfl(ipr), coefb_p)
 
-  allocate(gradni(ncelet,3))
   allocate(xinvro(ncelet))
 
   do iel = 1, ncel
@@ -412,29 +393,21 @@ else
   climgp = climgr(ipr)
   extrap = extrag(ipr)
 
-  call grdpre (ipr, imrgra, inc, iccocg, nswrgp, imligp,  &
-               iwarnp, epsrgp, climgp, extrap,            &
-               cvara_pr, xinvro, coefa_p, coefb_p,        &
-               gradni )
+  call gradient_weighted_s(ivarfl(ipr), imrgra, inc, iccocg, nswrgp, imligp,  &
+                           iwarnp, epsrgp, climgp, extrap,                    &
+                           cvara_pr, xinvro, coefa_p, coefb_p,                &
+                           grad )
 
-  do iel = 1, ncelet
-    do isou = 1, 3
-      grad(isou,iel) = gradni(iel,isou)
-    enddo
-  enddo
-
-  deallocate(gradni)
   deallocate(xinvro)
 
 endif
 
-
 !    Calcul des efforts aux parois (partie 2/5), si demande
 !    La pression a la face est calculee comme dans gradrc/gradmc
 !    et on la transforme en pression totale
 !    On se limite a la premiere iteration (pour faire simple par
 !      rapport a la partie issue de condli, hors boucle)
-if (ineedf.eq.1 .and. iterns.eq.1) then
+if (iforbr.ge.0 .and. iterns.eq.1) then
   call field_get_coefa_s (ivarfl(ipr), coefa_p)
   call field_get_coefb_s (ivarfl(ipr), coefb_p)
   do ifac = 1, nfabor
@@ -491,7 +464,6 @@ if (iappel.eq.1.and.irnpnw.eq.1) then
 
   if (irangp.ge.0.or.iperio.eq.1) then
     call synvin(trav)
-    !==========
   endif
 
 !     Calcul de rho dt/rho*grad P.n aux faces
@@ -510,7 +482,6 @@ if (iappel.eq.1.and.irnpnw.eq.1) then
   climgp = climgr(iu )
 
   call inimav                                                     &
-  !==========
  ( ivarfl(iu)      , itypfl ,                                     &
    iflmb0 , init   , inc    , imrgra , nswrp  , imligp ,          &
    iwarnp ,                                                       &
@@ -520,7 +491,9 @@ if (iappel.eq.1.and.irnpnw.eq.1) then
    coefav , coefbv ,                                              &
    viscf  , viscb  )
 
-!     Calcul de div(rho dt/rho*grad P)
+  ! Compute div(rho dt/rho*grad P)
+  allocate(xnormp(ncelet))
+
   init = 1
   call divmas(init,viscf,viscb,xnormp)
 
@@ -528,7 +501,7 @@ if (iappel.eq.1.and.irnpnw.eq.1) then
   if (ncesmp.gt.0) then
     do ii = 1, ncesmp
       iel = icetsm(ii)
-      xnormp(iel) = xnormp(iel) - volf(iel)*smacel(ii,ipr)
+      xnormp(iel) = xnormp(iel) - cell_f_vol(iel)*smacel(ii,ipr)
     enddo
   endif
 
@@ -559,7 +532,7 @@ if (iappel.eq.1.and.irnpnw.eq.1) then
   if (idilat.eq.2) then
     do iel = 1, ncel
       drom = crom(iel) - croma(iel)
-      xnormp(iel) = xnormp(iel) + drom*volf(iel)/dt(iel)
+      xnormp(iel) = xnormp(iel) + drom*cell_f_vol(iel)/dt(iel)
     enddo
   ! Semi-analytic weakly compressible algorithm add + 1/rho Drho/Dt
   else if (idilat.eq.4)then
@@ -576,7 +549,7 @@ if (iappel.eq.1.and.irnpnw.eq.1) then
   ! Cavitation source term
   if (icavit.gt.0) then
     do iel = 1, ncel
-      xnormp(iel) = xnormp(iel) -volf(iel)*gamcav(iel)*(1.d0/rov - 1.d0/rol)
+      xnormp(iel) = xnormp(iel) -cell_f_vol(iel)*gamcav(iel)*(1.d0/rov - 1.d0/rol)
     enddo
   endif
 
@@ -600,30 +573,30 @@ endif
 if (iappel.eq.1) then
   if (iphydr.eq.1) then
     do iel = 1, ncel
-      trav(1,iel) = (frcxt(1 ,iel) - grad(1,iel)) * volf(iel)
-      trav(2,iel) = (frcxt(2 ,iel) - grad(2,iel)) * volf(iel)
-      trav(3,iel) = (frcxt(3 ,iel) - grad(3,iel)) * volf(iel)
+      trav(1,iel) = (frcxt(1 ,iel) - grad(1,iel)) * cell_f_vol(iel)
+      trav(2,iel) = (frcxt(2 ,iel) - grad(2,iel)) * cell_f_vol(iel)
+      trav(3,iel) = (frcxt(3 ,iel) - grad(3,iel)) * cell_f_vol(iel)
     enddo
-    elseif (iphydr.eq.2) then
+  else if (iphydr.eq.2) then
     do iel = 1, ncel
       rom = crom(iel)
-      trav(1,iel) = (rom*gx - grdphd(iel,1) - grad(1,iel)) * volf(iel)
-      trav(2,iel) = (rom*gy - grdphd(iel,2) - grad(2,iel)) * volf(iel)
-      trav(3,iel) = (rom*gz - grdphd(iel,3) - grad(3,iel)) * volf(iel)
+      trav(1,iel) = (rom*gx - grdphd(1,iel) - grad(1,iel)) * cell_f_vol(iel)
+      trav(2,iel) = (rom*gy - grdphd(2,iel) - grad(2,iel)) * cell_f_vol(iel)
+      trav(3,iel) = (rom*gz - grdphd(3,iel) - grad(3,iel)) * cell_f_vol(iel)
     enddo
-    elseif (ippmod(icompf).ge.0) then
+  else if (ippmod(icompf).ge.0) then
     do iel = 1, ncel
       rom = crom(iel)
-      trav(1,iel) = (rom*gx - grad(1,iel)) * volf(iel)
-      trav(2,iel) = (rom*gy - grad(2,iel)) * volf(iel)
-      trav(3,iel) = (rom*gz - grad(3,iel)) * volf(iel)
+      trav(1,iel) = (rom*gx - grad(1,iel)) * cell_f_vol(iel)
+      trav(2,iel) = (rom*gy - grad(2,iel)) * cell_f_vol(iel)
+      trav(3,iel) = (rom*gz - grad(3,iel)) * cell_f_vol(iel)
     enddo
   else
     do iel = 1, ncel
       drom = (crom(iel)-ro0)
-      trav(1,iel) = (drom*gx - grad(1,iel) ) * volf(iel)
-      trav(2,iel) = (drom*gy - grad(2,iel) ) * volf(iel)
-      trav(3,iel) = (drom*gz - grad(3,iel) ) * volf(iel)
+      trav(1,iel) = (drom*gx - grad(1,iel) ) * cell_f_vol(iel)
+      trav(2,iel) = (drom*gy - grad(2,iel) ) * cell_f_vol(iel)
+      trav(3,iel) = (drom*gz - grad(3,iel) ) * cell_f_vol(iel)
     enddo
   endif
 
@@ -631,23 +604,23 @@ else if(iappel.eq.2) then
 
   if (iphydr.eq.1) then
     do iel = 1, ncel
-      trav(1,iel) = trav(1,iel) + (frcxt(1 ,iel) - grad(1,iel))*volf(iel)
-      trav(2,iel) = trav(2,iel) + (frcxt(2 ,iel) - grad(2,iel))*volf(iel)
-      trav(3,iel) = trav(3,iel) + (frcxt(3 ,iel) - grad(3,iel))*volf(iel)
+      trav(1,iel) = trav(1,iel) + (frcxt(1 ,iel) - grad(1,iel))*cell_f_vol(iel)
+      trav(2,iel) = trav(2,iel) + (frcxt(2 ,iel) - grad(2,iel))*cell_f_vol(iel)
+      trav(3,iel) = trav(3,iel) + (frcxt(3 ,iel) - grad(3,iel))*cell_f_vol(iel)
     enddo
-    elseif (iphydr.eq.2) then
+  else if (iphydr.eq.2) then
     do iel = 1, ncel
       rom = crom(iel)
-      trav(1,iel) = trav(1,iel) + (rom*gx - grdphd(iel,1) - grad(1,iel))*volf(iel)
-      trav(2,iel) = trav(2,iel) + (rom*gy - grdphd(iel,2) - grad(2,iel))*volf(iel)
-      trav(3,iel) = trav(3,iel) + (rom*gz - grdphd(iel,3) - grad(3,iel))*volf(iel)
+      trav(1,iel) = trav(1,iel) + (rom*gx - grdphd(1,iel) - grad(1,iel))*cell_f_vol(iel)
+      trav(2,iel) = trav(2,iel) + (rom*gy - grdphd(2,iel) - grad(2,iel))*cell_f_vol(iel)
+      trav(3,iel) = trav(3,iel) + (rom*gz - grdphd(3,iel) - grad(3,iel))*cell_f_vol(iel)
     enddo
   else
     do iel = 1, ncel
       drom = (crom(iel)-ro0)
-      trav(1,iel) = trav(1,iel) + (drom*gx - grad(1,iel))*volf(iel)
-      trav(2,iel) = trav(2,iel) + (drom*gy - grad(2,iel))*volf(iel)
-      trav(3,iel) = trav(3,iel) + (drom*gz - grad(3,iel))*volf(iel)
+      trav(1,iel) = trav(1,iel) + (drom*gx - grad(1,iel))*cell_f_vol(iel)
+      trav(2,iel) = trav(2,iel) + (drom*gy - grad(2,iel))*cell_f_vol(iel)
+      trav(3,iel) = trav(3,iel) + (drom*gz - grad(3,iel))*cell_f_vol(iel)
     enddo
   endif
 
@@ -743,7 +716,7 @@ if (iappel.eq.1) then
 
   do iel = 1, ncel
     do isou = 1, 3
-      fimp(isou,isou,iel) = istat(iu)*pcrom(iel)/dt(iel)*volf(iel)
+      fimp(isou,isou,iel) = istat(iu)*pcrom(iel)/dt(iel)*cell_f_vol(iel)
       do jsou = 1, 3
         if(jsou.ne.isou) fimp(isou,jsou,iel) = 0.d0
       enddo
@@ -798,7 +771,7 @@ if(     (itytur.eq.2 .or. itytur.eq.5 .or. iturb.eq.60) &
     call field_get_val_s(icrom, crom)
     call field_get_val_prev_s(icrom, croma)
     do iel = 1, ncel
-      romvom = -croma(iel)*volf(iel)*d2s3
+      romvom = -croma(iel)*cell_f_vol(iel)*d2s3
       do isou = 1, 3
         c_st_vel(isou,iel) = c_st_vel(isou,iel)+grad(isou,iel)*romvom
       enddo
@@ -807,14 +780,14 @@ if(     (itytur.eq.2 .or. itytur.eq.5 .or. iturb.eq.60) &
   else
     if(nterup.eq.1) then
       do iel = 1, ncel
-        romvom = -crom(iel)*volf(iel)*d2s3
+        romvom = -crom(iel)*cell_f_vol(iel)*d2s3
         do isou = 1, 3
           trav(isou,iel) = trav(isou,iel) + grad(isou,iel) * romvom
         enddo
       enddo
     else
       do iel = 1, ncel
-        romvom = -crom(iel)*volf(iel)*d2s3
+        romvom = -crom(iel)*cell_f_vol(iel)*d2s3
         do isou = 1, 3
           trava(isou,iel) = trava(isou,iel) + grad(isou,iel) * romvom
         enddo
@@ -823,7 +796,7 @@ if(     (itytur.eq.2 .or. itytur.eq.5 .or. iturb.eq.60) &
   endif
 
   ! Calcul des efforts aux parois (partie 3/5), si demande
-  if (ineedf.eq.1) then
+  if (iforbr.ge.0) then
     call field_get_coefa_s (ivarfl(ik), coefa_k)
     call field_get_coefb_s (ivarfl(ik), coefb_k)
     do ifac = 1, nfabor
@@ -855,7 +828,7 @@ endif
 
 if (ivisse.eq.1) then
 
-  call visecv(propce, secvif, secvib)
+  call visecv(secvif, secvib)
 
 endif
 
@@ -884,15 +857,6 @@ if ((ncepdp.gt.0).and.(iphydr.ne.1)) then
 
     call tspdcv(ncepdp, icepdc, vela, ckupdc, trav)
 
-    ! With porosity
-    if (iporos.ge.1) then
-      do iel = 1, ncel
-        trav(1, iel) = trav(1, iel)*porosi(iel)
-        trav(2, iel) = trav(2, iel)*porosi(iel)
-        trav(3, iel) = trav(3, iel)*porosi(iel)
-      enddo
-    endif
-
     ! Si on itere sur navsto, on utilise TRAVA ; sinon TRAV
     if(nterup.gt.1) then
       do iel = 1, ncel
@@ -923,7 +887,7 @@ if (iappel.eq.1) then
     thetap = thetav(iu)
     do ielpdc = 1, ncepdp
       iel = icepdc(ielpdc)
-      romvom = crom(iel)*volf(iel)*thetap
+      romvom = crom(iel)*cell_f_vol(iel)*thetap
 
       ! Diagonal part
       do isou = 1, 3
@@ -963,7 +927,7 @@ if ((icorio.eq.1.or.iturbo.eq.1) .and. iphydr.ne.1) then
       call field_get_val_s(icrom, crom)
 
       do iel = 1, ncel
-        romvom = -ccorio*crom(iel)*volf(iel)
+        romvom = -ccorio*crom(iel)*cell_f_vol(iel)
         call add_coriolis_v(irotce(iel), romvom, vela(:,iel), trav(:,iel))
       enddo
 
@@ -971,7 +935,7 @@ if ((icorio.eq.1.or.iturbo.eq.1) .and. iphydr.ne.1) then
     else
 
       do iel = 1, ncel
-        romvom = -ccorio*crom(iel)*volf(iel)
+        romvom = -ccorio*crom(iel)*cell_f_vol(iel)
         call add_coriolis_v(irotce(iel), romvom, vela(:,iel), trava(:,iel))
       enddo
 
@@ -988,7 +952,7 @@ if(iappel.eq.1) then
     thetap = thetav(iu)
 
     do iel = 1, ncel
-      romvom = -ccorio*crom(iel)*volf(iel)*thetap
+      romvom = -ccorio*crom(iel)*cell_f_vol(iel)*thetap
       call add_coriolis_t(irotce(iel), romvom, fimp(:,:,iel))
     enddo
 
@@ -1001,32 +965,47 @@ endif
 if(itytur.eq.3.and.iterns.eq.1) then
 
   allocate(rij(6,ncelet))
-  do iel = 1, ncelet
-    rij(1,iel) = cvara_r11(iel)
-    rij(2,iel) = cvara_r22(iel)
-    rij(3,iel) = cvara_r33(iel)
-    rij(4,iel) = cvara_r12(iel)
-    rij(5,iel) = cvara_r23(iel)
-    rij(6,iel) = cvara_r13(iel)
-  enddo
-
+  if(irijco.eq.1) then !TODO change index of rij
+    do iel = 1, ncelet
+      rij(1,iel) = cvara_rij(1,iel)
+      rij(2,iel) = cvara_rij(2,iel)
+      rij(3,iel) = cvara_rij(3,iel)
+      rij(4,iel) = cvara_rij(4,iel)
+      rij(5,iel) = cvara_rij(5,iel)
+      rij(6,iel) = cvara_rij(6,iel)
+    enddo
+  else
+    do iel = 1, ncelet
+      rij(1,iel) = cvara_r11(iel)
+      rij(2,iel) = cvara_r22(iel)
+      rij(3,iel) = cvara_r33(iel)
+      rij(4,iel) = cvara_r12(iel)
+      rij(5,iel) = cvara_r23(iel)
+      rij(6,iel) = cvara_r13(iel)
+    enddo
+  endif
 ! --- Boundary conditions on the components of the tensor Rij
 
   allocate(coefat(6,nfabor))
-  call field_get_coefad_s(ivarfl(ir11),coef1)
-  call field_get_coefad_s(ivarfl(ir22),coef2)
-  call field_get_coefad_s(ivarfl(ir33),coef3)
-  call field_get_coefad_s(ivarfl(ir12),coef4)
-  call field_get_coefad_s(ivarfl(ir23),coef5)
-  call field_get_coefad_s(ivarfl(ir13),coef6)
-  do ifac = 1, nfabor
-    coefat(1,ifac) = coef1(ifac)
-    coefat(2,ifac) = coef2(ifac)
-    coefat(3,ifac) = coef3(ifac)
-    coefat(4,ifac) = coef4(ifac)
-    coefat(5,ifac) = coef5(ifac)
-    coefat(6,ifac) = coef6(ifac)
-  enddo
+  if(irijco.eq.1) then
+    call field_get_coefad_v(ivarfl(irij),coefap)
+    coefat = coefap
+  else
+    call field_get_coefad_s(ivarfl(ir11),coef1)
+    call field_get_coefad_s(ivarfl(ir22),coef2)
+    call field_get_coefad_s(ivarfl(ir33),coef3)
+    call field_get_coefad_s(ivarfl(ir12),coef4)
+    call field_get_coefad_s(ivarfl(ir23),coef5)
+    call field_get_coefad_s(ivarfl(ir13),coef6)
+    do ifac = 1, nfabor
+      coefat(1,ifac) = coef1(ifac)
+      coefat(2,ifac) = coef2(ifac)
+      coefat(3,ifac) = coef3(ifac)
+      coefat(4,ifac) = coef4(ifac)
+      coefat(5,ifac) = coef5(ifac)
+      coefat(6,ifac) = coef6(ifac)
+    enddo
+  endif
 
   allocate(coefbt(6,6,nfabor))
   do ifac = 1, nfabor
@@ -1036,20 +1015,26 @@ if(itytur.eq.3.and.iterns.eq.1) then
       enddo
     enddo
   enddo
-  call field_get_coefbd_s(ivarfl(ir11),coef1)
-  call field_get_coefbd_s(ivarfl(ir22),coef2)
-  call field_get_coefbd_s(ivarfl(ir33),coef3)
-  call field_get_coefbd_s(ivarfl(ir12),coef4)
-  call field_get_coefbd_s(ivarfl(ir23),coef5)
-  call field_get_coefbd_s(ivarfl(ir13),coef6)
-  do ifac = 1, nfabor
-    coefbt(1,1,ifac) = coef1(ifac)
-    coefbt(2,2,ifac) = coef2(ifac)
-    coefbt(3,3,ifac) = coef3(ifac)
-    coefbt(4,4,ifac) = coef4(ifac)
-    coefbt(5,5,ifac) = coef5(ifac)
-    coefbt(6,6,ifac) = coef6(ifac)
-  enddo
+
+  if(irijco.eq.1) then
+    call field_get_coefbd_v(ivarfl(irij),coefbp)
+    coefbt = coefbp
+  else
+    call field_get_coefbd_s(ivarfl(ir11),coef1)
+    call field_get_coefbd_s(ivarfl(ir22),coef2)
+    call field_get_coefbd_s(ivarfl(ir33),coef3)
+    call field_get_coefbd_s(ivarfl(ir12),coef4)
+    call field_get_coefbd_s(ivarfl(ir23),coef5)
+    call field_get_coefbd_s(ivarfl(ir13),coef6)
+    do ifac = 1, nfabor
+      coefbt(1,1,ifac) = coef1(ifac)
+      coefbt(2,2,ifac) = coef2(ifac)
+      coefbt(3,3,ifac) = coef3(ifac)
+      coefbt(4,4,ifac) = coef4(ifac)
+      coefbt(5,5,ifac) = coef5(ifac)
+      coefbt(6,6,ifac) = coef6(ifac)
+    enddo
+  endif
 
   ! Flux computation options
   f_id = -1
@@ -1067,7 +1052,6 @@ if(itytur.eq.3.and.iterns.eq.1) then
   allocate(tflmab(3,nfabor))
 
   call divrij &
-  !==========
  ( f_id   , itypfl ,                                              &
    iflmb0 , init   , inc    , imrgra , nswrgp , imligp ,          &
    iwarnp ,                                                       &
@@ -1082,7 +1066,7 @@ if(itytur.eq.3.and.iterns.eq.1) then
 
   !     Calcul des efforts aux bords (partie 5/5), si necessaire
 
-  if (ineedf.eq.1) then
+  if (iforbr.ge.0) then
     do ifac = 1, nfabor
       do isou = 1, 3
         forbr(isou,ifac) = forbr(isou,ifac) + tflmab(isou,ifac)
@@ -1153,7 +1137,6 @@ if (idiff(iu).ge. 1) then
   if (idften(iu).eq.1) then
 
     call viscfa &
-    !==========
    ( imvisf ,                                                       &
      w1     ,                                                       &
      viscf  , viscb  )
@@ -1167,7 +1150,6 @@ if (idiff(iu).ge. 1) then
       enddo
 
       call viscfa &
-      !==========
    ( imvisf ,                                                       &
      w1     ,                                                       &
      viscfi , viscbi )
@@ -1186,7 +1168,6 @@ if (idiff(iu).ge. 1) then
     enddo
 
     call vistnv &
-    !==========
      ( imvisf ,                                                       &
        viscce ,                                                       &
        viscf  , viscb  )
@@ -1209,7 +1190,6 @@ if (idiff(iu).ge. 1) then
       enddo
 
       call vistnv &
-      !==========
        ( imvisf ,                                                       &
          viscce ,                                                       &
          viscfi , viscbi )
@@ -1293,7 +1273,7 @@ if (iappel.eq.1.and.iphydr.eq.1.and.iterns.eq.1) then
   ! Add -div( rho R) as external force
   if (itytur.eq.3.and.igprij.eq.1) then
     do iel = 1, ncel
-      dvol = 1.d0/volf(iel)
+      dvol = 1.d0/cell_f_vol(iel)
       do isou = 1, 3
         dfrcxt(isou, iel) = dfrcxt(isou, iel) - divt(isou, iel)*dvol
       enddo
@@ -1349,15 +1329,22 @@ do iel = 1, ncel
 enddo
 
 ! The computation of esplicit and implicit source terms is performed
-! at the first iter only.
+! at the first iteration only.
 if (iterns.eq.1) then
 
   if (iihmpr.eq.1) then
     call uitsnv (vel, tsexp, tsimp)
   endif
 
+  n_fans = cs_fan_n_fans()
+  if (n_fans .gt. 0) then
+    if (ntcabs.eq.ntpabs+1) then
+      call debvtl(flumas, flumab, crom, brom)
+    endif
+    call tsvvtl(tsexp)
+  endif
+
   call ustsnv &
-  !==========
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    iu   ,                                                         &
    icepdc , icetsm , itypsm ,                                     &
@@ -1378,14 +1365,13 @@ if (iterns.eq.1) then
   if (nbrcpl.gt.0) then
     !vectorial interleaved exchange
     call csccel(iu, vela, coefav, coefbv, tsexp)
-    !==========
   endif
 
   if (iphydr.eq.1.and.igpust.eq.1) then
 
     do iel = 1, ncel
       !FIXME when using porosity
-      dvol = 1.d0/volume(iel)
+      dvol = 1.d0/cell_f_vol(iel)
       do isou = 1, 3
         dfrcxt(isou, iel) = dfrcxt(isou, iel) + tsexp(isou, iel)*dvol
       enddo
@@ -1396,15 +1382,6 @@ if (iterns.eq.1) then
     endif
   endif
 
-  ! Porosity
-  if (iporos.ge.1) then
-    do iel = 1, ncel
-      do isou = 1, 3
-        tsexp(isou, iel) = porosi(iel)*tsexp(isou, iel)
-      enddo
-    enddo
-  endif
-
 endif
 
 ! if PISO sweeps are expected, implicit user sources terms are stored in ximpa
@@ -1420,54 +1397,26 @@ endif
 
 ! ---> Explicit contribution due to implicit terms
 
-! Without porosity
-if (iporos.eq.0) then
-  if (iterns.eq.1) then
-    if (nterup.gt.1) then
-      do iel = 1, ncel
-        do isou = 1, 3
-          do jsou = 1, 3
-            trava(isou,iel) = trava(isou,iel)                                  &
-                            + tsimp(isou,jsou,iel)*vela(jsou,iel)
-          enddo
+if (iterns.eq.1) then
+  if (nterup.gt.1) then
+    do iel = 1, ncel
+      do isou = 1, 3
+        do jsou = 1, 3
+          trava(isou,iel) = trava(isou,iel)                                  &
+                          + tsimp(isou,jsou,iel)*vela(jsou,iel)
         enddo
       enddo
-    else
-      do iel = 1, ncel
-        do isou = 1, 3
-          do jsou = 1, 3
-            trav(isou,iel) = trav(isou,iel)                                    &
-                           + tsimp(isou,jsou,iel)*vela(jsou,iel)
-          enddo
+    enddo
+  else
+    do iel = 1, ncel
+      do isou = 1, 3
+        do jsou = 1, 3
+          trav(isou,iel) = trav(isou,iel)                                    &
+                         + tsimp(isou,jsou,iel)*vela(jsou,iel)
         enddo
       enddo
-    endif
+    enddo
   endif
-
-! With porosity
-else
-  if (iterns.eq.1) then
-    if (nterup.gt.1) then
-      do iel = 1, ncel
-        do isou = 1, 3
-          do jsou = 1, 3
-            trava(isou,iel) = trava(isou,iel)                                  &
-                            + tsimp(isou,jsou,iel)*vela(jsou,iel)*porosi(iel)
-          enddo
-        enddo
-      enddo
-    else
-      do iel = 1, ncel
-        do isou = 1, 3
-          do jsou = 1, 3
-            trav(isou,iel) = trav(isou,iel)                                    &
-                           + tsimp(isou,jsou,iel)*vela(jsou,iel)*porosi(iel)
-          enddo
-        enddo
-      enddo
-    endif
-  endif
-
 endif
 
 ! At the first PISO iteration, explicit source terms are added
@@ -1559,17 +1508,15 @@ if (ncesmp.gt.0) then
   allocate(gavinj(3,ncelet))
   if (nterup.eq.1) then
     call catsmv &
-    !==========
   ( ncelet , ncel , ncesmp , iterns , isno2t, thetav(iu),       &
     icetsm , itypsm(1,iu),                                      &
-    volume , vela , smacel(1,iu) ,smacel(1,ipr) ,               &
+    cell_f_vol    , vela , smacel(1,iu) , smacel(1,ipr) ,       &
     trav   , fimp , gavinj )
   else
     call catsmv &
-    !==========
   ( ncelet , ncel , ncesmp , iterns , isno2t, thetav(iu),       &
     icetsm , itypsm(1,iu),                                      &
-    volume , vela , smacel(1,iu) ,smacel(1,ipr) ,               &
+    cell_f_vol    , vela , smacel(1,iu) , smacel(1,ipr) ,       &
     trava  , fimp  , gavinj )
   endif
 
@@ -1678,7 +1625,7 @@ if (ippmod(ielarc).ge.1) then
   do iel = 1, ncel
     do isou = 1, 3
       smbr(isou,iel) = smbr(isou,iel)                               &
-                     + volf(iel)*propce(iel,ipproc(ilapla(isou)))
+                     + cell_f_vol(iel)*propce(iel,ipproc(ilapla(isou)))
     enddo
   enddo
 endif
@@ -1722,7 +1669,6 @@ if (iappel.eq.1) then
     ! Warning: in case of convergence estimators, eswork give the estimator
     ! of the predicted velocity
     call coditv &
-    !==========
  ( idtvar , iu     , iconvp , idiffp , ndircp ,                   &
    imrgra , nswrsp , nswrgp , imligp , ircflp , ivisse ,          &
    ischcp , isstpp , iescap , idftnp , iswdyp ,                   &
@@ -1739,10 +1685,9 @@ if (iappel.eq.1) then
    vel    ,                                                       &
    eswork )
 
-  elseif(iterns.gt.1) then
+  else if(iterns.gt.1) then
 
     call coditv &
-    !==========
  ( idtvar , iu     , iconvp , idiffp , ndircp ,                   &
    imrgra , nswrsp , nswrgp , imligp , ircflp , ivisse ,          &
    ischcp , isstpp , iescap , idftnp , iswdyp ,                   &
@@ -1774,7 +1719,7 @@ if (iappel.eq.1) then
     nswrsp = -1
     do iel = 1, ncel
       do isou = 1, 3
-        smbr(isou,iel) = volf(iel)
+        smbr(isou,iel) = cell_f_vol(iel)
       enddo
     enddo
     do iel = 1, ncelet
@@ -1788,7 +1733,6 @@ if (iappel.eq.1) then
     ivisep = 0
 
     call coditv &
-    !==========
  ( idtvar , iu     , iconvp , idiffp , ndircp ,                   &
    imrgra , nswrsp , nswrgp , imligp , ircflp , ivisep ,          &
    ischcp , isstpp , iescap , idftnp , iswdyp ,                   &
@@ -1833,14 +1777,13 @@ if (iappel.eq.1) then
 
 ! ---> End of the construction of the total estimator:
 !       RHS resiudal of (U^{n+1}, P^{n+1}) + rho*volume*(U^{n+1} - U^n)/dt
-elseif (iappel.eq.2) then
+else if (iappel.eq.2) then
 
   inc = 1
   ! Pas de relaxation en stationnaire
   idtva0 = 0
 
   call bilscv &
-  !==========
  ( idtva0 , iu     , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , ivisse ,                   &
    iwarnp , idftnp ,                                              &
@@ -1886,7 +1829,6 @@ if (iappel.eq.1.and.irnpnw.eq.1) then
   climgp = climgr(iu )
 
   call inimav &
-  !==========
  ( ivarfl(iu)      , itypfl ,                                     &
    iflmb0 , init   , inc    , imrgra , nswrp  , imligp ,          &
    iwarnp ,                                                       &
@@ -1900,9 +1842,10 @@ if (iappel.eq.1.and.irnpnw.eq.1) then
   call divmas(init,viscf,viscb,xnormp)
 
   ! Compute the norm rnormp used in resopv
-  isqrt = 1
-  call prodsc(ncel,isqrt,xnormp,xnormp,rnormp)
+  rnormp = sqrt(cs_gdot(ncel,xnormp,xnormp))
 
+  ! Free memory
+  deallocate(xnormp)
 endif
 
 ! ---> Finilaze estimators + Printings
@@ -1917,7 +1860,7 @@ if (iappel.eq.1) then
       do iel = 1, ncel
         c_estim(iel) = sqrt(c_estim(iel))
       enddo
-    elseif (iescal(iespre).eq.2) then
+    else if (iescal(iespre).eq.2) then
       do iel = 1, ncel
         c_estim(iel) = sqrt(c_estim(iel)*volume(iel))
       enddo
@@ -1935,18 +1878,28 @@ if (iappel.eq.1) then
     if (irangp.ge.0) call parmax (rnorm)
 
     write(nfecra,1100) rnorm
+
+    do iel = 1, ncel
+      vitnor = sqrt(vel(1,iel)**2+vel(2,iel)**2+vel(3,iel)**2)
+      rnorm = min(rnorm,vitnor)
+    enddo
+
+    if (irangp.ge.0) call parmin (rnorm)
+
+    write(nfecra,1200) rnorm
+
   endif
 
 ! ---> Estimator on the whole Navier-Stokes:
 !      square root (norm) or square root of the sum times the volume (L2 norm)
-elseif (iappel.eq.2) then
+else if (iappel.eq.2) then
 
   call field_get_val_s(iestim(iestot), c_estim)
   if (iescal(iestot).eq.1) then
     do iel = 1, ncel
       c_estim(iel) = sqrt(c_estim(iel))
     enddo
-  elseif (iescal(iestot).eq.2) then
+  else if (iescal(iestot).eq.2) then
     do iel = 1, ncel
       c_estim(iel) = sqrt(c_estim(iel)*volume(iel))
     enddo
@@ -1962,7 +1915,6 @@ deallocate(tsexp)
 deallocate(tsimp)
 if (allocated(viscce)) deallocate(viscce)
 if (allocated(divt)) deallocate(divt)
-if (allocated(xvolf)) deallocate(xvolf)
 
 !--------
 ! Formats
@@ -1972,11 +1924,17 @@ if (allocated(xvolf)) deallocate(xvolf)
  1100 format(/,                                                   &
  1X,'Vitesse maximale apres prediction ',E12.4)
 
+ 1200 format(/,                                                   &
+ 1X,'Vitesse minimale apres prediction ',E12.4)
+
 #else
 
  1100 format(/,                                                   &
  1X,'Maximum velocity after prediction ',E12.4)
 
+ 1200 format(/,                                                   &
+ 1X,'Minimum velocity after prediction ',E12.4)
+
 #endif
 
 !----
