@@ -181,7 +181,6 @@ integer          iflmas, iflmab
 integer          idiffp, iconvp, ndircp
 integer          iinvpe, indhyd
 integer          itypfl
-integer          iesdep
 integer          isou  , ibsize, iesize
 integer          imucpp, idftnp, iswdyp
 integer          iescap, ircflp, ischcp, isstpp, ivar
@@ -238,6 +237,7 @@ double precision, dimension(:), pointer :: brom, crom, croma
 double precision, dimension(:), pointer :: cvar_pr, cvara_pr
 double precision, dimension(:,:), pointer :: cpro_wgrec_v
 double precision, dimension(:), pointer :: cpro_wgrec_s
+double precision, dimension(:), pointer :: c_estim_der
 double precision, allocatable, dimension(:) :: surfbm
 
 !===============================================================================
@@ -836,6 +836,7 @@ if (idiff(ipr).ge.1) then
       do iel = 1, ncel
         cpro_wgrec_s(iel) = viscap(iel)
       enddo
+      call synsca(cpro_wgrec_s)
     endif
 
   ! Tensor diffusivity
@@ -860,6 +861,7 @@ if (idiff(ipr).ge.1) then
           cpro_wgrec_v(isou,iel) = vitenp(isou,iel)
         enddo
       enddo
+      call syntis(cpro_wgrec_v)
     endif
 
   endif
@@ -1198,15 +1200,15 @@ if (arak.gt.0.d0) then
 
     call itrmav &
     !==========
- ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-   iphydr , iwarnp ,                                              &
-   epsrgp , climgp , extrap ,                                     &
-   frcxt  ,                                                       &
-   cvara_pr,                                                      &
-   coefa_p , coefb_p , coefaf_p , coefbf_p ,                      &
-   viscf  , viscb  ,                                              &
-   vitenp ,                                                       &
-   weighf , weighb ,                                              &
+ ( f_id0  , init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
+   iphydr , iwarnp ,                                                       &
+   epsrgp , climgp , extrap ,                                              &
+   frcxt  ,                                                                &
+   cvara_pr,                                                               &
+   coefa_p , coefb_p , coefaf_p , coefbf_p ,                               &
+   viscf  , viscb  ,                                                       &
+   vitenp ,                                                                &
+   weighf , weighb ,                                                       &
    imasfl , bmasfl )
 
     ! Projection du terme source pour oter la partie hydrostat de la pression
@@ -1540,16 +1542,16 @@ if (iswdyp.ge.1) then
 
     call itrgrv &
     !==========
- ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-   iphydr , iwarnp ,                                              &
-   epsrgp , climgp , extrap ,                                     &
-   dfrcxt ,                                                       &
-   dpvar  ,                                                       &
-   coefa_dp  , coefb_dp  ,                                        &
-   coefaf_dp , coefbf_dp ,                                        &
-   viscf  , viscb  ,                                              &
-   vitenp ,                                                       &
-   weighf , weighb ,                                              &
+ ( f_id0  , init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
+   iphydr , iwarnp ,                                                       &
+   epsrgp , climgp , extrap ,                                              &
+   dfrcxt ,                                                                &
+   dpvar  ,                                                                &
+   coefa_dp  , coefb_dp  ,                                                 &
+   coefaf_dp , coefbf_dp ,                                                 &
+   viscf  , viscb  ,                                                       &
+   vitenp ,                                                                &
+   weighf , weighb ,                                                       &
    rhs0   )
 
   endif
@@ -1631,16 +1633,16 @@ do while (isweep.le.nswmpr.and.residu.gt.epsrsm(ipr)*rnormp)
 
       call itrgrv &
       !==========
-   ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-     iphydr , iwarnp ,                                              &
-     epsrgp , climgp , extrap ,                                     &
-     dfrcxt ,                                                       &
-     dpvar  ,                                                       &
-     coefa_dp  , coefb_dp  ,                                        &
-     coefaf_dp , coefbf_dp ,                                        &
-     viscf  , viscb  ,                                              &
-     vitenp ,                                                       &
-     weighf , weighb ,                                              &
+   ( f_id0  , init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
+     iphydr , iwarnp ,                                                       &
+     epsrgp , climgp , extrap ,                                              &
+     dfrcxt ,                                                                &
+     dpvar  ,                                                                &
+     coefa_dp  , coefb_dp  ,                                                 &
+     coefaf_dp , coefbf_dp ,                                                 &
+     viscf  , viscb  ,                                                       &
+     vitenp ,                                                                &
+     weighf , weighb ,                                                       &
      adxk   )
 
     endif
@@ -1762,16 +1764,16 @@ do while (isweep.le.nswmpr.and.residu.gt.epsrsm(ipr)*rnormp)
 
     call itrgrv &
     !==========
- ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-   iphydr , iwarnp ,                                              &
-   epsrgp , climgp , extrap ,                                     &
-   dfrcxt ,                                                       &
-   cvar_pr   ,                                                    &
-   coefa_dp  , coefb_dp  ,                                        &
-   coefaf_dp , coefbf_dp ,                                        &
-   viscf  , viscb  ,                                              &
-   vitenp ,                                                       &
-   weighf , weighb ,                                              &
+ ( f_id0  , init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
+   iphydr , iwarnp ,                                                       &
+   epsrgp , climgp , extrap ,                                              &
+   dfrcxt ,                                                                &
+   cvar_pr   ,                                                             &
+   coefa_dp  , coefb_dp  ,                                                 &
+   coefaf_dp , coefbf_dp ,                                                 &
+   viscf  , viscb  ,                                                       &
+   vitenp ,                                                                &
+   weighf , weighb ,                                                       &
    rhs    )
 
   endif
@@ -1822,13 +1824,13 @@ call field_set_key_struct_solving_info(ivarfl(ipr), sinfo)
 ! --- Compute the indicator, taken the volume into account (L2 norm)
 !     or not
 if(iescal(iesder).gt.0) then
-  iesdep = ipproc(iestim(iesder))
+  call field_get_val_s(iestim(iesder), c_estim_der)
   do iel = 1, ncel
-    propce(iel,iesdep) = abs(rhs(iel))/volume(iel)
+    c_estim_der(iel) = abs(rhs(iel))/volume(iel)
   enddo
   if(iescal(iesder).eq.2) then
     do iel = 1, ncel
-      propce(iel,iesdep) = propce(iel,iesdep)*sqrt(volume(iel))
+      c_estim_der(iel) = c_estim_der(iel)*sqrt(volume(iel))
     enddo
   endif
 endif
@@ -1898,16 +1900,16 @@ else if (idften(ipr).eq.6) then
 
   call itrmav &
   !==========
- ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-   iphydr , iwarnp ,                                              &
-   epsrgp , climgp , extrap ,                                     &
-   dfrcxt ,                                                       &
-   presa  ,                                                       &
-   coefa_dp  , coefb_dp  ,                                        &
-   coefaf_dp , coefbf_dp ,                                        &
-   viscf  , viscb  ,                                              &
-   vitenp ,                                                       &
-   weighf , weighb ,                                              &
+ ( f_id0  , init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
+   iphydr , iwarnp ,                                                       &
+   epsrgp , climgp , extrap ,                                              &
+   dfrcxt ,                                                                &
+   presa  ,                                                                &
+   coefa_dp  , coefb_dp  ,                                                 &
+   coefaf_dp , coefbf_dp ,                                                 &
+   viscf  , viscb  ,                                                       &
+   vitenp ,                                                                &
+   weighf , weighb ,                                                       &
    imasfl , bmasfl )
 
   ! The last increment is not reconstructed to fullfill exactly the continuity
@@ -1919,16 +1921,16 @@ else if (idften(ipr).eq.6) then
 
   call itrmav &
   !==========
- ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-   iphydr , iwarnp ,                                              &
-   epsrgp , climgp , extrap ,                                     &
-   dfrcxt ,                                                       &
-   dpvar  ,                                                       &
-   coefa_dp  , coefb_dp  ,                                        &
-   coefaf_dp , coefbf_dp ,                                        &
-   viscf  , viscb  ,                                              &
-   vitenp ,                                                       &
-   weighf , weighb ,                                              &
+ ( f_id0  , init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
+   iphydr , iwarnp ,                                                       &
+   epsrgp , climgp , extrap ,                                              &
+   dfrcxt ,                                                                &
+   dpvar  ,                                                                &
+   coefa_dp  , coefb_dp  ,                                                 &
+   coefaf_dp , coefbf_dp ,                                                 &
+   viscf  , viscb  ,                                                       &
+   vitenp ,                                                                &
+   weighf , weighb ,                                                       &
    imasfl , bmasfl )
 
 endif
@@ -2249,15 +2251,15 @@ if (idilat.eq.5) then
 
     call itrmav &
     !==========
-   ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-     iphydr , iwarnp ,                                              &
-     epsrgp , climgp , extrap ,                                     &
-     dfrcxt ,                                                       &
-     dpvar  ,                                                       &
-     coefa_dp2       , coefb_p, coefaf_dp2      ,coefbf_p,          &
-     viscf  , viscb  ,                                              &
-     tpucou ,                                                       &
-     weighf , weighb ,                                              &
+   ( f_id0  , init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
+     iphydr , iwarnp ,                                                       &
+     epsrgp , climgp , extrap ,                                              &
+     dfrcxt ,                                                                &
+     dpvar  ,                                                                &
+     coefa_dp2       , coefb_p, coefaf_dp2      ,coefbf_p,                   &
+     viscf  , viscb  ,                                                       &
+     tpucou ,                                                                &
+     weighf , weighb ,                                                       &
      imasfl , bmasfl )
 
     ! The last increment is not reconstructed to fullfill exactly the continuity
@@ -2268,15 +2270,15 @@ if (idilat.eq.5) then
 
     call itrmav &
     !==========
-   ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-     iphydr , iwarnp ,                                              &
-     epsrgp , climgp , extrap ,                                     &
-     dfrcxt ,                                                       &
-     ddpvar ,                                                       &
-     coefa_dp2       , coefb_p, coefaf_dp2      ,coefbf_p,          &
-     viscf  , viscb  ,                                              &
-     tpucou ,                                                       &
-     weighf , weighb ,                                              &
+   ( f_id0  , init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
+     iphydr , iwarnp ,                                                       &
+     epsrgp , climgp , extrap ,                                              &
+     dfrcxt ,                                                                &
+     ddpvar ,                                                                &
+     coefa_dp2       , coefb_p, coefaf_dp2      ,coefbf_p,                   &
+     viscf  , viscb  ,                                                       &
+     tpucou ,                                                                &
+     weighf , weighb ,                                                       &
      imasfl , bmasfl )
 
   endif
@@ -2314,6 +2316,7 @@ if (idilat.eq.4) then
   do ifac = 1, nfac
     ii = ifacel(1, ifac)
     jj = ifacel(2, ifac)
+    ! FIXME: should be coherent with the convective scheme of the species...
     rho = pond(ifac)*crom(ii)+(1.d0-pond(ifac))*crom(jj)
     imasfl(ifac) = imasfl(ifac) * rho
   enddo
