@@ -86,7 +86,8 @@ use field
 use rotation
 use darcy_module
 use cs_f_interfaces
-use cs_tagmr, only:rob, condb,cpb,hext,text,tpar0
+use cs_c_bindings
+use cs_tagmr, only: rob, condb, cpb, hext, text
 use cs_tagms, only: t_metal, tmet0
 use cs_nz_tagmr
 use cs_nz_condensation
@@ -111,25 +112,26 @@ double precision, pointer, dimension(:) :: prhyd
 
 ! Local variables
 
-logical          interleaved
+logical          interleaved, must_return
 
-integer          iel   , ifac  , inod  , ivar  , iscal , iappel
-integer          ncv   , iok   , ifld  , nfld  , f_id  , f_dim  , f_type
+integer          iel   , ifac  , inod  , ivar  , iscal , iappel, n_fans
+integer          iok   , ifld  , nfld  , f_id  , f_dim  , f_type
 integer          nbccou
 integer          ntrela
 integer          icmst
 
 integer          isvhb, iz
-integer          ii    , ientha, ippcv
+integer          ii    , ippcv , ikpdc
 integer          iterns, inslst, icvrge
 integer          italim, itrfin, itrfup, ineefl
 integer          nbzfmx, nozfmx
-integer          ielpdc
+integer          ielpdc, iflmas, iflmab
 
 double precision tditot, tdist2, tdist1, cvcst
 double precision xxp0, xyp0, xzp0
 double precision relaxk, relaxe, relaxw, relaxn
 double precision hdls(6)
+
 double precision, save :: tpar, tmet
 
 integer          ipass
@@ -150,7 +152,7 @@ double precision, allocatable, dimension(:,:,:) :: rcodcl
 double precision, allocatable, dimension(:) :: hbord, theipb
 double precision, allocatable, dimension(:) :: visvdr
 double precision, allocatable, dimension(:) :: prdv2f
-double precision, dimension(:), pointer :: crom, crom_prev, crom_prev2
+double precision, dimension(:), pointer :: brom, crom, crom_prev, crom_prev2
 
 double precision, pointer, dimension(:,:) :: uvwk
 double precision, pointer, dimension(:,:) :: trava
@@ -174,7 +176,8 @@ integer, allocatable, dimension(:) :: delay_id
 double precision, dimension(:), pointer :: cpro_delay, cpro_capacity, cpro_sat
 double precision, dimension(:), pointer :: cproa_delay, cproa_capacity
 double precision, dimension(:), pointer :: cproa_sat
-character*80     fname
+double precision, dimension(:), pointer :: i_mass_flux, b_mass_flux
+character(len=80) :: fname
 
 double precision, dimension(:), pointer :: coefap, cofafp, cofbfp
 
@@ -185,8 +188,6 @@ double precision, dimension(:), pointer :: coefap, cofafp, cofbfp
 interface
 
   subroutine navstv &
-  !================
-
   ( nvar   , nscal  , iterns , icvrge , itrale ,                   &
     isostd ,                                                       &
     dt     , propce ,                                              &
@@ -212,8 +213,6 @@ interface
   end subroutine navstv
 
   subroutine richards &
-  !================
-
  (icvrge, dt)
 
     use dimens, only: ndimfb
@@ -228,6 +227,7 @@ interface
 
 end interface
 
+
 !===============================================================================
 
 ! Map field arrays
@@ -240,6 +240,8 @@ call field_get_n_fields(nfld)
 ! 1.  INITIALISATION
 !===============================================================================
 
+must_return = .false.
+
 if (iwarni(iu).ge.1) then
   write(nfecra,1000)
 endif
@@ -255,7 +257,6 @@ ipass = ipass + 1
 !     couplage Syrthes), sinon on stocke le scalaire thermique de la phase 1.
 
 call nbcsyr (nbccou)
-!==========
 isvhb = 0
 if (nbccou .ge. 1) then
   do iscal = 1, nscal
@@ -271,8 +272,7 @@ endif
 
 !     Si la distance a la paroi doit etre mise a jour, on l'initialise a GRAND
 !     des maintenant (pour le premier passage dans phyvar en k-omega)
-if(ipass.eq.1.and.ineedy.eq.1.and.abs(icdpar).eq.1.and.           &
-                                  imajdy.eq.0) then
+if (ipass.eq.1 .and. ineedy.eq.1 .and. imajdy.eq.0) then
   do iel = 1, ncel
     dispar(iel) = grand
   enddo
@@ -370,6 +370,10 @@ if (irangp.ge.0 .or. iperio.eq.1) then
         call field_get_val_v(f_id, cvar_vec)
         call synvie(cvar_vec)
 
+      else if (f_dim.eq.6) then
+
+        call field_get_val_v(f_id, cvar_vec)
+        call syntis(cvar_vec)
       else
         call csexit(1)
       endif
@@ -379,14 +383,13 @@ if (irangp.ge.0 .or. iperio.eq.1) then
 
 endif
 
-! ---> Periodicity of rotation
+! ---> Periodicity of rotation for related fields
 
 if (iperio.eq.1) then
 
   !  -- Reynolds stress tensor
 
-  if (itytur.eq.3) then
-
+  if (itytur.eq.3 .and. irijco.eq.0) then
     call field_get_val_s(ivarfl(ir11), cvar_r11)
     call field_get_val_s(ivarfl(ir22), cvar_r22)
     call field_get_val_s(ivarfl(ir33), cvar_r33)
@@ -396,9 +399,9 @@ if (iperio.eq.1) then
 
     call perrte &
     !==========
-  ( cvar_r11, cvar_r12, cvar_r13,           &
-    cvar_r12, cvar_r22, cvar_r23,           &
-    cvar_r13, cvar_r23, cvar_r33 )
+    ( cvar_r11, cvar_r12, cvar_r13,           &
+      cvar_r12, cvar_r22, cvar_r23,           &
+      cvar_r13, cvar_r23, cvar_r33 )
   endif
 
   !  -- Note for v2f:
@@ -430,7 +433,6 @@ if (ipass.eq.1) then
     call field_get_val_s(icrom, crom)
     if (irangp.ge.0 .or. iperio.eq.1) then
       call synsce (crom)
-      !==========
     endif
 
   endif
@@ -440,7 +442,6 @@ if (ipass.eq.1) then
 
     if (irangp.ge.0 .or. iperio.eq.1) then
       call synsce (prhyd(1))
-      !==========
     endif
 
   endif
@@ -495,12 +496,11 @@ endif
 !  on ne touche pas au flux de masse non plus
 
 
-if(inpdt0.eq.1.and.isuite.eq.1) goto 200
+if (inpdt0.eq.1.and.isuite.eq.1) return
 
 if (itrale.gt.0) then
   iappel = 1
   call schtmp(nscal, iappel, propce)
-  !==========
 endif
 
 
@@ -522,7 +522,6 @@ if (imobil.eq.1) then
   call rotation_update_coords(nnod, ttcmob, xyznod)
 
   call algrma(volmin, volmax, voltot)
-  !==========
 
   ! Abort at the end of the current time-step if there is a negative volume
   if (volmin.le.0.d0) ntmabs = ntcabs
@@ -541,7 +540,6 @@ endif
 !   - soit a un deplacement impose (cf ci-dessus)
 
 if (nbrcpl.gt.0) call cscloc
-                 !==========
 
 !===============================================================================
 ! 7.  CALCUL DES PROPRIETES PHYSIQUES VARIABLES
@@ -555,12 +553,10 @@ if (iwarni(iu).ge.1) then
 endif
 
 call phyvar(nvar, nscal, dt, propce)
-!==========
 
 if (itrale.gt.0) then
   iappel = 2
   call schtmp(nscal, iappel, propce)
-  !==========
 endif
 
 
@@ -574,11 +570,15 @@ if (ncpdct.gt.0) then
 
   iappel = 3
 
+  do ikpdc = 1, 6
+    do ielpdc = 1, ncepdc
+      ckupdc(ielpdc,ikpdc) = 0.d0
+    enddo
+  enddo
+
   if (iihmpr.eq.1) then
     call uikpdc &
-    !==========
-  ( iappel, ncelet, ncepdc,             &
-    icepdc, ckupdc)
+  ( iappel, ncepdc, icepdc, ckupdc)
   endif
 
   call cs_user_head_losses &
@@ -587,6 +587,10 @@ if (ncpdct.gt.0) then
   dt     ,                                                       &
   ckupdc )
 
+ if (iflow .eq.1) then
+   call laghlo(ncepdc, icepdc, ckupdc)
+ endif
+
 endif
 
 ! REMPLISSAGE DES COEFS DE TERME SOURCE DE MASSE
@@ -635,7 +639,6 @@ if (nftcdt.gt.0) then
   enddo
 
   call cs_user_boundary_mass_source_terms &
-  !======================================
 ( nvar   , nscal  ,                                              &
   nfbpcd , iappel ,                                              &
   ifbpcd , itypcd , izftcd ,                                     &
@@ -659,7 +662,6 @@ if (nftcdt.gt.0) then
   ! as boundary condition.
 
   call condensation_copain_model &
-  !=============================
 ( nvar   , nfbpcd , ifbpcd , izzftcd ,                           &
   tpar   ,                                                       &
   spcond , hpcond )
@@ -684,7 +686,6 @@ if (icond.eq.1) then
   enddo
 
   call cs_user_metal_structures_source_terms &
-  !=========================================
 ( nvar   , nscal  ,                                              &
   ncmast , ltmast,                                               &
   itypst , izmast ,                                              &
@@ -696,7 +697,6 @@ if (icond.eq.1) then
   ! volume where this phenomenon occurs.
 
   call metal_structures_copain_model &
-  !=================================
 ( ncmast , ltmast ,                                          &
   tmet   ,                                                   &
   svcond(:, ipr)  , flxmst )
@@ -759,17 +759,15 @@ if(iwarni(iu).ge.1) then
 endif
 
 call dttvar &
-!==========
  ( nvar   , nscal  , ncepdc , ncetsm ,                            &
    iwarni(iu)   ,                                                 &
    icepdc , icetsm , itypsm ,                                     &
-   dt     , propce ,                                              &
+   dt     ,                                                       &
    ckupdc , smacel )
 
 if (nbaste.gt.0.and.itrale.gt.nalinf) then
   ntrela = ntcabs - ntpabs
   call astpdt(dt, ncelet, ntrela)
-  !==========
 endif
 
 ! Compute the pseudo tensorial time step if needed for the pressure solving
@@ -810,7 +808,6 @@ endif
 
 if (idilat.eq.3) then
   call pthrbm &
-  !==========
  ( nvar   , ncetsm , nfbpcd , ncmast,                             &
    dt     , smacel , spcond , svcond )
 
@@ -832,7 +829,6 @@ if (ivrtex.eq.1) then
 
   iappel = 2
   call usvort &
-  !==========
  ( nvar   , nscal  ,                                              &
    iappel ,                                                       &
    dt     )
@@ -841,12 +837,10 @@ if (ivrtex.eq.1) then
 !       (au premier passage seulement)
   if (ipass.eq.1) then
     call vorver ( nfabor , iappel )
-    !==========
   endif
 
   if(irangp.le.0) then
     call vortex
-    !==========
   endif
 
 ! -- Fin de zone Methode des vortex
@@ -890,21 +884,20 @@ endif
 !     pour Syrthes, T1D ou rayonnement.
 itrfup = 1
 
-if (nterup.gt.1.or.isno2t.gt.0) then
-
+if (nterup.gt.1) then
   allocate(ximpav(ndim,ndim,ncelet))
   allocate(uvwk(ndim,ncelet))
   allocate(trava(ndim,ncelet))
-
-  if (nbccou.gt.0 .or. nfpt1t.gt.0 .or. iirayo.gt.0) itrfup = 0
-
 else
-
+  ximpav => rvoid3
   uvwk => rvoid2
   trava => rvoid2
-  ximpav => rvoid3
-
 endif
+
+if (nterup.gt.1.or.isno2t.gt.0) then
+  if (nbccou.gt.0 .or. nfpt1t.gt.0 .or. iirayo.gt.0) itrfup = 0
+endif
+
 ! Compute the number of variable plus the number of turbulent fluxes
 nvarcl = nvar
 do iscal = 1, nscal
@@ -940,7 +933,6 @@ endif
 do while (iterns.le.nterup)
 
   call precli(nvar, nscal, icodcl, rcodcl)
-  !==========
 
   !     - Interface Code_Saturne
   !       ======================
@@ -952,7 +944,6 @@ do while (iterns.le.nterup)
   !    -> sera modifie lors de la restructuration des zones de bord
 
     call uiclim &
-    !==========
   ( ntcabs, nfabor, ippmod(idarcy),                                &
     darcy_gravity, darcy_gravity_x, darcy_gravity_y,               &
     darcy_gravity_z,                                               &
@@ -967,7 +958,7 @@ do while (iterns.le.nterup)
     qimp,   qimpat, qimpcp, dh,     xintur,                        &
     timpat, timpcp, tkent ,  fment, distch, nvarcl, rcodcl)
 
-    if (ippmod(iphpar).eq.0) then
+    if (ippmod(iphpar).eq.0.or.ippmod(igmix).ge.0.or.ippmod(icompf).ge.0) then
 
     ! ON NE FAIT PAS DE LA PHYSIQUE PARTICULIERE
 
@@ -977,7 +968,6 @@ do while (iterns.le.nterup)
       allocate(qcalc(nozfmx))
 
       call stdtcl &
-      !==========
     ( nbzfmx , nozfmx ,                                              &
       iqimp  , icalke , qimp   , dh , xintur,                        &
       itypfb , izfppp , ilzfbr ,                                     &
@@ -995,7 +985,6 @@ do while (iterns.le.nterup)
   !       ==========================
 
   call cs_user_boundary_conditions &
-  !===============================
   ( nvar   , nscal  ,                                              &
     icodcl , itrifb , itypfb , izfppp ,                            &
     dt     ,                                                       &
@@ -1007,7 +996,6 @@ do while (iterns.le.nterup)
   if(iihmpr.eq.1) then
 
     call uiclve &
-    !==========
   ( nfabor, nozppm,                                                &
     iindef, ientre, iesicf, iephcf, isspcf, isopcf,                &
     iparoi, iparug, isymet, isolib, ifrent, ifresf, iale  ,        &
@@ -1020,7 +1008,6 @@ do while (iterns.le.nterup)
 
   if (ivrtex.eq.1) then
     call vor2cl(itypfb, rcodcl)
-    !==========
   endif
 
   ! --- Couplage code/code entre deux instances (ou plus) de Code_Saturne
@@ -1030,7 +1017,6 @@ do while (iterns.le.nterup)
   if (nbrcpl.gt.0) then
 
     call cscfbr &
-    !==========
   ( nscal  ,                                                       &
     icodcl , itypfb ,                                              &
     dt     ,                                                       &
@@ -1042,7 +1028,6 @@ do while (iterns.le.nterup)
 !    (Transfert des structures dans les tableaux rcodcl)
 
     call synthe &
-    !==========
   ( nvar   , nscal  ,                                              &
     iu     , iv     , iw     ,                                     &
     ttcabs , dt     ,                                              &
@@ -1064,7 +1049,6 @@ do while (iterns.le.nterup)
     if (iihmpr.eq.1) then
 
       call uialcl &
-      !==========
     ( nozppm,                            &
       ibfixe, igliss, ivimpo, ifresf,    &
       ialtyb,                            &
@@ -1077,7 +1061,6 @@ do while (iterns.le.nterup)
     endif
 
     call usalcl &
-    !==========
   ( itrale ,                                                       &
     nvar   , nscal  ,                                              &
     icodcl , itypfb , ialtyb ,                                     &
@@ -1099,7 +1082,6 @@ do while (iterns.le.nterup)
     if (nbstru.gt.0.or.nbaste.gt.0) then
 
       call strpre &
-      !==========
     ( itrale , italim , ineefl ,                                     &
       impale ,                                                       &
       flmalf , flmalb , xprale , cofale )
@@ -1121,21 +1103,17 @@ do while (iterns.le.nterup)
   if (itrfin.eq.1 .and. itrfup.eq.1) then
 
     call cpvosy(iscalt, dt)
-    !==========
 
     call coupbi(nfabor, nscal, icodcl, rcodcl)
-    !==========
 
     if (nfpt1t.gt.0) then
       call cou1di(nfabor, iscalt, icodcl, rcodcl)
-      !==========
     endif
 
     ! coupling 1D thermal model with condensation modelling
     ! to take into account the solid temperature evolution over time
     if (nftcdt.gt.0) then
       call cs_tagmri(nfabor, iscalt, icodcl, rcodcl)
-      !=============
     endif
 
   endif
@@ -1144,7 +1122,6 @@ do while (iterns.le.nterup)
   if (iirayo.gt.0 .and. itrfin.eq.1 .and. itrfup.eq.1) then
 
     call raycli &
-    !==========
   ( nvar   , nscal  ,                                              &
     icodcl , itypfb ,                                              &
     izfrad ,                                                       &
@@ -1155,7 +1132,6 @@ do while (iterns.le.nterup)
   !     ON CALCULE LES COEFFICIENTS ASSOCIES AUX CONDITIONS LIMITES
 
   call condli &
-  !==========
 ( nvar   , nscal  , iterns ,                                     &
   isvhb  ,                                                       &
   icodcl , isostd ,                                              &
@@ -1205,42 +1181,20 @@ do while (iterns.le.nterup)
   !     FACILEMENT (I.E. SANS RECALCULS INUTILES) LES TERMES A
   !     ENVOYER POUR LES COUPLAGES AUX BORDS (TYPE SYRTHES)
 
-
-  ! On indique si la variable couplee est l'enthalpie
-  ientha = 0
-  if(iscalt.gt.0) then
-    if(itherm.eq.2) then
-      ientha = 1
-    endif
-  endif
-
-  ! Compressible : on indique si la variable couple est l'energie
-
-  if (ippmod(icompf).ge.0) then
-    if(iscalt.gt.0) then
-      if(itherm.eq.3) then
-        ientha = 2
-      endif
-    endif
-  endif
-
   ! En compressible et si on couple ave l'energie
   ! on recupere le Cv de la phase couplee
 
-  if ( ippmod(icompf).ge.0 .and. ientha .eq. 2 ) then
+  if (itherm .eq. 3) then
 
     if(icv.gt.0) then
       ippcv = ipproc(icv)
-      ncv   = ncelet
       cvcst = 0.d0
     else
       ippcv = 1
-      ncv   = 1
       cvcst = cv0
     endif
   else
     ippcv = 1
-    ncv   = 1
     cvcst = 0.d0
   endif
 
@@ -1248,19 +1202,14 @@ do while (iterns.le.nterup)
   !  constant ou variable
   if (itrfin.eq.1 .and. itrfup.eq.1) then
 
-    call coupbo &
-    !==========
-  ( ncv    , ientha ,                                              &
-    cvcst  , propce(:,ippcv),                                      &
-    hbord  , theipb )
+    call coupbo(itherm, cvcst, hbord, theipb)
 
     if (nfpt1t.gt.0) then
       call cou1do &
-      !==========
     ( nvar   , nscal  , nfpt1d ,                                   &
-      ientha , ifpt1d , iclt1d ,                                   &
+      ifpt1d , iclt1d ,                                            &
       tppt1d , tept1d , hept1d , fept1d ,                          &
-      xlmbt1 , rcpt1d , dtpt1d , dt     ,                          &
+      xlmbt1 , rcpt1d , dtpt1d , dt     , cvcst  ,                 &
       hbord  , theipb )
     endif
 
@@ -1268,7 +1217,6 @@ do while (iterns.le.nterup)
     ! on a surface region
     if (nftcdt.gt.0.and.nztag1d.eq.1) then
       call cs_tagmro &
-      !=============
      ( nfbpcd , ifbpcd , izzftcd ,                  &
        dt     )
     endif
@@ -1277,7 +1225,6 @@ do while (iterns.le.nterup)
      ! on a volume region associated to metal structures
     if (icond.eq.1.and.itagms.eq.1) then
       call cs_metal_structures_tag &
-      !===========================
      ( ncmast , ltmast ,                          &
        dt     )
     endif
@@ -1311,44 +1258,40 @@ do while (iterns.le.nterup)
     !  parois qui deviennent autre chose)
 
     ! Nombre de faces de paroi
-    if(ipass.eq.1) then
-      if(ineedy.eq.1) then
+    if (ipass.eq.1) then
+      if (ineedy.eq.1) then
         infpar = 0
         do ifac = 1, nfabor
           if (itypfb(ifac).eq.iparoi .or. itypfb(ifac).eq.iparug) then
             infpar = infpar+1
           endif
         enddo
-        if(irangp.ge.0) then
+        if (irangp.ge.0) then
           call parcpt(infpar)
         endif
       endif
     endif
 
-
     !     On calcule la distance a la paroi
     !          si elle doit etre mise a jour
     !       et si on en a besoin,
     !       et si on a choisi ce mode de calcul,
-    if( imajdy.eq.0.and.ineedy.eq.1.and.abs(icdpar).eq.1) then
+    if (imajdy.eq.0 .and. ineedy.eq.1) then
 
-      !     S'il n'y a pas de paroi, on garde l'initialisation a GRAND
-      if(infpar.eq.0) then
+      !  S'il n'y a pas de paroi, on garde l'initialisation a GRAND
+      if (infpar.eq.0) then
         imajdy = 1
-
-        !     S'il y a des parois, il faut calculer
+        ! If we have walls, we must compute
       else
-
-
-        !     On doit conserver la memoire de memcli a cause de 'uetbor'
-        !       dans DISTYP (uniquement en LES avec van Driest mais tant pis)
-
-        call distpr(itypfb, dispar)
-        !==========
-
+        ! On doit conserver la memoire de memcli a cause de 'uetbor'
+        ! dans distyp (uniquement en LES avec van Driest mais tant pis)
+        if (abs(icdpar).eq.1) then
+          call distpr(itypfb, dispar)
+        else if (abs(icdpar).eq.2) then
+          call distpr2(itypfb, dispar)
+        endif
         !     La distance n'a plus a etre mise a jour sauf en ALE
         if (iale.eq.0) imajdy = 1
-
       endif
     endif
 
@@ -1361,33 +1304,28 @@ do while (iterns.le.nterup)
 
   !     On calcule y+ si on en a besoin
 
-  if( (itytur.eq.4.and.idries.eq.1)                 &
-       .or. (iilagr.ge.1 .and. iroule.eq.2) ) then
+  if (     (itytur.eq.4 .and. idries.eq.1)                 &
+      .or. (iilagr.ge.1 .and. iroule.eq.2)) then
 
     !       On calcule si on a demande ce mode de calcul
     !               et s'il y a des parois (si pas de paroi, pas de y+)
-    if(abs(icdpar).eq.1.and.infpar.gt.0) then
-
-      !     On doit conserver la memoire de memcli a cause de 'uetbor'
-      !       dans DISTYP
 
+    if (abs(infpar).gt.0) then
       call distyp(itypfb, dispar, yplpar)
-      !==========
-
     endif
 
   endif
 
   if (itytur.eq.4 .and. idries.eq.1) then
 
-    !     Pas d'amortissement si pas de paroi
+    ! Pas d'amortissement si pas de paroi
     if (infpar.gt.0) then
-      call vandri(itypfb, ifapat, visvdr, yplpar)
+      call vandri(visvdr, yplpar)
     endif
 
   endif
 
-  if(ineedy.eq.1.and.iwarny.ge.1) then
+  if (ineedy.eq.1.and.iwarny.ge.1) then
     call dmtmps(tdist2)
     tditot = tdist2-tdist1
     write(nfecra,4010)tditot
@@ -1398,9 +1336,9 @@ do while (iterns.le.nterup)
 !      ON SORT ICI
 !===============================================================================
 
-  if (inpdt0.eq.1.and.isuite.eq.0) goto 200
+  if (inpdt0.eq.1.and.isuite.eq.0) must_return = .true.
 
-  if (iilagr.eq.3) goto 200
+  if (iilagr.eq.3) must_return = .true.
 
 !===============================================================================
 ! 11. RESOLUTION DE LA VITESSE DE MAILLAGE EN ALE
@@ -1412,12 +1350,36 @@ do while (iterns.le.nterup)
     if (itrale.eq.0) then
 
       call alelav(propce)
-      goto 200
+      must_return = .true.
 
     endif
 
   endif
 
+!===============================================================================
+! Return now if required
+!===============================================================================
+
+  if (must_return) then
+
+    if (allocated(hbord)) deallocate(hbord)
+    if (allocated(theipb)) deallocate(theipb)
+    if (allocated(visvdr)) deallocate(visvdr)
+
+    if (nterup.gt.1) then
+      deallocate(ximpav, uvwk, trava)
+    endif
+
+    deallocate(icodcl, rcodcl)
+
+    if (allocated(delay_id)) deallocate(delay_id)
+
+    return
+
+  endif
+
+!===============================================================================
+
 !===============================================================================
 ! 11. CALCUL A CHAMP DE VITESSE NON FIGE :
 !      ON RESOUT VITESSE ET TURBULENCE
@@ -1426,7 +1388,6 @@ do while (iterns.le.nterup)
 
   ! En cas de champ de vitesse fige, on ne boucle pas sur U/P
   if (iccvfg.eq.0) then
-  !===============
 
 !===============================================================================
 ! 12. RESOLUTION QUANTITE DE MOUVEMENT ET MASSE
@@ -1441,7 +1402,6 @@ do while (iterns.le.nterup)
     if (ippmod(idarcy).eq.-1) then
 
       call navstv &
-      !==========
       ( nvar   , nscal  , iterns , icvrge , itrale ,                   &
         isostd ,                                                       &
         dt     , propce ,                                              &
@@ -1454,7 +1414,6 @@ do while (iterns.le.nterup)
 
       if (iihmpr.eq.1) then
         call uidapp                                                    &
-        !==========
          ( darcy_anisotropic_permeability,                             &
            darcy_anisotropic_diffusion,                                &
            darcy_gravity,                                              &
@@ -1515,7 +1474,6 @@ do while (iterns.le.nterup)
       if ((istmpf.eq.0.and.inslst.eq.0) .or. istmpf.ne.0) then
         iappel = 3
         call schtmp(nscal, iappel, propce)
-        !==========
       endif
 
       if (inslst.eq.1) goto 100
@@ -1542,7 +1500,6 @@ enddo
 if (ippmod(idarcy).eq.1) then
 
   call precli(nvar, nscal, icodcl, rcodcl)
-  !==========
 
   if (iihmpr.eq.1) then
 
@@ -1551,7 +1508,6 @@ if (ippmod(idarcy).eq.1) then
   !    -> sera modifie lors de la restructuration des zones de bord
 
     call uiclim &
-    !==========
   ( ntcabs, nfabor, ippmod(idarcy),                                &
     darcy_gravity, darcy_gravity_x, darcy_gravity_y,               &
     darcy_gravity_z,                                               &
@@ -1576,7 +1532,6 @@ if (ippmod(idarcy).eq.1) then
       allocate(qcalc(nozfmx))
 
       call stdtcl &
-      !==========
     ( nbzfmx , nozfmx ,                                              &
       iqimp  , icalke , qimp   , dh , xintur,                        &
       itypfb , izfppp , ilzfbr ,                                     &
@@ -1591,7 +1546,6 @@ if (ippmod(idarcy).eq.1) then
   endif
 
   call cs_user_boundary_conditions &
-  !===============================
   ( nvar   , nscal  ,                                              &
     icodcl , itrifb , itypfb , izfppp ,                            &
     dt     ,                                                       &
@@ -1611,14 +1565,12 @@ if (allocated(hbord)) deallocate(hbord)
 if (allocated(theipb)) deallocate(theipb)
 if (allocated(visvdr)) deallocate(visvdr)
 
-if (nterup.gt.1.or.isno2t.gt.0) then
-  deallocate(uvwk, trava)
-  deallocate(ximpav)
+if (nterup.gt.1) then
+  deallocate(ximpav, uvwk, trava)
 endif
 
 ! Calcul sur champ de vitesse fige SUITE (a cause de la boucle U/P)
 if (iccvfg.eq.0) then
-!===============
 
 !===============================================================================
 ! 13.  DEPLACEMENT DES STRUCTURES EN ALE ET TEST DE BOUCLAGE IMPLICITE
@@ -1627,7 +1579,6 @@ if (iccvfg.eq.0) then
   if (nbstru.gt.0.or.nbaste.gt.0) then
 
     call strdep &
-    !==========
   ( itrale , italim , itrfin ,                                     &
     nvar   ,                                                       &
     dt     ,                                                       &
@@ -1655,7 +1606,6 @@ if (iccvfg.eq.0) then
   if (istmpf.eq.0) then
     iappel = 4
     call schtmp(nscal, iappel, propce)
-    !==========
   endif
 
 !===============================================================================
@@ -1675,7 +1625,6 @@ if (iccvfg.eq.0) then
 
   ! Si on est en v2f (phi-fbar ou BL-v2/k), on reserve un tableau
   ! de taille NCELET pour eviter de recalculer la production dans RESV2F
-  ! (trois appels a GRDCEL)
   if (itytur.eq.5) then
     allocate(prdv2f(ncelet))
   endif
@@ -1683,7 +1632,6 @@ if (iccvfg.eq.0) then
   if ((itytur.eq.2) .or. (itytur.eq.5)) then
 
     call turbke &
-    !==========
   ( nvar   , nscal  ,                                              &
     ncepdc , ncetsm ,                                              &
     icepdc , icetsm , itypsm ,                                     &
@@ -1695,7 +1643,6 @@ if (iccvfg.eq.0) then
     if( itytur.eq.5 )  then
 
       call resv2f &
-      !==========
     ( nvar   , nscal  ,                                              &
       ncepdc , ncetsm ,                                              &
       icepdc , icetsm , itypsm ,                                     &
@@ -1725,16 +1672,14 @@ if (iccvfg.eq.0) then
 
   else if(itytur.eq.3) then
 
-    ! Calcul de Alpha pour l'EBRSM
+    ! Compute Alpha for EBRSM
     if (iturb.eq.32) then
 
-      call resalp(nvar)
-      !==========
+      call resalp()
 
     endif
 
     call turrij &
-    !==========
   ( nvar   , nscal  ,                                              &
     ncepdc , ncetsm ,                                              &
     icepdc , icetsm , itypsm ,                                     &
@@ -1745,7 +1690,6 @@ if (iccvfg.eq.0) then
   else if (iturb.eq.60) then
 
     call turbkw &
-    !==========
   ( nvar   , nscal  ,                                              &
     ncepdc , ncetsm ,                                              &
     icepdc , icetsm , itypsm ,                                     &
@@ -1766,12 +1710,11 @@ if (iccvfg.eq.0) then
         cvar_k(iel)   = relaxk*cvar_k(iel)   + (1.d0-relaxk)*cvara_k(iel)
         cvar_omg(iel) = relaxw*cvar_omg(iel) + (1.d0-relaxw)*cvara_omg(iel)
       enddo
-    endif
+    end if
 
   else if( iturb.eq.70 ) then
 
     call turbsa &
-    !==========
   ( nvar   , nscal  ,                                              &
     ncepdc , ncetsm ,                                              &
     icepdc , icetsm , itypsm ,                                     &
@@ -1808,7 +1751,6 @@ if (nscal.ge.1 .and. iirayo.gt.0) then
   endif
 
   call raydom &
-  !==========
  ( nvar   , nscal  ,                                              &
    itypfb ,                                                       &
    izfrad ,                                                       &
@@ -1823,7 +1765,6 @@ if (nscal.ge.1) then
   endif
 
   call scalai                                                     &
-  !==========
  ( nvar   , nscal  ,                                              &
    dt     , propce )
 
@@ -1851,14 +1792,21 @@ if (allocated(delay_id)) deallocate(delay_id)
 
 iappel = 5
 call schtmp(nscal, iappel, propce)
-!==========
 
 !===============================================================================
-! 17.  SORTIE DANS LE CAS DE "zero pas de temps" ET INIT ALE
+! Update flow through fans
 !===============================================================================
 
- 200  continue
-
+n_fans = cs_fan_n_fans()
+if (n_fans .gt. 0) then
+  call field_get_key_int(ivarfl(iu), kimasf, iflmas)
+  call field_get_key_int(ivarfl(iu), kbmasf, iflmab)
+  call field_get_val_s(iflmas, i_mass_flux)
+  call field_get_val_s(iflmab, b_mass_flux)
+  call field_get_val_s(icrom, crom)
+  call field_get_val_s(ibrom, brom)
+  call debvtl(i_mass_flux, b_mass_flux, crom, brom)
+endif
 
 !===============================================================================
 
