@@ -87,11 +87,11 @@ character(len=80) :: f_name, f_label, s_label, s_name
 
 interface
 
-  subroutine cs_field_pointer_map_base()  &
-    bind(C, name='cs_field_pointer_map_base')
+  subroutine cs_turbulence_model_init_bc_ids()  &
+    bind(C, name='cs_turbulence_model_init_bc_ids')
     use, intrinsic :: iso_c_binding
     implicit none
-  end subroutine cs_field_pointer_map_base
+  end subroutine cs_turbulence_model_init_bc_ids
 
 end interface
 
@@ -597,7 +597,10 @@ endif
 ! Map to field pointers
 !===============================================================================
 
-call cs_field_pointer_map_base()
+call cs_field_pointer_map_base
+call cs_field_pointer_map_boundary
+
+call cs_turbulence_model_init_bc_ids
 
 return
 
