@@ -21,19 +21,25 @@
 !-------------------------------------------------------------------------------
 
 !> \file visecv.f90
-!> \brief Computes the secondary viscosity contribution \f$\kappa -2/3 \mu\f$
-!> in order to compute:
+!> \brief Computes the secondary viscosity contribution \f$\kappa
+!> -\dfrac{2}{3} \mu\f$ in order to compute:
 !> \f[
-!> \grad( \kappa -2/3 \mu) \trace( \gradt(\vect{u})) )
+!> \grad\left( (\kappa -\dfrac{2}{3} \mu) \trace( \gradt(\vect{u})) \right)
 !> \f]
 !> with:
 !>   - \f$ \mu = \mu_{laminar} + \mu_{turbulent} \f$
 !>   - \f$ \kappa \f$ is the volume viscosity (generally zero)
 !>
-!> \remark:
-!>   In LES, the tensor \f$<(u-<u>)(u-<u>)>\f$ is modeled by \f$mut <S>\f$
-!>   and not by \f$mut <S> - 2/3 mut Tr(<S>) Id + 2/3 k Id\f$
-!>   so that no term \f$mut div<u>\f$ is needed.
+!> \remark
+!> In LES, the tensor
+!> \f$\overline{\left(\vect{u}-\overline{\vect{u}}\right)\otimes\left(\vect{u}
+!>-\overline{\vect{u}}\right)}\f$
+!> is modeled by \f$\mu_t \overline{\tens{S}}\f$
+!> and not by
+!> \f$\mu_t\overline{\tens{S}}-\dfrac{2}{3}\mu_t
+!> \trace\left(\overline{\tens{S}}\right)\tens{1}+\dfrac{2}{3}k\tens{1}\f$
+!> so that no term
+!> \f$\mu_t \dive \left(\overline{\vect{u}}\right)\f$ is needed.
 !------------------------------------------------------------------------------
 
 !------------------------------------------------------------------------------
@@ -41,14 +47,12 @@
 !------------------------------------------------------------------------------
 !   mode          name          role
 !------------------------------------------------------------------------------
-!> \param[in]     propce        physical properties at cell centers
 !> \param[in,out] secvif        lambda*surface at interior faces
 !> \param[in,out] secvib        lambda*surface at boundary faces
 !______________________________________________________________________________
 
 subroutine visecv &
- ( propce ,                            &
-   secvif , secvib )
+ ( secvif , secvib )
 
 !===============================================================================
 ! Module files
@@ -73,20 +77,21 @@ implicit none
 
 ! Arguments
 
-double precision propce(ncelet,*)
 double precision secvif(nfac), secvib(nfabor)
 
 ! Local variables
 
 integer          iel, ifac, ii, jj
-integer          ipcvis, ipcvst
+integer          ipcvst
 integer          ipcvsv
 
-double precision d2s3m
+double precision d2s3m, secvsi, secvsj, pnd
 
 double precision, allocatable, dimension(:) :: secvis
 double precision, dimension(:), pointer :: porosi
 double precision, dimension(:), pointer :: viscl, visct
+double precision, dimension(:), pointer :: cpro_viscv
+double precision, dimension(:), pointer :: cproa_viscl, cproa_visct
 
 !===============================================================================
 
@@ -103,6 +108,7 @@ call field_get_val_s(iprpfl(ivisct), visct)
 if(ippmod(icompf).ge.0) then
   if(iviscv.gt.0) then
     ipcvsv = ipproc(iviscv)
+    call field_get_val_s(iprpfl(iviscv), cpro_viscv)
   else
     ipcvsv = 0
   endif
@@ -114,7 +120,6 @@ endif
 ! time n FIXME check if it is consistent with viscfa.f90
 if(isno2t.gt.0) then
   if(iviext.gt.0) then
-    ipcvis = ipproc(ivisla)
     ipcvst = ipproc(ivista)
   endif
 endif
@@ -129,8 +134,9 @@ d2s3m = -2.d0/3.d0
 
 ! Laminar viscosity
 if(isno2t.gt.0 .and. iviext.gt.0) then
+  call field_get_val_prev_s(iprpfl(iviscl), cproa_viscl)
   do iel = 1, ncel
-    secvis(iel) = d2s3m*propce(iel,ipcvis)
+    secvis(iel) = d2s3m*cproa_viscl(iel)
   enddo
 else
   do iel = 1, ncel
@@ -141,7 +147,7 @@ endif
 ! Volume viscosity if present
 if (ipcvsv.gt.0) then
   do iel = 1, ncel
-    secvis(iel) = secvis(iel) + propce(iel,ipcvsv)
+    secvis(iel) = secvis(iel) + cpro_viscv(iel)
   enddo
 elseif (ipcvsv.eq.0) then
   do iel = 1, ncel
@@ -152,8 +158,9 @@ endif
 ! Turbulent viscosity (if not in Rij or LES)
 if (itytur.ne.3 .and. itytur.ne.4) then
   if(isno2t.gt.0 .and. iviext.gt.0) then
+    call field_get_val_prev_s(iprpfl(ivisct), cproa_visct)
     do iel = 1, ncel
-      secvis(iel) = secvis(iel) + d2s3m*propce(iel,ipcvst)
+      secvis(iel) = secvis(iel) + d2s3m*cproa_visct(iel)
     enddo
   else
     do iel = 1, ncel
@@ -179,14 +186,31 @@ if (irangp.ge.0.or.iperio.eq.1) then
 endif
 
 ! --- Interior faces
-! TODO we should (re)test the weigthen walue and also add a consistent
-! geometrical weigthen if imvisf>0. (see viscfa.f90)
+! TODO we should (re)test the weigthen walue for imvisf=0
 
-do ifac = 1, nfac
-  ii = ifacel(1,ifac)
-  jj = ifacel(2,ifac)
-  secvif(ifac) = 0.5d0*(secvis(ii)+secvis(jj))
-enddo
+if (imvisf.eq.0) then
+  do ifac = 1, nfac
+    ii = ifacel(1,ifac)
+    jj = ifacel(2,ifac)
+
+    secvsi = secvis(ii)
+    secvsj = secvis(jj)
+    pnd = pond(ifac)
+
+    secvif(ifac) = 0.5d0*(secvsi+secvsj)
+  enddo
+else
+  do ifac = 1, nfac
+    ii = ifacel(1,ifac)
+    jj = ifacel(2,ifac)
+
+    secvsi = secvis(ii)
+    secvsj = secvis(jj)
+    pnd = pond(ifac)
+
+    secvif(ifac) = secvsi*secvsj/(pnd*secvsi+(1.d0-pnd)*secvsj)
+  enddo
+endif
 
 ! --- Boundary faces
 ! TODO shall we extrapolate this value?
