@@ -39,8 +39,8 @@
  * Local headers
  *----------------------------------------------------------------------------*/
 
-#include <bft_mem.h>
-#include <bft_printf.h>
+#include "bft_mem.h"
+#include "bft_printf.h"
 
 #include "cs_order.h"
 #include "cs_sort.h"
@@ -83,11 +83,11 @@ typedef struct {
 /*!
  * \brief  Add a entry in the face --> edges connectivity
  *
- * \param[in]    shift     position where to add the new entry
- * \param[in]    v1_num    number of the first vertex
- * \param[in]    v2_num    number of the second vertex
- * \param[in]    builder   pointer to a _edge_builder_t structure
- * \param[inout] f2e       face --> edges connectivity
+ * \param[in]      shift     position where to add the new entry
+ * \param[in]      v1_num    number of the first vertex
+ * \param[in]      v2_num    number of the second vertex
+ * \param[in]      builder   pointer to a _edge_builder_t structure
+ * \param[in, out] f2e       face --> edges connectivity
  */
 /*----------------------------------------------------------------------------*/
 
@@ -482,7 +482,7 @@ _free_edge_builder(_edge_builder_t  **p_builder)
  * \brief  Define the cell -> faces connectivity which is stored in a
  *         cs_sla_matrix_t structure
  *
- * \param[in]  m         pointer to a cs_mesh_t structure
+ * \param[in]  mesh      pointer to a cs_mesh_t structure
  *
  * \return a pointer to a new allocated cs_sla_matrix_t structure
  */
@@ -580,7 +580,7 @@ _build_c2f_connect(const cs_mesh_t   *mesh)
  *        c2e: cell --> edges connectivity
  *        c2v: cell --> vertices connectivity
  *
- * \param[inout]  connect     pointer to the cs_cdo_connect_t struct.
+ * \param[in, out]  connect     pointer to the cs_cdo_connect_t struct.
  */
 /*----------------------------------------------------------------------------*/
 
@@ -684,17 +684,13 @@ _connect_info_create(cs_lnum_t     n_elts)
 
   BFT_MALLOC(info, 1, cs_connect_info_t);
 
-  BFT_MALLOC(info->flag, n_elts, short int);
+  BFT_MALLOC(info->flag, n_elts, cs_flag_t);
   for (i = 0; i < n_elts; i++)
     info->flag[i] = 0;
 
-  info->n = n_elts;
-  info->n_in = 0;
-  info->n_bd = 0;
-  info->n_ii = 0;
-  info->n_ib = 0;
-  info->n_bb = 0;
-  info->n_bi = 0;
+  info->n_ent = n_elts;
+  info->n_ent_in = 0;
+  info->n_ent_bd = 0;
 
   return info;
 }
@@ -703,8 +699,7 @@ _connect_info_create(cs_lnum_t     n_elts)
 /*!
  * \brief  Allocated and initialize a cs_cdo_connect_info_t structure
  *
- * \param[in]     n_elts    Size of the maximal set of entities related to
- *                          this structure
+ * \param[in]     info      Info structure
  *
  * \return  a pointer to the new allocated structure
  */
@@ -724,23 +719,21 @@ _connect_info_free(cs_connect_info_t    *info)
 
 /*----------------------------------------------------------------------------*/
 /*!
- * \brief  Define a status Int/Border 1st and 2nd level for sets of vertices,
- *         edges and faces
+ * \brief  Define a status Int/Border
  *
- * \param[inout]     connect    pointer to a cs_cdo_connect_t struct.
+ * \param[in]       m        pointer to a cs_mesh_t structure
+ * \param[in, out]  connect  pointer to a cs_cdo_connect_t struct.
  */
 /*----------------------------------------------------------------------------*/
 
 static void
-_define_connect_info(cs_cdo_connect_t     *connect)
+_define_connect_info(const cs_mesh_t    *m,
+                     cs_cdo_connect_t   *connect)
 {
-  int  i, j, nn, v_id, e_id, f_id, c_id, count;
-  short int  flag1, flag2;
+  int  i, j, v_id, e_id, f_id, c_id;
 
-  cs_connect_index_t  *v2v = NULL, *v2e = NULL, *e2v = NULL;
   cs_connect_info_t  *vi = NULL, *ei = NULL, *fi = NULL, *ci = NULL;
 
-  const cs_mesh_t  *m = cs_glob_mesh;
   const cs_lnum_t  n_vertices = connect->v2e->n_rows;
   const cs_lnum_t  n_edges = connect->e2f->n_rows;
   const cs_lnum_t  n_faces = connect->f2e->n_rows;
@@ -752,33 +745,36 @@ _define_connect_info(cs_cdo_connect_t     *connect)
   fi = _connect_info_create(n_faces);
   ci = _connect_info_create(n_cells);
 
-  /* By default all entities are set "interior" */
+  /* By default all entities are set to the flag CS_CDO_CONNECT_IN (interior) */
   for (i = 0; i < n_vertices; i++)
     vi->flag[i] = CS_CDO_CONNECT_IN;
-
   for (i = 0; i < n_edges; i++)
     ei->flag[i] = CS_CDO_CONNECT_IN;
-
   for (i = 0; i < n_faces; i++)
     fi->flag[i] = CS_CDO_CONNECT_IN;
-
   for (i = 0; i < n_cells; i++)
     ci->flag[i] = CS_CDO_CONNECT_IN;
 
-  /* Loop on border faces => flag all border entities */
+  /* Loop on border faces and flag all border entities
+     -> cells, faces, edges and vertices */
   for (f_id = m->n_i_faces; f_id < n_faces; f_id++) {
 
+    /* Flag related face */
     fi->flag[f_id] = CS_CDO_CONNECT_BD;
     assert(connect->f2c->idx[f_id+1]-connect->f2c->idx[f_id]==1);
+
+    /* Flag related cell */
     c_id = connect->f2c->col_id[connect->f2c->idx[f_id]];
     ci->flag[c_id] = CS_CDO_CONNECT_BD;
 
     for (i = connect->f2e->idx[f_id]; i < connect->f2e->idx[f_id+1]; i++) {
 
+      /* Flag related edges */
       e_id = connect->f2e->col_id[i];
       ei->flag[e_id] = CS_CDO_CONNECT_BD;
       for (j = connect->e2v->idx[e_id]; j < connect->e2v->idx[e_id+1]; j++) {
 
+        /* Flag related edges */
         v_id = connect->e2v->col_id[j];
         vi->flag[v_id] = CS_CDO_CONNECT_BD;
 
@@ -791,113 +787,29 @@ _define_connect_info(cs_cdo_connect_t     *connect)
   /* Count number of border vertices */
   for (i = 0; i < n_vertices; i++)
     if (vi->flag[i] & CS_CDO_CONNECT_BD)
-      vi->n_bd++;
-  vi->n_in = vi->n - vi->n_bd;
+      vi->n_ent_bd++;
+  vi->n_ent_in = vi->n_ent - vi->n_ent_bd;
 
   /* Count number of border edges */
   for (i = 0; i < n_edges; i++)
     if (ei->flag[i] & CS_CDO_CONNECT_BD)
-      ei->n_bd++;
-  ei->n_in = ei->n - ei->n_bd;
+      ei->n_ent_bd++;
+  ei->n_ent_in = ei->n_ent - ei->n_ent_bd;
 
   /* Count number of border faces */
   for (i = 0; i < n_faces; i++)
     if (fi->flag[i] & CS_CDO_CONNECT_BD)
-      fi->n_bd++;
-  fi->n_in = fi->n - fi->n_bd;
-  assert(m->n_i_faces == fi->n_in);
+      fi->n_ent_bd++;
+  fi->n_ent_in = fi->n_ent - fi->n_ent_bd;
+
+  /* Sanity check */
+  assert(m->n_i_faces == fi->n_ent_in);
 
   /* Count number of border cells */
   for (i = 0; i < n_cells; i++)
     if (ci->flag[i] & CS_CDO_CONNECT_BD)
-      ci->n_bd++;
-  ci->n_in = ci->n - ci->n_bd;
-
-  /* Build v -> v connectivity */
-  v2e = cs_index_map(n_vertices, connect->v2e->idx, connect->v2e->col_id);
-  e2v = cs_index_map(n_edges, connect->e2v->idx, connect->e2v->col_id);
-  v2v = cs_index_compose(n_vertices, v2e, e2v);
-
-  /* Compute second level interior/border for vertices */
-  for (i = 0; i < n_vertices; i++) {
-
-    nn = v2v->idx[i+1] - v2v->idx[i], count = 0;
-    for (j = v2v->idx[i]; j < v2v->idx[i+1]; j++)
-      if (vi->flag[v2v->ids[j]] & CS_CDO_CONNECT_BD)
-        count++;
-
-    if (vi->flag[i] & CS_CDO_CONNECT_BD) { /* Border vertices */
-      if (count == nn) vi->flag[i] |= CS_CDO_CONNECT_BB, vi->n_bb++;
-      else             vi->flag[i] |= CS_CDO_CONNECT_BI;
-    }
-    else if (vi->flag[i] & CS_CDO_CONNECT_IN) { /* Interior vertices */
-      if (count == 0) vi->flag[i] |= CS_CDO_CONNECT_II, vi->n_ii++;
-      else            vi->flag[i] |= CS_CDO_CONNECT_IB;
-    }
-    else
-      bft_error(__FILE__, __LINE__, 0,
-                _(" Vertex %d is neither interior nor border.\n"
-                  " Stop execution\n"), i+1);
-
-  } /* End of loop on vertices */
-
-  vi->n_bi = vi->n_bd - vi->n_bb;
-  vi->n_ib = vi->n_in - vi->n_ii;
-
-  cs_index_free(&v2v);
-  cs_index_free(&v2e);
-  cs_index_free(&e2v);
-
-  /* Set of edges */
-  for (i = 0; i < n_edges; i++) {
-
-    j = connect->e2v->idx[i];
-    flag1 = vi->flag[connect->e2v->col_id[j  ]];
-    flag2 = vi->flag[connect->e2v->col_id[j+1]];
-
-    if (ei->flag[i] == CS_CDO_CONNECT_IN) {
-      if ( (flag1 & CS_CDO_CONNECT_II) && (flag2 & CS_CDO_CONNECT_II) )
-        ei->flag[i] |= CS_CDO_CONNECT_II, ei->n_ii++;
-      else
-        ei->flag[i] |= CS_CDO_CONNECT_IB;
-    }
-    else if (ei->flag[i] == CS_CDO_CONNECT_BD) {
-      if ( (flag1 & CS_CDO_CONNECT_BB) && (flag2 & CS_CDO_CONNECT_BB) )
-        ei->flag[i] |= CS_CDO_CONNECT_BB, ei->n_bb++;
-      else
-        ei->flag[i] |= CS_CDO_CONNECT_BI;
-    }
-    else
-      bft_error(__FILE__, __LINE__, 0,
-                _(" Edge %d is neither interior nor border.\n"
-                  " Stop execution\n"), i+1);
-  } /* Loop on edges */
-
-  ei->n_ib = ei->n_in - ei->n_ii;
-  ei->n_bi = ei->n_bd - ei->n_bb;
-
-  /* Set of faces */
-  for (f_id = 0; f_id < n_faces; f_id++) {
-
-    nn = connect->f2e->idx[f_id+1] - connect->f2e->idx[f_id];
-    count = 0;
-    for (j = connect->f2e->idx[f_id]; j < connect->f2e->idx[f_id+1]; j++) {
-      if (ei->flag[connect->f2e->col_id[j]] & CS_CDO_CONNECT_BD)
-        count++;
-    }
-
-    if (fi->flag[f_id] & CS_CDO_CONNECT_IN) {
-      if (count == 0) fi->flag[f_id] |= CS_CDO_CONNECT_II;
-      else            fi->flag[f_id] |= CS_CDO_CONNECT_IB;
-    }
-    else
-      /* Border faces are built from only border edges. Second level tag
-         is therfore not useful */
-      assert(fi->flag[f_id] & CS_CDO_CONNECT_BD && count == nn);
-
-} /* Loop on faces */
-
-  fi->n_ib = fi->n_in - fi->n_ii;
+      ci->n_ent_bd++;
+  ci->n_ent_in = ci->n_ent - ci->n_ent_bd;
 
   /* Return pointers */
   connect->v_info = vi;
@@ -921,42 +833,16 @@ _define_connect_info(cs_cdo_connect_t     *connect)
 const char *
 cs_cdo_connect_flagname(short int  flag)
 {
-  short int  _flag = 0;
-
-  /* Second level is prior */
-  if (flag & CS_CDO_CONNECT_II) _flag = CS_CDO_CONNECT_II;
-  if (flag & CS_CDO_CONNECT_IB) _flag = CS_CDO_CONNECT_IB;
-  if (flag & CS_CDO_CONNECT_BB) _flag = CS_CDO_CONNECT_BB;
-  if (flag & CS_CDO_CONNECT_BI) _flag = CS_CDO_CONNECT_BI;
-
-  if (_flag == 0) { /* Second level */
-    if (flag & CS_CDO_CONNECT_IN) _flag = CS_CDO_CONNECT_IN;
-    if (flag & CS_CDO_CONNECT_BD) _flag = CS_CDO_CONNECT_BD;
-  }
-
-  switch (_flag) {
+  switch (flag) {
 
   case CS_CDO_CONNECT_BD:
-    return " Bd ";
+    return " Border  ";
     break;
   case CS_CDO_CONNECT_IN:
-    return " In ";
-    break;
-  case CS_CDO_CONNECT_II:
-    return "InIn";
-    break;
-  case CS_CDO_CONNECT_IB:
-    return "InBd";
-    break;
-  case CS_CDO_CONNECT_BI:
-    return "BdIn";
-    break;
-  case CS_CDO_CONNECT_BB:
-    return "BdBd";
+    return " Interior";
     break;
   default:
-    return "Full";
-
+    return " Undefined";
   }
 
 }
@@ -981,15 +867,24 @@ cs_cdo_connect_build(const cs_mesh_t      *m)
   /* Build the connectivity structure */
   BFT_MALLOC(connect, 1, cs_cdo_connect_t);
 
-  /* Build DEC matrices related to connectivity */
+  /* Build DEC matrices related to connectivity
+     cell / face connectivity */
   connect->c2f = _build_c2f_connect(m);
+  cs_sla_matrix_set_info(connect->c2f);
   connect->f2c = cs_sla_matrix_transpose(connect->c2f);
+  cs_sla_matrix_set_info(connect->f2c);
 
+  /* face / edge conncetivity */
   connect->f2e = _build_f2e_connect(m, builder);
+  cs_sla_matrix_set_info(connect->f2e);
   connect->e2f = cs_sla_matrix_transpose(connect->f2e);
+  cs_sla_matrix_set_info(connect->e2f);
 
+  /* edge / vertex connectivity */
   connect->e2v = _build_e2v_connect(builder);
+  cs_sla_matrix_set_info(connect->e2v);
   connect->v2e = cs_sla_matrix_transpose(connect->e2v);
+  cs_sla_matrix_set_info(connect->v2e);
 
   _free_edge_builder(&builder);
 
@@ -998,14 +893,11 @@ cs_cdo_connect_build(const cs_mesh_t      *m)
 
   /* Build status flag: interior/border and related connection to
      interior/border entities */
-  _define_connect_info(connect);
+  _define_connect_info(m, connect);
 
   /* Max number of entities (vertices, edges and faces) by cell */
   _compute_max_ent(connect);
 
-  connect->max_set_size = CS_MAX(connect->v2e->n_rows, connect->e2v->n_rows);
-  connect->max_set_size = CS_MAX(connect->f2e->n_rows, connect->max_set_size);
-  connect->max_set_size = CS_MAX(connect->c2f->n_rows, connect->max_set_size);
 
   return connect;
 }
@@ -1049,14 +941,14 @@ cs_cdo_connect_free(cs_cdo_connect_t   *connect)
 
 /*----------------------------------------------------------------------------*/
 /*!
- * \brief  Resume connectivity information
+ * \brief  Summary of connectivity information
  *
  * \param[in]  connect     pointer to cs_cdo_connect_t structure
  */
 /*----------------------------------------------------------------------------*/
 
 void
-cs_cdo_connect_resume(const cs_cdo_connect_t  *connect)
+cs_cdo_connect_summary(const cs_cdo_connect_t  *connect)
 {
   cs_connect_info_t  *i = NULL;
 
@@ -1072,31 +964,27 @@ cs_cdo_connect_resume(const cs_cdo_connect_t  *connect)
   if (connect->v_info != NULL) {
     i = connect->v_info;
     bft_printf("\n");
-    bft_printf("                     |   full  |  intern |  border |  in/in  |"
-               "  in/bd  |  bd/bd  |  bd/in  |\n");
-    bft_printf("  --dim-- n_vertices |"
-               " %7d | %7d | %7d | %7d | %7d | %7d | %7d |\n",
-               i->n, i->n_in, i->n_bd, i->n_ii, i->n_ib, i->n_bb, i->n_bi);
+    bft_printf("                     |   full  |  intern |  border |\n");
+    bft_printf("  --dim-- n_vertices | %7d | %7d | %7d |\n",
+               i->n_ent, i->n_ent_in, i->n_ent_bd);
   }
   if (connect->e_info != NULL) {
     i = connect->e_info;
-    bft_printf("  --dim-- n_edges    |"
-               " %7d | %7d | %7d | %7d | %7d | %7d | %7d |\n",
-               i->n, i->n_in, i->n_bd, i->n_ii, i->n_ib, i->n_bb, i->n_bi);
+    bft_printf("  --dim-- n_edges    | %7d | %7d | %7d |\n",
+               i->n_ent, i->n_ent_in, i->n_ent_bd);
   }
   if (connect->f_info != NULL) {
     i = connect->f_info;
-    bft_printf("  --dim-- n_faces    |"
-               " %7d | %7d | %7d | %7d | %7d | %7d | %7d |\n",
-               i->n, i->n_in, i->n_bd, i->n_ii, i->n_ib, i->n_bb, i->n_bi);
+    bft_printf("  --dim-- n_faces    | %7d | %7d | %7d |\n",
+               i->n_ent, i->n_ent_in, i->n_ent_bd);
   }
   if (connect->c_info != NULL) {
     i = connect->c_info;
-    bft_printf("  --dim-- n_cells    |"
-               " %7d | %7d | %7d |\n", i->n, i->n_in, i->n_bd);
+    bft_printf("  --dim-- n_cells    | %7d | %7d | %7d |\n",
+               i->n_ent, i->n_ent_in, i->n_ent_bd);
   }
-
   bft_printf("\n");
+
 }
 
 /*----------------------------------------------------------------------------*/
@@ -1137,290 +1025,6 @@ cs_cdo_connect_dump(const cs_cdo_connect_t  *connect)
   fclose(fdump);
 }
 
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Create an index structure of size n
- *
- * \param[in]  n     number of entries of the indexed list
- *
- * \return  a pointer to a cs_connect_index_t
- */
-/*----------------------------------------------------------------------------*/
-
-cs_connect_index_t *
-cs_index_create(int  n)
-{
-  int  i;
-
-  cs_connect_index_t  *x = NULL;
-
-  BFT_MALLOC(x, 1, cs_connect_index_t);
-
-  x->n = n;
-  x->owner = true;
-  x->ids = NULL;
-
-  BFT_MALLOC(x->idx, n+1, int);
-  for (i = 0; i < x->n + 1; i++)  x->idx[i] = 0;
-
-  return x;
-}
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Map arrays into an index structure of size n (owner = false)
- *
- * \param[in]  n     number of entries of the indexed list
- * \param[in]  idx   array of size n+1
- * \param[in]  ids   array of size idx[n]
- *
- * \return  a pointer to a cs_connect_index_t
- */
-/*----------------------------------------------------------------------------*/
-
-cs_connect_index_t *
-cs_index_map(int    n,
-             int   *idx,
-             int   *ids)
-{
-  cs_connect_index_t  *x = NULL;
-
-  BFT_MALLOC(x, 1, cs_connect_index_t);
-
-  x->n = n;
-  x->owner = false;
-  x->idx = idx;
-  x->ids = ids;
-
-  return x;
-}
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Destroy a cs_connect_index_t structure
- *
- * \param[in]  pidx     pointer of pointer to a cs_connect_index_t structure
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_index_free(cs_connect_index_t   **pidx)
-{
-  cs_connect_index_t  *x = *pidx;
-
-  if (x == NULL)
-    return;
-
-  if (x->owner) {
-    BFT_FREE(x->idx);
-    BFT_FREE(x->ids);
-  }
-
-  BFT_FREE(x);
-  *pidx = NULL;
-}
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   From 2 indexes : A -> B and B -> C create a new index A -> C
- *
- * \param[in]  nc      number of elements in C set
- * \param[in]  xab     pointer to the index A -> B
- * \param[in]  b2c     pointer to the index B -> C
- *
- *\return  a pointer to the cs_connect_index_t structure A -> C
- */
-/*----------------------------------------------------------------------------*/
-
-cs_connect_index_t *
-cs_index_compose(int                        nc,
-                 const cs_connect_index_t  *a2b,
-                 const cs_connect_index_t  *b2c)
-{
-  int  i, pos_a, pos_b, a_id, b_id, c_id, shift;
-
-  int  *ctag = NULL;
-  cs_connect_index_t  *a2c = cs_index_create(a2b->n);
-
-  BFT_MALLOC(ctag, nc, int);
-  for (i = 0; i < nc; i++)
-    ctag[i] = -1;
-
-  /* Build index */
-  for (a_id = 0; a_id < a2b->n; a_id++) {
-
-    for (pos_a = a2b->idx[a_id]; pos_a < a2b->idx[a_id+1]; pos_a++) {
-
-      b_id = a2b->ids[pos_a];
-      for (pos_b = b2c->idx[b_id]; pos_b < b2c->idx[b_id+1]; pos_b++) {
-
-        c_id = b2c->ids[pos_b];
-        if (ctag[c_id] != a_id) { /* Not tagged yet */
-          ctag[c_id] = a_id;
-          a2c->idx[a_id+1] += 1;
-        }
-
-      } /* End of loop on C elements */
-    } /* End of loop on B elements */
-  } /* End of loop on A elements */
-
-  for (i = 0; i < a2c->n; i++)
-    a2c->idx[i+1] += a2c->idx[i];
-
-  BFT_MALLOC(a2c->ids, a2c->idx[a2c->n], int);
-
-  /* Reset ctag */
-  for (i = 0; i < nc; i++)
-    ctag[i] = -1;
-
-  /* Fill ids */
-  shift = 0;
-  for (a_id = 0; a_id < a2b->n; a_id++) {
-
-    for (pos_a = a2b->idx[a_id]; pos_a < a2b->idx[a_id+1]; pos_a++) {
-
-      b_id = a2b->ids[pos_a];
-      for (pos_b = b2c->idx[b_id]; pos_b < b2c->idx[b_id+1]; pos_b++) {
-
-        c_id = b2c->ids[pos_b];
-        if (ctag[c_id] != a_id) { /* Not tagged yet */
-          ctag[c_id] = a_id;
-          a2c->ids[shift++] = c_id;
-        }
-
-      } /* End of loop on C elements */
-    } /* End of loop on B elements */
-  } /* End of loop on A elements */
-
-  assert(shift == a2c->idx[a2c->n]);
-
-  BFT_FREE(ctag);
-
-  return a2c;
-}
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   From a cs_connect_index_t A -> B create a new index B -> A
- *
- * \param[in]  nb     size of the "b" set
- * \param[in]  a2b    pointer to the index A -> B
- *
- * \return  a new pointer to the cs_connect_index_t structure B -> A
- */
-/*----------------------------------------------------------------------------*/
-
-cs_connect_index_t *
-cs_index_transpose(int                        nb,
-                   const cs_connect_index_t  *a2b)
-{
-  int  i, j, b_id, shift;
-  int  *count = NULL;
-
-  cs_connect_index_t  *b2a = cs_index_create(nb);
-
-  if (nb == 0)
-    return b2a;
-
-  /* Build idx */
-  for (i = 0; i < a2b->n; i++)
-    for (j = a2b->idx[i]; j < a2b->idx[i+1]; j++)
-      b2a->idx[a2b->ids[j]+1] += 1;
-
-  for (i = 0; i < b2a->n; i++)
-    b2a->idx[i+1] += b2a->idx[i];
-
-  /* Allocate and initialize temporary buffer */
-  BFT_MALLOC(count, nb, int);
-  for (i = 0; i < nb; i++) count[i] = 0;
-
-  /* Build ids */
-  BFT_MALLOC(b2a->ids, b2a->idx[b2a->n], int);
-
-  for (i = 0; i < a2b->n; i++) {
-    for (j = a2b->idx[i]; j < a2b->idx[i+1]; j++) {
-      b_id = a2b->ids[j];
-      shift = count[b_id] + b2a->idx[b_id];
-      b2a->ids[shift] = i;
-      count[b_id] += 1;
-    }
-  }
-
-  /* Free temporary buffer */
-  BFT_FREE(count);
-
-  return b2a;
-}
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Sort each sub-list related to an entry in a cs_connect_index_t
- *          structure
- *
- * \param[in]  x     pointer to a cs_connect_index_t structure
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_index_sort(cs_connect_index_t   *x)
-{
-  if (x == NULL)
-    return;
-
-  for (int i = 0; i < x->n; i++)
-    cs_sort_shell(x->idx[i], x->idx[i+1], x->ids);
-}
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Dump a cs_connect_index_t structure to a file or into the
- *          standard output
- *
- * \param[in]  name  name of the dump file. Can be set to NULL
- * \param[in]  _f    pointer to a FILE structure. Can be set to NULL.
- * \param[in]  x     pointer to a cs_connect_index_t structure
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_index_dump(const char           *name,
-              FILE                 *_f,
-              cs_connect_index_t   *x)
-{
-  FILE  *f = _f;
-  _Bool  close_file = false;
-
-  if (f == NULL) {
-    if (name == NULL)
-      f = stdout;
-    else {
-      f = fopen(name,"w");
-      close_file = true;
-    }
-  }
-
-  fprintf(f, "\n Dump cs_connect_index_t struct: %p (%s)\n",
-          (const void *)x, name);
-
-  if (x == NULL) {
-    if (close_file) fclose(f);
-    return;
-  }
-
-  fprintf(f, "  owner:             %6d\n", x->owner);
-  fprintf(f, "  n_elts:            %6d\n", x->n);
-  fprintf(f, "  ids_size:          %6d\n", x->idx[x->n]);
-
-  for (int i = 0; i < x->n; i++) {
-    fprintf(f, "\n[%4d] ", i);
-    for (int j = x->idx[i]; j < x->idx[i+1]; j++)
-      fprintf(f, "%5d |", x->ids[j]);
-  }
-
-  if (close_file)
-    fclose(f);
-}
-
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
