@@ -58,20 +58,16 @@ BEGIN_C_DECLS
  * Local macro and structure definitions
  *============================================================================*/
 
-#define  INNOV_QUANT_DEBUG 0  /* Switch off/on debug information */
+#define  CDO_QUANTITIES_DBG 0  /* Switch off/on debug information */
 
-/*
-  Temporary structures to build mesh quantities
- */
+/* Temporary structures to build mesh quantities */
 
 typedef struct {
 
-  int     XYZ[3];    /* Direct permutation of the ref. axis such that nZ
-                        is maximal */
-  double  surf;      /* Face surface */
-  double  n[3];      /* Face normal with unitary norm */
-  double  omega;     /* P = Point belonging to the face
-                        omega = - < n, P> */
+  int         XYZ[3]; /* Direct permutation of the ref. axis such that nZ
+                         is maximal */
+  cs_nvec3_t  q;      /* face surface and its unit normal */
+  double      omega;  /* P = Point belonging to the face omega = - < n, P> */
 
 } _cdo_fspec_t;
 
@@ -104,7 +100,10 @@ typedef struct { /* These quantities are the integral of q on the plane
  * Static global variables
  *============================================================================*/
 
-static const double _overdim = 1./3.;
+static const double one_3 = 1/3.;
+static const double one_6 = 1/6.;
+static const double one_12 = 1/12.;
+static const double one_24 = 1/24.;
 
 /*============================================================================
  * Private function prototypes
@@ -122,12 +121,12 @@ static const double _overdim = 1./3.;
  * ---------------------------------------------------------------------------*/
 
 static _cdo_fspec_t
-_get_fspec(int                          fid,
+_get_fspec(cs_lnum_t                    f_id,
            const cs_mesh_t             *m,
            const cs_mesh_quantities_t  *mq)
 {
-  int  f, j, k, v, e, s;
-  double  inv_surf, inv_n, nx, ny, nz;
+  cs_lnum_t  f, j, k, v, e, s;
+  double  inv_n, nx, ny, nz;
   double  P[3]; /* Point belonging to the current face */
   _cdo_fspec_t  fspec;
 
@@ -135,10 +134,10 @@ _get_fspec(int                          fid,
 
   /* Treatment according to the kind of face (interior or border) */
 
-  if (fid < m->n_i_faces) { /* Interior face */
+  if (f_id < m->n_i_faces) { /* Interior face */
 
     /* Choose a vertex belonging to this face */
-    f = fid;
+    f = f_id;
     s = m->i_face_vtx_idx[f];
     e = m->i_face_vtx_idx[f+1];
     inv_n = 1.0 / (e - s);
@@ -155,14 +154,13 @@ _get_fspec(int                          fid,
     for (k = 0; k < 3; k++)
       P[k] *= inv_n;
 
-    for (k = 0; k < 3; k++)
-      fspec.n[k] = mq->i_face_normal[3*f+k];
+    cs_nvec3(&(mq->i_face_normal[3*f]), &(fspec.q));
 
   }
   else { /* Border face */
 
     /* Choose a vertex belonging to this face */
-    f = fid - m->n_i_faces;
+    f = f_id - m->n_i_faces;
     s = m->b_face_vtx_idx[f];
     e = m->b_face_vtx_idx[f+1];
     inv_n = 1.0 / (e - s);
@@ -179,23 +177,17 @@ _get_fspec(int                          fid,
     for (k = 0; k < 3; k++)
       P[k] *= inv_n;
 
-    for (k = 0; k < 3; k++)
-      fspec.n[k] = mq->b_face_normal[3*f+k];
+    cs_nvec3(&(mq->b_face_normal[3*f]), &(fspec.q));
 
   }
 
-  /* Define face normal with unitary norm and omega = -<n,P>*/
-  fspec.surf = _n3(fspec.n);
-  inv_surf = 1 / fspec.surf;
-  for (k = 0; k < 3; k++)
-    fspec.n[k] *= inv_surf;
-
-  fspec.omega = - _dp3(P, fspec.n);
+  /* Define omega = -<n,P>*/
+  fspec.omega = - _dp3(P, fspec.q.unitv);
 
   /* Define a direct basis such that n[Z] maximal */
-  nx = fabs(fspec.n[X]);
-  ny = fabs(fspec.n[Y]);
-  nz = fabs(fspec.n[Z]);
+  nx = fabs(fspec.q.unitv[X]);
+  ny = fabs(fspec.q.unitv[Y]);
+  nz = fabs(fspec.q.unitv[Z]);
 
   if (nx > ny && nx > nz)
     fspec.XYZ[Z] = X;
@@ -205,11 +197,11 @@ _get_fspec(int                          fid,
   fspec.XYZ[X] = (fspec.XYZ[Z] + 1) % 3;
   fspec.XYZ[Y] = (fspec.XYZ[X] + 1) % 3;
 
-#if INNOV_QUANT_DEBUG > 1
-    printf("\n F: (%d, %d) >> surf: %e; omega: %e; XYZ: %d%d%d; [%e, %e, %e]\n",
-           fid, f, fspec.surf, fspec.omega,
-           fspec.XYZ[0], fspec.XYZ[1], fspec.XYZ[2],
-           fspec.n[0], fspec.n[1], fspec.n[2]);
+#if CDO_QUANTITIES_DBG > 1
+  printf("\n F: (%d, %d) >> surf: %e; omega: %e; XYZ: %d%d%d; [%e, %e, %e]\n",
+         f_id, f, fspec.q.meas, fspec.omega,
+         fspec.XYZ[0], fspec.XYZ[1], fspec.XYZ[2],
+         fspec.q.unitv[0], fspec.q.unitv[1], fspec.q.unitv[2]);
 #endif
 
   return fspec;
@@ -220,102 +212,73 @@ _get_fspec(int                          fid,
  * ---------------------------------------------------------------------------*/
 
 static _cdo_projq_t
-_get_proj_quantities(int                        fid,
+_get_proj_quantities(cs_lnum_t                f_id,
                      const cs_cdo_connect_t  *connect,
-                     const double               vtx_coords[],
-                     const int                  axis[])
+                     const cs_real_t          coords[],
+                     const int                axis[])
 {
-  cs_lnum_t  i, e_sgn, e_id, s, e;
   cs_lnum_t  v_id[2];
-  double  da, db, C1, Ca, Cb, Cab, Ca2, Cb2, Kab;
-  double  a0, a1, a0_2, a1_2, a0_3;
-  double  b0, b1, b0_2, b1_2, b0_3;
+  cs_real_t  a[2], b[2], a2[2], b2[2];
 
-  cs_sla_matrix_t  *f2e = connect->f2e;
-  cs_sla_matrix_t  *e2v = connect->e2v;
-
-  const double over_6  = 1.0 / 6.0;
-  const double over_12 = 1.0 / 12.0;
-  const double over_24 = 1.0 / 24.0;
+  const cs_sla_matrix_t  *f2e = connect->f2e;
+  const cs_sla_matrix_t  *e2v = connect->e2v;
 
   /* Initialize structure */
-
   _cdo_projq_t  projq;
 
   /* These quantities are the integral of q on the plane
      (alpha, beta) where the face is projected */
 
-  projq.p1 = 0.0;
-  projq.pa = 0.0;
-  projq.pb = 0.0;
-  projq.pc = 0.0;
-  projq.pab = 0.0;
-  projq.pa2 = 0.0;
-  projq.pb2 = 0.0;
+  projq.p1 = projq.pa = projq.pb =  projq.pc = 0.0;
+  projq.pab = projq.pa2 = projq.pb2 = 0.0;
 
   /* Scan edges which belong to the current face */
+  for (cs_lnum_t  i = f2e->idx[f_id]; i < f2e->idx[f_id+1]; i++) {
 
-  for (i = f2e->idx[fid]; i < f2e->idx[fid+1]; i++) {
-
-    e_sgn = f2e->sgn[i];
-    e_id = f2e->col_id[i];
-    s = e2v->idx[e_id], e = e2v->idx[e_id+1];
-
-    /* Sanity check */
-    assert(e-s == 2);
+    short int  e_sgn = f2e->sgn[i];
+    cs_lnum_t  e_id = f2e->col_id[i];
+    cs_lnum_t  s = e2v->idx[e_id];
 
     if (e_sgn > 0)
       v_id[0] = e2v->col_id[s], v_id[1] = e2v->col_id[s+1];
     else
       v_id[0] = e2v->col_id[s+1], v_id[1] = e2v->col_id[s];
 
-    /* First vertex coordinnates in (alpha, beta) plane */
-    a0 = vtx_coords[3*v_id[0] + axis[0]];
-    b0 = vtx_coords[3*v_id[0] + axis[1]];
-
-    /* Second vertex coordinnates in (alpha, beta) plane */
-    a1 = vtx_coords[3*v_id[1] + axis[0]];
-    b1 = vtx_coords[3*v_id[1] + axis[1]];
+    /* Vertices in the plane (alpha, beta) */
+    for (int k = 0; k < 2; k++) {
+      a[k] = coords[3*v_id[k] + axis[0]];
+      a2[k] = a[k]*a[k];
+      b[k] = coords[3*v_id[k] + axis[1]];
+      b2[k] = b[k]*b[k];
+    }
 
     /* Related variables */
-    a0_2 = a0 * a0, a0_3 = a0_2 * a0;
-    b0_2 = b0 * b0, b0_3 = b0_2 * b0;
-    a1_2 = a1 * a1;
-    b1_2 = b1 * b1;
-    da  = a1 - a0;
-    db  = b1 - b0;
-
-    C1  = a0 + a1;
-    Ca  = C1 * a1 + a0_2;
-    Cb  = b1_2 + b1*b0 + b0_2;
-    Ca2 = a1 * Ca + a0_3;
-    Cb2 = b1 * Cb + b0_3;
-    Cab = 3*a1_2 + 2*a1*a0 +   a0_2;
-    Kab =   a1_2 + 2*a1*a0 + 3*a0_2;
+    cs_real_t  a0_3 = a2[0] * a[0];
+    cs_real_t  b0_3 = b2[0] * b[0];
+    cs_real_t  da  = a[1] - a[0], db  = b[1] - b[0];
+    cs_real_t  C1  = a[0] + a[1];
+    cs_real_t  Ca  = C1 * a[1] + a2[0];
+    cs_real_t  Cb  = b2[1] + b[1]*b[0] + b2[0];
+    cs_real_t  Ca2 = a[1] * Ca + a0_3;
+    cs_real_t  Cb2 = b[1] * Cb + b0_3;
+    cs_real_t  Cab = 3*a2[1] + 2*a[1]*a[0] + a2[0];
+    cs_real_t  Kab = a2[1] + 2*a[1]*a[0] + 3*a2[0];
 
     projq.p1  += db * C1;
     projq.pa  += db * Ca;
     projq.pb  += da * Cb;
     projq.pa2 += db * Ca2;
     projq.pb2 += da * Cb2;
-    projq.pab += db * (b1 * Cab + b0 * Kab);
-
-#if INNOV_QUANT_DEBUG > 1
-    printf(" enum: %d, vnum1: %d, vnum2: %d,"
-           " a0: %.2e, b0: %.2e, a1: %.2e, b1: %.2e, da: %.2e, db: %.2e,"
-           " p1: %.2e, pa: %.2e, pb: %.2e, pc: %.2e, pab: %.2e\n",
-           e_num, v_num[0], v_num[1], a0, b0, a1, b1, da, db,
-           projq.p1, projq.pa, projq.pb, projq.pc, projq.pab);
-#endif
+    projq.pab += db * (b[1] * Cab + b[0] * Kab);
 
   } /* Loop on face edges */
 
   projq.p1  *=  0.5;
-  projq.pa  *=  over_6;
-  projq.pb  *= -over_6;
-  projq.pab *=  over_24;
-  projq.pa2 *=  over_12;
-  projq.pb2 *= -over_12;
+  projq.pa  *=  one_6;
+  projq.pb  *= -one_6;
+  projq.pab *=  one_24;
+  projq.pa2 *=  one_12;
+  projq.pb2 *= -one_12;
 
   return  projq;
 }
@@ -323,29 +286,27 @@ _get_proj_quantities(int                        fid,
 /* ---------------------------------------------------------------------------*/
 
 static _cdo_fsubq_t
-_get_fsub_quantities(int                         fid,
+_get_fsub_quantities(cs_lnum_t                 f_id,
                      const cs_cdo_connect_t   *connect,
-                     const cs_mesh_t            *m,
+                     const cs_real_t          *coord,
                      _cdo_fspec_t              fspec)
 {
-  _cdo_projq_t  projq;
   _cdo_fsubq_t  fsubq;
 
-  double  na = fspec.n[fspec.XYZ[0]];
-  double  nb = fspec.n[fspec.XYZ[1]];
-  double  nc = fspec.n[fspec.XYZ[2]];
-  double  k1 = 1 / nc;
+  double  na = fspec.q.unitv[fspec.XYZ[0]];
+  double  nb = fspec.q.unitv[fspec.XYZ[1]];
+  double  nc = fspec.q.unitv[fspec.XYZ[2]];
+  double  k1 = 1./nc;
   double  k2 = k1 * k1;
   double  k3 = k2 * k1;
 
   /* Compute projected quantities */
+  _cdo_projq_t  projq = _get_proj_quantities(f_id, connect, coord, fspec.XYZ);
 
-  projq = _get_proj_quantities(fid, connect, m->vtx_coord, fspec.XYZ);
-
-#if INNOV_QUANT_DEBUG > 1
+#if CDO_QUANTITIES_DBG > 1
   printf(" F: %d >> p1: %.4e, pa: %.4e, pb: %.4e, pc: %.4e,"
          " pab: %.4e, pa2: %.4e, pb2: %.4e\n",
-         fid, projq.p1, projq.pa, projq.pb, projq.pc,
+         f_id, projq.p1, projq.pa, projq.pb, projq.pc,
          projq.pab, projq.pa2, projq.pb2);
 #endif
 
@@ -491,7 +452,10 @@ _compute_dcell_quantities(const cs_cdo_connect_t  *topo,
 
 /*----------------------------------------------------------------------------
  * Compute dual face normals (face crossed by primal edges).
- * Given a cell, a face and an edge, there are two dual face normals
+ * Given a cell and an edge, there are two faces attached to the
+ * couple (cell, edge)
+ * The triplet (edge, face, cell) induces an elementary triangle s(e,f,c)
+ * The dual face is the union of these two triangles.
  * Storage based on c2e connectivity
  * ---------------------------------------------------------------------------*/
 
@@ -499,9 +463,9 @@ static void
 _compute_dface_quantities(const cs_cdo_connect_t  *topo,
                           cs_cdo_quantities_t     *iq)  /* In/out */
 {
-  int  c_id, i, j, k, size, shift, parent;
-  double orient, area, inv;
-  cs_real_3_t  trinorm, xexf, xexc, xc;
+  cs_lnum_t  c_id, i, j, k, size, shift, parent;
+  cs_nvec3_t  nvec;
+  cs_real_3_t  trinorm, xexf, xexc;
 
   cs_lnum_t  *tag_shift = NULL;
 
@@ -510,8 +474,10 @@ _compute_dface_quantities(const cs_cdo_connect_t  *topo,
   assert(topo->f2c != NULL);
   assert(topo->c2e != NULL);
 
+  const cs_connect_index_t  *c2e = topo->c2e;
+
   /* Allocate and initialize arrays */
-  size = topo->c2e->idx[iq->n_cells];
+  size = c2e->idx[iq->n_cells];
   BFT_MALLOC(iq->dface, size, cs_dface_t);
 
   BFT_MALLOC(tag_shift, iq->n_edges, cs_lnum_t);
@@ -521,12 +487,11 @@ _compute_dface_quantities(const cs_cdo_connect_t  *topo,
   for (c_id = 0; c_id < iq->n_cells; c_id++) {
 
     /* Tag cell edges */
-    for (i = topo->c2e->idx[c_id]; i < topo->c2e->idx[c_id+1]; i++)
-      tag_shift[topo->c2e->ids[i]] = i+1;
+    for (i = c2e->idx[c_id]; i < c2e->idx[c_id+1]; i++)
+      tag_shift[c2e->ids[i]] = i+1;
 
     /* Get cell center */
-    for (k = 0; k < 3; k++)
-      xc[k] = iq->cell_centers[3*c_id+k];
+    const cs_real_t  *xc = iq->cell_centers + 3*c_id;
 
     for (i = topo->c2f->idx[c_id]; i < topo->c2f->idx[c_id+1]; i++) {
 
@@ -544,9 +509,10 @@ _compute_dface_quantities(const cs_cdo_connect_t  *topo,
           xexc[k] = xc[k] - e_q.center[k];
         }
         _cp3(xexf, xexc, &trinorm);
+        cs_nvec3(trinorm, &nvec);
 
         /* One should have (trinorm, te) > 0 */
-        orient = _dp3(trinorm, e_q.unitv);
+        const double  orient = _dp3(nvec.unitv, e_q.unitv);
         assert(fabs(orient) > 0);
 
         if (tag_shift[e_id] > 0) /* First time */
@@ -554,15 +520,15 @@ _compute_dface_quantities(const cs_cdo_connect_t  *topo,
         else /* Second time (<0) */
           tag_shift[e_id] *= -1, shift = tag_shift[e_id]-1, parent = 1;
 
+        /* Store the computed data */
         iq->dface[shift].parent_id[parent] = f_id;
-        if (orient < 0) {
+        iq->dface[shift].sface[parent].meas = 0.5*nvec.meas;
+        if (orient < 0)
           for (k = 0; k < 3; k++)
-            iq->dface[shift].unitv[3*parent+k] = -0.5 * trinorm[k];
-        }
-        else {
+            iq->dface[shift].sface[parent].unitv[k] = -nvec.unitv[k];
+        else
           for (k = 0; k < 3; k++)
-            iq->dface[shift].unitv[3*parent+k] =  0.5 * trinorm[k];
-        }
+            iq->dface[shift].sface[parent].unitv[k] =  nvec.unitv[k];
 
       } /* Loop on face edges */
 
@@ -570,25 +536,21 @@ _compute_dface_quantities(const cs_cdo_connect_t  *topo,
 
   } /* Loop on cells */
 
-  /* Normalize dual face normal and fill dual face area  */
+  BFT_FREE(tag_shift);
+
+  /* Compute the dual face normal from the two elementary contributions */
   for (c_id = 0; c_id < iq->n_cells; c_id++) {
-    for (i = topo->c2e->idx[c_id]; i < topo->c2e->idx[c_id+1]; i++) {
+    for (i = c2e->idx[c_id]; i < c2e->idx[c_id+1]; i++) {
+
+      cs_nvec3_t  t1 = iq->dface[i].sface[0];
+      cs_nvec3_t  t2 = iq->dface[i].sface[1];
 
       for (k = 0; k < 3; k++)
-        iq->dface[i].vect[k] = iq->dface[i].unitv[k] + iq->dface[i].unitv[3+k];
-
-      for (parent = 0; parent < 2; parent++) {
-        area = _n3(&(iq->dface[i].unitv[3*parent]));
-        iq->dface[i].meas[parent] = area;
-        inv = 1 / area;
-        for (k = 0; k < 3; k++)
-          iq->dface[i].unitv[3*parent+k] *= inv;
-      }
+        iq->dface[i].vect[k] = t1.meas*t1.unitv[k] + t2.meas*t2.unitv[k];
 
     }
   } /* End of loop on cells */
 
-  BFT_FREE(tag_shift);
 }
 
 /*----------------------------------------------------------------------------
@@ -600,12 +562,12 @@ _saturn_algorithm(const cs_mesh_t             *mesh,
                   const cs_mesh_quantities_t  *mq,
                   cs_cdo_quantities_t         *cdoq) /* In/out */
 {
-  int  i, j, k;
+  cs_lnum_t  i, j, k;
 
-  const int  n_cells = mesh->n_cells;
-  const int  n_i_faces = mesh->n_i_faces;
-  const int  n_b_faces = mesh->n_b_faces;
-  const int  n_faces = n_i_faces + n_b_faces;
+  const cs_lnum_t  n_cells = mesh->n_cells;
+  const cs_lnum_t  n_i_faces = mesh->n_i_faces;
+  const cs_lnum_t  n_b_faces = mesh->n_b_faces;
+  const cs_lnum_t  n_faces = n_i_faces + n_b_faces;
 
   assert(mq != NULL);
 
@@ -761,23 +723,26 @@ _mirtich_algorithm(const cs_mesh_t             *mesh,
                    const cs_cdo_connect_t      *connect,
                    cs_cdo_quantities_t         *iq) /* In/out */
 {
-  int  i, k, c_id, f_id, A, B, C, sgn;
+  cs_lnum_t  i, k, c_id, f_id, A, B, C, sgn;
   double  Fvol, inv_surf;
   _cdo_fspec_t  fspec;
   _cdo_fsubq_t  fsubq;
 
   const int X = 0, Y = 1, Z = 2;
-  const int n_cells = mesh->n_cells;
-  const int n_faces = iq->n_faces;
+  const cs_lnum_t n_cells = mesh->n_cells;
+  const cs_lnum_t n_faces = iq->n_faces;
 
   /* Sanity check */
+
   assert(connect->f2c != NULL);
   assert(connect->c2f != NULL);
 
   /* Allocate and initialize cell quantities */
+
   BFT_MALLOC(iq->face, n_faces, cs_quant_t);
-  BFT_MALLOC(iq->cell_centers, 3*n_cells, double);
-  BFT_MALLOC(iq->cell_vol, n_cells, double);
+  BFT_MALLOC(iq->cell_centers, 3*n_cells, cs_real_t);
+  BFT_MALLOC(iq->cell_vol, n_cells, cs_real_t);
+
   for (i = 0; i < n_cells; i++) {
     iq->cell_vol[i] = 0.0;
     for (k = 0; k < 3; k++)
@@ -796,7 +761,7 @@ _mirtich_algorithm(const cs_mesh_t             *mesh,
     B = fspec.XYZ[Y];
     C = fspec.XYZ[Z];
 
-    fsubq = _get_fsub_quantities(f_id, connect, mesh, fspec);
+    fsubq = _get_fsub_quantities(f_id, connect, mesh->vtx_coord, fspec);
 
     inv_surf = 1.0/fsubq.F1;
     iq->face[f_id].center[A] = inv_surf * fsubq.Fa;
@@ -812,10 +777,10 @@ _mirtich_algorithm(const cs_mesh_t             *mesh,
       Fvol = ( (fspec.XYZ[X] == 0) ? fsubq.Fa :
                ( (fspec.XYZ[Y] == 0) ? fsubq.Fb : fsubq.Fc) );
 
-      iq->cell_vol[c_id] += sgn * fspec.n[0] * Fvol;
-      iq->cell_centers[3*c_id + A] += sgn * fspec.n[A] * fsubq.Fa2;
-      iq->cell_centers[3*c_id + B] += sgn * fspec.n[B] * fsubq.Fb2;
-      iq->cell_centers[3*c_id + C] += sgn * fspec.n[C] * fsubq.Fc2;
+      iq->cell_vol[c_id] += sgn * fspec.q.unitv[0] * Fvol;
+      iq->cell_centers[3*c_id + A] += sgn * fspec.q.unitv[A] * fsubq.Fa2;
+      iq->cell_centers[3*c_id + B] += sgn * fspec.q.unitv[B] * fsubq.Fb2;
+      iq->cell_centers[3*c_id + C] += sgn * fspec.q.unitv[C] * fsubq.Fc2;
 
     } /* End of loop on cell faces */
 
@@ -833,7 +798,7 @@ _mirtich_algorithm(const cs_mesh_t             *mesh,
     for (k = 0; k < 3; k++)
       iq->cell_centers[3*i+k] *= inv_vol2;
 
-#if INNOV_QUANT_DEBUG > 1
+#if CDO_QUANTITIES_DBG > 1
     printf("\n (%4d) volINNOV: % -12.5e | volSAT % -12.5e | %-12.5e\n",
            i+1, iq->cell_vol[i], mq->cell_vol[i],
            fabs(iq->cell_vol[i] - mq->cell_vol[i]));
@@ -873,11 +838,12 @@ cs_cdo_quantities_build(const cs_mesh_t             *m,
                         const cs_cdo_connect_t      *topo)
 {
   short int  sgn;
-  int  i, j, k, ii, nnz, c_id, f_id;
-  double  mes, inv, vec[3], xc[3];
+  cs_lnum_t  i, j, k, c_id, f_id, idx_size;
+  double  vec[3];
+  cs_nvec3_t  v;
 
   cs_cdo_quantities_t  *cdoq = NULL;
-  cs_cdo_cc_algo_t cc_algo = CS_CDO_CC_SATUR; // default value
+  cs_cdo_cc_algo_t cc_algo = CS_CDO_CC_SATURNE; // default value
 
   /* Sanity check */
   assert(topo != NULL);
@@ -891,6 +857,7 @@ cs_cdo_quantities_build(const cs_mesh_t             *m,
   cdoq->n_b_faces = m->n_b_faces;
   cdoq->n_faces = m->n_i_faces + m->n_b_faces;
   cdoq->n_vertices = m->n_vertices;
+  cdoq->vtx_coord = m->vtx_coord;
 
   if (topo->e2v != NULL)
     cdoq->n_edges = topo->e2v->n_rows;
@@ -920,7 +887,7 @@ cs_cdo_quantities_build(const cs_mesh_t             *m,
     _vtx_algorithm(m, mq, topo, cdoq);
     break;
 
-  case CS_CDO_CC_SATUR:
+  case CS_CDO_CC_SATURNE:
     bft_printf(" -cdo- Cell.Center.Algo >> Original\n");
     _saturn_algorithm(m, mq, cdoq);
     break;
@@ -934,39 +901,26 @@ cs_cdo_quantities_build(const cs_mesh_t             *m,
   /* Finalize definition of cs_quant_t struct. for faces.
      Define face normal with unitary norm and face area */
   for (i = 0; i < m->n_i_faces; i++) {
-
+    cs_nvec3((mq->i_face_normal + 3*i), &v);
+    cdoq->face[i].meas = v.meas;
     for (k = 0; k < 3; k++)
-      vec[k] = mq->i_face_normal[3*i+k];
-    mes = _n3(vec);
-    inv = 1.0/mes;
-
-    cdoq->face[i].meas = mes;
-    for (k = 0; k < 3; k++)
-      cdoq->face[i].unitv[k] = inv*vec[k];
-
+      cdoq->face[i].unitv[k] = v.unitv[k];
   }
 
   for (i = 0, j = m->n_i_faces; i < m->n_b_faces; i++, j++) {
-
+    cs_nvec3((mq->b_face_normal + 3*i), &v);
+    cdoq->face[j].meas = v.meas;
     for (k = 0; k < 3; k++)
-      vec[k] = mq->b_face_normal[3*i+k];
-    mes = _n3(vec);
-    inv = 1.0/mes;
-
-    cdoq->face[j].meas = mes;
-    for (k = 0; k < 3; k++)
-      cdoq->face[j].unitv[k] = inv*vec[k];
-
+      cdoq->face[j].unitv[k] = v.unitv[k];
   }
 
   /* Compute dual edge quantities */
-  nnz = topo->c2f->idx[cdoq->n_cells];
-  BFT_MALLOC(cdoq->dedge, 4*nnz, double);
+  idx_size = topo->c2f->idx[cdoq->n_cells];
+  BFT_MALLOC(cdoq->dedge, idx_size, cs_nvec3_t);
 
   for (c_id = 0; c_id < cdoq->n_cells; c_id++) {
 
-    for (k = 0; k < 3; k++)
-      xc[k] = cdoq->cell_centers[3*c_id+k];
+    cs_real_t  *xc = cdoq->cell_centers + 3*c_id;
 
     for (i = topo->c2f->idx[c_id]; i < topo->c2f->idx[c_id+1]; i++) {
 
@@ -974,23 +928,25 @@ cs_cdo_quantities_build(const cs_mesh_t             *m,
       sgn = topo->c2f->sgn[i];
       for (k = 0; k < 3; k++)
         vec[k] = cdoq->face[f_id].center[k] - xc[k];
-      mes = _n3(vec);
 
       /* Fill dedge */
-      cdoq->dedge[4*i] = mes;
-      ii = 4*i+1, inv = 1.0/mes;
+      double  meas = _n3(vec);
+      double  inv = 1.0/meas;
+
+      cdoq->dedge[i].meas = meas;
       for (k = 0; k < 3; k++)
-        cdoq->dedge[ii+k] = sgn*inv*vec[k];
+        cdoq->dedge[i].unitv[k] = sgn*inv*vec[k];
 
     }
 
   } /* End of loop on cells */
 
   /* Compute edge quantities if needed */
-  if (cdoq->n_edges > 0)
+  if (cdoq->n_edges > 0) {
     _compute_edge_quantities(m, topo, cdoq);
+    _compute_dface_quantities(topo, cdoq);
+  }
 
-  _compute_dface_quantities(topo, cdoq);
   _compute_dcell_quantities(topo, cdoq);
 
   return cdoq;
@@ -1023,6 +979,8 @@ cs_cdo_quantities_free(cs_cdo_quantities_t   *q)
 
   BFT_FREE(q->dcell_vol);
 
+  /* vtx_coord is free when the structure cs_mesh_t is destroyed */
+
   BFT_FREE(q);
 
   return NULL;
@@ -1040,7 +998,7 @@ cs_cdo_quantities_free(cs_cdo_quantities_t   *q)
 void
 cs_cdo_quantities_dump(const cs_cdo_quantities_t  *cdoq)
 {
-  int  i, p;
+  cs_lnum_t  i, p;
 
   FILE  *fdump = NULL;
 
@@ -1088,7 +1046,7 @@ cs_cdo_quantities_dump(const cs_cdo_quantities_t  *cdoq)
  *
  * \param[in]  f         FILE struct (stdout if NULL)
  * \param[in]  num       entity number related to this quantity struct.
- * \param[in]  quant     cs_quant_t structure to dump
+ * \param[in]  q         cs_quant_t structure to dump
  */
 /*----------------------------------------------------------------------------*/
 
@@ -1112,11 +1070,11 @@ cs_quant_dump(FILE             *f,
  * \brief  Compute for each vertex the dual cell volume which is also
  *
  *                sum    |celld(v) cap c| = pvol_v
- *              c\in\C_v
+ *              c in C_v
  *
- * \param[in]    connect   pointer to a cs_cdo_connect_t structure
- * \param[in]    quant     pointer to a cs_cdo_quantites_t structure
- * \param[inout] p_pvol    pvol (if NULL, allocated in this routine)
+ * \param[in]      connect   pointer to a cs_cdo_connect_t structure
+ * \param[in]      quant     pointer to a cs_cdo_quantites_t structure
+ * \param[in, out] p_pvol    pvol (if NULL, allocated in this routine)
  */
 /*----------------------------------------------------------------------------*/
 
@@ -1125,7 +1083,7 @@ cs_compute_pvol_vtx(const cs_cdo_connect_t     *connect,
                     const cs_cdo_quantities_t  *quant,
                     double                     *p_pvol[])
 {
-  int  i, j;
+  cs_lnum_t  i, j;
 
   double  *pvol = *p_pvol;
 
@@ -1142,6 +1100,7 @@ cs_compute_pvol_vtx(const cs_cdo_connect_t     *connect,
       pvol[c2v->ids[j]] += quant->dcell_vol[j];
 
   /* Return pointer */
+
   *p_pvol = pvol;
 }
 
@@ -1150,9 +1109,9 @@ cs_compute_pvol_vtx(const cs_cdo_connect_t     *connect,
  * \brief  Compute for each edge a related volume pvol_e which constitutes
  *         a partition of unity
  *
- * \param[in]    connect   pointer to a cs_cdo_connect_t structure
- * \param[in]    quant     pointer to a cs_cdo_quantites_t structure
- * \param[inout] p_pvol    pvol (if NULL, allocated in this routine)
+ * \param[in]      connect   pointer to a cs_cdo_connect_t structure
+ * \param[in]      quant     pointer to a cs_cdo_quantites_t structure
+ * \param[in, out] p_pvol    pvol (if NULL, allocated in this routine)
  */
 /*----------------------------------------------------------------------------*/
 
@@ -1161,7 +1120,7 @@ cs_compute_pvol_edge(const cs_cdo_connect_t      *connect,
                      const cs_cdo_quantities_t   *quant,
                      double                      *p_pvol[])
 {
-  int  i, j;
+  cs_lnum_t  i, j;
   double  dvol;
 
   double  *pvol = *p_pvol;
@@ -1176,12 +1135,13 @@ cs_compute_pvol_edge(const cs_cdo_connect_t      *connect,
     for (j = connect->c2e->idx[i]; j < connect->c2e->idx[i+1]; j++) {
 
       const cs_lnum_t  e_id = connect->c2e->ids[j];
-      const cs_quant_t  edgeq = quant->edge[e_id];
-      const cs_dface_t  dface = quant->dface[j];
+      const cs_quant_t  peq = quant->edge[e_id];
+      const cs_nvec3_t  df0q = quant->dface[j].sface[0];
+      const cs_nvec3_t  df1q = quant->dface[j].sface[1];
 
-      dvol  = dface.meas[0] * _dp3(edgeq.unitv, &(dface.unitv[0]));
-      dvol += dface.meas[1] * _dp3(edgeq.unitv, &(dface.unitv[3]));
-      pvol[e_id] += dvol * _overdim * edgeq.meas;
+      dvol  = df0q.meas * _dp3(peq.unitv, df0q.unitv);
+      dvol += df1q.meas * _dp3(peq.unitv, df1q.unitv);
+      pvol[e_id] += dvol * one_3 * peq.meas;
 
     }
   }
@@ -1195,9 +1155,9 @@ cs_compute_pvol_edge(const cs_cdo_connect_t      *connect,
  * \brief  Compute for each face a related volume pvol_f which constitutes
  *         a partition of unity
  *
- * \param[in]    connect   pointer to a cs_cdo_connect_t structure
- * \param[in]    quant     pointer to a cs_cdo_quantites_t structure
- * \param[inout] p_pvol    pvol (if NULL, allocated in this routine)
+ * \param[in]      connect   pointer to a cs_cdo_connect_t structure
+ * \param[in]      quant     pointer to a cs_cdo_quantites_t structure
+ * \param[in, out] p_pvol    pvol (if NULL, allocated in this routine)
  */
 /*----------------------------------------------------------------------------*/
 
@@ -1206,9 +1166,7 @@ cs_compute_pvol_face(const cs_cdo_connect_t     *connect,
                      const cs_cdo_quantities_t  *quant,
                      double                     *p_pvol[])
 {
-  cs_lnum_t  i, k, pos;
-  double  height;
-  cs_real_3_t  xfc, xc;
+  cs_lnum_t  i, j, c_id;
 
   double  *pvol = *p_pvol;
 
@@ -1220,23 +1178,16 @@ cs_compute_pvol_face(const cs_cdo_connect_t     *connect,
   for (i = 0; i < quant->n_faces; i++)
     pvol[i] = 0;
 
-  for (cs_lnum_t  c_id = 0; c_id < quant->n_cells; c_id++) {
+  for (c_id = 0; c_id < quant->n_cells; c_id++) {
 
-    for (k = 0; k < 3; k++)
-      xc[k] = quant->cell_centers[3*c_id+k];
+    for (j = c2f->idx[c_id]; j < c2f->idx[c_id+1]; j++) {
 
-    for (pos = c2f->idx[c_id]; pos < c2f->idx[c_id+1]; pos++) {
+      const cs_lnum_t  f_id = c2f->col_id[j];
+      const cs_quant_t  pfq = quant->face[f_id];
+      const cs_nvec3_t  deq = quant->dedge[j];
 
-      cs_lnum_t  f_id = c2f->col_id[pos];
-      const cs_quant_t  fq = quant->face[f_id];
-
-      /* Step 1: Compute h_(f,c) the height of the pyramid of base face f */
-      for (k = 0; k < 3; k++)
-        xfc[k] = xc[k] - fq.center[k];
-      height = fabs(_dp3(fq.unitv, xfc));
-
-      /* Step 2: Compute volume of the pyramid */
-      pvol[f_id] += _overdim * fq.meas * height;
+      /* Compute volume of the pyramid p_fc */
+      pvol[f_id] += one_3 * pfq.meas * deq.meas * _dp3(pfq.unitv, deq.unitv);
 
     }
   }
@@ -1251,11 +1202,11 @@ cs_compute_pvol_face(const cs_cdo_connect_t     *connect,
  *         This weight is equal to |dc(v) cap f|/|f| so that the sum of the
  *         weights is equal to 1.
  *
- * \param[in]    f_id      id of the face
- * \param[in]    connect   pointer to a cs_cdo_connect_t structure
- * \param[in]    quant     pointer to a cs_cdo_quantites_t structure
- * \param[in]    loc_ids   indirection to a local numbering
- * \param[inout] wf        already allocated to n_max_vbyc (reset)
+ * \param[in]      f_id      id of the face
+ * \param[in]      connect   pointer to a cs_cdo_connect_t structure
+ * \param[in]      quant     pointer to a cs_cdo_quantites_t structure
+ * \param[in]      loc_ids   indirection to a local numbering
+ * \param[in, out] wf        already allocated to n_max_vbyc (reset)
  */
 /*----------------------------------------------------------------------------*/
 
