@@ -35,6 +35,7 @@
 #include <assert.h>
 #include <float.h>
 #include <limits.h>
+#include <string.h>
 
 /*----------------------------------------------------------------------------
  *  Local headers
@@ -44,6 +45,7 @@
 #include <bft_printf.h>
 
 #include "cs_cdo.h"
+#include "cs_sort.h"
 
 /*----------------------------------------------------------------------------
  *  Header for the current file
@@ -69,7 +71,7 @@ struct _subsum_t {
 
 static struct _subsum_t  _op_subsum;
 
-static const double  _tools_oversix = 1/6.0;
+static const double  _oversix = 1/6.0;
 static const double  _overdim = 1/3.0;
 
 /*============================================================================
@@ -121,9 +123,9 @@ _init_dinfo(cs_datatype_t   datatype)
  * \brief   Compute simple information about an array of data.
  *          >> Algorithm from Mark Hoemmen (U.C. Berkeley)
  *
- * \param[in]    n_elts    number of couples in data
- * \param[in]    data      buffer containing input data
- * \param[inout] info      pointer to a cs_data_info_t structure
+ * \param[in]      n_elts    number of couples in data
+ * \param[in]      data      buffer containing input data
+ * \param[in, out] info      pointer to a cs_data_info_t structure
  */
 /*----------------------------------------------------------------------------*/
 
@@ -161,9 +163,9 @@ _compute_info_double(cs_lnum_t         n_elts,
  * \brief   Compute simple information about an array of data.
  *          >> Algorithm from Mark Hoemmen (U.C. Berkeley)
  *
- * \param[in]    n_elts    number of couples in data
- * \param[in]    data      buffer containing input data
- * \param[inout] info      pointer to a cs_data_info_t structure
+ * \param[in]      n_elts    number of couples in data
+ * \param[in]      data      buffer containing input data
+ * \param[in, out] info      pointer to a cs_data_info_t structure
  */
 /*----------------------------------------------------------------------------*/
 
@@ -199,7 +201,7 @@ _compute_info_int32(cs_lnum_t         n_elts,
 }
 
 /*============================================================================
- * Inline Public function prototypes for frequent usage
+ * Inline public function prototypes for frequent usage
  *============================================================================*/
 
 /*----------------------------------------------------------------------------*/
@@ -238,7 +240,7 @@ _n3(const cs_real_3_t  v)
 
 /*----------------------------------------------------------------------------*/
 /*!
- * \brief  Compute the length (euclidien norm) between two points xu and xv in
+ * \brief  Compute the length (euclidien norm) between two points xa and xb in
  *         a cartesian coordinate system of dimension 3
  *
  * \param[in]  xa   first coordinate
@@ -263,7 +265,7 @@ _length3(const cs_real_3_t  xa,
 
 /*----------------------------------------------------------------------------*/
 /*!
- * \brief  Compute the length (euclidien norm) between two points xu and xv in
+ * \brief  Compute the length (euclidien norm) between two points xa and xb in
  *         a cartesian coordinate system of dimension 3
  *
  * \param[in]   xa       coordinate of the first extremity
@@ -315,20 +317,40 @@ _cp3(const cs_real_3_t   u,
 /*!
  * \brief  Compute the 3x3 matrice by vector product
  *
- * \param[in]    m    a 3x3 matrix
- * \param[in]    v    a vector
- * \param[inout] mv   pointer to the vector resulting of the matrix-vector op.
+ * \param[in]      m    a 3x3 matrix
+ * \param[in]      v    a vector
+ * \param[in, out] mv   pointer to the vector resulting of the matrix-vector op.
  */
 /*----------------------------------------------------------------------------*/
 
 inline void
-_mv3(const cs_real_33_t  m,
-     const cs_real_3_t   v,
-     cs_real_3_t        *mv)
+_mv3(const cs_real_t     m[3][3],
+     const cs_real_t     v[3],
+     cs_real_t           mv[3])
 {
-  mv[0][0] = m[0][0]*v[0] + m[0][1]*v[1] + m[0][2]*v[2];
-  mv[0][1] = m[1][0]*v[0] + m[1][1]*v[1] + m[1][2]*v[2];
-  mv[0][2] = m[2][0]*v[0] + m[2][1]*v[1] + m[2][2]*v[2];
+  mv[0] = m[0][0]*v[0] + m[0][1]*v[1] + m[0][2]*v[2];
+  mv[1] = m[1][0]*v[0] + m[1][1]*v[1] + m[1][2]*v[2];
+  mv[2] = m[2][0]*v[0] + m[2][1]*v[1] + m[2][2]*v[2];
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Compute the determinant of a 3x3 matrix
+ *
+ * \param[in]  m    matrix
+ *
+ * \return the determinant
+ */
+/*----------------------------------------------------------------------------*/
+
+inline cs_real_t
+_detmat33(const cs_real_t   m[3][3])
+{
+  cs_real_t  com0 = m[1][1]*m[2][2] - m[2][1]*m[1][2];
+  cs_real_t  com1 = m[2][1]*m[0][2] - m[0][1]*m[2][2];
+  cs_real_t  com2 = m[0][1]*m[1][2] - m[1][1]*m[0][2];
+
+  return m[0][0]*com0 + m[1][0]*com1 + m[2][0]*com2;
 }
 
 /*----------------------------------------------------------------------------*/
@@ -341,37 +363,165 @@ _mv3(const cs_real_33_t  m,
 /*----------------------------------------------------------------------------*/
 
 inline void
-_invmat33(const cs_real_33_t   in,
-          cs_real_33_t        *inv)
+_invmat33(const cs_real_t   in[3][3],
+          cs_real_t         inv[3][3])
 {
   int  k, l;
   double  det, invdet;
 
-  inv[0][0][0] = in[1][1]*in[2][2] - in[2][1]*in[1][2];
-  inv[0][0][1] = in[2][1]*in[0][2] - in[0][1]*in[2][2];
-  inv[0][0][2] = in[0][1]*in[1][2] - in[1][1]*in[0][2];
+  inv[0][0] = in[1][1]*in[2][2] - in[2][1]*in[1][2];
+  inv[0][1] = in[2][1]*in[0][2] - in[0][1]*in[2][2];
+  inv[0][2] = in[0][1]*in[1][2] - in[1][1]*in[0][2];
 
-  inv[0][1][0] = in[2][0]*in[1][2] - in[1][0]*in[2][2];
-  inv[0][1][1] = in[0][0]*in[2][2] - in[2][0]*in[0][2];
-  inv[0][1][2] = in[1][0]*in[0][2] - in[0][0]*in[1][2];
+  inv[1][0] = in[2][0]*in[1][2] - in[1][0]*in[2][2];
+  inv[1][1] = in[0][0]*in[2][2] - in[2][0]*in[0][2];
+  inv[1][2] = in[1][0]*in[0][2] - in[0][0]*in[1][2];
 
-  inv[0][2][0] = in[1][0]*in[2][1] - in[2][0]*in[1][1];
-  inv[0][2][1] = in[2][0]*in[0][1] - in[0][0]*in[2][1];
-  inv[0][2][2] = in[0][0]*in[1][1] - in[1][0]*in[0][1];
+  inv[2][0] = in[1][0]*in[2][1] - in[2][0]*in[1][1];
+  inv[2][1] = in[2][0]*in[0][1] - in[0][0]*in[2][1];
+  inv[2][2] = in[0][0]*in[1][1] - in[1][0]*in[0][1];
 
-  det = in[0][0]*inv[0][0][0] + in[1][0]*inv[0][0][1] + in[2][0]*inv[0][0][2];
+  det = in[0][0]*inv[0][0] + in[1][0]*inv[0][1] + in[2][0]*inv[0][2];
   assert(fabs(det) > DBL_MIN*1e3);  /* inversibility ? */
   invdet = 1 / det;
 
   for (k = 0; k < 3; k++)
     for (l = 0; l < 3; l++)
-      inv[0][k][l] *= invdet;
+      inv[k][l] *= invdet;
 }
 
 /*============================================================================
  * Public function prototypes
  *============================================================================*/
 
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Allocate and initialize a private structure for this file used for
+ *         reducing round-off errors during summation
+ *
+ *  \param[in] ref_size    reference array dimension
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_toolbox_init(cs_lnum_t      ref_size)
+{
+  double  invln2 = 1/log(2);
+  double  estimate = log(ref_size)*invln2;
+  int  power = floor(log(estimate)*invln2);
+  int  size = (1 << power);
+
+  /* Compute a number of sub sums according to a reference size */
+  _op_subsum.size = CS_MAX(2, size);
+
+  BFT_MALLOC(_op_subsum.idx, _op_subsum.size + 1, int);
+  BFT_MALLOC(_op_subsum.sums, _op_subsum.size, double);
+
+  printf("# N_SUB_SUMS      %d\n", _op_subsum.size);
+  bft_printf(" -sla- n_subsums      %d\n", _op_subsum.size);
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Free a private structure for this file used for reducing round-off
+ *         errors during summation
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_toolbox_finalize(void)
+{
+  assert(_op_subsum.size > 0);
+
+  BFT_FREE(_op_subsum.idx);
+  BFT_FREE(_op_subsum.sums);
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Compute the eigenvalues of a 3x3 matrix which is symmetric and real
+ *         -> Oliver K. Smith "eigenvalues of a symmetric 3x3 matrix",
+ *         Communication of the ACM (April 1961)
+ *         -> Wikipedia article entitled "Eigenvalue algorithm"
+ *
+ * \param[in]  m          3x3 matrix
+ * \param[out] eig_ratio  max/min
+ * \param[out] eig_max    max. eigenvalue
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_eigen_mat33(const cs_real_t     m[3][3],
+               cs_real_t          *eig_ratio,
+               cs_real_t          *eig_max)
+{
+  cs_real_t  e, e1, e2, e3;
+
+  /* Sanity check */
+  e1 = m[0][1]-m[1][0], e2 = m[0][2]-m[2][0], e3 = m[1][2]-m[2][1];
+  assert(e1*e1 + e2*e2 + e3*e3 <= 0.0);
+
+  cs_real_t  p1 = m[0][1]*m[0][1] + m[0][2]*m[0][2] + m[1][2]*m[1][2];
+
+  if (p1 <= 0.0) { // m is diagonal
+
+    e1 = m[0][0], e2 = m[1][1], e3 = m[2][2];
+    if (e3 < e2) e = e3, e3 = e2, e2 = e;
+    if (e3 < e1) e = e3, e3 = e1, e1 = e2, e2 = e;
+    else {
+      if (e2 < e1) e = e2, e2 = e1, e1 = e;
+    }
+
+  }
+  else { // m is not diagonal
+
+    cs_real_t  theta;
+    cs_real_t  n[3][3];
+
+    cs_real_t  tr = _overdim*(m[0][0] + m[1][1] + m[2][2]);
+
+    e1 = m[0][0] - tr, e2 = m[1][1] - tr, e3 = m[2][2] - tr;
+    cs_real_t  p2 = e1*e1 + e2*e2 + e3*e3 + 2*p1;
+
+    assert(p2 > 0);
+    cs_real_t  p = sqrt(p2*_oversix);
+    cs_real_t  ovp = 1./p;
+
+    for (int  i = 0; i < 3; i++) {
+      n[i][i] = ovp * (m[i][i] - tr);
+      for (int j = i + 1; j < 3; j++) {
+        n[i][j] = ovp*m[i][j];
+        n[j][i] = n[i][j];
+      }
+    }
+
+    /* r should be between -1 and 1 but truncation error and bad conditionning
+       can lead to slighty under/over-shoot */
+    cs_real_t  r = 0.5 * _detmat33((const cs_real_t (*)[3])n);
+    cs_real_t  pi = 4*atan(1.0);
+
+    if (r <= -1)
+      theta = _overdim*pi;
+    else if (r >= 1)
+      theta = 0.;
+    else
+      theta = _overdim*acos(r);
+
+    // eigenvalues computed should satisfy e1 < e2 < e3
+    e3 = tr + 2*p*cos(theta);
+    e1 = tr + 2*p*cos(theta + 2*pi*_overdim);
+    e2 = 3*tr - e1 -e3; // since tr(m) = e1 + e2 + e3
+  }
+
+  /* Debug */
+  printf(" --msg-- Computed eigenvalues %5.3e < %5.3e < %5.3e\n", e1, e2, e3);
+
+  /* Return values */
+  assert(fabs(e1) > 0);
+  *eig_ratio = e3/e1;
+  *eig_max = e3;
+}
+
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief  Compute the area of the convex_hull generated by 3 points.
@@ -434,21 +584,21 @@ cs_voltet(const cs_real_3_t   xv,
   _lenunit3(xe, xf, &lef, &uef);
   _lenunit3(xe, xc, &lec, &uec);
   _cp3(uev, uef, &ucp);
-  vol = _tools_oversix * lev * lef * lec * fabs(_dp3(ucp, uec));
+  vol = _oversix * lev * lef * lec * fabs(_dp3(ucp, uec));
 
   return  vol;
 }
 
 /*----------------------------------------------------------------------------*/
 /*!
- * \brief  Compute alpha*x + beta*y = z
+ * \brief  Compute alpha*x + beta*y = p_z
  *
  * \param[in]     size    vector dimension
  * \param[in]     alpha   coefficient for x vector
  * \param[in]     x       first vector
  * \param[in]     beta    coefficient for y vector
  * \param[in]     y       second vector
- * \param[inout]  z       resulting vector (allocated if NULL)
+ * \param[in,out] p_z     resulting vector (allocated if NULL)
  * \param[in]     reset   reset z vector before computation
  */
 /*----------------------------------------------------------------------------*/
@@ -713,55 +863,12 @@ cs_sum(cs_lnum_t              size,
   return _op_subsum.sums[0];
 }
 
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Allocate and initialize a private structure for this file used for
- *         reducing round-off errors during summation
- *
- *  \param[in] ref_size    reference array dimension
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_toolbox_init(cs_lnum_t      ref_size)
-{
-  double  invln2 = 1/log(2);
-  double  estimate = log(ref_size)*invln2;
-  int  power = floor(log(estimate)*invln2);
-  int  size = (1 << power);
-
-  /* Compute a number of sub sums according to a reference size */
-  _op_subsum.size = CS_MAX(2, size);
-
-  BFT_MALLOC(_op_subsum.idx, _op_subsum.size + 1, int);
-  BFT_MALLOC(_op_subsum.sums, _op_subsum.size, double);
-
-  printf("# N_SUB_SUMS      %d\n", _op_subsum.size);
-  bft_printf(" -sla- n_subsums      %d\n", _op_subsum.size);
-}
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Free a private structure for this file used for reducing round-off
- *         errors during summation
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_toolbox_finalize(void)
-{
-  assert(_op_subsum.size > 0);
-
-  BFT_FREE(_op_subsum.idx);
-  BFT_FREE(_op_subsum.sums);
-}
-
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief  Allocate or reallocate a temporary buffer structure
  *
- * \param[in]     bufsize   reference size
- * \param[inout]  p_tb      pointer to the temporary structure to allocate
+ * \param[in]       bufsize   reference size
+ * \param[in, out]  p_tb      pointer to the temporary structure to allocate
  */
 /*----------------------------------------------------------------------------*/
 
@@ -812,104 +919,6 @@ cs_tmpbuf_free(cs_tmpbuf_t  *tb)
   return NULL;
 }
 
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Allocate and initialize a cs_toolbox_locmat_t structure
- *
- * \param[in]  n_max_ent    max number of entities
- *
- * \return  a new allocated cs_toolbox_locmat_t structure
- */
-/*----------------------------------------------------------------------------*/
-
-cs_toolbox_locmat_t *
-cs_toolbox_locmat_create(int   n_max_ent)
-{
-  int  i;
-
-  cs_toolbox_locmat_t  *lm = NULL;
-
-  BFT_MALLOC(lm, 1, cs_toolbox_locmat_t);
-
-  lm->n_max_ent = n_max_ent;
-  lm->n_ent = 0;
-  lm->ids = NULL;
-  lm->mat = NULL;
-
-  if (n_max_ent > 0) {
-
-    int  msize = n_max_ent*n_max_ent;
-
-    BFT_MALLOC(lm->ids, n_max_ent, cs_lnum_t);
-    for (i = 0; i < n_max_ent; i++)
-      lm->ids[i] = 0;
-
-    BFT_MALLOC(lm->mat, msize, double);
-    for (i = 0; i < msize; i++)
-      lm->mat[i] = 0;
-
-  }
-
-  return lm;
-}
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Dump a local discrete Hodge operator
- *
- * \param[in]    parent_id  id of the related parent entity
- * \param[in]    lm         pointer to the cs_sla_locmat_t struct.
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_toolbox_locmat_dump(int                         parent_id,
-                       const cs_toolbox_locmat_t  *lm)
-{
-  int  i, j;
-
-  bft_printf("\n  << parent id: %d >>\n", parent_id);
-
-  /* List sub-entity ids */
-  for (i = 0; i < lm->n_ent; i++)
-    bft_printf(" %9d", lm->ids[i]);
-  bft_printf("\n");
-
-  for (i = 0; i < lm->n_ent; i++) {
-    bft_printf(" %5d", lm->ids[i]);
-    for (j = 0; j < lm->n_ent; j++)
-      bft_printf(" % .4e", lm->mat[i*lm->n_ent+j]);
-    bft_printf("\n");
-  }
-
-}
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Free a cs_toolbox_locmat_t structure
- *
- * \param[in]  hb    pointer to a cs_toolbox_locmat_t struct. to free
- *
- * \return  a NULL pointer
- */
-/*----------------------------------------------------------------------------*/
-
-cs_toolbox_locmat_t *
-cs_toolbox_locmat_free(cs_toolbox_locmat_t  *lm)
-{
-  if (lm == NULL)
-    return lm;
-
-  if (lm->n_max_ent > 0) {
-    BFT_FREE(lm->ids);
-    BFT_FREE(lm->mat);
-  }
-
-  BFT_FREE(lm);
-
-  return NULL;
-}
-
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief   Compute some simple statistics from an array
@@ -1060,6 +1069,517 @@ cs_data_info_dump(const char              *name,
   if (close_file)  fclose(_f);
 }
 
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Create an index structure of size n
+ *
+ * \param[in]  n     number of entries of the indexed list
+ *
+ * \return  a pointer to a cs_connect_index_t
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_connect_index_t *
+cs_index_create(int  n)
+{
+  int  i;
+
+  cs_connect_index_t  *x = NULL;
+
+  BFT_MALLOC(x, 1, cs_connect_index_t);
+
+  x->n = n;
+  x->owner = true;
+  x->ids = NULL;
+
+  BFT_MALLOC(x->idx, n+1, int);
+  for (i = 0; i < x->n + 1; i++)  x->idx[i] = 0;
+
+  return x;
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Map arrays into an index structure of size n (owner = false)
+ *
+ * \param[in]  n     number of entries of the indexed list
+ * \param[in]  idx   array of size n+1
+ * \param[in]  ids   array of size idx[n]
+ *
+ * \return  a pointer to a cs_connect_index_t
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_connect_index_t *
+cs_index_map(int    n,
+             int   *idx,
+             int   *ids)
+{
+  cs_connect_index_t  *x = NULL;
+
+  BFT_MALLOC(x, 1, cs_connect_index_t);
+
+  x->n = n;
+  x->owner = false;
+  x->idx = idx;
+  x->ids = ids;
+
+  return x;
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Destroy a cs_connect_index_t structure
+ *
+ * \param[in]  pidx     pointer of pointer to a cs_connect_index_t structure
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_index_free(cs_connect_index_t   **pidx)
+{
+  cs_connect_index_t  *x = *pidx;
+
+  if (x == NULL)
+    return;
+
+  if (x->owner) {
+    BFT_FREE(x->idx);
+    BFT_FREE(x->ids);
+  }
+
+  BFT_FREE(x);
+  *pidx = NULL;
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   From 2 indexes : A -> B and B -> C create a new index A -> C
+ *
+ * \param[in]  nc      number of elements in C set
+ * \param[in]  a2b     pointer to the index A -> B
+ * \param[in]  b2c     pointer to the index B -> C
+ *
+ *\return  a pointer to the cs_connect_index_t structure A -> C
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_connect_index_t *
+cs_index_compose(int                        nc,
+                 const cs_connect_index_t  *a2b,
+                 const cs_connect_index_t  *b2c)
+{
+  int  i, pos_a, pos_b, a_id, b_id, c_id, shift;
+
+  int  *ctag = NULL;
+  cs_connect_index_t  *a2c = cs_index_create(a2b->n);
+
+  BFT_MALLOC(ctag, nc, int);
+  for (i = 0; i < nc; i++)
+    ctag[i] = -1;
+
+  /* Build index */
+  for (a_id = 0; a_id < a2b->n; a_id++) {
+
+    for (pos_a = a2b->idx[a_id]; pos_a < a2b->idx[a_id+1]; pos_a++) {
+
+      b_id = a2b->ids[pos_a];
+      for (pos_b = b2c->idx[b_id]; pos_b < b2c->idx[b_id+1]; pos_b++) {
+
+        c_id = b2c->ids[pos_b];
+        if (ctag[c_id] != a_id) { /* Not tagged yet */
+          ctag[c_id] = a_id;
+          a2c->idx[a_id+1] += 1;
+        }
+
+      } /* End of loop on C elements */
+    } /* End of loop on B elements */
+  } /* End of loop on A elements */
+
+  for (i = 0; i < a2c->n; i++)
+    a2c->idx[i+1] += a2c->idx[i];
+
+  BFT_MALLOC(a2c->ids, a2c->idx[a2c->n], int);
+
+  /* Reset ctag */
+  for (i = 0; i < nc; i++)
+    ctag[i] = -1;
+
+  /* Fill ids */
+  shift = 0;
+  for (a_id = 0; a_id < a2b->n; a_id++) {
+
+    for (pos_a = a2b->idx[a_id]; pos_a < a2b->idx[a_id+1]; pos_a++) {
+
+      b_id = a2b->ids[pos_a];
+      for (pos_b = b2c->idx[b_id]; pos_b < b2c->idx[b_id+1]; pos_b++) {
+
+        c_id = b2c->ids[pos_b];
+        if (ctag[c_id] != a_id) { /* Not tagged yet */
+          ctag[c_id] = a_id;
+          a2c->ids[shift++] = c_id;
+        }
+
+      } /* End of loop on C elements */
+    } /* End of loop on B elements */
+  } /* End of loop on A elements */
+
+  assert(shift == a2c->idx[a2c->n]);
+
+  BFT_FREE(ctag);
+
+  return a2c;
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   From a cs_connect_index_t A -> B create a new index B -> A
+ *
+ * \param[in]  nb     size of the "b" set
+ * \param[in]  a2b    pointer to the index A -> B
+ *
+ * \return  a new pointer to the cs_connect_index_t structure B -> A
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_connect_index_t *
+cs_index_transpose(int                        nb,
+                   const cs_connect_index_t  *a2b)
+{
+  int  i, j, b_id, shift;
+  int  *count = NULL;
+
+  cs_connect_index_t  *b2a = cs_index_create(nb);
+
+  if (nb == 0)
+    return b2a;
+
+  /* Build idx */
+  for (i = 0; i < a2b->n; i++)
+    for (j = a2b->idx[i]; j < a2b->idx[i+1]; j++)
+      b2a->idx[a2b->ids[j]+1] += 1;
+
+  for (i = 0; i < b2a->n; i++)
+    b2a->idx[i+1] += b2a->idx[i];
+
+  /* Allocate and initialize temporary buffer */
+  BFT_MALLOC(count, nb, int);
+  for (i = 0; i < nb; i++) count[i] = 0;
+
+  /* Build ids */
+  BFT_MALLOC(b2a->ids, b2a->idx[b2a->n], int);
+
+  for (i = 0; i < a2b->n; i++) {
+    for (j = a2b->idx[i]; j < a2b->idx[i+1]; j++) {
+      b_id = a2b->ids[j];
+      shift = count[b_id] + b2a->idx[b_id];
+      b2a->ids[shift] = i;
+      count[b_id] += 1;
+    }
+  }
+
+  /* Free temporary buffer */
+  BFT_FREE(count);
+
+  return b2a;
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Sort each sub-list related to an entry in a cs_connect_index_t
+ *          structure
+ *
+ * \param[in]  x     pointer to a cs_connect_index_t structure
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_index_sort(cs_connect_index_t   *x)
+{
+  if (x == NULL)
+    return;
+
+  for (int i = 0; i < x->n; i++)
+    cs_sort_shell(x->idx[i], x->idx[i+1], x->ids);
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Dump a cs_connect_index_t structure to a file or into the
+ *          standard output
+ *
+ * \param[in]  name  name of the dump file. Can be set to NULL
+ * \param[in]  _f    pointer to a FILE structure. Can be set to NULL.
+ * \param[in]  x     pointer to a cs_connect_index_t structure
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_index_dump(const char           *name,
+              FILE                 *_f,
+              cs_connect_index_t   *x)
+{
+  FILE  *f = _f;
+  _Bool  close_file = false;
+
+  if (f == NULL) {
+    if (name == NULL)
+      f = stdout;
+    else {
+      f = fopen(name,"w");
+      close_file = true;
+    }
+  }
+
+  fprintf(f, "\n Dump cs_connect_index_t struct: %p (%s)\n",
+          (const void *)x, name);
+
+  if (x == NULL) {
+    if (close_file) fclose(f);
+    return;
+  }
+
+  fprintf(f, "  owner:             %6d\n", x->owner);
+  fprintf(f, "  n_elts:            %6d\n", x->n);
+  fprintf(f, "  ids_size:          %6d\n", x->idx[x->n]);
+
+  for (int i = 0; i < x->n; i++) {
+    fprintf(f, "\n[%4d] ", i);
+    for (int j = x->idx[i]; j < x->idx[i+1]; j++)
+      fprintf(f, "%5d |", x->ids[j]);
+  }
+
+  if (close_file)
+    fclose(f);
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Allocate and initialize a cs_locmat_t structure
+ *
+ * \param[in]  n_max_ent    max number of entities
+ *
+ * \return  a new allocated cs_locmat_t structure
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_locmat_t *
+cs_locmat_create(int   n_max_ent)
+{
+  int  i;
+
+  cs_locmat_t  *lm = NULL;
+
+  BFT_MALLOC(lm, 1, cs_locmat_t);
+
+  lm->n_max_ent = n_max_ent;
+  lm->n_ent = 0;
+  lm->ids = NULL;
+  lm->mat = NULL;
+
+  if (n_max_ent > 0) {
+
+    int  msize = n_max_ent*n_max_ent;
+
+    BFT_MALLOC(lm->ids, n_max_ent, cs_lnum_t);
+    for (i = 0; i < n_max_ent; i++)
+      lm->ids[i] = 0;
+
+    BFT_MALLOC(lm->mat, msize, double);
+    for (i = 0; i < msize; i++)
+      lm->mat[i] = 0;
+
+  }
+
+  return lm;
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Free a cs_locmat_t structure
+ *
+ * \param[in]  lm    pointer to a cs_locmat_t struct. to free
+ *
+ * \return  a NULL pointer
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_locmat_t *
+cs_locmat_free(cs_locmat_t  *lm)
+{
+  if (lm == NULL)
+    return lm;
+
+  if (lm->n_max_ent > 0) {
+    BFT_FREE(lm->ids);
+    BFT_FREE(lm->mat);
+  }
+
+  BFT_FREE(lm);
+
+  return NULL;
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Copy a cs_locmat_t structure into another cs_locmat_t structure
+ *          which has been already allocated
+ *
+ * \param[in, out]  recv    pointer to a cs_locmat_t struct.
+ * \param[in]       send    pointer to a cs_locmat_t struct.
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_locmat_copy(cs_locmat_t        *recv,
+               const cs_locmat_t  *send)
+{
+  /* Sanity check */
+  assert(recv->n_max_ent >= send->n_max_ent);
+
+  recv->n_ent = send->n_ent;
+
+  /* Copy ids */
+  for (int  i = 0; i < send->n_ent; i++)
+    recv->ids[i] = send->ids[i];
+
+  /* Copy values */
+  memcpy(recv->mat, send->mat, sizeof(double)*send->n_ent*send->n_ent);
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Compute a local dense matrix-vector product
+ *          matvec has been previously allocated
+ *
+ * \param[in]      loc    local matrix to use
+ * \param[in]      vec    local vector to use
+ * \param[in, out] matvec result of the local matrix-vector product
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_locmat_matvec(const cs_locmat_t   *loc,
+                 const cs_real_t     *vec,
+                 cs_real_t           *matvec)
+{
+  /* Sanity checks */
+  assert(loc != NULL && vec != NULL && matvec != NULL);
+
+  const int  n = loc->n_ent;
+
+  /* Init. matvec */
+  cs_real_t  v = vec[0];
+  for (int i = 0; i < n; i++)
+    matvec[i] = v*loc->mat[i*n];
+
+  /* Increment matvec */
+  for (int i = 0; i < n; i++) {
+    int shift =  i*n;
+    for (int j = 1; j < n; j++)
+      matvec[i] += vec[j]*loc->mat[shift + j];
+  }
+
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Add two local dense matrices: loc += add
+ *
+ * \param[in, out] loc   local matrix storing the result
+ * \param[in]      add   values to add to loc
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_locmat_add(cs_locmat_t        *loc,
+              const cs_locmat_t  *add)
+{
+  /* Sanity checks */
+  assert(loc != NULL && add != NULL);
+  assert(loc->n_max_ent <= add->n_max_ent);
+
+  for (int i = 0; i < loc->n_ent*loc->n_ent; i++)
+    loc->mat[i] += add->mat[i];
+
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Define a new matrix by adding a local matrix with its transpose.
+ *          Keep the transposed matrix for future use.
+ *
+ * \param[in, out] loc   local matrix to transpose and add
+ * \param[in, out] tr    transposed of the local matrix
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_locmat_add_transpose(cs_locmat_t  *loc,
+                        cs_locmat_t  *tr)
+{
+  /* Sanity check */
+  assert(loc != NULL && tr != NULL && tr->n_max_ent == loc->n_max_ent);
+
+  if (loc->n_ent < 1)
+    return;
+
+  tr->n_ent = loc->n_ent;
+
+  for (int i = 0; i < loc->n_ent; i++) {
+
+    int  ii = i*loc->n_ent + i;
+
+    tr->ids[i] = loc->ids[i];
+    tr->mat[ii] = loc->mat[ii];
+    loc->mat[ii] *= 2;
+
+    for (int j = i+1; j < loc->n_ent; j++) {
+
+      int  ij = i*loc->n_ent + j;
+      int  ji = j*loc->n_ent + i;
+
+      tr->mat[ji] = loc->mat[ij];
+      tr->mat[ij] = loc->mat[ji];
+      loc->mat[ij] += tr->mat[ij];
+      loc->mat[ji] += tr->mat[ji];
+
+    }
+  }
+
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Dump a local discrete Hodge operator
+ *
+ * \param[in]    parent_id  id of the related parent entity
+ * \param[in]    lm         pointer to the cs_sla_locmat_t struct.
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_locmat_dump(int                 parent_id,
+               const cs_locmat_t  *lm)
+{
+  int  i, j;
+
+  bft_printf("\n  << parent id: %d >>\n", parent_id);
+
+  /* List sub-entity ids */
+  for (i = 0; i < lm->n_ent; i++)
+    bft_printf(" %9d", lm->ids[i]);
+  bft_printf("\n");
+
+  for (i = 0; i < lm->n_ent; i++) {
+    bft_printf(" %5d", lm->ids[i]);
+    for (j = 0; j < lm->n_ent; j++)
+      bft_printf(" % .4e", lm->mat[i*lm->n_ent+j]);
+    bft_printf("\n");
+  }
+
+}
+
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
