@@ -31,6 +31,7 @@
  *  Local headers
  *----------------------------------------------------------------------------*/
 
+#include "cs_mesh.h"
 #include "cs_cdo.h"
 #include "cs_quadrature.h"
 
@@ -43,43 +44,51 @@ BEGIN_C_DECLS
  *============================================================================*/
 
 /* Tag to build parameter flag */
-#define CS_PARAM_FLAG_UNIFORM  (1 <<  0)  //    1: uniform (in space)
-#define CS_PARAM_FLAG_VERTEX   (1 <<  1)  //    2: on vertices
-#define CS_PARAM_FLAG_EDGE     (1 <<  2)  //    4: on edges
-#define CS_PARAM_FLAG_FACE     (1 <<  3)  //    8: on faces
-#define CS_PARAM_FLAG_CELL     (1 <<  4)  //   16: on cells
-#define CS_PARAM_FLAG_PRIMAL   (1 <<  5)  //   32: on primal mesh
-#define CS_PARAM_FLAG_DUAL     (1 <<  6)  //   64: on dual mesh
-#define CS_PARAM_FLAG_BORDER   (1 <<  7)  //  128: scalar-valued
-#define CS_PARAM_FLAG_SCAL     (1 <<  8)  //  256: scalar-valued
-#define CS_PARAM_FLAG_VECT     (1 <<  9)  //  512: vector-valued
-#define CS_PARAM_FLAG_TENS     (1 << 10)  // 1024: tensor-valued
-#define CS_PARAM_FLAG_SYMMET   (1 << 11)  // 2048: symmetric
-#define CS_PARAM_FLAG_IMPLICIT (1 << 12)  // 4096: implicit
-#define CS_PARAM_FLAG_EXPLICIT (1 << 13)  // 8192: explicit
-#define CS_PARAM_FLAG_UNSTEADY (1 << 14)  //16384: unsteady
+#define CS_PARAM_FLAG_UNIFORM  (1 <<  0) //    1: uniform (in space)
+#define CS_PARAM_FLAG_CELLWISE (1 <<  1) //    2: cellwise uniform
+#define CS_PARAM_FLAG_UNSTEADY (1 <<  2) //    4: unsteady
+#define CS_PARAM_FLAG_VERTEX   (1 <<  3) //    8: on vertices
+#define CS_PARAM_FLAG_EDGE     (1 <<  4) //   16: on edges
+#define CS_PARAM_FLAG_FACE     (1 <<  5) //   32: on faces
+#define CS_PARAM_FLAG_CELL     (1 <<  6) //   64: on cells
+#define CS_PARAM_FLAG_PRIMAL   (1 <<  7) //  128: on primal mesh
+#define CS_PARAM_FLAG_DUAL     (1 <<  8) //  256: on dual mesh
+#define CS_PARAM_FLAG_BORDER   (1 <<  9) //  512: scalar-valued
+#define CS_PARAM_FLAG_SCAL     (1 << 10) // 1024: scalar-valued
+#define CS_PARAM_FLAG_VECT     (1 << 11) // 2048: vector-valued
+#define CS_PARAM_FLAG_TENS     (1 << 12) // 4096: tensor-valued
+#define CS_PARAM_FLAG_BY_CELL  (1 << 13) // 8192: by cell (c2e, c2f, c2v)
 
 /*============================================================================
  * Type definitions
  *============================================================================*/
 
+/* User-defined function */
+typedef void (cs_user_func_t) (const void         *input1,
+                               const void         *input2,
+                               cs_real_t           tcur,
+                               const cs_real_3_t   xyz,
+                               cs_get_t           *output);
+
 typedef union {
 
-  cs_get_t              get;       // definition by value
-  cs_analytic_func_t   *analytic;  // definition by an analytic function
-  cs_user_func_t       *user_func; // definition by an user-defined function
+  cs_get_t               get;       // definition by value
+  cs_analytic_func_t    *analytic;  // definition by an analytic function
+  cs_timestep_func_t    *time_func; // definition of the time step by a function
+  cs_user_func_t        *user_func; // definition by an user-defined function
+  cs_onevar_law_func_t  *law1_func; // definition by law depending one variable
 
 } cs_def_t;
 
 typedef enum {
 
-  CS_PARAM_DEF_BY_VALUE,
-  CS_PARAM_DEF_BY_FIELD,
-  CS_PARAM_DEF_BY_EVALUATOR,
   CS_PARAM_DEF_BY_ANALYTIC_FUNCTION,
+  CS_PARAM_DEF_BY_ARRAY,
+  CS_PARAM_DEF_BY_FIELD,
+  CS_PARAM_DEF_BY_ONEVAR_LAW,
+  CS_PARAM_DEF_BY_TIME_FUNCTION,
   CS_PARAM_DEF_BY_USER_FUNCTION,
-  CS_PARAM_DEF_BY_LAW,
-  CS_PARAM_DEF_BY_FILE,
+  CS_PARAM_DEF_BY_VALUE,
   CS_PARAM_N_DEF_TYPES
 
 } cs_param_def_type_t;
@@ -95,63 +104,23 @@ typedef enum {
 
 } cs_param_var_type_t;
 
-/* MATERIAL PROPERTIES */
-/* =================== */
-
-/* Material property: parametrization for conductivity, diffusion coef.
-   or viscosity */
-typedef enum {
-
-  CS_PARAM_PTY_ISO,
-  CS_PARAM_PTY_ORTHO,
-  CS_PARAM_PTY_ANISO,
-  CS_PARAM_N_PTY_TYPES
-
-} cs_param_pty_type_t;
-
-/* Material parameter definitions */
-typedef struct {
-
-  char        *restrict name;
-  cs_flag_t             flag;  /* Short descriptor (mask of bits) */
-
-  int        post_freq; /* -1 (no post-processing), 0 (at the beginning)
-                           otherwise every post_freq iteration(s) */
-  int        field_id;  /* If post-processing is required (-1 if not used) */
-
-  /* Material properties:
-     Uniform material. The number of values to set depends on the material
-     definition.
-       - isotropic   = 1
-       - orthotropic = 3
-       - anisotropic = 9
-     Not uniform or not steady material. Values have to be defined by a
-     user function.
-  */
-
-  cs_param_pty_type_t  type;
-  cs_param_def_type_t  def_type;
-  cs_def_t             def;
-
-} cs_param_pty_t;
-
 /* DISCRETE HODGE OPERATORS */
 /* ======================== */
 
 typedef enum {
 
-  CS_PARAM_HODGE_TYPE_VPCD,
-  CS_PARAM_HODGE_TYPE_EPFD,
-  CS_PARAM_HODGE_TYPE_FPED,
-  CS_PARAM_HODGE_TYPE_EDFP,
-  CS_PARAM_HODGE_TYPE_CPVD,
+  CS_PARAM_HODGE_TYPE_VPCD, // from primal vertices to dual cells
+  CS_PARAM_HODGE_TYPE_EPFD, // from primal edges to dual faces
+  CS_PARAM_HODGE_TYPE_FPED, // from primal faces to dual edges
+  CS_PARAM_HODGE_TYPE_EDFP, // from dual edges to primal faces
+  CS_PARAM_HODGE_TYPE_CPVD, // from primal cells to dual vertices
   CS_PARAM_N_HODGE_TYPES
 
 } cs_param_hodge_type_t;
 
 typedef enum {
 
-  CS_PARAM_HODGE_ALGO_VORONOI,
+  CS_PARAM_HODGE_ALGO_VORONOI, // Under othogonality condition gives a diag. op.
   CS_PARAM_HODGE_ALGO_WBS,     // WBS: Whitney Barycentric Subdivision
   CS_PARAM_HODGE_ALGO_COST,    // COST: COnsistency & STabilization splitting
   CS_PARAM_N_HODGE_ALGOS
@@ -160,20 +129,121 @@ typedef enum {
 
 typedef struct {
 
-  int                     pty_id;  /* id of the related material property */
-  bool                    inv_pty; /* Definition based on material property
+  bool                    inv_pty; /* Definition based on the property
                                       or its inverse */
 
-  cs_param_hodge_type_t   type;
-  cs_param_hodge_algo_t   algo;
-  double                  coef;    /* Value of the stabilization parameter
-                                      if the COST algo. is used, other 0. */
+  cs_param_hodge_type_t   type;  /* type of discrete Hodge operator */
+  cs_param_hodge_algo_t   algo;  /* type of algorithm used to build this op. */
+  double                  coef;  /* Value of the stabilization parameter
+                                    if the COST algo. is used, otherwise 0. */
 
 } cs_param_hodge_t;
 
+/* TIME SCHEME */
+/* =========== */
+
+/* Type of numerical scheme for the discretization in time */
+typedef enum {
+
+  CS_TIME_SCHEME_IMPLICIT,  // fully implicit (forward Euler/theta-scheme = 1)
+  CS_TIME_SCHEME_EXPLICIT,  // fully explicit (backward Euler/theta-scheme = 0)
+  CS_TIME_SCHEME_CRANKNICO, // Crank-Nicolson (theta-scheme = 0.5)
+  CS_TIME_SCHEME_THETA,     // theta-scheme
+  CS_TIME_N_SCHEMES
+
+} cs_time_scheme_t;
+
+/* Parameters related to time discretization */
+typedef struct {
+
+  cs_time_scheme_t   scheme;     // numerical scheme
+  cs_real_t          theta;      // used in theta-scheme
+  bool               do_lumping; // perform mass lumping ?
+
+  /* Initial conditions */
+  cs_param_def_type_t   ic_def_type;  // type of definition
+  cs_def_t              ic_def;       // definition
+
+} cs_param_time_t;
+
+/* ADVECTION OPERATOR PARAMETRIZATION */
+/* ================================== */
+
+typedef enum {
+
+  CS_PARAM_ADVECTION_FORM_CONSERV,
+  CS_PARAM_ADVECTION_FORM_NONCONS,
+  CS_PARAM_N_ADVECTION_FORMULATIONS
+
+} cs_param_advection_form_t;
+
+/* Type of weight functions considered */
+typedef enum {
+
+  CS_PARAM_ADVECTION_WEIGHT_ALGO_CENTERED,
+  CS_PARAM_ADVECTION_WEIGHT_ALGO_UPWIND,
+  CS_PARAM_ADVECTION_WEIGHT_ALGO_SAMARSKII,
+  CS_PARAM_ADVECTION_WEIGHT_ALGO_SG,
+  CS_PARAM_ADVECTION_WEIGHT_ALGO_D10G5,
+  CS_PARAM_N_ADVECTION_WEIGHT_ALGOS
+
+} cs_param_advection_weight_algo_t;
+
+/* Choice on the type of algo. used to set the argument used in
+   the weight function */
+typedef enum {
+
+  CS_PARAM_ADVECTION_WEIGHT_FLUX,
+  CS_PARAM_ADVECTION_WEIGHT_XEXC,
+  CS_PARAM_N_ADVECTION_WEIGHTS
+
+} cs_param_advection_weight_t;
+
+/* Set of options for building a contraction operator (also called interior
+   product) which is closely related to the advection operator */
+typedef struct {
+
+  cs_param_advection_form_t         formulation; // conservative or not
+  cs_param_advection_weight_algo_t  weight_algo;
+  cs_param_advection_weight_t       weight_criterion;
+  cs_quadra_type_t                  quad_type; // barycentric, higher, highest
+
+} cs_param_advection_t;
+
+/* REACTION TERM PARAMETRIZATION */
+/* ============================= */
+
+typedef enum {
+
+  CS_PARAM_REACTION_TYPE_LINEAR,
+  CS_PARAM_N_REACTION_TYPES
+
+} cs_param_reaction_type_t;
+
+typedef struct {
+
+  char                      *name;
+  cs_param_reaction_type_t   type;
+
+  cs_param_hodge_t           hodge;
+  bool                       do_lumping;
+
+} cs_param_reaction_t;
+
 /* BOUNDARY CONDITIONS */
 /* =================== */
 
+/* Physic-driven boundary */
+typedef enum {
+
+  CS_PARAM_BOUNDARY_WALL,
+  CS_PARAM_BOUNDARY_INLET,
+  CS_PARAM_BOUNDARY_OUTLET,
+  CS_PARAM_BOUNDARY_SYMMETRY,
+  CS_PARAM_N_BOUNDARY_TYPES
+
+} cs_param_boundary_type_t;
+
 /* Mathematical boundary conditions */
 typedef enum {
 
@@ -182,22 +252,22 @@ typedef enum {
   CS_PARAM_BC_HMG_NEUMANN,
   CS_PARAM_BC_NEUMANN,
   CS_PARAM_BC_ROBIN,
-
   CS_PARAM_N_BC_TYPES
 
 } cs_param_bc_type_t;
 
-/* Physic-driven boundary */
+/* Choice between different method to enforce the BCs */
 typedef enum {
 
-  CS_PARAM_BOUNDARY_WALL,
-  CS_PARAM_BOUNDARY_INLET,
-  CS_PARAM_BOUNDARY_OUTLET,
-  CS_PARAM_BOUNDARY_SYMMETRY,
+  CS_PARAM_BC_ENFORCE_STRONG,       /* Strong enforcement of the BCs */
+  CS_PARAM_BC_ENFORCE_WEAK_PENA,    /* Weak enforcement with a strong
+                                       penalization coefficient */
+  CS_PARAM_BC_ENFORCE_WEAK_NITSCHE, /* Weak enforcement using Nitsche method */
+  CS_PARAM_BC_ENFORCE_WEAK_SYM,     /* Weak enforcement using symmetric Nitsche
+                                       method */
+  CS_PARAM_N_BC_ENFORCEMENTS
 
-  CS_PARAM_N_BOUNDARY_TYPES
-
-} cs_param_boundary_type_t;
+} cs_param_bc_enforce_t;
 
 /* Definition of the value of a boundary condition (BC)
    One or two values may be needed according to the type of BC.
@@ -210,8 +280,10 @@ typedef struct {
   int                    loc_id;   // Id related to the list of border faces
 
   cs_param_bc_type_t     bc_type;  // type of mathematical BC
+  cs_param_var_type_t    var_type; // type of variable
   cs_param_def_type_t    def_type; // Type of definition for a and b
 
+
   /* Access to the value related to the first coefficient and possibly
      the second one */
   cs_def_t               def_coef1;
@@ -221,13 +293,14 @@ typedef struct {
 
 typedef struct {
 
-  cs_param_bc_type_t   default_bc;
-  bool                 strong_enforcement;
-  double               penalty_coef; // TODO: preliminary step
-  cs_quadra_type_t     quad_type;    // barycentric, higher, highest...
+  cs_param_bc_type_t     default_bc;   // BC used by default
+  cs_param_bc_enforce_t  enforcement;  // type of boundary enforcement
+  cs_quadra_type_t       quad_type;    // barycentric, higher, highest...
+  bool                   use_subdiv;   /* subdivide or not into tetrahedra for
+                                          evaluating BC values */
 
-  int                  n_defs;
-  cs_param_bc_def_t   *defs;
+  int                    n_defs;
+  cs_param_bc_def_t     *defs;
 
 } cs_param_bc_t;
 
@@ -237,9 +310,7 @@ typedef struct {
 /* Types of source terms */
 typedef enum {
 
-  CS_PARAM_SOURCE_TERM_BASIC,    // in the right hand side
-  CS_PARAM_SOURCE_TERM_IMPLICIT, // in the matrix to invert
-  CS_PARAM_SOURCE_TERM_IMEX,     // implicit/explicit: two contributions
+  CS_PARAM_SOURCE_TERM_USER,     // user-defined
   CS_PARAM_SOURCE_TERM_MASS,     // specific treatment
   CS_PARAM_SOURCE_TERM_HEADLOSS, // specific treatment
   CS_PARAM_N_SOURCE_TERM_TYPES
@@ -248,20 +319,22 @@ typedef enum {
 
 typedef struct {
 
-  char  *restrict name;  /* short description of the source term */
+  char  *restrict name;   /* short description of the source term */
 
-  int                          location_id;  /* id of the related mesh location
-                                                structure */
+  int             ml_id;  /* id of the related mesh location structure */
+  int             post;   /* -1: no post, 0: at the beginning,
+                              n: at each 'n' iterations */
 
   /* Specification related to the way of computing the source term */
-  cs_param_source_term_type_t  type;      /* mass, head loss... */
-  cs_param_var_type_t          var_type;  /* scalar, vector... */
-  cs_param_def_type_t          def_type;  /* by value, by function... */
-  cs_quadra_type_t             quad_type; /* barycentric, higher, highest */
+  cs_param_source_term_type_t  type;       // mass, head loss...
+  cs_param_var_type_t          var_type;   // scalar, vector...
+  cs_param_def_type_t          def_type;   // by value, by function...
+  cs_quadra_type_t             quad_type;  // barycentric, higher, highest
+  bool                         use_subdiv; // use a subdivision into tetrahedra
 
-  /* Two potential values (implicit and explicit) */
-  cs_def_t                     imp_def;
-  cs_def_t                     exp_def;
+  /* Values if one needs an implicit and explicit part
+     implicit part comes first */
+  cs_def_t                     def;
 
 } cs_param_source_term_t;
 
@@ -317,226 +390,129 @@ typedef struct {
 
 /*----------------------------------------------------------------------------*/
 /*!
- * \brief  Destroy all structures related to properties
+ * \brief  Set a cs_def_t structure
+ *
+ * \param[in]      def_type   type of definition (by value, function...)
+ * \param[in]      var_type   type of variables (scalar, vector, tensor...)
+ * \param[in]      val        value to set
+ * \param[in, out] def        pointer to cs_def_t structure
  */
 /*----------------------------------------------------------------------------*/
 
 void
-cs_param_pty_free_all(void);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Retrieve a cs_param_pty_t structure from its id
- *
- * \param[in]  pty_id   id related to a property
- *
- * \return a pointer to a cs_param_pty_t
- */
-/*----------------------------------------------------------------------------*/
-
-cs_param_pty_t *
-cs_param_pty_get(int  pty_id);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Find the id related to a property definition from its name
- *
- * \param[in]  ref_name    name of the property to find
- *
- * \return -1 if not found otherwise the associated id
- */
-/*----------------------------------------------------------------------------*/
-
-int
-cs_param_pty_get_id_by_name(const char  *ref_name);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Add by default several material properties
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_param_pty_set_default(void);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Create and intialize a material property
- *
- * \param[in]  name        name of the material property
- * \param[in]  type        type of behavior of this material property
- * \param[in]  post_freq   -1 (no post-processing), 0 (at the beginning)
- *                         otherwise every post_freq iteration(s)
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_param_pty_add(const char             *name,
-                 cs_param_pty_type_t     type,
-                 int                     post_freq);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Create a field related to a material property
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_param_pty_add_fields(void);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Define a material property by value
- *
- * \param[in]  name      name of the material property
- * \param[in]  matval    value to set
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_param_pty_set_by_val(const char   *name,
-                        cs_get_t      matval);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Define a material property by an analytical function
- *
- * \param[in]  name       name of the material property
- * \param[in]  analytic   pointer to a cs_analytic_func_t
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_param_pty_set_by_analytic_func(const char          *name,
-                                  cs_analytic_func_t  *analytic_func);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Query to know if the material property is uniform
- *
- * \param[in]    pty_id    id related to the material property to deal with
- *
- * \return  true or false
- */
-/*----------------------------------------------------------------------------*/
-
-bool
-cs_param_pty_is_uniform(int       pty_id);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Retrieve the name of a material property from its id
- *
- * \param[in]    pty_id    id related to the material property to deal with
- *
- * \return  the name of the related property
- */
-/*----------------------------------------------------------------------------*/
-
-const char *
-cs_param_pty_get_name(int            pty_id);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Retrieve the 3x3 matrix related to a general material property.
- *         This value is computed at location (x,y,z) and time t.
- *
- * \param[in]    pty_id    id related to the material property to deal with
- * \param[in]    t         time at which we evaluate the material property
- * \param[in]    xyz       location at which  we evaluate the material property
- * \param[in]    invers    true or false
- * \param[inout] matval    pointer to the 3x3 matrix to return
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_param_pty_get_val(int            pty_id,
-                     cs_real_t      t,
-                     cs_real_3_t    xyz,
-                     bool           invers,
-                     cs_real_33_t  *matval);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Resume all the cs_param_pty_t structures
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_param_pty_resume_all(void);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Free structures dedicated to the definition of material properties
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_param_pty_finalize(void);
+cs_param_set_def(cs_param_def_type_t      def_type,
+                 cs_param_var_type_t      var_type,
+                 const void              *val,
+                 cs_def_t                *def);
 
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief  Allocate and initialize a new cs_param_bc_t structure
  *
  * \param[in]  default_bc     default boundary condition
- * \param[in]  is_penalized   true/false
  *
  * \return a pointer to the new structure (free with cs_param_eq_t)
  */
 /*----------------------------------------------------------------------------*/
 
 cs_param_bc_t *
-cs_param_bc_create(cs_param_bc_type_t  default_bc,
-                   bool                is_penalized);
+cs_param_bc_create(cs_param_bc_type_t  default_bc);
 
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief  Set a cs_param_bc_def_t structure
  *
- * \param[inout] bc_def     pointer to cs_param_bc_def_t struct. to set
- * \param[in]    loc_id     id related to a cs_mesh_location_t
- * \param[in]    bc_type    generic type of admissible boundary conditions
- * \param[in]    def_type   by value, function...
- * \param[in]    def_coef1  access to the value of the first coef
- * \param[in]    def_coef2  access to the value of the second coef (optional)
+ * \param[in, out] bcpd       pointer to cs_param_bc_def_t struct. to set
+ * \param[in]      loc_id     id related to a cs_mesh_location_t
+ * \param[in]      bc_type    generic type of admissible boundary conditions
+ * \param[in]      var_type   type of variables (scalar, vector, tensor...)
+ * \param[in]      def_type   by value, function...
+ * \param[in]      coef1      access to the value of the first coef
+ * \param[in]      coef2      access to the value of the second coef (optional)
  */
 /*----------------------------------------------------------------------------*/
 
 void
-cs_param_bc_def_set(cs_param_bc_def_t     *bc_def,
-                    int                    loc_id,
-                    cs_param_bc_type_t     bc_type,
-                    cs_param_def_type_t    def_type,
-                    cs_def_t               def_coef1,
-                    cs_def_t               def_coef2);
+cs_param_bc_def_set(cs_param_bc_def_t      *bcpd,
+                    int                     loc_id,
+                    cs_param_bc_type_t      bc_type,
+                    cs_param_var_type_t     var_type,
+                    cs_param_def_type_t     def_type,
+                    const void             *coef1,
+                    const void             *coef2);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Define a new reaction term. The structure related to this reaction
+ *         term has already been allocated among the list of reaction terms
+ *         associated to an equation
+ *
+ * \param[in, out] rp         pointer to cs_param_reaction_t structure
+ * \param[in]      r_name     name of the reaction term
+ * \param[in]      h_type     type of discrete Hodge op. associated to this term
+ * \param[in]      h_algo     algorithm used to build the discrete Hodge op.
+ * \param[in]      r_type     type of reaction term
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_param_reaction_add(cs_param_reaction_t          *rp,
+                      const char                   *r_name,
+                      cs_param_hodge_type_t         h_type,
+                      cs_param_hodge_algo_t         h_algo,
+                      cs_param_source_term_type_t   r_type);
 
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief  Define a source term. This source term is added to the list of
  *         source terms associated to an equation
  *
- * \param[inout] st         pointer to the cs_param_source_term_t struc. to set
- * \param[in]    st_name    name of the source term (for log/post-processing)
- * \param[in]    ml_id      id related to a cs_mesh_location_t
- * \param[in]    type       type of source term
- * \param[in]    var_type   type of variables (scalar, vector, tensor...)
- * \param[in]    quad_type  type of quadrature rule to use
- * \param[in]    def_type   type of definition (by value, function...)
- * \param[in]    imp_def    access to the definition of the implicit part
- * \param[in]    exp-def    access to the definition of the explicit part
+ * \param[in, out] stp        pointer to cs_param_source_term_t structure
+ * \param[in]      st_name    name of the source term
+ * \param[in]      ml_id      id of the related to a cs_mesh_location_t struct.
+ * \param[in]      type       type of source term
+ * \param[in]      var_type   type of variables (scalar, vector, tensor...)
+ * \param[in]      quad_type  type of quadrature rule to use
+ * \param[in]      def_type   type of definition (by value, function...)
+ * \param[in]      val        access to the definition of the source term
  */
 /*----------------------------------------------------------------------------*/
 
 void
-cs_param_source_term_add(cs_param_source_term_t       *st,
+cs_param_source_term_add(cs_param_source_term_t       *stp,
                          const char                   *st_name,
                          int                           ml_id,
                          cs_param_source_term_type_t   type,
                          cs_param_var_type_t           var_type,
                          cs_quadra_type_t              quad_type,
                          cs_param_def_type_t           def_type,
-                         cs_def_t                      imp_def,
-                         cs_def_t                      exp_def);
+                         const void                   *val);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Get the name related to a reaction term
+ *
+ * \param[in] r_info     cs_param_reaction_t structure
+ *
+ * \return the name of the reaction term
+ */
+/*----------------------------------------------------------------------------*/
+
+const char *
+cs_param_reaction_get_name(const cs_param_reaction_t   r_info);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Get the name of the type of reaction term
+ *
+ * \param[in] r_info     set of parameters related to a reaction term
+ *
+ * \return the name associated with this type of reaction term
+ */
+/*----------------------------------------------------------------------------*/
+
+const char *
+cs_param_reaction_get_type_name(cs_param_reaction_t  r_info);
 
 /*----------------------------------------------------------------------------*/
 /*!
@@ -553,11 +529,11 @@ cs_param_source_term_get_name(const cs_param_source_term_t   st_info);
 
 /*----------------------------------------------------------------------------*/
 /*!
- * \brief   Get the name related to a source term
+ * \brief   Get the name of type of a given source term structure
  *
  * \param[in] st_info     cs_param_source_term_t structure
  *
- * \return the name of the source term
+ * \return  the name of the type
  */
 /*----------------------------------------------------------------------------*/
 
@@ -631,17 +607,42 @@ cs_param_get_solver_name(cs_param_itsol_type_t  solver);
 
 /*----------------------------------------------------------------------------*/
 /*!
- * \brief   Get the name of the preconditionner
+ * \brief   Get the name of the preconditioner
  *
- * \param[in] precond     type of preconditionner
+ * \param[in] precond     type of preconditioner
  *
- * \return the associated preconditionner name
+ * \return the associated preconditioner name
  */
 /*----------------------------------------------------------------------------*/
 
 const char *
 cs_param_get_precond_name(cs_param_precond_type_t  precond);
 
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Get the name of the type of boundary condition
+ *
+ * \param[in] bc          type of boundary condition
+ *
+ * \return the associated bc name
+ */
+/*----------------------------------------------------------------------------*/
+
+const char *
+cs_param_get_bc_name(cs_param_bc_type_t  bc);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Get the name of the type of enforcement of the boundary condition
+ *
+ * \param[in] type          type of enforcement of boundary conditions
+ *
+ * \return the associated name
+ */
+/*----------------------------------------------------------------------------*/
+
+const char *
+cs_param_get_bc_enforcement_name(cs_param_bc_enforce_t  type);
 
 /*----------------------------------------------------------------------------*/
 
