@@ -51,9 +51,10 @@ BEGIN_C_DECLS
  *============================================================================*/
 
 /* Matrix flag */
-#define  CS_SLA_MATRIX_SYM        (1 <<  0)  /*    1: symmetric */
-#define  CS_SLA_MATRIX_SORTED     (1 <<  1)  /*    2: sorted */
-#define  CS_SLA_MATRIX_SHARED     (1 <<  2)  /*    4: share pattern */
+#define  CS_SLA_MATRIX_SYM        (1 <<  0)  /* 1: symmetric */
+#define  CS_SLA_MATRIX_SORTED     (1 <<  1)  /* 2: sorted */
+#define  CS_SLA_MATRIX_SHARED     (1 <<  2)  /* 4: share pattern */
+#define  CS_SLA_MATRIX_INFO       (1 <<  3)  /* 8: info struct. is set */
 
 /*============================================================================
  * Type definitions for matrices
@@ -82,13 +83,11 @@ typedef struct {
 
 } cs_sla_matrix_info_t;
 
-typedef struct _sla_mat_prop_t cs_sla_mat_prop_t; /* Private definition */
-
 typedef struct {
 
-  cs_sla_matrix_type_t   type;
-  cs_sla_mat_prop_t     *properties;
-  int                    flag;       /* Symmetric, sorted, shared... */
+  cs_sla_matrix_type_t   type;  /* Type of matrix storage */
+  cs_sla_matrix_info_t   info;  /* Information on how matrix is filled */
+  int                    flag;  /* Symmetric, sorted, shared... */
 
   int     stride;   /* Number of entries in "val" for each couple A(i,j) */
   int     n_rows;
@@ -119,281 +118,10 @@ typedef struct {
 
 } cs_sla_sumup_t;
 
-
 /*============================================================================
  * Public function prototypes for SLA matrices
  *============================================================================*/
 
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Write in binary format a matrix in CSR format, its righ hand side
- *         and the solution
- *
- * \param[in]     name      name of the output file
- * \param[in]     A         system to solve
- * \param[in]     rhs       right hand side
- * \param[in]     x         solution
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_sla_bwrite(const char            *name,
-              const cs_sla_matrix_t *m,
-              const double          *rhs,
-              const double          *sol);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief  Read from a binary file a matrix in CSR format, its righ hand side
- *         and the solution. Matrix must have a stride equal to 1.
- *
- * \param[in]     name      name of the output file
- * \param[inout]  p_mat     system to solve
- * \param[inout]  p_rhs     right hand side
- * \param[inout]  p_sol       solution
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_sla_bread(const char        *name,
-             cs_sla_matrix_t  **p_mat,
-             double            *p_rhs[],
-             double            *p_sol[]);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Change matrix representation from MSR to CSR
- *
- * \param[inout] a     matrix to transform
- *
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_sla_matrix_msr2csr(cs_sla_matrix_t  *a);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Change matrix representation from CSR to MSR
- *
- * \param[inout] a     matrix to transform
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_sla_matrix_csr2msr(cs_sla_matrix_t  *a);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Allocate its own pattern if shared
- *
- * \param[inout] a     matrix to transform
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_sla_matrix_share2own(cs_sla_matrix_t  *a);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Build a new matrix resulting from the extraction of some listed
- *          rows and columns. The output is a new matrix packed (or zipped)
- *          w.r.t the initial matrix.
- *
- * \param[in]  n_final_rows   number of rows to extract
- * \param[in]  n_final_cols   number of columns to extract
- * \param[in]  init           init matrix to work with
- * \param[in]  row_z2i_ids    zipped -> initial ids for rows
- * \param[in]  col_i2z_ids    initial-> zipped ids for columns (-1 ==> remove)
- * \param[in]  keep_sym       true or false
- *
- * \return a pointer to the new (packed) matrix structure
- */
-/*----------------------------------------------------------------------------*/
-
-cs_sla_matrix_t *
-cs_sla_matrix_pack(cs_lnum_t                n_final_rows,
-                   cs_lnum_t                n_final_cols,
-                   const cs_sla_matrix_t   *init,
-                   const cs_lnum_t         *row_z2i_ids,
-                   const cs_lnum_t         *col_i2z_ids,
-                   bool                     keep_sym);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Build diagonal index
- *
- * \param[inout]  m   matrix to work with
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_sla_matrix_diag_idx(cs_sla_matrix_t    *m);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Get the diagonal entries of a given matrix.
- *
- * \param[in]    m        matrix to work with
- * \param[inout] p_diag   pointer to diag array to define (allocated if NULL)
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_sla_matrix_get_diag(const cs_sla_matrix_t  *m,
-                       double                 *p_diag[]);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Sort each row by increasing colomn number
- *
- * \param[in]  mat     matrix to sort
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_sla_matrix_sort(cs_sla_matrix_t  *m);
-
-/*----------------------------------------------------------------------------
- * Create a new matrix from a block description (not done for all matrix
- * combinations, see below).
- *
- *     |A | B|
- * M = |--|--|
- *     |C | D|
- *----------------------------------------------------------------------------*/
-
-cs_sla_matrix_t *
-cs_sla_block2mat(cs_sla_matrix_t         *A,
-                 const cs_sla_matrix_t   *B,
-                 const cs_sla_matrix_t   *C,
-                 const cs_sla_matrix_t   *D,
-                 bool                     sym);
-
-/* Operations on matrices */
-void cs_sla_matvec(const cs_sla_matrix_t *m,
-                   const double           v[],
-                   double                *inout[],
-                   bool                   reset);
-
-void cs_sla_amxby(double                  alpha,
-                  const cs_sla_matrix_t  *m,
-                  const double            x[],
-                  double                  beta,
-                  const double            y[],
-                  double                 *inout[]);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Matrix block 2x2 multiply by a vector
- *
- *              | A  B | |X| = |F|= |AX + BY|
- *              | C  D | |Y|   |G|  |CX + DY|
- *
- * \param[in]    A     pointer to a cs_sla_matrix_t block (1,1)
- * \param[in]    B     pointer to a cs_sla_matrix_t block (1,2)
- * \param[in]    C     pointer to a cs_sla_matrix_t block (2,1)
- * \param[in]    D     pointer to a cs_sla_matrix_t block (2,2)
- * \param[in]    X     upper vector
- * \param[in]    Y     lower vector
- * \param[inout] F     upper result
- * \param[inout] G     lower result
- * \param[in]    reset reset before computation (true/false)
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_sla_matvec_block2(const cs_sla_matrix_t  *A,
-                     const cs_sla_matrix_t  *B,
-                     const cs_sla_matrix_t  *C,
-                     const cs_sla_matrix_t  *D,
-                     const double            X[],
-                     const double            Y[],
-                     double                 *F[],
-                     double                 *G[],
-                     bool                    reset);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Add two sparse matrices a and b. c = alpha*a + beta*b
- *
- * \param[in]  alpha   first coef.
- * \param[in]  a       first matrix to add
- * \param[in]  beta    second coef.
- * \param[in]  b       second matrix to add
- *
- * \return  a pointer to the resulting matrix
- */
-/*----------------------------------------------------------------------------*/
-
-cs_sla_matrix_t *
-cs_sla_matrix_add(double                  alpha,
-                  const cs_sla_matrix_t  *a,
-                  double                  beta,
-                  const cs_sla_matrix_t  *b);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Main subroutine to multiply two sparse matrices a and b. c= a*b
- *
- * \param[in]  a     first matrix to multiply
- * \param[in]  b     second matrix to multiply
- *
- * \return  a pointer to the resulting matrix
- */
-/*----------------------------------------------------------------------------*/
-
-cs_sla_matrix_t *
-cs_sla_matrix_multiply(const cs_sla_matrix_t   *a,
-                       const cs_sla_matrix_t   *b);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Specific matrix multiplication. Compute Bt * beta * B + alpha * A
- *          alpha and beta are scalar
- *
- * \param[in] alpha     real coefficient
- * \param[in] a         square sym. matrix
- * \param[in] beta      real coefficient
- * \param[in] b         matrix (CSR or DEC)
- * \param[in] bt        adjoint matrix of b
- *
- * \return the matrix corresponding to this operation
- */
-/*----------------------------------------------------------------------------*/
-
-cs_sla_matrix_t *
-cs_sla_matrix_combine(double                  alpha,
-                      const cs_sla_matrix_t  *a,
-                      double                  beta,
-                      const cs_sla_matrix_t  *bt,
-                      const cs_sla_matrix_t  *b);
-
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Compute the product C = At * Diag * A
- *
- * \param[in]     At   pointer to a cs_sla_matrix_t struct. (DEC type)
- * \param[in]     D    array standing for a diagonal operator
- * \param[in]     A    pointer to a cs_sla_matrix_t struct. (DEC type)
- * \param[inout]  w    work buffer
- *
- * \return a pointer to a new cs_sla_matrix_t
- */
-/*----------------------------------------------------------------------------*/
-
-cs_sla_matrix_t * cs_sla_multiply_AtDA(const cs_sla_matrix_t   *At,
-                                       const double             D[],
-                                       const cs_sla_matrix_t   *A,
-                                       int                     *w);
-
-int cs_sla_get_mat_spectral_radius(const cs_sla_matrix_t  *matrix,
-                                   int                    iter_max,
-                                   double                 epsilon,
-                                   double                *lambda);
-
-double cs_sla_get_matrix_norm(const cs_sla_matrix_t  *m);
-
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief   Create a cs_sla_matrix_t structure
@@ -409,28 +137,52 @@ double cs_sla_get_matrix_norm(const cs_sla_matrix_t  *m);
 /*----------------------------------------------------------------------------*/
 
 cs_sla_matrix_t *
-cs_sla_matrix_create(int                   n_rows,
-                     int                   n_cols,
+cs_sla_matrix_create(cs_lnum_t             n_rows,
+                     cs_lnum_t             n_cols,
                      int                   stride,
                      cs_sla_matrix_type_t  type,
                      bool                  sym);
 
 /*----------------------------------------------------------------------------*/
 /*!
- * \brief   Create a cs_sla_matrix_t structure from an existing one
+ * \brief   Create a cs_sla_matrix_t structure from an existing one.
+ *          idx, didx and col_id are shared with ref.
+ *          Initialize related buffers.
  *
  * \param[in]  ref      pointer to a reference matrix with the same pattern
  * \param[in]  type     type of the matrix to create
- * \param[in]  stride   number of values associated to each entry
+ * \param[in]  stride   number of values for each entry
  *
  * \return  a pointer to new allocated matrix structure
  */
 /*----------------------------------------------------------------------------*/
 
 cs_sla_matrix_t *
-cs_sla_matrix_create_from_pattern(const cs_sla_matrix_t  *ref,
-                                  cs_sla_matrix_type_t    type,
-                                  int                     stride);
+cs_sla_matrix_create_from_ref(const cs_sla_matrix_t  *ref,
+                              cs_sla_matrix_type_t    type,
+                              int                     stride);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Create a cs_sla_matrix_t structure with MSR type from an existing
+ *          connectivity index.
+ *          Be aware of removing the diagonal entry in the connectivity index
+ *          before the call to this routine.
+ *
+ * \param[in]  connect_idx     pointer to a connectivity index
+ * \param[in]  is_symmetric    true or false
+ * \param[in]  sorted_idx      true if the connectivity index is sorted
+ * \param[in]  stride          number of values for each entry
+ *
+ * \return  a pointer to new (shared) matrix structure
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_sla_matrix_t *
+cs_sla_matrix_create_msr_from_index(const cs_connect_index_t   *connect_idx,
+                                    bool                        is_symmetric,
+                                    bool                        sorted_idx,
+                                    int                         stride);
 
 /*----------------------------------------------------------------------------*/
 /*!
@@ -473,13 +225,27 @@ cs_sla_matrix_transpose(const cs_sla_matrix_t  *mat);
 cs_sla_matrix_t *
 cs_sla_matrix_free(cs_sla_matrix_t  *m);
 
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Remove entries with zero values
+ *          Only available for CSR and MSR matrices with stride = 1
+ *
+ * \param[in, out] m       matrix to clean
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_sla_matrix_rmzeros(cs_sla_matrix_t   *m);
+
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief   Remove entries in a cs_sla_matrix_t structure below a given
  *          threshold. |a(i,j)| < eps * max|a(i,j)|
+ *          Be careful when using this function since one can loose the symmetry
+ *          Only available for matrices with stride = 1
  *
- * \param[inout]  mat     matrix to clean
- * \param[in]     eps     value of the threshold
+ * \param[in, out] m       matrix to clean
+ * \param[in]      eps     value of the threshold
  */
 /*----------------------------------------------------------------------------*/
 
@@ -491,7 +257,7 @@ cs_sla_matrix_clean(cs_sla_matrix_t   *m,
 /*!
  * \brief   Retrieve the number of non-zeros (nnz) elements in a matrix
  *
- * \param[in]  mat     matrix
+ * \param[in]  m       matrix
  *
  * \return the number of nnz
  */
@@ -502,53 +268,360 @@ cs_sla_matrix_get_nnz(const cs_sla_matrix_t   *m);
 
 /*----------------------------------------------------------------------------*/
 /*!
- * \brief   Compute general information related to a cs_sla_matrix_t structure
+ * \brief   Build diagonal index
  *
- * \param[in]  m           matrix to analyse
+ * \param[in, out]  m   matrix to work with
  */
 /*----------------------------------------------------------------------------*/
 
-cs_sla_matrix_info_t
-cs_sla_matrix_analyse(const cs_sla_matrix_t   *m);
+void
+cs_sla_matrix_diag_idx(cs_sla_matrix_t    *m);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Get the diagonal entries of a given matrix.
+ *
+ * \param[in]      m        matrix to work with
+ * \param[in, out] p_diag   pointer to diag array to define (allocated if NULL)
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_sla_matrix_get_diag(const cs_sla_matrix_t  *m,
+                       double                 *p_diag[]);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Sort each row by increasing colomn number
+ *
+ * \param[in]  m       matrix to sort
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_sla_matrix_sort(cs_sla_matrix_t  *m);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Compute general information related to a cs_sla_matrix_t structure
+ *          and store it into a cs_sla_matrix_info_t structure
+ *
+ * \param[in, out]  m           matrix to analyse
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_sla_matrix_set_info(cs_sla_matrix_t    *m);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Change matrix representation from MSR to CSR
+ *
+ * \param[in, out] a     matrix to transform
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_sla_matrix_msr2csr(cs_sla_matrix_t  *a);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Change matrix representation from CSR to MSR
+ *
+ * \param[in, out] a     matrix to transform
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_sla_matrix_csr2msr(cs_sla_matrix_t  *a);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Allocate its own pattern if shared
+ *
+ * \param[in, out] a     matrix to transform
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_sla_matrix_share2own(cs_sla_matrix_t  *a);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Assemble a MSR matrix from local contributions
+ *          --> We assume that the local matrices are symmetric
+ *          --> We assume that the assembled matrix has its columns sorted
+ *
+ * \param[in]       loc        pointer to a local matrix
+ * \param[in, out]  ass        pointer to a cs_sla_matrix_t struct.
+ * \param[in]       only_diag  true if assembly is only for diagonal terms
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_sla_assemble_msr_sym(const cs_locmat_t  *loc,
+                        cs_sla_matrix_t    *ass,
+                        bool                only_diag);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Assemble a MSR matrix from local contributions
+ *          --> We assume that the assembled matrix has its columns sorted
+ *
+ * \param[in]       loc     pointer to a local matrix
+ * \param[in, out]  ass     pointer to a cs_sla_matrix_t struct. collecting data
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_sla_assemble_msr(const cs_locmat_t  *loc,
+                    cs_sla_matrix_t    *ass);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Build a new matrix resulting from the extraction of some listed
+ *          rows and columns. The output is a new matrix packed (or zipped)
+ *          w.r.t the initial matrix.
+ *
+ * \param[in]  n_final_rows   number of rows to extract
+ * \param[in]  n_final_cols   number of columns to extract
+ * \param[in]  init           init matrix to work with
+ * \param[in]  row_z2i_ids    zipped -> initial ids for rows
+ * \param[in]  col_i2z_ids    initial-> zipped ids for columns (-1 ==> remove)
+ * \param[in]  keep_sym       true or false
+ *
+ * \return a pointer to the new (packed) matrix structure
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_sla_matrix_t *
+cs_sla_matrix_pack(cs_lnum_t                n_final_rows,
+                   cs_lnum_t                n_final_cols,
+                   const cs_sla_matrix_t   *init,
+                   const cs_lnum_t         *row_z2i_ids,
+                   const cs_lnum_t         *col_i2z_ids,
+                   bool                     keep_sym);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Add two sparse matrices a and b. c = alpha*a + beta*b
+ *
+ * \param[in]  alpha   first coef.
+ * \param[in]  a       first matrix to add
+ * \param[in]  beta    second coef.
+ * \param[in]  b       second matrix to add
+ *
+ * \return  a pointer to the resulting matrix
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_sla_matrix_t *
+cs_sla_matrix_add(double                  alpha,
+                  const cs_sla_matrix_t  *a,
+                  double                  beta,
+                  const cs_sla_matrix_t  *b);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Compute a matrix vector product.
+ *         If inout is not allocated, allocation is done inside this function
+ *         If reset is set to true, initialization inout to 0
+ *
+ * \param[in]       m        pointer to a cs_sla_matrix_t structure
+ * \param[in]       v        pointer to an array of double
+ * \param[in, out]  inout    pointer to a pointer of double
+ * \param[in]       reset    if true, first initialize inout to zero
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_sla_matvec(const cs_sla_matrix_t *m,
+              const double           v[],
+              double                *inout[],
+              bool                   reset);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Compute an array resulting from alpha * M(x) + beta * y
+ *         If inout is not allocated, allocation is done inside this function
+ *
+ * \param[in]       alpha    multiplicative coefficient
+ * \param[in]       m        pointer to a cs_sla_matrix_t structure
+ * \param[in]       x        pointer to an array of double
+ * \param[in]       beta     multiplicative coefficient
+ * \param[in]       y        pointer to an array of double
+ * \param[in, out]  inout    pointer to a pointer of double
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_sla_amxby(double                  alpha,
+             const cs_sla_matrix_t  *m,
+             const double            x[],
+             double                  beta,
+             const double            y[],
+             double                 *inout[]);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Main subroutine to multiply two sparse matrices a and b. c= a*b
+ *
+ * \param[in]  a     first matrix to multiply
+ * \param[in]  b     second matrix to multiply
+ *
+ * \return  a pointer to the resulting matrix
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_sla_matrix_t *
+cs_sla_matrix_multiply(const cs_sla_matrix_t   *a,
+                       const cs_sla_matrix_t   *b);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Compute the product C = At * Diag * A
+ *
+ * \param[in]       At   pointer to a cs_sla_matrix_t struct. (DEC type)
+ * \param[in]       D    array standing for a diagonal operator
+ * \param[in]       A    pointer to a cs_sla_matrix_t struct. (DEC type)
+ * \param[in, out]  w    work buffer
+ *
+ * \return a pointer to a new cs_sla_matrix_t
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_sla_matrix_t *
+cs_sla_multiply_AtDA(const cs_sla_matrix_t   *At,
+                     const double             D[],
+                     const cs_sla_matrix_t   *A,
+                     cs_lnum_t               *w);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Specific matrix multiplication. Compute Bt * beta * B + alpha * A
+ *          where alpha and beta are scalar
+ *
+ * \param[in] alpha     real coefficient
+ * \param[in] a         square sym. matrix
+ * \param[in] beta      real coefficient
+ * \param[in] b         matrix (CSR or DEC)
+ * \param[in] bt        adjoint matrix of b
+ *
+ * \return the matrix corresponding to this operation
+ */
+/*----------------------------------------------------------------------------*/
+
+cs_sla_matrix_t *
+cs_sla_matrix_combine(double                  alpha,
+                      const cs_sla_matrix_t  *a,
+                      double                  beta,
+                      const cs_sla_matrix_t  *bt,
+                      const cs_sla_matrix_t  *b);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief   Matrix block 2x2 multiply by a vector
+ *
+ *              | A  B | |X| = |F|= |AX + BY|
+ *              | C  D | |Y|   |G|  |CX + DY|
+ *
+ * \param[in]      A     pointer to a cs_sla_matrix_t block (1,1)
+ * \param[in]      B     pointer to a cs_sla_matrix_t block (1,2)
+ * \param[in]      C     pointer to a cs_sla_matrix_t block (2,1)
+ * \param[in]      D     pointer to a cs_sla_matrix_t block (2,2)
+ * \param[in]      X     upper vector
+ * \param[in]      Y     lower vector
+ * \param[in, out] F     upper result
+ * \param[in, out] G     lower result
+ * \param[in]      reset reset before computation (true/false)
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_sla_matvec_block2(const cs_sla_matrix_t  *A,
+                     const cs_sla_matrix_t  *B,
+                     const cs_sla_matrix_t  *C,
+                     const cs_sla_matrix_t  *D,
+                     const double            X[],
+                     const double            Y[],
+                     double                 *F[],
+                     double                 *G[],
+                     bool                    reset);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Write in binary format a matrix in CSR format, its righ hand side
+ *         and the solution
+ *
+ * \param[in]     name      name of the output file
+ * \param[in]     m         system to solve
+ * \param[in]     rhs       right hand side
+ * \param[in]     sol       solution
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_sla_bwrite(const char            *name,
+              const cs_sla_matrix_t *m,
+              const double          *rhs,
+              const double          *sol);
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief  Read from a binary file a matrix in CSR format, its righ hand side
+ *         and the solution. Matrix must have a stride equal to 1.
+ *
+ * \param[in]       name      name of the output file
+ * \param[in, out]  p_mat     system to solve
+ * \param[in, out]  p_rhs     right hand side
+ * \param[in, out]  p_sol       solution
+ */
+/*----------------------------------------------------------------------------*/
+
+void
+cs_sla_bread(const char        *name,
+             cs_sla_matrix_t  **p_mat,
+             double            *p_rhs[],
+             double            *p_sol[]);
 
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief   Synthesis of a cs_sla_matrix_t structure
  *
- * \param[in]  name        either name of the file if f is NULL or description
- * \param[in]  f           pointer to a FILE struct.
- * \param[in]  m           matrix to dump
+ * \param[in]       name   either name of the file if f is NULL or description
+ * \param[in]       f      pointer to a FILE struct.
+ * \param[in, out]  m      matrix to dump (info can be computed inside)
  */
 /*----------------------------------------------------------------------------*/
 
 void
-cs_sla_matrix_resume(const char              *name,
-                     FILE                    *f,
-                     const cs_sla_matrix_t   *m);
+cs_sla_matrix_summary(const char        *name,
+                      FILE              *f,
+                      cs_sla_matrix_t   *m);
 
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief   Dump a cs_sla_matrix_t structure
  *
- * \param[in]  name        either name of the file if f is NULL or description
- * \param[in]  f           pointer to a FILE struct.
- * \param[in]  m           matrix to dump
+ * \param[in]  name    either name of the file if f is NULL or description
+ * \param[in]  f       pointer to a FILE struct.
+ * \param[in]  m       matrix to dump
  */
 /*----------------------------------------------------------------------------*/
 
 void
-cs_sla_matrix_dump(const char              *name,
-                   FILE                    *f,
-                   const cs_sla_matrix_t   *m);
+cs_sla_matrix_dump(const char             *name,
+                   FILE                   *f,
+                   const cs_sla_matrix_t  *m);
 
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief   Dump a cs_sla_matrix_t structure and its related right-hand side
  *
- * \param[in]  name        either name of the file if f is NULL or description
- * \param[in]  f           pointer to a FILE struct.
- * \param[in]  m           matrix to dump
- * \param[in]  rhs         right-hand side to dump
+ * \param[in]  name    either name of the file if f is NULL or description
+ * \param[in]  f       pointer to a FILE struct.
+ * \param[in]  m       matrix to dump
+ * \param[in]  rhs     right-hand side to dump
  */
 /*----------------------------------------------------------------------------*/
 
@@ -558,21 +631,6 @@ cs_sla_system_dump(const char              *name,
                    const cs_sla_matrix_t   *m,
                    const double            *rhs);
 
-/*----------------------------------------------------------------------------*/
-/*!
- * \brief   Assemble a MSR matrix from local contributions
- *          --> We assume that the local matrices are symmetric
- *          --> We assume that the assembled matrix has its columns sorted
- *
- * \param[in]     loc     pointer to a local matrix
- * \param[inout]  ass     pointer to a cs_sla_matrix_t struct. collecting data
- */
-/*----------------------------------------------------------------------------*/
-
-void
-cs_sla_assemble_msr(const cs_toolbox_locmat_t  *loc,
-                    cs_sla_matrix_t            *ass);
-
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
