@@ -41,22 +41,18 @@
 !> \param[in]     icetsm        index of cells with mass source term
 !> \param[in]     itypsm        type of mass source term for the variables
 !> \param[in]     dt            time step (per cell)
-!> \param[in,out] propce        physical properties at cell centers
 !> \param[in]     ckupdc        work array for the head loss
 !> \param[in]     smacel        variable value associated to the mass source
 !>                               term (for ivar=ipr, smacel is the mass flux
 !>                               \f$ \Gamma^n \f$)
-!> \param[in]     viscf         visc*surface/dist at internal faces
-!> \param[in]     viscb         visc*surface/dist at boundary faces
 !_______________________________________________________________________________
 
 subroutine cfener &
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    iscal  ,                                                       &
    icepdc , icetsm , itypsm ,                                     &
-   dt     , propce ,                                              &
-   ckupdc , smacel ,                                              &
-   viscf  , viscb  )
+   dt     ,                                                       &
+   ckupdc , smacel )
 
 !===============================================================================
 
@@ -65,6 +61,7 @@ subroutine cfener &
 !===============================================================================
 
 use paramx
+use pointe, only:rvoid1
 use numvar
 use entsor
 use optcal
@@ -78,6 +75,9 @@ use ppincl
 use cfpoin
 use mesh
 use field
+use field_operator
+use cs_c_bindings
+use cs_cf_bindings
 
 !===============================================================================
 
@@ -91,18 +91,17 @@ integer          iscal
 
 integer          icepdc(ncepdp)
 integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
+integer          use_previous
 
 double precision dt(ncelet)
-double precision propce(ncelet,*)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
-double precision viscf(nfac), viscb(nfabor)
 
 ! Local variables
 
 character(len=80) :: chaine
-integer          ivar
+integer          ivar  , ivarsp, iesp
 integer          ifac  , iel
-integer          init  , isqrt , iii
+integer          init  , iii
 integer          ifcvsl, iflmas, iflmab
 integer          icvflb
 integer          nswrgp, imligp, iwarnp
@@ -112,34 +111,40 @@ double precision epsrgp, climgp, extrap, blencp, epsilp
 double precision sclnor, thetap, epsrsp, relaxp
 
 integer          inc    , iccocg , imucpp , idftnp , iswdyp
-integer          ivar0  , ii , jj
+integer          f_id0  , ii, jj
 integer          iel1  , iel2
-integer          iterns
+integer          iterns, irecpt
 
-double precision flux
+double precision flux, flui, fluj, yip, yjp, gradnb, tip
 double precision dijpfx, dijpfy, dijpfz, pnd  , pip   , pjp
 double precision diipfx, diipfy, diipfz, djjpfx, djjpfy, djjpfz
 
+double precision mk, cpk, cvk
 double precision rvoid(1)
 
-double precision, allocatable, dimension(:) :: wb
+double precision, allocatable, dimension(:) :: wb, iprtfl, bprtfl, viscf, viscb
+double precision, allocatable, dimension(:) :: viscfk, viscbk
 double precision, allocatable, dimension(:) :: dpvar, smbrs, rovsdt
 double precision, allocatable, dimension(:,:) :: grad
-double precision, allocatable, dimension(:) :: w1
-double precision, allocatable, dimension(:) :: w4, w5, w6
-double precision, allocatable, dimension(:) :: w7, w8, w9
+double precision, allocatable, dimension(:) :: grad_dd
+double precision, allocatable, dimension(:) :: gapinj
+double precision, allocatable, dimension(:) :: w1, w7, w9
+double precision, allocatable, dimension(:) :: kspe, btemp
 
 double precision, dimension(:), pointer :: imasfl, bmasfl
 double precision, dimension(:), pointer :: brom, crom, cromo
 double precision, dimension(:,:), pointer :: coefau
 double precision, dimension(:,:,:), pointer :: coefbu
+double precision, dimension(:), pointer :: coefat, coefbt, coefayk, coefbyk
 double precision, dimension(:), pointer :: coefap, coefbp, cofafp, cofbfp
 double precision, dimension(:), pointer :: coefa_p, coefb_p
 double precision, dimension(:,:), pointer :: vel
 
 double precision, dimension(:), pointer :: cvar_pr, cvar_energ, cvara_energ
-double precision, dimension(:), pointer :: cvar_tempk
-double precision, dimension(:), pointer :: visct, cpro_cp, cpro_viscls
+double precision, dimension(:), pointer :: cvar_tempk, cvar_yk
+double precision, dimension(:), pointer :: visct, cpro_cp, cpro_cv, cpro_viscls
+
+type(gas_mix_species_prop) :: s_k
 
 !===============================================================================
 
@@ -152,8 +157,20 @@ call field_get_val_s(ivarfl(ivar), cvar_energ)
 call field_get_val_s(ivarfl(isca(itempk)), cvar_tempk)
 call field_get_val_v(ivarfl(iu), vel)
 
+if (icp.gt.0) then
+  call field_get_val_s(iprpfl(icp), cpro_cp)
+else
+  cpro_cp => rvoid1
+endif
+
+if (icv.gt.0) then
+  call field_get_val_s(iprpfl(icv), cpro_cv)
+else
+  cpro_cv => rvoid1
+endif
+
 !===============================================================================
-! 1. INITIALIZATION
+! 1. Initialization
 !===============================================================================
 
 ! Allocate a temporary array
@@ -161,14 +178,10 @@ allocate(wb(nfabor))
 allocate(smbrs(ncelet), rovsdt(ncelet))
 
 ! Allocate work arrays
-allocate(grad(ncelet,3))
-allocate(w1(ncelet))
-allocate(w4(ncelet), w5(ncelet), w6(ncelet))
-allocate(w7(ncelet), w8(ncelet), w9(ncelet))
+allocate(grad(3,ncelet))
+allocate(w7(ncelet), w9(ncelet))
 allocate(dpvar(ncelet))
 
-
-
 ! Physical property numbers
 call field_get_val_s(icrom, crom)
 call field_get_val_s(ibrom, brom)
@@ -196,7 +209,7 @@ if(iwarni(ivar).ge.1) then
 endif
 
 !===============================================================================
-! 2. SOURCE TERMS
+! 2. Source terms
 !===============================================================================
 
 ! Theta-scheme:
@@ -239,11 +252,13 @@ enddo
 !                                     inj
 if (ncesmp.gt.0) then
   iterns = 1
+  allocate(gapinj(ncelet))
   call catsma ( ncelet , ncel , ncesmp , iterns ,                              &
                 isno2t, thetav(ivar),                                          &
                 icetsm , itypsm(1,ivar),                                       &
-                volume , cvara_energ   , smacel(1,ivar),                       &
-                smacel(1,ipr) , smbrs , rovsdt , w1    )
+                cell_f_vol    , cvara_energ   , smacel(1,ivar),                &
+                smacel(1,ipr) , smbrs , rovsdt , gapinj)
+  deallocate(gapinj)
 endif
 
 
@@ -253,12 +268,12 @@ endif
 
 do iel = 1, ncel
   rovsdt(iel) = rovsdt(iel)                                                    &
-                + istat(ivar)*(cromo(iel)/dt(iel))*volume(iel)
+                + istat(ivar)*(cromo(iel)/dt(iel))*cell_f_vol(iel)
 enddo
 
 !                                       __        v
-!     TERME DE DISSIPATION VISQUEUS   : >  ((SIGMA *U).n)  *S
-!     ==============================    --               ij  ij
+!     VISCOUS DISSIPATION TERM        : >  ((SIGMA *U).n)  *S
+!     ========================          --               ij  ij
 
 if (idiff(iu).ge. 1) then
   call cfdivs(smbrs, vel)
@@ -268,100 +283,97 @@ endif
 ! PRESSURE TRANSPORT TERM  : - >  (---)  *(Q    .n)  *S
 ! =======================      --  RHO ij   pr     ij  ij
 
-do iel = 1, ncel
-  w9(iel) = crom(iel)
-enddo
+irecpt = 0
+allocate(iprtfl(nfac))
+allocate(bprtfl(nfabor))
 
-!     Avec Reconstruction : ca pose probleme pour l'instant
+if (irecpt.eq.1) then
 
-!   Calcul du gradient de P/RHO
+  ! With reconstruction: yields problems for now
 
-!      do iel = 1, ncel
-!        w7(iel) = cvar_pr(iel)/w9(iel)
-!      enddo
+  ! gradient of P/rho
 
-! Rq : A defaut de connaitre les parametres pour P/RHO on prend ceux de P
+  do iel = 1, ncel
+    w7(iel) = cvar_pr(iel)/crom(iel)
+  enddo
 
-!      iii = ipr
-!      inc = 1
-!      iccocg = 1
-!      nswrgp = nswrgr(iii)
-!      imligp = imligr(iii)
-!      iwarnp = iwarni(iii)
-!      epsrgp = epsrgr(iii)
-!      climgp = climgr(iii)
-!      extrap = extrag(iii)
+  ! Since we don't know the parameters for P/rho,
+  ! parameters of P are set.
 
-!       On alloue localement 2 tableaux de NFABOR pour le calcul
-!       de COEFA et COEFB de P/RHO
+  iii = ipr
+  inc = 1
+  iccocg = 1
+  nswrgp = nswrgr(iii)
+  imligp = imligr(iii)
+  iwarnp = iwarni(iii)
+  epsrgp = epsrgr(iii)
+  climgp = climgr(iii)
+  extrap = extrag(iii)
 
-!      allocate(coefap(nfabor))
-!      allocate(coefbp(nfabor))
+  allocate(coefap(nfabor))
+  allocate(coefbp(nfabor))
 
-!      do ifac = 1, nfabor
-!        coefap(ifac) = zero
-!        coefbp(ifac) = 1.d0
-!      enddo
+  do ifac = 1, nfabor
+    coefap(ifac) = zero
+    coefbp(ifac) = 1.d0
+  enddo
 
-!  IVAR0 = 0 (indique pour la periodicite de rotation que la variable
-!     n'est pas la vitesse ni Rij)
-!      ivar0 = 0
-!      call grdcel
-!      !==========
-!     & ( ivar0  , imrgra , inc    , iccocg , nswrgp , imligp ,
-!     &   iwarnp , nfecra , epsrgp , climgp , extrap ,
-!     &   w7     , coefap , coefbp ,
-!     &   grad   )
+  !  f_id0 = -1
+  ! (indicates for the periodicity of rotation that the variable is not a Rij)
+  f_id0 = -1
 
-!     Faces internes
-!      do ifac = 1, nfac
+  call gradient_s                                       &
+ ( f_id0  , imrgra , inc    , iccocg , nswrgp , imligp ,&
+   iwarnp , epsrgp , climgp , extrap ,                  &
+   w7     , coefap , coefbp ,                           &
+   grad   )
 
-!        ii = ifacel(1,ifac)
-!        jj = ifacel(2,ifac)
+  ! internal faces
+  do ifac = 1, nfac
 
-!        dijpfx = dijpf(1,ifac)
-!        dijpfy = dijpf(2,ifac)
-!        dijpfz = dijpf(3,ifac)
+    ii = ifacel(1,ifac)
+    jj = ifacel(2,ifac)
 
-!        pnd   = pond(ifac)
+    dijpfx = dijpf(1,ifac)
+    dijpfy = dijpf(2,ifac)
+    dijpfz = dijpf(3,ifac)
 
-!        Calcul II' et JJ'
+    pnd   = pond(ifac)
 
-!        diipfx = cdgfac(1,ifac) - (xyzcen(1,ii)+ (1.d0-pnd) * dijpfx)
-!        diipfy = cdgfac(2,ifac) - (xyzcen(2,ii)+ (1.d0-pnd) * dijpfy)
-!        diipfz = cdgfac(3,ifac) - (xyzcen(3,ii)+ (1.d0-pnd) * dijpfz)
-!        djjpfx = cdgfac(1,ifac) -  xyzcen(1,jj)+       pnd  * dijpfx
-!        djjpfy = cdgfac(2,ifac) -  xyzcen(2,jj)+       pnd  * dijpfy
-!        djjpfz = cdgfac(3,ifac) -  xyzcen(3,jj)+       pnd  * dijpfz
+    ! Computation of II' and JJ'
 
-!        pip = w7(ii) +grad(ii,1)*diipfx+grad(ii,2)*diipfy+grad(ii,3)*diipfz
-!        pjp = w7(jj) +grad(jj,1)*djjpfx+grad(jj,2)*djjpfy+grad(jj,3)*djjpfz
+    diipfx = cdgfac(1,ifac) - (xyzcen(1,ii)+ (1.d0-pnd) * dijpfx)
+    diipfy = cdgfac(2,ifac) - (xyzcen(2,ii)+ (1.d0-pnd) * dijpfy)
+    diipfz = cdgfac(3,ifac) - (xyzcen(3,ii)+ (1.d0-pnd) * dijpfz)
+    djjpfx = cdgfac(1,ifac) -  xyzcen(1,jj)+       pnd  * dijpfx
+    djjpfy = cdgfac(2,ifac) -  xyzcen(2,jj)+       pnd  * dijpfy
+    djjpfz = cdgfac(3,ifac) -  xyzcen(3,jj)+       pnd  * dijpfz
 
-!        flui = (imasfl(ifac)+abs(imasfl(ifac)))
-!        fluj = (imasfl(ifac)-abs(imasfl(ifac)))
+    pip = w7(ii) +grad(1,ii)*diipfx+grad(2,ii)*diipfy+grad(3,ii)*diipfz
+    pjp = w7(jj) +grad(1,jj)*djjpfx+grad(2,jj)*djjpfy+grad(3,jj)*djjpfz
 
-!        viscf(ifac) = -(pnd*pip*flui+pnd*pjp*fluj)
+    flui = (imasfl(ifac)+abs(imasfl(ifac)))
+    fluj = (imasfl(ifac)-abs(imasfl(ifac)))
 
-!      enddo
+    iprtfl(ifac) = -(pnd*pip*flui+pnd*pjp*fluj)
 
-!     Sans Reconstruction
+  enddo
+
+else
+
+  ! without reconstruction
+
+  ! Internal faces
+  do ifac = 1, nfac
+    iel1 = ifacel(1,ifac)
+    iel2 = ifacel(2,ifac)
+    iprtfl(ifac) =                                                             &
+         - cvar_pr(iel1)/crom(iel1) * 0.5d0*(imasfl(ifac) +abs(imasfl(ifac)))  &
+         - cvar_pr(iel2)/crom(iel2) * 0.5d0*(imasfl(ifac) -abs(imasfl(ifac)))
+  enddo
 
-!     En periodique et parallele, echange avant utilisation
-!       des valeurs aux faces
-if (irangp.ge.0.or.iperio.eq.1) then
-  call synsca(w9)
-  !==========
 endif
 
-! Internal faces
-do ifac = 1, nfac
-  iel1 = ifacel(1,ifac)
-  iel2 = ifacel(2,ifac)
-  viscf(ifac) =                                                                 &
-     - cvar_pr(iel1)/w9(iel1) * 0.5d0*(imasfl(ifac) +abs(imasfl(ifac)))             &
-     - cvar_pr(iel2)/w9(iel2) * 0.5d0*(imasfl(ifac) -abs(imasfl(ifac)))
-enddo
-
 ! Boundary faces: for the faces where a flux (Rusanov or analytical) has been
 ! computed, the standard contribution is replaced by this flux in bilsc2.
 
@@ -371,24 +383,26 @@ call field_get_coefb_s(ivarfl(ipr), coefb_p)
 do ifac = 1, nfabor
   if (icvfli(ifac).eq.0) then
     iel = ifabor(ifac)
-    viscb(ifac) = - bmasfl(ifac)                                                &
-                    * (coefa_p(ifac) + coefb_p(ifac)*cvar_pr(iel))                  &
+    bprtfl(ifac) = - bmasfl(ifac)                                            &
+                    * (coefa_p(ifac) + coefb_p(ifac)*cvar_pr(iel))          &
                     / brom(ifac)
   else
-    viscb(ifac) = 0.d0
+    bprtfl(ifac) = 0.d0
   endif
 enddo
 
 !     Divergence
 init = 0
-call divmas(init, viscf, viscb, smbrs)
+call divmas(init, iprtfl, bprtfl, smbrs)
 
+deallocate(iprtfl)
+deallocate(bprtfl)
 
 ! GRAVITATION FORCE TERM : RHO*g.U *VOLUME
 ! ======================
 
 do iel = 1, ncel
-  smbrs(iel) = smbrs(iel) + w9(iel)*volume(iel)                                &
+  smbrs(iel) = smbrs(iel) + crom(iel)*cell_f_vol(iel)                          &
                            *( gx*vel(1,iel)                                    &
                             + gy*vel(2,iel)                                    &
                             + gz*vel(3,iel) )
@@ -398,6 +412,12 @@ enddo
 !     FACE DIFFUSION "VELOCITY" : --------- avec K = ------ + -- .------
 !     =========================    IJ.nij              Cv     Cv  SIGMAS
 
+! Only SGDH available
+
+allocate(w1(ncelet))
+allocate(viscf(nfac))
+allocate(viscb(nfabor))
+
 if( idiff(ivar).ge. 1 ) then
 
 !     MUT/SIGMAS
@@ -406,7 +426,6 @@ if( idiff(ivar).ge. 1 ) then
   enddo
 !     CP*MUT/SIGMAS
   if(icp.gt.0) then
-    call field_get_val_s(iprpfl(icp), cpro_cp)
     do iel = 1, ncel
       w1(iel) = w1(iel)*cpro_cp(iel)
     enddo
@@ -418,7 +437,7 @@ if( idiff(ivar).ge. 1 ) then
 !     (CP/CV)*MUT/SIGMAS
   if(icv.gt.0) then
     do iel = 1, ncel
-      w1(iel) = w1(iel)/propce(iel,ipproc(icv))
+      w1(iel) = w1(iel)/cpro_cv(iel)
     enddo
   else
     do iel = 1, ncel
@@ -453,12 +472,12 @@ if( idiff(ivar).ge. 1 ) then
   ! Compute e - CvT
 
   ! At cell centers
-  call cf_thermo_eps_sup(w9, ncel)
-  !=====================
+  call cs_cf_thermo_eps_sup(crom, w9, ncel)
+  !========================
 
   ! At boundary faces centers
-  call cf_thermo_eps_sup(wb, nfabor)
-  !=====================
+  call cs_cf_thermo_eps_sup(brom, wb, nfabor)
+  !========================
 
 ! Divergence computation with reconstruction
 
@@ -493,13 +512,13 @@ if( idiff(ivar).ge. 1 ) then
     coefbp(ifac) = 1.d0
   enddo
 
-!  IVAR0 = 0 (indicates, for the rotation periodicity,
-!  that the variable is not Rij)
-  ivar0 = 0
-  call grdcel                                                       &
+!  f_id0 = -1 (indicates, for the rotation periodicity,
+!              that the variable is not Rij)
+  f_id0 = -1
+  call gradient_s                                                   &
   !==========
-   ( ivar0  , imrgra , inc    , iccocg , nswrgp , imligp ,          &
-     iwarnp , nfecra , epsrgp , climgp , extrap ,                   &
+   ( f_id0  , imrgra , inc    , iccocg , nswrgp , imligp ,          &
+     iwarnp , epsrgp , climgp , extrap ,                            &
      w7     , coefap , coefbp ,                                     &
      grad   )
 
@@ -528,8 +547,8 @@ if( idiff(ivar).ge. 1 ) then
     djjpfy = cdgfac(2,ifac) -  xyzcen(2,jj) +  pnd  * dijpfy
     djjpfz = cdgfac(3,ifac) -  xyzcen(3,jj) +  pnd  * dijpfz
 
-    pip = w7(ii) + grad(ii,1)*diipfx+grad(ii,2)*diipfy+grad(ii,3)*diipfz
-    pjp = w7(jj) + grad(jj,1)*djjpfx+grad(jj,2)*djjpfy+grad(jj,3)*djjpfz
+    pip = w7(ii) + grad(1,ii)*diipfx+grad(2,ii)*diipfy+grad(3,ii)*diipfz
+    pjp = w7(jj) + grad(1,jj)*djjpfx+grad(2,jj)*djjpfy+grad(3,jj)*djjpfz
 
     flux = viscf(ifac)*(pip-pjp)
 
@@ -538,6 +557,102 @@ if( idiff(ivar).ge. 1 ) then
 
   enddo
 
+  if (ippmod(igmix).gt.0) then
+
+    ! Diffusion flux for the species at internal faces
+
+    allocate(kspe(ncelet),viscfk(nfac),viscbk(nfabor))
+
+    ! Diffusion coefficient  T*lambda*Cvk/Cv
+    do iel =1, ncel
+      kspe(iel) = w1(iel)* cvar_tempk(iel)
+    enddo
+
+    call viscfa(imvisf, kspe, viscfk, viscbk)
+
+    deallocate(kspe)
+
+    allocate(grad_dd(nfac))
+
+    do ifac = 1, nfac
+      grad_dd(ifac) = 0.d0
+    enddo
+
+    do iesp = 1, nscasp
+
+      ivarsp = isca(iscasp(iesp))
+      call field_get_val_s(ivarfl(ivarsp), cvar_yk)
+      call field_get_key_struct_gas_mix_species_prop(ivarfl(ivarsp), s_k)
+
+      mk =  s_k%mol_mas
+      cpk = s_k%cp
+      cvk = cpk - cs_physical_constants_r/mk
+
+      use_previous = 0
+      call field_gradient_scalar(ivarfl(ivarsp), use_previous, imrgra, inc, &
+                                 iccocg, grad)
+
+      do ifac = 1, nfac
+
+        ii = ifacel(1,ifac)
+        jj = ifacel(2,ifac)
+
+        dijpfx = dijpf(1,ifac)
+        dijpfy = dijpf(2,ifac)
+        dijpfz = dijpf(3,ifac)
+
+        pnd   = pond(ifac)
+
+        ! Computation of II' and JJ'
+        diipfx = cdgfac(1,ifac) - (xyzcen(1,ii) + (1.d0-pnd) * dijpfx)
+        diipfy = cdgfac(2,ifac) - (xyzcen(2,ii) + (1.d0-pnd) * dijpfy)
+        diipfz = cdgfac(3,ifac) - (xyzcen(3,ii) + (1.d0-pnd) * dijpfz)
+        djjpfx = cdgfac(1,ifac) -  xyzcen(1,jj) +  pnd  * dijpfx
+        djjpfy = cdgfac(2,ifac) -  xyzcen(2,jj) +  pnd  * dijpfy
+        djjpfz = cdgfac(3,ifac) -  xyzcen(3,jj) +  pnd  * dijpfz
+
+        yip = cvar_yk(ii) + grad(1,ii)*diipfx &
+                          + grad(2,ii)*diipfy &
+                          + grad(3,ii)*diipfz
+        yjp = cvar_yk(jj) + grad(1,jj)*djjpfx &
+                          + grad(2,jj)*djjpfy &
+                          + grad(3,jj)*djjpfz
+
+        ! Gradient of deduced species
+        grad_dd(ifac) = grad_dd(ifac)-(yjp-yip)
+
+        flux = viscfk(ifac)*cvk*(yip-yjp)
+
+        smbrs(ii) = smbrs(ii) + flux
+        smbrs(jj) = smbrs(jj) - flux
+
+      enddo
+
+    enddo
+
+    ! Diffusion flux for the deduced species
+
+    call field_get_key_struct_gas_mix_species_prop(iddgas, s_k)
+    mk =  s_k%mol_mas
+    cpk = s_k%cp
+    cvk = cpk - cs_physical_constants_r/mk
+
+    do ifac = 1, nfac
+
+      ii = ifacel(1,ifac)
+      jj = ifacel(2,ifac)
+
+      flux = viscf(ifac)*grad_dd(ifac)*cvk
+
+      smbrs(ii) = smbrs(ii) + flux
+      smbrs(jj) = smbrs(jj) - flux
+
+    enddo
+
+    deallocate(grad_dd)
+
+  endif ! ippmod(igmix)
+
   ! Assembling based on boundary faces
   ! for the faces where a flux or a temperature is imposed,
   ! all is taken into account by the energy diffusion term.
@@ -572,12 +687,88 @@ if( idiff(ivar).ge. 1 ) then
               )**2                                               &
             ))
 
-
       smbrs(iel) = smbrs(iel) + flux
+
     endif
 
   enddo
 
+  if (ippmod(igmix).gt.0) then
+
+    call field_get_coefa_s(ivarfl(isca(itempk)), coefat)
+    call field_get_coefb_s(ivarfl(isca(itempk)), coefbt)
+
+    allocate(grad_dd(nfabor), btemp(nfabor))
+
+    use_previous = 0
+    call field_gradient_scalar(ivarfl(isca(itempk)), use_previous, imrgra, inc,&
+                               iccocg, grad)
+
+    do ifac = 1, nfabor
+      grad_dd(ifac) = 0.d0
+
+      tip = cvar_tempk(iel) + grad(1,iel)*diipb(1,ifac) &
+                            + grad(2,iel)*diipb(2,ifac) &
+                            + grad(3,iel)*diipb(3,ifac)
+      btemp(ifac) = coefat(ifac)+coefbt(ifac)*tip
+    enddo
+
+    do iesp = 1, nscasp
+      ivarsp = isca(iscasp(iesp))
+      call field_get_coefa_s(ivarfl(ivarsp), coefayk)
+      call field_get_coefb_s(ivarfl(ivarsp), coefbyk)
+      call field_get_val_s(ivarfl(ivarsp), cvar_yk)
+      call field_get_key_struct_gas_mix_species_prop(ivarfl(ivarsp), s_k)
+
+      mk =  s_k%mol_mas
+      cpk = s_k%cp
+      cvk = cpk - cs_physical_constants_r/mk
+
+      use_previous = 0
+      call field_gradient_scalar(ivarfl(ivarsp), use_previous, imrgra, inc, &
+                                 iccocg, grad)
+
+      do ifac = 1, nfabor
+        if (ifbet(ifac).eq.0) then
+          iel = ifabor(ifac)
+
+          yip = cvar_yk(iel) + grad(1,iel)*diipb(1,ifac) &
+                             + grad(2,iel)*diipb(2,ifac) &
+                             + grad(3,iel)*diipb(3,ifac)
+
+          gradnb = coefayk(ifac)+(coefbyk(ifac)-1)*yip
+
+          grad_dd(ifac) =  grad_dd(ifac) - gradnb
+
+          flux = viscbk(ifac)*w1(iel)*btemp(ifac)*cvk/distb(ifac)*(-gradnb)
+
+          smbrs(iel) = smbrs(iel) + flux
+        endif
+      enddo ! end ifac loop
+    enddo ! end iesp loop
+
+    ! Boundary diffusion flux for the deduced species
+    call field_get_key_struct_gas_mix_species_prop(iddgas, s_k)
+
+    mk =  s_k%mol_mas
+    cpk = s_k%cp
+    cvk = cpk - cs_physical_constants_r/mk
+
+    do ifac = 1, nfabor
+      if (ifbet(ifac).eq.0) then
+        iel = ifabor(ifac)
+
+        flux = viscbk(ifac)*w1(iel)*btemp(ifac)*cvk/distb(ifac)*grad_dd(ifac)
+
+        smbrs(iel) = smbrs(iel) + flux
+      endif
+    enddo
+
+    deallocate(grad_dd, btemp)
+    deallocate(viscfk, viscbk)
+
+  endif ! ippmod(igmix)
+
 else
 
   do ifac = 1, nfac
@@ -643,42 +834,44 @@ call codits                                                      &
   rovsdt , smbrs  , cvar_energ      , dpvar  ,                   &
   rvoid  , rvoid  )
 
+deallocate(viscf)
+deallocate(viscb)
 
 !===============================================================================
-! 5. PRINTINGS AND CLIPPINGS
+! 5. Printings and clippings
 !===============================================================================
 
 call clpsca(iscal)
 
 ! --- Traitement utilisateur pour gestion plus fine des bornes
 !       et actions correctives eventuelles.
-call cf_check_internal_energy(cvar_energ, ncel, vel)
+call cs_cf_check_internal_energy(cvar_energ, ncel, vel)
 
 ! Explicit balance (see codits : the increment is removed)
 
 if (iwarni(ivar).ge.2) then
   do iel = 1, ncel
     smbrs(iel) = smbrs(iel)                                                    &
-            - istat(ivar)*(crom(iel)/dt(iel))*volume(iel)                      &
+            - istat(ivar)*(crom(iel)/dt(iel))*cell_f_vol(iel)                  &
                 *(cvar_energ(iel)-cvara_energ(iel))                            &
                 * max(0,min(nswrsm(ivar)-2,1))
   enddo
-  isqrt = 1
-  call prodsc(ncel,isqrt,smbrs,smbrs,sclnor)
+  sclnor = sqrt(cs_gdot(ncel,smbrs,smbrs))
   write(nfecra,1200)chaine(1:8) ,sclnor
 endif
 
 !===============================================================================
-! 6. FINAL UPDATING OF THE PRESSURE (AND TEMPERATURE)
+! 6. Final updating of the pressure (and temperature)
 !===============================================================================
 !                             n+1      n+1  n+1
 ! The state equation is used P   =P(RHO   ,H   )
 
 ! Computation of P and T at cell centers
-call cf_thermo_pt_from_de(crom, cvar_energ, cvar_pr, cvar_tempk, vel, ncel)
+call cs_cf_thermo_pt_from_de(cpro_cp, cpro_cv, crom, cvar_energ, cvar_pr, &
+                             cvar_tempk, vel, ncel)
 
 !===============================================================================
-! 7. COMMUNICATION OF PRESSURE, ENERGY AND TEMPERATURE
+! 7. Communication of pressure, energy and temperature
 !===============================================================================
 
 if (irangp.ge.0.or.iperio.eq.1) then
@@ -695,11 +888,10 @@ deallocate(wb)
 deallocate(smbrs, rovsdt)
 deallocate(grad)
 deallocate(w1)
-deallocate(w4, w5, w6)
-deallocate(w7, w8, w9)
+deallocate(w7, w9)
 
 !--------
-! FORMATS
+! Formats
 !--------
 
  1000 format(/,                                                   &
@@ -708,7 +900,7 @@ deallocate(w7, w8, w9)
  1200 format(1X,A8,' : EXPLICIT BALANCE = ',E14.5)
 
 !----
-! FIN
+! End
 !----
 
 return
