@@ -44,7 +44,6 @@
 !> \param[in]     itypsm        type of mass source term for each variable
 !>                               (see uttsma.f90)
 !> \param[in]     dt            time step (per cell)
-!> \param[in]     propce        physical properties at cell centers
 !> \param[in]     vela          velocity value at time step beginning
 !> \param[in]     ckupdc        work array for the head loss
 !> \param[in]     smacel        variable value associated to the mass source
@@ -55,7 +54,7 @@
 subroutine cfmspr &
  ( nvar   , nscal  , iterns , ncepdp , ncesmp ,                   &
    icepdc , icetsm , itypsm ,                                     &
-   dt     , propce , vela   ,                                     &
+   dt     , vela   ,                                              &
    ckupdc , smacel )
 
 !===============================================================================
@@ -63,6 +62,7 @@ subroutine cfmspr &
 !===============================================================================
 
 use paramx
+use pointe, only:rvoid1
 use numvar
 use entsor
 use optcal
@@ -92,7 +92,6 @@ integer          icepdc(ncepdp)
 integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
 
 double precision dt(ncelet)
-double precision propce(ncelet,*)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 double precision vela  (3  ,ncelet)
 
@@ -133,7 +132,7 @@ double precision, allocatable, dimension(:) :: c2
 double precision, dimension(:), pointer :: coefaf_p, coefbf_p
 double precision, dimension(:), pointer :: imasfl, bmasfl
 double precision, dimension(:), pointer :: rhopre, crom
-double precision, dimension(:), pointer :: cvar_pr, cvara_pr
+double precision, dimension(:), pointer :: cvar_pr, cvara_pr, cpro_cp, cpro_cv
 
 !===============================================================================
 !===============================================================================
@@ -170,7 +169,7 @@ call field_get_val_prev_s(icrom, rhopre)
 call field_get_val_s(ivarfl(ipr), cvar_pr)
 call field_get_val_prev_s(ivarfl(ipr), cvara_pr)
 
-call field_get_label(ivarfl(ivar), chaine)
+call field_get_label(ivarfl(ipr), chaine)
 
 if(iwarni(ivar).ge.1) then
   write(nfecra,1000) chaine(1:8)
@@ -179,6 +178,18 @@ endif
 call field_get_coefaf_s(ivarfl(ipr), coefaf_p)
 call field_get_coefbf_s(ivarfl(ipr), coefbf_p)
 
+if (icp.gt.0) then
+  call field_get_val_s(iprpfl(icp), cpro_cp)
+else
+  cpro_cp => rvoid1
+endif
+
+if (icv.gt.0) then
+  call field_get_val_s(iprpfl(icv), cpro_cv)
+else
+  cpro_cv => rvoid1
+endif
+
 ! Computation of the boundary coefficients for the pressure gradient
 ! recontruction in accordance with the diffusion boundary coefficients (coefaf_p,
 ! coefbf_p). Always a homogeneous Neumann except at walls where the hydrostatic
@@ -224,7 +235,7 @@ endif
 
 allocate(c2(ncelet))
 
-call cs_cf_thermo_c_square(cvar_pr, crom, c2, ncel)
+call cs_cf_thermo_c_square(cpro_cp, cpro_cv, cvar_pr, crom, c2, ncel)
 !=========================
 
 do iel = 1, ncel
@@ -243,7 +254,7 @@ call cfmsfp
 !==========
 ( nvar   , nscal  , iterns , ncepdp , ncesmp ,                                  &
   icepdc , icetsm , itypsm ,                                                    &
-  dt     , propce , vela   ,                                                    &
+  dt     , vela   ,                                                             &
   ckupdc , smacel ,                                                             &
   wflmas , wflmab )
 
