@@ -72,6 +72,7 @@ subroutine cfxtcl &
 ! Module files
 !===============================================================================
 
+use dimens, only : nscal
 use paramx
 use numvar
 use optcal
@@ -85,6 +86,7 @@ use ppincl
 use cfpoin
 use mesh
 use field
+use cs_cf_bindings
 
 !===============================================================================
 
@@ -104,7 +106,7 @@ double precision rcodcl(nfabor,nvarcl,3)
 
 integer          ivar  , ifac  , iel, l_size
 integer          ii    , iii   , iccfth
-integer          icalep, icalgm
+integer          icalep
 integer          iflmab
 integer          ien   , itk
 integer          nvarcf
@@ -113,17 +115,18 @@ integer          nvcfmx
 parameter       (nvcfmx=6)
 integer          ivarcf(nvcfmx)
 
-double precision hint  , gammag
+double precision hint, cpb(1), cvb(1)
 
 double precision, allocatable, dimension(:) :: w1, w2
 double precision, allocatable, dimension(:) :: w4, w5, w6
 double precision, allocatable, dimension(:) :: w7
-double precision, allocatable, dimension(:) :: wbfb
-double precision, allocatable, dimension(:,:) :: bval
+double precision, allocatable, dimension(:) :: wbfb, wbfa
+double precision, allocatable, dimension(:) :: bc_en, bc_pr, bc_tk
+double precision, allocatable, dimension(:,:) :: bc_vel
 
 double precision, dimension(:), pointer :: bmasfl
 double precision, dimension(:), pointer :: coefbp
-double precision, dimension(:), pointer :: crom, brom, cpro_cv, cvar_en
+double precision, dimension(:), pointer :: crom, brom, cpro_cp, cpro_cv, cvar_en
 double precision, dimension(:,:), pointer :: vel
 
 !===============================================================================
@@ -138,9 +141,11 @@ call field_get_val_v(ivarfl(iu), vel)
 ! Allocate temporary arrays
 allocate(w1(ncelet), w2(ncelet))
 allocate(w4(ncelet), w5(ncelet), w6(ncelet))
-
-allocate(w7(nfabor), wbfb(nfabor))
-allocate(bval(nfabor,nvar))
+allocate(w7(nfabor), wbfa(nfabor), wbfb(nfabor))
+allocate(bc_en(nfabor))
+allocate(bc_pr(nfabor))
+allocate(bc_tk(nfabor))
+allocate(bc_vel(3,nfabor))
 
 ien = isca(ienerg)
 itk = isca(itempk)
@@ -153,6 +158,7 @@ call field_get_val_s(ibrom, brom)
 
 call field_get_val_s(ivarfl(ien), cvar_en)
 
+if (icp.gt.0) call field_get_val_s(iprpfl(icp), cpro_cp)
 if (icv.gt.0) call field_get_val_s(iprpfl(icv), cpro_cv)
 
 ! list of the variables of the compressible model
@@ -180,35 +186,10 @@ do ifac = 1, nfabor
 enddo
 if(icalep.ne.0) then
   ! At cell centers
-  call cf_thermo_eps_sup(w5, ncel)
+  call cs_cf_thermo_eps_sup(crom, w5, ncel)
 
   ! At boundary faces centers
-  call cf_thermo_eps_sup(w7, nfabor)
-endif
-
-! Computation of gamma (can be constant or variable)
-! Needed for to compute the Rusanov fluxes at imposed inlet.
-
-icalgm = 0
-do ifac = 1, nfabor
-  if ( ( itypfb(ifac).eq.iesicf ) .or.                    &
-       ( itypfb(ifac).eq.ieqhcf ) ) then
-    icalgm = 1
-  endif
-enddo
-if(icalgm.ne.0) then
-  if(ieos.eq.1) then
-    call cf_thermo_gamma(gammag)
-  else
-    ! TODO for thermodynamic with variable gamma
-    ! Gamma is used in cfrusb. If non uniform (ieos different from 1),
-    ! the cell values have to be passed and used as gammag(ifabor(ifac))
-    ! in the Rusanov flux computation.
-    ! For now, we stop here and an error message is printed out.
-    write(nfecra,7000)
-    call csexit (1)
-  endif
-
+  call cs_cf_thermo_eps_sup(brom, w7, nfabor)
 endif
 
 ! Loop on all boundary faces and treatment of types of BCs given by itypfb
@@ -253,23 +234,16 @@ do ifac = 1, nfabor
 
       ! generally proportional to the bulk value
       ! (Pboundary = COEFB*Pi)
-      ! If rarefaction is too strong : homogeneous Dirichlet
+      ! The part deriving from pinf in stiffened gas is set in explicit for now
+      call cs_cf_thermo_wall_bc(wbfa, wbfb, ifac-1)
 
-      call cf_thermo_wall_bc(wbfb, ifac)
-
-      ! In addition, a pre-correction has to be applied to cancel the
-      ! treatment done afterward in condli.
-      ! TODO see if coefa, coefb could be directly set. In this case,
-      ! a test on ippmod in condli would be necessary.
-
-      !FIXME with the new cofaf
-      icodcl(ifac,ipr) = 1
-      if(wbfb(ifac).lt.rinfin*0.5d0.and.                  &
-         wbfb(ifac).gt.0.d0  ) then
-        hint = dt(iel)/distb(ifac)
-        rcodcl(ifac,ipr,1) = 0.d0
-        rcodcl(ifac,ipr,2) = hint*(1.d0/wbfb(ifac)-1.d0)
+      if (wbfb(ifac).lt.rinfin*0.5d0.and.wbfb(ifac).gt.0.d0) then
+        icodcl(ifac,ipr) = 11
+        rcodcl(ifac,ipr,1) = wbfa(ifac)
+        rcodcl(ifac,ipr,2) = wbfb(ifac)
       else
+        ! If rarefaction is too strong : homogeneous Dirichlet
+        icodcl(ifac,ipr) = 1
         rcodcl(ifac,ipr,1) = 0.d0
       endif
 
@@ -419,17 +393,15 @@ do ifac = 1, nfabor
       endif
     enddo
 
-    ! missing thermo variables among P,rho,T,E are computed
-    do ivar = 1, nvar
-      bval(ifac,ivar) = rcodcl(ifac,ivar,1)
-    enddo
-
-    call cfther &
-    !==========
- ( nvar   ,               &
-   iccfth , ifac   ,      &
-   w1     , w2     , bval )
+    ! missing thermo variables among P, rho, T, E are computed
+    bc_en(ifac) = rcodcl(ifac,ien,1)
+    bc_pr(ifac) = rcodcl(ifac,ipr,1)
+    bc_tk(ifac) = rcodcl(ifac,itk,1)
+    bc_vel(1,ifac) = rcodcl(ifac,iu,1)
+    bc_vel(2,ifac) = rcodcl(ifac,iv,1)
+    bc_vel(3,ifac) = rcodcl(ifac,iw,1)
 
+    call cs_cf_thermo(iccfth, ifac-1, bc_en, bc_pr, bc_tk, bc_vel)
 
     ! Rusanov fluxes, mass flux and boundary conditions types (icodcl) are
     ! dealt with further below
@@ -462,19 +434,22 @@ do ifac = 1, nfabor
 
     ! density, velocity and total energy values
     brom(ifac) = crom(iel) ! TODO: test without (already done in phyvar)
-    rcodcl(ifac,iu ,1) = vel(1,iel)
-    rcodcl(ifac,iv ,1) = vel(2,iel)
-    rcodcl(ifac,iw ,1) = vel(3,iel)
-    rcodcl(ifac,ien,1) = cvar_en(iel)
+    bc_en(ifac) = cvar_en(iel)
+    bc_pr(ifac) = rcodcl(ifac,ipr,1)
+    bc_tk(ifac) = rcodcl(ifac,itk,1)
+    bc_vel(1,ifac) = vel(1,iel)
+    bc_vel(2,ifac) = vel(2,iel)
+    bc_vel(3,ifac) = vel(3,iel)
 
-    do ivar = 1, nvar
-      bval(ifac,ivar) = rcodcl(ifac,ivar,1)
-    enddo
+    cpb(1) = 0.d0
+    cvb(1) = 0.d0
+    if (icp.gt.0) cpb(1) = cpro_cp(iel)
+    if (icv.gt.0) cvb(1) = cpro_cv(iel)
 
     l_size = 1
-    call cf_thermo_pt_from_de_ni(brom(ifac:ifac), bval(ifac,ien), bval(ifac,ipr),  &
-                                 bval(ifac,itk), bval(ifac,iu), bval(ifac,iv),     &
-                                 bval(ifac,iw), l_size)
+    call cs_cf_thermo_pt_from_de(cpb, cvb, brom(ifac:ifac), bc_en(ifac:ifac), &
+                                 bc_pr(ifac:ifac), bc_tk(ifac:ifac), &
+                                 bc_vel(:,ifac:ifac), l_size)
 
     ! mass fluxes and boundary conditions codes, see further below.
 
@@ -504,13 +479,14 @@ do ifac = 1, nfabor
       endif
     enddo
 
-    ! values of the density, the velocity and the total energy
-    do ivar = 1, nvar
-      bval(ifac,ivar) = rcodcl(ifac,ivar,1)
-    enddo
+    bc_en(ifac) = rcodcl(ifac,ien,1)
+    bc_pr(ifac) = rcodcl(ifac,ipr,1)
+    bc_tk(ifac) = rcodcl(ifac,itk,1)
+    bc_vel(1,ifac) = rcodcl(ifac,iu,1)
+    bc_vel(2,ifac) = rcodcl(ifac,iv,1)
+    bc_vel(3,ifac) = rcodcl(ifac,iw,1)
 
-    call cf_thermo_subsonic_outlet_bc(bval, ifac)
-    !==============================
+    call cs_cf_thermo_subsonic_outlet_bc(bc_en, bc_pr, bc_vel, ifac-1)
 
     ! mass fluxes and boundary conditions codes, see further below.
 
@@ -543,12 +519,14 @@ do ifac = 1, nfabor
       endif
     enddo
 
-    do ivar = 1, nvar
-      bval(ifac,ivar) = rcodcl(ifac,ivar,1)
-    enddo
+    bc_en(ifac) = rcodcl(ifac,ien,1)
+    bc_pr(ifac) = rcodcl(ifac,ipr,1)
+    bc_tk(ifac) = rcodcl(ifac,itk,1)
+    bc_vel(1,ifac) = rcodcl(ifac,iu,1)
+    bc_vel(2,ifac) = rcodcl(ifac,iv,1)
+    bc_vel(3,ifac) = rcodcl(ifac,iw,1)
 
-    call cf_thermo_ph_inlet_bc(bval, ifac)
-    !=======================
+    call cs_cf_thermo_ph_inlet_bc(bc_en, bc_pr, bc_vel, ifac-1)
 
     ! mass fluxes and boundary conditions codes, see further below.
 
@@ -563,11 +541,11 @@ do ifac = 1, nfabor
     call csexit (1)
 
     !     On utilise un scenario dans lequel on a un 2-contact et une
-    !       3-dtente entrant dans le domaine. On dtermine les conditions
+    !       3-détente entrant dans le domaine. On détermine les conditions
     !       sur l'interface selon la thermo et on passe dans Rusanov
     !       ensuite pour lisser.
 
-    !     Si rho et u ne sont pas donns, erreur
+    !     Si rho et u ne sont pas donnés, erreur
     if(rcodcl(ifac,irunh,1).lt.-rinfin*0.5d0) then
       write(nfecra,1300)
       call csexit (1)
@@ -585,20 +563,17 @@ do ifac = 1, nfabor
       endif
     enddo
 
-!     IRUNH = ISCA(IENER)
-!     (aliases pour simplifier uscfcl)
 
 !===============================================================================
 ! 5. Unexpected boundary condition type
 !===============================================================================
 
-  else
+  elseif ( itypfb(ifac).ne.iindef ) then
 
     ! The computation stops.
     write(nfecra,1400)
     call csexit (1)
 
-
   endif ! end of test on boundary condition types
 
 
@@ -626,19 +601,18 @@ do ifac = 1, nfabor
 
       ! only the mass flux is computed
       bmasfl(ifac) = brom(ifac) *                                              &
-                     ( bval(ifac,iu)*surfbo(1,ifac)                            &
-                     + bval(ifac,iv)*surfbo(2,ifac)                            &
-                     + bval(ifac,iw)*surfbo(3,ifac) )
+                     (  bc_vel(1,ifac)*suffbo(1,ifac)                          &
+                      + bc_vel(2,ifac)*suffbo(2,ifac)                          &
+                      + bc_vel(3,ifac)*suffbo(3,ifac) )
 
     ! other inlets/outlets
     else
 
       ! Rusanov fluxes are computed only for the imposed inlet for stability
       ! reasons (the mass flux computation is concluded)
-      if ( itypfb(ifac).eq.iesicf ) then
+      if (itypfb(ifac).eq.iesicf) then
 
-        call cfrusb(nvar, ifac, gammag, bval)
-        !==========
+        call cfrusb(ifac, bc_en, bc_pr, bc_vel)
 
       ! For the other types of inlets/outlets (subsonic outlet, QH inlet,
       ! PH inlet), analytical fluxes are computed
@@ -646,8 +620,7 @@ do ifac = 1, nfabor
 
         ! the pressure part of the boundary analytical flux is not added here,
         ! but set through the pressure gradient boundary conditions (Dirichlet)
-        call cffana(nvar, ifac, bval)
-        !==========
+        call cffana(ifac, bc_en, bc_pr, bc_vel)
 
       endif
 
@@ -657,9 +630,12 @@ do ifac = 1, nfabor
 ! 6.2 Copy of boundary values into the Dirichlet values array
 !===============================================================================
 
-    do ivar = 1, nvar
-      rcodcl(ifac,ivar,1) = bval(ifac,ivar)
-    enddo
+    rcodcl(ifac,ien,1) = bc_en(ifac)
+    rcodcl(ifac,ipr,1) = bc_pr(ifac)
+    rcodcl(ifac,itk,1) = bc_tk(ifac)
+    rcodcl(ifac,iu,1)  = bc_vel(1,ifac)
+    rcodcl(ifac,iv,1)  = bc_vel(2,ifac)
+    rcodcl(ifac,iw,1)  = bc_vel(3,ifac)
 
 !===============================================================================
 ! 6.3 Boundary conditions codes (Dirichlet or Neumann)
@@ -732,11 +708,16 @@ do ifac = 1, nfabor
       elseif(iturb.eq.70) then
         icodcl(ifac,inusa) = 3
       endif
-      if(nscaus.gt.0) then
+      if (nscaus.gt.0) then
         do ii = 1, nscaus
           icodcl(ifac,isca(ii)) = 3
         enddo
       endif
+      if (nscasp.gt.0) then
+        do ii = 1, nscasp
+          icodcl(ifac,iscasp(ii)) = 3
+        enddo
+      endif
     else
       if(itytur.eq.2) then
         if(rcodcl(ifac,ik ,1).gt.0.d0.and.               &
@@ -802,7 +783,7 @@ do ifac = 1, nfabor
            icodcl(ifac,inusa) = 3
          endif
        endif
-       if(nscaus.gt.0) then
+       if (nscaus.gt.0) then
          do ii = 1, nscaus
            if(rcodcl(ifac,isca(ii),1).gt.-rinfin*0.5d0) then
              icodcl(ifac,isca(ii)) = 1
@@ -811,6 +792,15 @@ do ifac = 1, nfabor
            endif
          enddo
        endif
+       if (nscasp.gt.0) then
+         do ii = 1, nscasp
+           if(rcodcl(ifac,iscasp(ii),1).gt.-rinfin*0.5d0) then
+             icodcl(ifac,iscasp(ii)) = 1
+           else
+             icodcl(ifac,iscasp(ii)) = 3
+           endif
+         enddo
+       endif
      endif
 
      ! rcodcl elements have been initialized at -RINFIN to allow to check wether
@@ -832,8 +822,8 @@ do ifac = 1, nfabor
 ! Free memory
 deallocate(w1, w2)
 deallocate(w4, w5, w6)
-deallocate(w7)
-deallocate(bval)
+deallocate(w7, wbfb, wbfa)
+deallocate(bc_en, bc_pr, bc_tk, bc_vel)
 
 !----
 ! FORMATS
@@ -934,22 +924,6 @@ deallocate(bval)
 '@    cs_user_boundary_conditions                             ',/,&
 '@                                                            ',/,&
 '@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
-'@                                                            ',/)
- 7000 format(                                                           &
-'@                                                            ',/,&
-'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
-'@                                                            ',/,&
-'@ @@ WARNING : Error during execution,                       ',/,&
-'@    =========                                               ',/,&
-'@    cfxtcl should be modified to take into account a state  ',/,&
-'@    law with a variable gamma. Only ieos = 1 is available   ',/,&
-'@    for now.                                                ',/,&
-'@                                                            ',/,&
-'@  The computation will stop.                                ',/,&
-'@                                                            ',/,&
-'@  Check ieos in routine uscfx1.                             ',/,&
-'@                                                            ',/,&
-'@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@@',/,&
 '@                                                            ',/)
 !----
 ! END
