@@ -331,7 +331,7 @@ do iel =1, ncel
       if ( ipass.gt.1 .or.                                        &
           (isuite.eq.1.and.initro.eq.1) ) then
         rhol(idirac) = p0 * maml(idirac)                   &
-             / (rr*teml(idirac))
+             / (cs_physical_constants_r*teml(idirac))
       else
         rhol(idirac) = ro0
       endif
@@ -397,7 +397,7 @@ do iel =1, ncel
     if ( ipass.gt.1 .or.                                          &
         (isuite.eq.1.and.initro.eq.1) ) then
       crom(iel) = srrom*crom(iel)               &
-                          +(1.d0-srrom)*(p0/(rr*temsmm))
+                          +(1.d0-srrom)*(p0/(cs_physical_constants_r*temsmm))
     endif
 
   else
@@ -544,7 +544,7 @@ do iel =1, ncel
       if ( ipass.gt.1 .or.                                        &
           (isuite.eq.1.and.initro.eq.1) ) then
         rhol(idirac) = p0 * maml(idirac)                   &
-             /(rr*teml(idirac))
+             /(cs_physical_constants_r*teml(idirac))
       else
         rhol(idirac) = ro0
       endif
@@ -629,7 +629,7 @@ do iel =1, ncel
     if ( ipass.gt.1 .or.                                          &
         (isuite.eq.1.and.initro.eq.1) ) then
       crom(iel) = srrom * crom(iel)             &
-           + (1.d0-srrom) * (p0/(rr*temsmm))
+           + (1.d0-srrom) * (p0/(cs_physical_constants_r*temsmm))
     endif
 
   endif
