@@ -352,7 +352,7 @@ coyfpp=coyfp(iel)
       if ( ipass.gt.1 .or.                                        &
           (isuite.eq.1.and.initro.eq.1) ) then
         rhol(idirac) = p0 * maml(idirac)                   &
-             / (rr*teml(idirac))
+             / (cs_physical_constants_r*teml(idirac))
       else
         rhol(idirac) = ro0
       endif
@@ -416,7 +416,7 @@ coyfpp=coyfp(iel)
     if ( ipass.gt.1.or.                                           &
         (isuite.eq.1.and.initro.eq.1) ) then
       crom(iel) = srrom*crom(iel)               &
-           +(1.d0-srrom)*(p0/(rr*temsmm))
+           +(1.d0-srrom)*(p0/(cs_physical_constants_r*temsmm))
     endif
 
   else
@@ -740,7 +740,7 @@ coyfpp=coyfp(iel)
     if ( ipass.gt.1.or.                                           &
         (isuite.eq.1.and.initro.eq.1)) then
       rhol(idirac) = p0 * maml(idirac)                     &
-           /(rr*teml(idirac))
+           /(cs_physical_constants_r*teml(idirac))
     else
       rhol(idirac) = ro0
     endif
@@ -825,7 +825,7 @@ coyfpp=coyfp(iel)
   if ( ipass.gt.1 .or.                                            &
       (isuite.eq.1.and.initro.eq.1) ) then
     crom(iel) = srrom * crom(iel)               &
-         + (1.d0-srrom) * (p0/(rr*temsmm))
+         + (1.d0-srrom) * (p0/(cs_physical_constants_r*temsmm))
   endif
 
 ! de passage ou non par la PDF
