@@ -111,7 +111,7 @@ double precision, pointer, dimension(:)   :: dt
 
 integer iccocg, inc   , iel, isou, init
 integer nswrgp, imligp, iwarnp
-integer imucpp, ircflp, isqrt, isweep, isym, lchain
+integer imucpp, ircflp, isweep, isym, lchain
 integer ndircp, niterf, nswmpr
 integer iinvpe, iflmas, iflmab, iesize, idiffp, iconvp, ibsize
 integer fid
@@ -247,7 +247,6 @@ if (darcy_unsteady.eq.1) isym  = 2
 ! Matrix block size. Copied from reopv.
 ibsize = 1
 iesize = 1
-isqrt = 1
 
 allocate(dam(ncelet), xam(isym,nfac))
 
@@ -281,6 +280,7 @@ if (darcy_anisotropic_permeability.eq.0) then
     do iel = 1, ncel
       cpro_wgrec_s(iel) = cpro_permeability(iel)
     enddo
+    call synsca(cpro_wgrec_s)
   endif
 else if (darcy_anisotropic_permeability.eq.1) then
   allocate(weighf(2,nfac))
@@ -298,6 +298,7 @@ else if (darcy_anisotropic_permeability.eq.1) then
         cpro_wgrec_v(isou,iel) = cpro_permeability_6(isou,iel)
       enddo
     enddo
+    call syntis(cpro_wgrec_v)
   endif
 endif
 
@@ -368,16 +369,16 @@ else if (darcy_anisotropic_permeability.eq.1) then
 
   call itrgrv &
   !==========
-( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp ,        &
-  iphydr , iwarnp ,                                                     &
-  epsrgp , climgp , extrap ,                                            &
-  rvoid  ,                                                              &
-  cvar_pr   ,                                                           &
-  coefa_p  , coefb_p  ,                                                 &
-  coefaf_p , coefbf_p ,                                                 &
-  viscf  , viscb  ,                                                     &
-  cpro_permeability_6 ,                                                 &
-  weighf , weighb ,                                                     &
+( ivarfl(ipr), init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp ,        &
+  iphydr , iwarnp ,                                                                  &
+  epsrgp , climgp , extrap ,                                                         &
+  rvoid  ,                                                                           &
+  cvar_pr   ,                                                                        &
+  coefa_p  , coefb_p  ,                                                              &
+  coefaf_p , coefbf_p ,                                                              &
+  viscf  , viscb  ,                                                                  &
+  cpro_permeability_6 ,                                                              &
+  weighf , weighb ,                                                                  &
   rhs   )
 
 endif
@@ -411,7 +412,7 @@ do iel = 1, ncel
   endif
 enddo
 
-call prodsc(ncel, isqrt, rhs, rhs, residu)
+residu = sqrt(cs_gdot(ncel, rhs, rhs))
 
 sinfo%rnsmbr = residu
 
@@ -427,7 +428,7 @@ call promav(isym, ibsize, iesize, iinvpe, dam, xam, cvar_pr, w1)
 do iel = 1, ncel
   w1(iel) = w1(iel) + rhs(iel)
 enddo
-call prodsc(ncel, isqrt, w1, w1, rnormp)
+rnormp = sqrt(cs_gdot(ncel, w1, w1))
 
 ! Free memory
 deallocate(w1)
@@ -490,16 +491,16 @@ do while ( (isweep.le.nswmpr.and.residu.gt.epsrsm(ipr)*rnormp) &
 
     call itrgrv &
     !==========
-  ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp ,        &
-    iphydr , iwarnp ,                                                     &
-    epsrgp , climgp , extrap ,                                            &
-    rvoid  ,                                                              &
-    cvar_pr   ,                                                           &
-    coefa_p  , coefb_p  ,                                                 &
-    coefaf_p , coefbf_p ,                                                 &
-    viscf  , viscb  ,                                                     &
-    cpro_permeability_6 ,                                                 &
-    weighf , weighb ,                                                     &
+    ( ivarfl(ipr), init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp ,        &
+    iphydr , iwarnp ,                                                                    &
+    epsrgp , climgp , extrap ,                                                           &
+    rvoid  ,                                                                             &
+    cvar_pr   ,                                                                          &
+    coefa_p  , coefb_p  ,                                                                &
+    coefaf_p , coefbf_p ,                                                                &
+    viscf  , viscb  ,                                                                    &
+    cpro_permeability_6 ,                                                                &
+    weighf , weighb ,                                                                    &
     rhs   )
 
   endif
@@ -514,7 +515,7 @@ do while ( (isweep.le.nswmpr.and.residu.gt.epsrsm(ipr)*rnormp) &
   enddo
 
   ! --- Convergence test
-  call prodsc(ncel, isqrt, rhs, rhs, residu)
+  residu = sqrt(cs_gdot(ncel, rhs, rhs))
 
   ! Writing
   sinfo%nbivar = sinfo%nbivar + niterf
@@ -605,15 +606,15 @@ else if (darcy_anisotropic_permeability.eq.1) then
 
   call itrmav &
   !==========
- ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
-   iphydr , iwarnp ,                                              &
-   epsrgp , climgp , extrap ,                                     &
-   rvoid  ,                                                       &
-   presa  ,                                                       &
-   coefa_p , coefb_p , coefaf_p , coefbf_p ,                      &
-   viscf  , viscb  ,                                              &
-   cpro_permeability_6 ,                                          &
-   weighf , weighb ,                                              &
+ ( f_id0, init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp , &
+   iphydr , iwarnp ,                                                     &
+   epsrgp , climgp , extrap ,                                            &
+   rvoid  ,                                                              &
+   presa  ,                                                              &
+   coefa_p , coefb_p , coefaf_p , coefbf_p ,                             &
+   viscf  , viscb  ,                                                     &
+   cpro_permeability_6 ,                                                 &
+   weighf , weighb ,                                                     &
    imasfl , bmasfl )
 
   ! The last increment is not reconstructed to fullfill exactly the continuity
@@ -626,15 +627,15 @@ else if (darcy_anisotropic_permeability.eq.1) then
 
   call itrmav &
   !==========
- ( init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp ,  &
-   iphydr , iwarnp ,                                               &
-   epsrgp , climgp , extrap ,                                      &
-   rvoid  ,                                                        &
-   dpvar  ,                                                        &
-   coefa_p , coefb_p , coefaf_p , coefbf_p ,                       &
-   viscf  , viscb  ,                                               &
-   cpro_permeability_6 ,                                           &
-   weighf , weighb ,                                               &
+ ( f_id0, init   , inc    , imrgra , iccocg , nswrgp , imligp , ircflp ,  &
+   iphydr , iwarnp ,                                                      &
+   epsrgp , climgp , extrap ,                                             &
+   rvoid  ,                                                               &
+   dpvar  ,                                                               &
+   coefa_p , coefb_p , coefaf_p , coefbf_p ,                              &
+   viscf  , viscb  ,                                                      &
+   cpro_permeability_6 ,                                                  &
+   weighf , weighb ,                                                      &
    imasfl , bmasfl )
 
 endif
