@@ -58,6 +58,7 @@
 #include "fvm_hilbert.h"
 #include "fvm_morton.h"
 
+#include "cs_all_to_all.h"
 #include "cs_order.h"
 
 /*----------------------------------------------------------------------------
@@ -402,30 +403,23 @@ _fvm_io_num_global_order(fvm_io_num_t       *this_io_num,
                          const cs_lnum_t     n_sub_entities[],
                          MPI_Comm            comm)
 {
-
-  cs_gnum_t   n_ent_recv, num_prev, num_cur;
-  size_t      i, j, slice_size;
-  cs_lnum_t   k;
-  int         rank;
+  cs_gnum_t   num_prev, num_cur;
 
   _Bool       may_be_shared = false;
 
-  cs_gnum_t   *recv_global_num = NULL;
-  cs_lnum_t   *recv_n_sub = NULL, *recv_order = NULL;
-  int         *send_count = NULL, *recv_count = NULL;
-  int         *send_shift = NULL, *recv_shift = NULL;
+  cs_lnum_t  *b_nsub = NULL;
   int         have_sub_loc = 0, have_sub_glob = 0;
 
   int         local_rank, size;
 
-  cs_gnum_t   current_global_num = 0, global_num_shift = 0;
+  cs_gnum_t   current_gnum = 0, gnum_shift = 0;
 
   /* Initialization */
 
   MPI_Comm_rank(comm, &local_rank);
   MPI_Comm_size(comm, &size);
 
-  num_prev = 0;    /* true initialization later for slice 0, */
+  num_prev = 0;    /* true initialization later for block 0, */
 
   /* If numbering is shared, we will check later it was changed or if
      it can remain shared (in which case the copy may be discarded) */
@@ -439,49 +433,30 @@ _fvm_io_num_global_order(fvm_io_num_t       *this_io_num,
 
   this_io_num->global_count = _fvm_io_num_global_max(this_io_num, comm);
 
-  /* slice_size = ceil(this_io_num->global_count/size) */
+  /* block_size = ceil(this_io_num->global_count/size) */
 
-  slice_size = this_io_num->global_count / size;
-  if (this_io_num->global_count % size > 0)
-    slice_size += 1;
+  cs_block_dist_info_t
+    bi = cs_block_dist_compute_sizes(local_rank,
+                                     size,
+                                     1,
+                                     0,
+                                     this_io_num->global_count);
 
-  assert(sizeof(cs_gnum_t) >= sizeof(cs_lnum_t));
+  cs_all_to_all_t
+    *d = cs_all_to_all_create_from_block(this_io_num->global_num_size,
+                                         0, /* flags */
+                                         this_io_num->global_num,
+                                         bi,
+                                         comm);
 
-  BFT_MALLOC(send_count, size, int);
-  BFT_MALLOC(recv_count, size, int);
+  cs_gnum_t *b_gnum = cs_all_to_all_copy_array(d,
+                                               CS_GNUM_TYPE,
+                                               1,
+                                               false, /* reverse */
+                                               this_io_num->global_num,
+                                               NULL);
 
-  BFT_MALLOC(send_shift, size, int);
-  BFT_MALLOC(recv_shift, size, int);
-
-  /* Count number of values to send to each process */
-
-  for (rank = 0; rank < size; rank++)
-    send_count[rank] = 0;
-
-  for (i = 0; i < (size_t)(this_io_num->global_num_size); i++)
-    send_count[(this_io_num->global_num[i] - 1) / slice_size] += 1;
-
-  MPI_Alltoall(send_count, 1, MPI_INT, recv_count, 1, MPI_INT, comm);
-
-  send_shift[0] = 0;
-  recv_shift[0] = 0;
-
-  for (rank = 1; rank < size; rank++) {
-    send_shift[rank] = send_shift[rank - 1] + send_count[rank -1];
-    recv_shift[rank] = recv_shift[rank - 1] + recv_count[rank -1];
-  }
-
-  /* As data is sorted by increasing base global numbering, we do not
-     need to build an extra array, but only to send the correct parts
-     of the n_sub_entities[] array to the correct processors */
-
-  n_ent_recv = recv_shift[size - 1] + recv_count[size - 1];
-
-  BFT_MALLOC(recv_global_num, n_ent_recv, cs_gnum_t);
-  BFT_MALLOC(recv_order, n_ent_recv, cs_lnum_t);
-
-  MPI_Alltoallv(this_io_num->_global_num, send_count, send_shift, CS_MPI_GNUM,
-                recv_global_num, recv_count, recv_shift, CS_MPI_GNUM, comm);
+  cs_lnum_t b_size = cs_all_to_all_n_elts_dest(d);
 
   /* Do we have sub-entities ? */
 
@@ -490,107 +465,98 @@ _fvm_io_num_global_order(fvm_io_num_t       *this_io_num,
 
   MPI_Allreduce(&have_sub_loc, &have_sub_glob, 1, MPI_INT, MPI_MAX, comm);
 
-  if (have_sub_glob > 0) {
+  if (have_sub_glob > 0)
+    b_nsub = cs_all_to_all_copy_array(d,
+                                      CS_LNUM_TYPE,
+                                      1,
+                                      false, /* reverse */
+                                      n_sub_entities,
+                                      NULL);
 
-    cs_lnum_t   *send_n_sub;
+  if (b_size > 0) {
 
-    BFT_MALLOC(send_n_sub, this_io_num->global_num_size, cs_lnum_t);
-    BFT_MALLOC(recv_n_sub, n_ent_recv, cs_lnum_t);
+    cs_lnum_t *b_order;
 
-    if (n_sub_entities != NULL) {
-      for (i = 0; i < (size_t)(this_io_num->global_num_size); i++)
-        send_n_sub[i] = n_sub_entities[i];
-    }
-    else {
-      for (i = 0; i < (size_t)(this_io_num->global_num_size); i++)
-        send_n_sub[i] = 1;
-    }
-
-    MPI_Alltoallv(send_n_sub, send_count, send_shift, CS_MPI_LNUM,
-                  recv_n_sub, recv_count, recv_shift, CS_MPI_LNUM, comm);
-
-    BFT_FREE(send_n_sub);
-  }
-
-  if (n_ent_recv > 0) {
+    BFT_MALLOC(b_order, b_size, cs_lnum_t);
 
     cs_order_gnum_allocated(NULL,
-                            recv_global_num,
-                            recv_order,
-                            n_ent_recv);
+                            b_gnum,
+                            b_order,
+                            b_size);
 
     /* Determine global order; requires ordering to loop through buffer by
-       increasing number (slice blocks associated with each process are
-       already sorted, but the whole "gathered" slice is not).
+       increasing number (blocks associated with each process are
+       already sorted, but the whole "gathered" block is not).
        We build an initial global order based on the initial global numbering,
-       such that for each slice, the global number of an entity is equal to
+       such that for each block, the global number of an entity is equal to
        the cumulative number of sub-entities */
 
     if (have_sub_glob > 0) {
 
-      current_global_num = recv_n_sub[recv_order[0]];
-      num_prev = recv_global_num[recv_order[0]];
-      recv_global_num[recv_order[0]] = current_global_num;
+      current_gnum = b_nsub[b_order[0]];
+      num_prev = b_gnum[b_order[0]];
+      b_gnum[b_order[0]] = current_gnum;
 
-      for (i = 1; i < n_ent_recv; i++) {
-        num_cur = recv_global_num[recv_order[i]];
+      for (cs_lnum_t i = 1; i < b_size; i++) {
+        num_cur = b_gnum[b_order[i]];
         if (num_cur > num_prev)
-          current_global_num += recv_n_sub[recv_order[i]];
-        recv_global_num[recv_order[i]] = current_global_num;
+          current_gnum += b_nsub[b_order[i]];
+        b_gnum[b_order[i]] = current_gnum;
         num_prev = num_cur;
       }
 
     }
     else { /* if (have_sub_glob == 0) */
 
-      current_global_num = 1;
-      num_prev = recv_global_num[recv_order[0]];
-      recv_global_num[recv_order[0]] = current_global_num;
+      current_gnum = 1;
+      num_prev = b_gnum[b_order[0]];
+      b_gnum[b_order[0]] = current_gnum;
 
-      for (i = 1; i < n_ent_recv; i++) {
-        num_cur = recv_global_num[recv_order[i]];
+      for (cs_lnum_t i = 1; i < b_size; i++) {
+        num_cur = b_gnum[b_order[i]];
         if (num_cur > num_prev)
-          current_global_num += 1;
-        recv_global_num[recv_order[i]] = current_global_num;
+          current_gnum += 1;
+        b_gnum[b_order[i]] = current_gnum;
         num_prev = num_cur;
       }
 
     }
 
+    BFT_FREE(b_order);
+
   }
 
   /* Partial clean-up */
 
-  BFT_FREE(recv_n_sub);
-  BFT_FREE(recv_order);
+  BFT_FREE(b_nsub);
 
-  /* At this stage, recv_global_num[] is valid for this process, and
-     current_global_num indicates the total number of entities handled
+  /* At this stage, b_gnum[] is valid for this process, and
+     current_gnum indicates the total number of entities handled
      by this process; we must now shift global numberings on different
      processes by the cumulative total number of entities handled by
      each process */
 
-  MPI_Scan(&current_global_num, &global_num_shift, 1, CS_MPI_GNUM,
+  MPI_Scan(&current_gnum, &gnum_shift, 1, CS_MPI_GNUM,
            MPI_SUM, comm);
-  global_num_shift -= current_global_num;
+  gnum_shift -= current_gnum;
 
-  for (i = 0; i < n_ent_recv; i++)
-    recv_global_num[i] += global_num_shift;
+  for (cs_lnum_t i = 0; i < b_size; i++)
+    b_gnum[i] += gnum_shift;
 
   /* Return global order to all processors */
 
-  MPI_Alltoallv(recv_global_num, recv_count, recv_shift, CS_MPI_GNUM,
-                this_io_num->_global_num, send_count, send_shift, CS_MPI_GNUM,
-                comm);
+  cs_all_to_all_copy_array(d,
+                           CS_GNUM_TYPE,
+                           1,
+                           true, /* reverse */
+                           b_gnum,
+                           this_io_num->_global_num);
 
   /* Free memory */
 
-  BFT_FREE(recv_global_num);
+  BFT_FREE(b_gnum);
 
-  BFT_FREE(send_count);
-  BFT_FREE(recv_count);
-  BFT_FREE(send_shift);
-  BFT_FREE(recv_shift);
+  cs_all_to_all_destroy(&d);
 
   /* Get final maximum global number value */
 
@@ -602,14 +568,15 @@ _fvm_io_num_global_order(fvm_io_num_t       *this_io_num,
 
   if (n_sub_entities != NULL) {
 
+    cs_lnum_t i, j, k;
     cs_gnum_t *_global_num;
 
-    for (i = 0, j = 0; i < (size_t)(this_io_num->global_num_size); i++)
+    for (i = 0, j = 0; i < this_io_num->global_num_size; i++)
       j += n_sub_entities[i];
 
     BFT_MALLOC(_global_num, j, cs_gnum_t);
 
-    for (i = 0, j = 0; i < (size_t)(this_io_num->global_num_size); i++) {
+    for (i = 0, j = 0; i < this_io_num->global_num_size; i++) {
       for (k = 0; k < n_sub_entities[i]; j++, k++)
         _global_num[j] = this_io_num->_global_num[i] - n_sub_entities[i] + k + 1;
     }
@@ -630,22 +597,26 @@ _fvm_io_num_global_order(fvm_io_num_t       *this_io_num,
      may remain shared (in which case the copy may be discarded) */
 
   if (may_be_shared == true) {
-    for (i = 0; i < (size_t)(this_io_num->global_num_size); i++)
+    cs_lnum_t i;
+    for (i = 0; i < this_io_num->global_num_size; i++)
       if (this_io_num->_global_num[i] != this_io_num->global_num[i])
         break;
-    if (i < (size_t)(this_io_num->global_num_size))
+    if (i < this_io_num->global_num_size)
       this_io_num->global_num = this_io_num->_global_num;
     else
       BFT_FREE(this_io_num->_global_num);
   }
+
+  /* Get final maximum global number value */
+
+  this_io_num->global_count = _fvm_io_num_global_max(this_io_num, comm);
 }
 
 /*----------------------------------------------------------------------------
  * Global ordering associated with an I/O numbering structure.
  *
- * The structure should contain an initial ordering, which should
- * be sorted, but need not be contiguous. On output, the numbering
- * will be contiguous.
+ * The structure does not need to contain an initial ordering,
+ * though the array should be allocated.
  *
  * parameters:
  *   this_io_num    <-> pointer to structure that should be ordered
@@ -660,18 +631,10 @@ _fvm_io_num_global_order_s(fvm_io_num_t       *this_io_num,
                            cs_gnum_t           global_num[],
                            MPI_Comm            comm)
 {
-  cs_gnum_t   n_ent_recv;
-  size_t      i, j, slice_size;
-  int         rank;
+  int  local_rank, size;
+  cs_gnum_t current_gnum = 0, gnum_shift = 0;
 
-  cs_gnum_t   *block_global_num = NULL, *recv_global_num = NULL;
-  cs_lnum_t   *recv_order = NULL;
-  int         *send_count = NULL, *recv_count = NULL;
-  int         *send_shift = NULL, *recv_shift = NULL;
-
-  int         local_rank, size;
-
-  cs_gnum_t   current_global_num = 0, global_num_shift = 0;
+  cs_gnum_t *r_gnum = NULL;
 
   /* Initialization */
 
@@ -691,130 +654,115 @@ _fvm_io_num_global_order_s(fvm_io_num_t       *this_io_num,
     this_io_num->global_count = global_max;
   }
 
-  /* slice_size = ceil(this_io_num->global_count/size) */
+  /* block_info */
 
-  slice_size = this_io_num->global_count / size;
-  if (this_io_num->global_count % size > 0)
-    slice_size += 1;
+  cs_block_dist_info_t
+    bi = cs_block_dist_compute_sizes(local_rank,
+                                     size,
+                                     1,
+                                     0,
+                                     this_io_num->global_count);
 
-  assert(sizeof(cs_gnum_t) >= sizeof(cs_lnum_t));
+  const cs_gnum_t block_size = bi.block_size;
 
-  BFT_MALLOC(send_count, size, int);
-  BFT_MALLOC(recv_count, size, int);
+  int *dest_rank;
+  BFT_MALLOC(dest_rank, this_io_num->global_num_size, int);
 
-  BFT_MALLOC(send_shift, size, int);
-  BFT_MALLOC(recv_shift, size, int);
-
-  /* Count number of values to send to each process */
-
-  for (rank = 0; rank < size; rank++)
-    send_count[rank] = 0;
-
-  for (i = 0; i < (size_t)(this_io_num->global_num_size); i++)
-    send_count[(global_num[stride*i] - 1) / slice_size] += stride;
-
-  MPI_Alltoall(send_count, 1, MPI_INT, recv_count, 1, MPI_INT, comm);
-
-  send_shift[0] = 0;
-  recv_shift[0] = 0;
-
-  for (rank = 1; rank < size; rank++) {
-    send_shift[rank] = send_shift[rank - 1] + send_count[rank -1];
-    recv_shift[rank] = recv_shift[rank - 1] + recv_count[rank -1];
+  for (cs_lnum_t i = 0; i < this_io_num->global_num_size; i++) {
+    cs_gnum_t g_elt_id = global_num[stride*i] - 1;
+    dest_rank[i] = g_elt_id / block_size;
   }
 
-  /* As data is sorted by increasing base global numbering, we do not
-     need to build an extra array, but only to send the correct parts
-     of the n_sub_entities[] array to the correct processors */
+  cs_all_to_all_t
+    *d = cs_all_to_all_create(this_io_num->global_num_size,
+                              0,      /* flags */
+                              NULL,  /* dest_id */
+                              dest_rank,
+                              comm);
 
-  n_ent_recv = (recv_shift[size - 1] + recv_count[size - 1]) / stride;
+  cs_all_to_all_transfer_dest_rank(d, &dest_rank);
 
-  BFT_MALLOC(recv_global_num, stride*n_ent_recv, cs_gnum_t);
-  BFT_MALLOC(recv_order, n_ent_recv, cs_lnum_t);
+  cs_gnum_t *b_gnum = cs_all_to_all_copy_array(d,
+                                               CS_GNUM_TYPE,
+                                               stride,
+                                               false, /* reverse */
+                                               global_num,
+                                               NULL);
 
-  MPI_Alltoallv(global_num, send_count, send_shift, CS_MPI_GNUM,
-                recv_global_num, recv_count, recv_shift, CS_MPI_GNUM, comm);
+  cs_lnum_t b_size = cs_all_to_all_n_elts_dest(d);
 
-  if (n_ent_recv > 0) {
+  /* Order received data based on global number sets */
 
-    size_t prev_id, cur_id;
+  if (b_size > 0) {
+
+    cs_lnum_t *b_order = NULL;
+
+    BFT_MALLOC(r_gnum, b_size, cs_gnum_t);
+    BFT_MALLOC(b_order, b_size, cs_lnum_t);
 
     cs_order_gnum_allocated_s(NULL,
-                              recv_global_num,
+                              b_gnum,
                               stride,
-                              recv_order,
-                              n_ent_recv);
+                              b_order,
+                              b_size);
 
-    /* Determine global order; requires ordering to loop through buffer by
-       increasing number (slice blocks associated with each process are
-       already sorted, but the whole "gathered" slice is not).
-       We build an initial global order based on the initial global numbering,
-       such that for each slice, the global number of an entity is equal to
+    /* We build an initial global order based on the initial global numbering,
+       such that for each block, the global number of an entity is equal to
        the cumulative number of sub-entities */
 
-    BFT_MALLOC(block_global_num, n_ent_recv, cs_gnum_t);
+    current_gnum = 1;
+    cs_lnum_t prev_id = b_order[0];
+    r_gnum[b_order[0]] = current_gnum;
 
-    current_global_num = 1;
-    prev_id = recv_order[0];
-    block_global_num[recv_order[0]] = current_global_num;
+    const cs_lnum_t _stride = stride;
 
-    for (i = 1; i < n_ent_recv; i++) {
+    for (cs_lnum_t i = 1; i < b_size; i++) {
       bool greater_than_prev = false;
-      cur_id = recv_order[i];
-      for (j = 0; j < stride; j++) {
-        if (  recv_global_num[cur_id*stride + j]
-            > recv_global_num[prev_id*stride + j])
+      cs_lnum_t cur_id = b_order[i];
+      for (cs_lnum_t j = 0; j < _stride; j++) {
+        if (  b_gnum[cur_id*_stride + j]
+            > b_gnum[prev_id*_stride + j])
           greater_than_prev = true;
       }
       if (greater_than_prev)
-        current_global_num += 1;
-      block_global_num[recv_order[i]] = current_global_num;
+        current_gnum += 1;
+      r_gnum[b_order[i]] = current_gnum;
       prev_id = cur_id;
     }
 
+    BFT_FREE(b_order);
+
   }
 
-  /* Partial clean-up */
+  BFT_FREE(b_gnum);
 
-  BFT_FREE(recv_order);
-  BFT_FREE(recv_global_num);
-
-  /* At this stage, recv_global_num[] is valid for this process, and
-     current_global_num indicates the total number of entities handled
+  /* At this stage, r_gnum[] is valid for this process, and
+     current_gnum indicates the total number of entities handled
      by this process; we must now shift global numberings on different
      processes by the cumulative total number of entities handled by
      each process */
 
-  MPI_Scan(&current_global_num, &global_num_shift, 1, CS_MPI_GNUM,
+  MPI_Scan(&current_gnum, &gnum_shift, 1, CS_MPI_GNUM,
            MPI_SUM, comm);
-  global_num_shift -= current_global_num;
+  gnum_shift -= current_gnum;
 
-  for (i = 0; i < n_ent_recv; i++)
-    block_global_num[i] += global_num_shift;
+  for (cs_lnum_t i = 0; i < b_size; i++)
+    r_gnum[i] += gnum_shift;
 
-  /* Return global order to all processors */
+  /* Return global order to all ranks */
 
-  for (rank = 0; rank < size; rank++) {
-    send_count[rank] /= stride;
-    recv_count[rank] /= stride;
-  }
+  cs_all_to_all_copy_array(d,
+                           CS_GNUM_TYPE,
+                           1,
+                           true, /* reverse */
+                           r_gnum,
+                           this_io_num->_global_num);
 
-  for (rank = 1; rank < size; rank++) {
-    send_shift[rank] = send_shift[rank - 1] + send_count[rank -1];
-    recv_shift[rank] = recv_shift[rank - 1] + recv_count[rank -1];
-  }
+  /* Partial clean-up */
 
-  MPI_Alltoallv(block_global_num, recv_count, recv_shift, CS_MPI_GNUM,
-                this_io_num->_global_num, send_count, send_shift, CS_MPI_GNUM,
-                comm);
+  BFT_FREE(r_gnum);
 
-  /* Free memory */
-
-  BFT_FREE(block_global_num);
-  BFT_FREE(send_count);
-  BFT_FREE(recv_count);
-  BFT_FREE(send_shift);
-  BFT_FREE(recv_shift);
+  cs_all_to_all_destroy(&d);
 
   /* Get final maximum global number value */
 
@@ -893,7 +841,7 @@ _fvm_io_num_global_order_index(fvm_io_num_t       *this_io_num,
                                MPI_Comm            comm)
 {
   int  rank, local_rank, size;
-  size_t  i, shift, slice_size;
+  size_t  i, shift, block_size;
 
   cs_gnum_t   n_ent_recv = 0, n_ent_send = 0;
   cs_gnum_t   current_global_num = 0, global_num_shift = 0;
@@ -921,13 +869,13 @@ _fvm_io_num_global_order_index(fvm_io_num_t       *this_io_num,
     this_io_num->global_count = global_max;
   }
 
-  /* slice_size = ceil(this_io_num->global_count/size) */
+  /* block_size = ceil(this_io_num->global_count/size) */
 
-  slice_size = this_io_num->global_count / size;
+  block_size = this_io_num->global_count / size;
   if (this_io_num->global_count % size > 0)
-    slice_size += 1;
+    block_size += 1;
 
-  /* Build for each slice, a new ordered indexed list from the received
+  /* Build for each block, a new ordered indexed list from the received
      elements */
 
   assert(sizeof(cs_gnum_t) >= sizeof(cs_lnum_t));
@@ -943,7 +891,7 @@ _fvm_io_num_global_order_index(fvm_io_num_t       *this_io_num,
     send_count[rank] = 0;
 
   for (i = 0; i < (size_t)(this_io_num->global_num_size); i++) {
-    rank = (global_num[index[i]] - 1) / slice_size;
+    rank = (global_num[index[i]] - 1) / block_size;
     send_count[rank] += 1;
   }
 
@@ -971,7 +919,7 @@ _fvm_io_num_global_order_index(fvm_io_num_t       *this_io_num,
     send_count[rank] = 0;
 
   for (i = 0; i < (size_t)this_io_num->global_num_size; i++) {
-    rank = (global_num[index[i]] - 1) / slice_size;
+    rank = (global_num[index[i]] - 1) / block_size;
     shift = send_shift[rank] + send_count[rank];
     send_sub_count[shift] = index[i+1] - index[i];
     send_count[rank] +=  1;
@@ -997,7 +945,7 @@ _fvm_io_num_global_order_index(fvm_io_num_t       *this_io_num,
     send_count[rank] = 0;
 
   for (i = 0; i < (size_t)(this_io_num->global_num_size); i++) {
-    rank = (global_num[index[i]] - 1) / slice_size;
+    rank = (global_num[index[i]] - 1) / block_size;
     send_count[rank] += index[i+1] - index[i];
   }
 
@@ -1033,10 +981,10 @@ _fvm_io_num_global_order_index(fvm_io_num_t       *this_io_num,
                               n_ent_recv);
 
     /* Determine global order; requires ordering to loop through buffer by
-       increasing number (slice blocks associated with each process are
-       already sorted, but the whole "gathered" slice is not).
+       increasing number (blocks associated with each process are
+       already sorted, but the whole "gathered" block is not).
        We build an initial global order based on the initial global numbering,
-       such that for each slice, the global number of an entity is equal to
+       such that for each block, the global number of an entity is equal to
        the cumulative number of elements */
 
     BFT_MALLOC(block_global_num, n_ent_recv, cs_gnum_t);
@@ -1086,7 +1034,7 @@ _fvm_io_num_global_order_index(fvm_io_num_t       *this_io_num,
     send_count[rank] = 0;
 
   for (i = 0; i < (size_t)(this_io_num->global_num_size); i++) {
-    rank = (global_num[index[i]] - 1) / slice_size;
+    rank = (global_num[index[i]] - 1) / block_size;
     send_count[rank] += 1;
   }
 
@@ -1138,7 +1086,7 @@ _fvm_io_num_global_sub_size(const fvm_io_num_t  *this_io_num,
 {
 
   cs_gnum_t   global_count, n_ent_recv, num_prev, num_cur;
-  size_t      i, slice_size;
+  size_t      i, block_size;
   int         rank;
 
   cs_gnum_t   *recv_global_num = NULL;
@@ -1157,17 +1105,17 @@ _fvm_io_num_global_sub_size(const fvm_io_num_t  *this_io_num,
 
   MPI_Comm_size(comm, &size);
 
-  num_prev = 0;    /* true initialization later for slice 0, */
+  num_prev = 0;    /* true initialization later for block 0, */
 
   /* Get temporary maximum global number value */
 
   global_count = _fvm_io_num_global_max(this_io_num, comm);
 
-  /* slice_size = ceil(this_io_num->global_count/size) */
+  /* block_size = ceil(this_io_num->global_count/size) */
 
-  slice_size = global_count / size;
+  block_size = global_count / size;
   if (global_count % size > 0)
-    slice_size += 1;
+    block_size += 1;
 
   assert(sizeof(cs_gnum_t) >= sizeof(cs_lnum_t));
 
@@ -1183,7 +1131,7 @@ _fvm_io_num_global_sub_size(const fvm_io_num_t  *this_io_num,
     send_count[rank] = 0;
 
   for (i = 0; i < (size_t)(this_io_num->global_num_size); i++)
-    send_count[(this_io_num->global_num[i] - 1) / slice_size] += 1;
+    send_count[(this_io_num->global_num[i] - 1) / block_size] += 1;
 
   MPI_Alltoall(send_count, 1, MPI_INT, recv_count, 1, MPI_INT, comm);
 
@@ -1258,10 +1206,10 @@ _fvm_io_num_global_sub_size(const fvm_io_num_t  *this_io_num,
                             n_ent_recv);
 
     /* Determine global order; requires ordering to loop through buffer by
-       increasing number (slice blocks associated with each process are
-       already sorted, but the whole "gathered" slice is not).
+       increasing number (blocks associated with each process are
+       already sorted, but the whole "gathered" block is not).
        We build an initial global order based on the initial global numbering,
-       such that for each slice, the global number of an entity is equal to
+       such that for each block, the global number of an entity is equal to
        the cumulative number of sub-entities */
 
     current_global_num = recv_n_sub[recv_order[0]];
@@ -1522,10 +1470,10 @@ _create_from_coords_morton(const cs_coord_t  coords[],
     _check_morton_ordering(dim, n_block_ents, recv_coords, m_code, order);
 
     /* Determine global order; requires ordering to loop through buffer by
-       increasing number (slice blocks associated with each process are
-       already sorted, but the whole "gathered" slice is not).
+       increasing number (blocks associated with each process are
+       already sorted, but the whole "gathered" block is not).
        We build an initial global order based on the initial global numbering,
-       such that for each slice, the global number of an entity is equal to
+       such that for each block, the global number of an entity is equal to
        the cumulative number of sub-entities */
 
     BFT_FREE(m_code);
@@ -1789,10 +1737,10 @@ _create_from_coords_hilbert(const cs_coord_t  coords[],
                                    order);
 
     /* Determine global order; requires ordering to loop through buffer by
-       increasing number (slice blocks associated with each process are
-       already sorted, but the whole "gathered" slice is not).
+       increasing number (blocks associated with each process are
+       already sorted, but the whole "gathered" block is not).
        We build an initial global order based on the initial global numbering,
-       such that for each slice, the global number of an entity is equal to
+       such that for each block, the global number of an entity is equal to
        the cumulative number of sub-entities */
 
     BFT_FREE(recv_coords);
