@@ -33,8 +33,9 @@
  *  Local headers
  *----------------------------------------------------------------------------*/
 
+#include "cs_block_dist.h"
+#include "cs_part_to_block.h"
 #include "fvm_defs.h"
-#include "fvm_gather.h"
 #include "fvm_nodal.h"
 #include "fvm_writer.h"
 
@@ -70,7 +71,7 @@ typedef struct _fvm_writer_section_t {
                                            differ from  section->type when
                                            using tesselations) */
 
-  _Bool   continues_previous;           /* Indicates if the corresponding FVM
+  bool    continues_previous;           /* Indicates if the corresponding FVM
                                            nodal section should be appended
                                            to the previous one on output */
 
@@ -87,6 +88,28 @@ typedef struct _fvm_writer_section_t {
 
 typedef struct _fvm_writer_field_helper_t fvm_writer_field_helper_t;
 
+/*----------------------------------------------------------------------------
+ * Function pointer for output of field values by a writer helper
+ *
+ * parameters:
+ *   context      <-> pointer to writer and field context
+ *   datatype     <-- output datatype
+ *   dimension    <-- output field dimension
+ *   component_id <-- output component id (if non-interleaved)
+ *   block_start  <-- start global number of element for current block
+ *   block_end    <-- past-the-end global number of element for current block
+ *   buffer       <-> associated output buffer
+ *----------------------------------------------------------------------------*/
+
+typedef void
+(fvm_writer_field_output_t) (void           *context,
+                             cs_datatype_t   datatype,
+                             int             dimension,
+                             int             component_id,
+                             cs_gnum_t       block_start,
+                             cs_gnum_t       block_end,
+                             void           *buffer);
+
 /*=============================================================================
  * Semi-private function prototypes
  *============================================================================*/
@@ -100,7 +123,8 @@ typedef struct _fvm_writer_field_helper_t fvm_writer_field_helper_t;
  *
  * parameters:
  *   mesh                 <-- pointer to nodal mesh structure
- *   group_same_type      <-- group sections of the same type
+ *   group_by_type        <-- if true, group sections of same type
+ *   group_all            <-- if true, all sections continue previous ones
  *   min_export_dim       <-- minimum dimension of sections to export
  *   discard_polygons     <-- ignore polygonal sections
  *   discard_polyhedra    <-- ignore polyhedral sections
@@ -113,13 +137,73 @@ typedef struct _fvm_writer_field_helper_t fvm_writer_field_helper_t;
  *----------------------------------------------------------------------------*/
 
 fvm_writer_section_t *
-fvm_writer_export_list(const fvm_nodal_t  *mesh,
-                       int                 min_export_dim,
-                       _Bool               group_same_type,
-                       _Bool               discard_polygons,
-                       _Bool               discard_polyhedra,
-                       _Bool               divide_polygons,
-                       _Bool               divide_polyhedra);
+fvm_writer_export_list(const fvm_nodal_t          *mesh,
+                       int                         min_export_dim,
+                       bool                        group_by_type,
+                       bool                        group_all,
+                       bool                        discard_polygons,
+                       bool                        discard_polyhedra,
+                       bool                        divide_polygons,
+                       bool                        divide_polyhedra);
+
+/*----------------------------------------------------------------------------
+ * Count number of extra vertices when tesselations are present
+ *
+ * parameters:
+ *   mesh               <-- pointer to nodal mesh structure
+ *   divide_polyhedra   <-- true if polyhedra are tesselated
+ *   n_extra_vertices_g --> global number of extra vertices (optional)
+ *   n_extra_vertices   --> local number of extra vertices (optional)
+ *----------------------------------------------------------------------------*/
+
+void
+fvm_writer_count_extra_vertices(const fvm_nodal_t  *mesh,
+                                bool                divide_polyhedra,
+                                cs_gnum_t          *n_extra_vertices_g,
+                                cs_lnum_t          *n_extra_vertices);
+
+#if defined(HAVE_MPI)
+
+/*----------------------------------------------------------------------------
+ * Build block info and part to block distribution helper for vertices.
+ *
+ * parameters:
+ *   min_rank_step    <-- minimum step between output ranks
+ *   min_block_size   <-- minimum block buffer size
+ *   n_g_add_vertices <-- global number of vertices due to tesselated polyhedra
+ *   n_add_vertices   <-- local number of vertices due to tesselated polyhedra
+ *   mesh             <-- pointer to nodal mesh structure
+ *   bi               --> block information structure
+ *   d                --> part to block distributor
+ *   comm             <-- associated communicator
+ *----------------------------------------------------------------------------*/
+
+void
+fvm_writer_vertex_part_to_block_create(int                     min_rank_step,
+                                       cs_lnum_t               min_block_size,
+                                       cs_gnum_t               n_g_add_vertices,
+                                       cs_lnum_t               n_add_vertices,
+                                       const fvm_nodal_t      *mesh,
+                                       cs_block_dist_info_t   *bi,
+                                       cs_part_to_block_t    **d,
+                                       MPI_Comm                comm);
+
+#endif /* defined(HAVE_MPI) */
+
+/*----------------------------------------------------------------------------
+ * Return extra vertex coordinates when tesselations are present
+ *
+ * parameters:
+ *   mesh             <-- pointer to nodal mesh structure
+ *   n_extra_vertices <-- number of extra vertices
+ *
+ * returns:
+ *   array containing all extra vertex coordinates
+ *----------------------------------------------------------------------------*/
+
+cs_coord_t *
+fvm_writer_extra_vertex_coords(const fvm_nodal_t  *mesh,
+                               cs_lnum_t           n_extra_vertices);
 
 /*----------------------------------------------------------------------------
  * Create field writer helper structure.
@@ -150,29 +234,22 @@ fvm_writer_field_helper_create(const fvm_nodal_t          *mesh,
 /*----------------------------------------------------------------------------
  * Destroy FVM field writer helper.
  *
- * parameters:
- *   helper <-> pointer to structure that should be destroyed
- *
- * returns:
- *   NULL pointer
+ * parameters: *   helper <-> pointer to pointer to structure that should be destroyed
  *----------------------------------------------------------------------------*/
 
-fvm_writer_field_helper_t *
-fvm_writer_field_helper_destroy(fvm_writer_field_helper_t *helper);
+void
+fvm_writer_field_helper_destroy(fvm_writer_field_helper_t **helper);
 
 #if defined(HAVE_MPI)
 
 /*----------------------------------------------------------------------------
- * Initialize global values for an fvm_writer_field_helper structure.
- *
- * Internal buffers for gathering of data to rank 0 of the given
- * communicator are also allocated.
+ * Set MPI info for an fvm_writer_field_helper structure.
  *
  * parameters:
- *   helper        <-> pointer to structure that should be initialized
- *   section_list  <-- point to export section list helper structure
- *   mesh          <-- pointer to nodal mesh structure
- *   comm          <-- associated MPI communicator
+ *   helper         <-> pointer to structure that should be initialized
+ *   min_rank_step  <-- minimum step between output ranks
+ *   min_block_size <-- minimum block buffer size
+ *   comm           <-- associated MPI communicator
  *
  * returns:
  *   pointer to allocated and initialized field writer helper
@@ -180,8 +257,8 @@ fvm_writer_field_helper_destroy(fvm_writer_field_helper_t *helper);
 
 void
 fvm_writer_field_helper_init_g(fvm_writer_field_helper_t   *helper,
-                               const fvm_writer_section_t  *section_list,
-                               const fvm_nodal_t           *mesh,
+                               int                          min_rank_step,
+                               int                          min_block_size,
                                MPI_Comm                     comm);
 
 #endif /* defined(HAVE_MPI) */
@@ -193,10 +270,6 @@ fvm_writer_field_helper_init_g(fvm_writer_field_helper_t   *helper,
  *   helper                   <-- pointer to helper structure
  *   input_size               --> Total field locations in input (or NULL)
  *   output_size              --> Total field locations in output (or NULL)
- *   max_grouped_elements_out --> Max. field locations in a single group
- *                                (elements of a given type if sections are
- *                                grouped, elements of a given section
- *                                otherwise; NULL if unused)
  *   min_output_buffer_size   --> Minimum required buffer size (or NULL)
  *----------------------------------------------------------------------------*/
 
@@ -204,7 +277,6 @@ void
 fvm_writer_field_helper_get_size(const fvm_writer_field_helper_t  *helper,
                                  size_t  *input_size,
                                  size_t  *output_size,
-                                 size_t  *max_grouped_elements_out,
                                  size_t  *min_output_buffer_size);
 
 /*----------------------------------------------------------------------------
@@ -234,7 +306,7 @@ cs_datatype_t
 fvm_writer_field_helper_datatype(const fvm_writer_field_helper_t  *helper);
 
 /*----------------------------------------------------------------------------
- * Partially distribute field values to an output buffer.
+ * Partially distribute field values to a local output buffer.
  *
  * parameters:
  *   helper             <-> pointer to helper structure
@@ -262,21 +334,21 @@ fvm_writer_field_helper_datatype(const fvm_writer_field_helper_t  *helper);
  *----------------------------------------------------------------------------*/
 
 int
-fvm_writer_field_helper_step_e(fvm_writer_field_helper_t   *helper,
-                               const fvm_writer_section_t  *export_section,
-                               int                          src_dim,
-                               int                          src_dim_shift,
-                               cs_interlace_t               src_interlace,
-                               int                          n_parent_lists,
-                               const cs_lnum_t              parent_num_shift[],
-                               cs_datatype_t                datatype,
-                               const void            *const field_values[],
-                               void                        *output_buffer,
-                               size_t                       output_buffer_size,
-                               size_t                      *output_size);
+fvm_writer_field_helper_step_el(fvm_writer_field_helper_t   *helper,
+                                const fvm_writer_section_t  *export_section,
+                                int                          src_dim,
+                                int                          src_dim_shift,
+                                cs_interlace_t               src_interlace,
+                                int                          n_parent_lists,
+                                const cs_lnum_t              parent_num_shift[],
+                                cs_datatype_t                datatype,
+                                const void            *const field_values[],
+                                void                        *output_buffer,
+                                size_t                       output_buffer_size,
+                                size_t                      *output_size);
 
 /*----------------------------------------------------------------------------
- * Partially distribute per node field values to an output buffer.
+ * Partially distribute per node field values to a local output buffer.
  *
  * parameters:
  *   helper             <-> pointer to helper structure
@@ -304,18 +376,102 @@ fvm_writer_field_helper_step_e(fvm_writer_field_helper_t   *helper,
  *----------------------------------------------------------------------------*/
 
 int
-fvm_writer_field_helper_step_n(fvm_writer_field_helper_t   *helper,
-                               const fvm_nodal_t           *mesh,
-                               int                          src_dim,
-                               int                          src_dim_shift,
-                               cs_interlace_t               src_interlace,
-                               int                          n_parent_lists,
-                               const cs_lnum_t              parent_num_shift[],
-                               cs_datatype_t                datatype,
-                               const void            *const field_values[],
-                               void                        *output_buffer,
-                               size_t                       output_buffer_size,
-                               size_t                      *output_size);
+fvm_writer_field_helper_step_nl(fvm_writer_field_helper_t   *helper,
+                                const fvm_nodal_t           *mesh,
+                                int                          src_dim,
+                                int                          src_dim_shift,
+                                cs_interlace_t               src_interlace,
+                                int                          n_parent_lists,
+                                const cs_lnum_t              parent_num_shift[],
+                                cs_datatype_t                datatype,
+                                const void            *const field_values[],
+                                void                        *output_buffer,
+                                size_t                       output_buffer_size,
+                                size_t                      *output_size);
+
+/*----------------------------------------------------------------------------
+ * Output per element field values, using writer-specific function
+ * and context structure pointers.
+ *
+ * Note that if the output data is not interleaved, for multidimensional data,
+ * the output function is called once per component, using the same buffer.
+ * This is a good fit for most options, but if a format requires writing
+ * additional buffering may be required in the context.
+ *
+ * parameters:
+ *   helper           <-> pointer to helper structure
+ *   context          <-> pointer to writer context
+ *   export_section   <-- pointer to section helper structure
+ *   src_dim          <-- dimension of source data
+ *   src_interlace    <-- indicates if field in memory is interlaced
+ *   comp_order       <-- field component reordering array, or NULL
+ *   n_parent_lists   <-- indicates if field values are to be obtained
+ *                        directly through the local entity index (when 0) or
+ *                        through the parent entity numbers (when 1 or more)
+ *   parent_num_shift <-- parent list to common number index shifts;
+ *                        size: n_parent_lists
+ *   datatype         <-- indicates the data type of (source) field values
+ *   field_values     <-- array of associated field value arrays
+ *   output_func      <-- pointer to output function
+ *
+ * returns:
+ *   pointer to next section helper structure in list
+ *----------------------------------------------------------------------------*/
+
+const fvm_writer_section_t *
+fvm_writer_field_helper_output_e(fvm_writer_field_helper_t   *helper,
+                                 void                        *context,
+                                 const fvm_writer_section_t  *export_section,
+                                 int                          src_dim,
+                                 cs_interlace_t               src_interlace,
+                                 const int                   *comp_order,
+                                 int                          n_parent_lists,
+                                 const cs_lnum_t              parent_num_shift[],
+                                 cs_datatype_t                datatype,
+                                 const void            *const field_values[],
+                                 fvm_writer_field_output_t   *output_func);
+
+/*----------------------------------------------------------------------------
+ * Output per node field values, using writer-specific function
+ * and context structure pointers.
+ *
+ * Note that if the output data is not interleaved, for multidimensional data,
+ * the output function is called once per component, using the same buffer.
+ * This is a good fit for most options, but if a format requires writing
+ * additional buffering may be required in the context.
+ *
+ * parameters:
+ *   helper             <-> pointer to helper structure
+ *   context            <-> pointer to writer context
+ *   mesh               <-- pointer to nodal mesh
+ *   divide_polyhedra   <-- tesselate polyhedral sections
+ *   src_dim            <-- dimension of source data
+ *   src_dim_shift      <-- source data dimension shift (start index)
+ *   src_interlace      <-- indicates if field in memory is interlaced
+ *   n_parent_lists     <-- indicates if field values are to be obtained
+ *                          directly through the local entity index (when 0) or
+ *                          through the parent entity numbers (when 1 or more)
+ *   parent_num_shift   <-- parent list to common number index shifts;
+ *                          size: n_parent_lists
+ *   datatype           <-- indicates the data type of (source) field values
+ *   field_values       <-- array of associated field value arrays
+ *   datatype           <-- input data type
+ *   field_values       <-- pointer to input array
+ *   output_func        <-- pointer to output function
+ *----------------------------------------------------------------------------*/
+
+void
+fvm_writer_field_helper_output_n(fvm_writer_field_helper_t  *helper,
+                                 void                       *context,
+                                 const fvm_nodal_t          *mesh,
+                                 int                         src_dim,
+                                 cs_interlace_t              src_interlace,
+                                 const int                  *comp_order,
+                                 int                         n_parent_lists,
+                                 const cs_lnum_t             parent_num_shift[],
+                                 cs_datatype_t               datatype,
+                                 const void           *const field_values[],
+                                 fvm_writer_field_output_t  *output_func);
 
 /*----------------------------------------------------------------------------*/
 
