@@ -66,10 +66,13 @@
 #include "cs_base.h"
 #include "cs_gui_util.h"
 #include "cs_gui_variables.h"
+#include "cs_mesh_location.h"
 #include "cs_selector.h"
 #include "cs_post.h"
 #include "cs_field.h"
 #include "cs_field_pointer.h"
+#include "cs_parameters.h"
+#include "cs_thermal_model.h"
 #include "cs_time_moment.h"
 
 /*----------------------------------------------------------------------------
@@ -1111,7 +1114,7 @@ void CS_PROCF (cspstb, CSPSTB) (cs_int_t        *ipstdv)
 
   /* Surfacic variables output */
 
-  for (int i = 0; i < 6; i++)
+  for (int i = 0; i < 5; i++)
     ipstdv[i] = 0;
 
   if (_surfacic_variable_post("stress", true))
@@ -1127,10 +1130,16 @@ void CS_PROCF (cspstb, CSPSTB) (cs_int_t        *ipstdv)
     ipstdv[2] = 1;
   if (_surfacic_variable_post("thermal_flux", true))
     ipstdv[3] = 1;
-  if (_surfacic_variable_post("boundary_temperature", true))
-    ipstdv[4] = 1;
+  if (_surfacic_variable_post("boundary_temperature", true)) {
+    cs_field_t *bf = cs_parameters_add_boundary_temperature();
+    if (bf != NULL) {
+      int k_vis = cs_field_key_id("post_vis");
+      cs_field_set_key_int(bf, k_vis, 1);
+    }
+  }
+
   if (_surfacic_variable_post("boundary_layer_nusselt", true))
-    ipstdv[5] = 1;
+    ipstdv[4] = 1;
 }
 
 /*----------------------------------------------------------------------------
