@@ -122,13 +122,13 @@ static char  ** _cs_gui_var_rayt = NULL;
  * Return integer parameters for radiation
  *
  *   parameters:
- *    param    -->   name of parameter
- *    keyword  <--   value of parameter
+ *    param    <--   name of parameter
+ *    keyword  -->   value of parameter
  *----------------------------------------------------------------------------*/
 
 static void
-_radiative_transfer_int(const char *const param,
-                              int *const keyword)
+_radiative_transfer_int(const char  *param,
+                              int  *keyword)
 {
   char *path;
   int value = 0;
@@ -149,13 +149,13 @@ _radiative_transfer_int(const char *const param,
  * Return float parameters for radiation
  *
  *   parameters:
- *    param    -->   name of parameter
- *    keyword  <--   value of parameter
+ *    param    <--   name of parameter
+ *    keyword  -->   value of parameter
  *----------------------------------------------------------------------------*/
 
 static void
-_radiative_transfer_double(const char   *const param,
-                                 double *const keyword)
+_radiative_transfer_double(const char  *param,
+                           double      *keyword)
 {
   char *path;
   double value;
@@ -176,13 +176,13 @@ _radiative_transfer_double(const char   *const param,
  * Return value of the parameter of the character type for radiation
  *
  *   parameters:
- *    param    -->   name of parameter
- *    keyword  <--   value of parameter
+ *    param    <--   name of parameter
+ *    keyword  -->   value of parameter
  *----------------------------------------------------------------------------*/
 
 static void
-_radiative_transfer_char(const char *const param,
-                               int  *const keyword)
+_radiative_transfer_char(const char  *param,
+                               int   *keyword)
 {
   char *path;
   int result;
@@ -204,14 +204,14 @@ _radiative_transfer_char(const char *const param,
  * Return status and label of the property for post treatment of radiation
  *
  * parameters:
- *   name  --> name of property
- *   value <-- value of status
+ *   name  <-- name of property
+ *   value --> value of status
  *----------------------------------------------------------------------------*/
 
 static char *
-_radiative_transfer_char_post(const char *const name,
-                              int        *const list_value,
-                              int        *const record_value)
+_radiative_transfer_char_post(const char  *name,
+                              int         *list_value,
+                              int         *record_value)
 {
   char *path = NULL;
   char *path1 = NULL;
@@ -258,13 +258,13 @@ _radiative_transfer_char_post(const char *const name,
  * Return value of the type of absorption coefficient for radiation
  *
  *   parameters:
- *    param    -->   name of parameter "absorption coefficient"
- *    keyword  <--   value of the type of the coefficent
+ *    param    <--   name of parameter "absorption coefficient"
+ *    keyword  -->   value of the type of the coefficent
  *----------------------------------------------------------------------------*/
 
 static void
-_radiative_transfer_type(const char *const param,
-                                     int  *const keyword)
+_radiative_transfer_type(const char  *param,
+                         int         *keyword)
 {
   char *path;
   char *type;
@@ -301,16 +301,16 @@ _radiative_transfer_type(const char *const param,
 /*----------------------------------------------------------------------------
  *  Return value of radiative variable
  *
- *   parameters:
- *    label    -->   label of boundary nature
- *    param    -->   name of the  variable
- *    value    <--   value of the variable
+ *  parameters:
+ *    label <-- label of boundary nature
+ *    param <-- name of the  variable
+ *    value --> value of the variable
  *----------------------------------------------------------------------------*/
 
 static void
-_radiative_boundary(const   char *const label,
-                    const   char *const param,
-                          double *const value)
+_radiative_boundary(const char  *label,
+                    const char  *param,
+                    double      *value)
 {
   char *path = NULL;
   double res = 0.0;
@@ -336,8 +336,8 @@ _radiative_boundary(const   char *const label,
 /*----------------------------------------------------------------------------
  *  Return int value of the type of radiative condition
  *
- *   parameters:
- *    label    -->   label of boundary "wall"
+ *  parameters:
+ *    label    <--   label of boundary "wall"
  *    itpimp   <--   if wall faces with imposed temperature
  *    ipgrno   <--   if grey or black wall faces
  *    iprefl   <--   if reflecting wall faces
@@ -346,12 +346,12 @@ _radiative_boundary(const   char *const label,
  *----------------------------------------------------------------------------*/
 
 static int
-_radiative_boundary_type(const char *const label,
-                                 const int itpimp,
-                                 const int ipgrno,
-                                 const int iprefl,
-                                 const int ifgrno,
-                                 const int ifrefl)
+_radiative_boundary_type(const char  *label,
+                         int          itpimp,
+                         int          ipgrno,
+                         int          iprefl,
+                         int          ifgrno,
+                         int          ifrefl)
 {
   char *path = NULL;
   char *type = NULL;
@@ -427,62 +427,60 @@ _radiative_boundary_output_zone_max(void)
  *
  *----------------------------------------------------------------------------*/
 
-void CS_PROCF (uiray1, UIRAY1) (int *const iirayo,
-                                int *const isuird,
-                                int *const i_quad,
-                                int *const ndirec,
-                                int *const nfreqr,
-                                int *const idiver,
-                                int *const iimpar,
-                                int *const iimlum)
+void CS_PROCF (uiray1, UIRAY1) (int  *iirayo,
+                                int  *isuird,
+                                int  *i_quad,
+                                int  *ndirec,
+                                int  *nfreqr,
+                                int  *idiver,
+                                int  *iimpar,
+                                int  *iimlum)
 {
-    char *model = NULL;
+  char *model = NULL;
 
-    model = cs_gui_get_thermophysical_model("radiative_transfer");
+  model = cs_gui_get_thermophysical_model("radiative_transfer");
 
-    if (cs_gui_strcmp(model, "off"))
-        *iirayo = 0;
-    else if (cs_gui_strcmp(model, "dom"))
-        *iirayo = 1;
-    else if (cs_gui_strcmp(model, "p-1"))
-        *iirayo = 2;
+  if (cs_gui_strcmp(model, "off"))
+    *iirayo = 0;
+  else if (cs_gui_strcmp(model, "dom"))
+    *iirayo = 1;
+  else if (cs_gui_strcmp(model, "p-1"))
+    *iirayo = 2;
 
-    if (*iirayo)
-    {
-        _radiative_transfer_char("restart", isuird);
-        _radiative_transfer_int("quadrature", i_quad);
-        _radiative_transfer_int("directions_number", ndirec);
-        _radiative_transfer_int("frequency", nfreqr);
-        _radiative_transfer_int("thermal_radiative_source_term", idiver);
-        _radiative_transfer_int("temperature_listing_printing", iimpar);
-        _radiative_transfer_int("intensity_resolution_listing_printing", iimlum);
-    }
+  if (*iirayo) {
+    _radiative_transfer_char("restart", isuird);
+    _radiative_transfer_int("quadrature", i_quad);
+    _radiative_transfer_int("directions_number", ndirec);
+    _radiative_transfer_int("frequency", nfreqr);
+    _radiative_transfer_int("thermal_radiative_source_term", idiver);
+    _radiative_transfer_int("temperature_listing_printing", iimpar);
+    _radiative_transfer_int("intensity_resolution_listing_printing", iimlum);
+  }
 #if _XML_DEBUG_
-    bft_printf("==>UIRAY1\n");
-    bft_printf("--rayonnement : %s  (iirayo = %i)\n", model, *iirayo);
-    if (*iirayo)
-    {
-        bft_printf("--isuird = %d\n", *isuird);
-        bft_printf("--quadra = %d\n", *i_quad);
-        bft_printf("--ndirec = %d\n", *ndirec);
-        bft_printf("--nfreqr = %d\n", *nfreqr);
-        bft_printf("--idiver = %d\n", *idiver);
-        bft_printf("--iimpar = %d\n", *iimpar);
-        bft_printf("--iimlum = %d\n", *iimlum);
-    }
+  bft_printf("==>UIRAY1\n");
+  bft_printf("--rayonnement : %s  (iirayo = %i)\n", model, *iirayo);
+  if (*iirayo) {
+    bft_printf("--isuird = %d\n", *isuird);
+    bft_printf("--quadra = %d\n", *i_quad);
+    bft_printf("--ndirec = %d\n", *ndirec);
+    bft_printf("--nfreqr = %d\n", *nfreqr);
+    bft_printf("--idiver = %d\n", *idiver);
+    bft_printf("--iimpar = %d\n", *iimpar);
+    bft_printf("--iimlum = %d\n", *iimlum);
+  }
 #endif
-    BFT_FREE(model);
+  BFT_FREE(model);
 }
 
 /*----------------------------------------------------------------------------
  *
  *----------------------------------------------------------------------------*/
 
-void CS_PROCF (uiray4, UIRAY4) (int *const iirayo)
+void CS_PROCF (uiray4, UIRAY4) (int  *iirayo)
 {
   const int n_rad_b_f = 8;
 
-  const char *const b_rad_names[8] = {
+  const char  *b_rad_names[8] = {
     "wall_temp",
     "flux_incident",
     "thickness",
@@ -493,7 +491,7 @@ void CS_PROCF (uiray4, UIRAY4) (int *const iirayo)
     "coeff_ech_conv"};
 
   cs_field_t * b_rad_f[8] = {
-    CS_F_(tparo),
+    CS_F_(t_b),
     CS_F_(qinci),
     CS_F_(epa),
     CS_F_(xlam),
@@ -540,26 +538,26 @@ void CS_PROCF (uiray4, UIRAY4) (int *const iirayo)
 
 void CS_PROCF (uiray2, UIRAY2)
 (
- const    int *const itypfb,
- const    int *const iparoi,
- const    int *const iparug,
- const    int *const ivart,
-          int *const izfrdp,
-          int *const isothp,
- const    int *const itpimp,
- const    int *const ipgrno,
- const    int *const iprefl,
- const    int *const ifgrno,
- const    int *const ifrefl,
- const    int *const nozppm,
- const    int *const nfabor,
- const    int *const nvar,
-       double *const epsp,
-       double *const epap,
-       double *const tintp,
-       double *const textp,
-       double *const xlamp,
-       double *const rcodcl
+ const    int  *itypfb,
+ const    int  *iparoi,
+ const    int  *iparug,
+ const    int  *ivart,
+          int  *izfrdp,
+          int  *isothp,
+ const    int  *itpimp,
+ const    int  *ipgrno,
+ const    int  *iprefl,
+ const    int  *ifgrno,
+ const    int  *ifrefl,
+ const    int  *nozppm,
+ const    int  *nfabor,
+ const    int  *nvar,
+       double  *epsp,
+       double  *epap,
+       double  *tintp,
+       double  *textp,
+       double  *xlamp,
+       double  *rcodcl
 )
 {
   int zones = 0;
@@ -598,48 +596,48 @@ void CS_PROCF (uiray2, UIRAY2)
     /* nature, label and description (color or group)
        of the ith initialization zone */
 
-        ith_zone = izone + 1;
+      ith_zone = izone + 1;
 
-        nature = cs_gui_boundary_zone_nature(ith_zone);
+      nature = cs_gui_boundary_zone_nature(ith_zone);
 
-        label = cs_gui_boundary_zone_label(ith_zone);
+      label = cs_gui_boundary_zone_label(ith_zone);
 
-        BFT_MALLOC(boundary->label[izone], strlen(label)+1, char);
-        strcpy(boundary->label[izone], label);
+      BFT_MALLOC(boundary->label[izone], strlen(label)+1, char);
+      strcpy(boundary->label[izone], label);
 
-        BFT_MALLOC(boundary->nature[izone], strlen(nature)+1, char);
-        strcpy(boundary->nature[izone], nature);
+      BFT_MALLOC(boundary->nature[izone], strlen(nature)+1, char);
+      strcpy(boundary->nature[izone], nature);
 
-        /* Default initialization: these values are the same that in raycli
-           but given on each face in raycli whereas here one does not
-           necessarily have boundary faces (parallism) -> duplication */
-        boundary->type[izone] = -1;
-        boundary->output_zone[izone] = -1;
-        boundary->emissivity[izone] = -1.e12;
-        boundary->thickness[izone] = -1.e12;
-        boundary->thermal_conductivity[izone] = -1.e12;
-        boundary->external_temp[izone] = -1.e12;
-        boundary->internal_temp[izone] = -1.e12;
-        boundary->conduction_flux[izone] = 1.e30;
+      /* Default initialization: these values are the same that in raycli
+         but given on each face in raycli whereas here one does not
+         necessarily have boundary faces (parallism) -> duplication */
+      boundary->type[izone] = -1;
+      boundary->output_zone[izone] = -1;
+      boundary->emissivity[izone] = -1.e12;
+      boundary->thickness[izone] = -1.e12;
+      boundary->thermal_conductivity[izone] = -1.e12;
+      boundary->external_temp[izone] = -1.e12;
+      boundary->internal_temp[izone] = -1.e12;
+      boundary->conduction_flux[izone] = 1.e30;
 
-        if (cs_gui_strcmp(nature, "wall")) {
-          boundary->type[izone] = _radiative_boundary_type(label,
-                                                           *itpimp, *ipgrno, *iprefl,
-                                                           *ifgrno, *ifrefl);
-          tmp = (double) boundary->output_zone[izone];
-          _radiative_boundary(label, "output_zone", &tmp);
-          boundary->output_zone[izone] = (int) tmp;
-          _radiative_boundary(label, "emissivity", &boundary->emissivity[izone]);
-          _radiative_boundary(label, "thickness", &boundary->thickness[izone]);
-          _radiative_boundary(label, "wall_thermal_conductivity", &boundary->thermal_conductivity[izone]);
-          _radiative_boundary(label, "external_temperature_profile", &boundary->external_temp[izone]);
-          _radiative_boundary(label, "internal_temperature_profile", &boundary->internal_temp[izone]);
-          _radiative_boundary(label, "flux", &boundary->conduction_flux[izone]);
+      if (cs_gui_strcmp(nature, "wall")) {
+        boundary->type[izone] = _radiative_boundary_type(label,
+                                                         *itpimp, *ipgrno, *iprefl,
+                                                         *ifgrno, *ifrefl);
+        tmp = (double) boundary->output_zone[izone];
+        _radiative_boundary(label, "output_zone", &tmp);
+        boundary->output_zone[izone] = (int) tmp;
+        _radiative_boundary(label, "emissivity", &boundary->emissivity[izone]);
+        _radiative_boundary(label, "thickness", &boundary->thickness[izone]);
+        _radiative_boundary(label, "wall_thermal_conductivity", &boundary->thermal_conductivity[izone]);
+        _radiative_boundary(label, "external_temperature_profile", &boundary->external_temp[izone]);
+        _radiative_boundary(label, "internal_temperature_profile", &boundary->internal_temp[izone]);
+        _radiative_boundary(label, "flux", &boundary->conduction_flux[izone]);
 
-        } /* if (cs_gui_strcmp(nature, "wall")) */
+      } /* if (cs_gui_strcmp(nature, "wall")) */
 
-        BFT_FREE(nature);
-        BFT_FREE(label);
+      BFT_FREE(nature);
+      BFT_FREE(label);
 
     }  /* for izones */
 
@@ -653,10 +651,8 @@ void CS_PROCF (uiray2, UIRAY2)
                                        boundaries->label[izone],
                                        *nfabor, *nozppm, &faces);
 
-    if (cs_gui_strcmp(boundary->nature[izone], "wall"))
-    {
-      for (n = 0; n < faces; n++)
-      {
+    if (cs_gui_strcmp(boundary->nature[izone], "wall")) {
+      for (n = 0; n < faces; n++) {
         ifbr = faces_list[n];
 
         if (itypfb[ifbr] != *iparoi && itypfb[ifbr] != *iparug)
@@ -669,13 +665,11 @@ void CS_PROCF (uiray2, UIRAY2)
 
         izfrdp[ifbr] = boundary->output_zone[izone];
         isothp[ifbr] = boundary->type[izone];
-        if (isothp[ifbr] == *itpimp)
-        {
+        if (isothp[ifbr] == *itpimp) {
           epsp[ifbr] = boundary->emissivity[izone];
           tintp[ifbr] = boundary->internal_temp[izone];
         }
-        else if (isothp[ifbr] == *ipgrno)
-        {
+        else if (isothp[ifbr] == *ipgrno) {
           xlamp[ifbr] = boundary->thermal_conductivity[izone];
           epap[ifbr] = boundary->thickness[izone];
           textp[ifbr] = boundary->external_temp[izone];
@@ -689,9 +683,10 @@ void CS_PROCF (uiray2, UIRAY2)
           rcodcl[2 * (*nfabor) * (*nvar) + (*ivart - 1) * (*nfabor) + ifbr]
             = boundary->conduction_flux[izone];
           tintp[ifbr] = boundary->internal_temp[izone];
-          epsp[ifbr] = boundary->emissivity[izone];
           if (!cs_gui_is_equal_real(boundary->emissivity[izone], 0.))
             isothp[ifbr] = *ifrefl;
+          else
+            epsp[ifbr] = boundary->emissivity[izone];
         }
       }
 
@@ -753,9 +748,9 @@ void CS_PROCF (uiray2, UIRAY2)
  *----------------------------------------------------------------------------*/
 
 
-void CS_PROCF (uiray3, UIRAY3) (      double *const ck,
-                                const    int *const ncel,
-                                         int *const imodak)
+void CS_PROCF (uiray3, UIRAY3) (      double  *ck,
+                                const    int  *ncel,
+                                         int  *imodak)
 {
     double value = 0.;
     int i, type = 0;
@@ -789,9 +784,8 @@ void CS_PROCF (uiray3, UIRAY3) (      double *const ck,
  *
  * Fortran Interface:
  *
- * SUBROUTINE MEMUI2
+ * subroutine memui2
  * *****************
- *
  *----------------------------------------------------------------------------*/
 
 void CS_PROCF (memui2, MEMUI2) (void)
