@@ -225,7 +225,7 @@ _get_diameter_type(const int icha)
 {
   char *path;
   char *buff = NULL;
-  int   ichoice;
+  int   ichoice = 0;
   path = cs_xpath_init_path();
   cs_xpath_add_elements(&path, 2,"thermophysical_models", "solid_fuels");
   cs_xpath_add_element_num(&path, "solid_fuel", icha);
@@ -637,14 +637,14 @@ _get_ashes_thermal_capacity(const int icha)
  *    integer for PCI type
  *----------------------------------------------------------------------------*/
 
-static double
-_get_PCI_type(const int icha)
+static int
+_get_PCI_type(int icha)
 {
   char *path;
   char *path2;
   char *buff = NULL;
   char *buff2 = NULL;
-  double ichoice;
+  int ichoice = 0.;
 
   path = cs_xpath_init_path();
   cs_xpath_add_elements(&path, 2,"thermophysical_models", "solid_fuels");
@@ -652,9 +652,7 @@ _get_PCI_type(const int icha)
   cs_xpath_add_element(&path, "Heating_model");
   cs_xpath_add_attribute(&path,"choice");
   buff = cs_gui_get_attribute_value(path);
-  if (buff == NULL) {
-    ichoice = 0.;
-  } else {
+  if (buff != NULL) {
     if (cs_gui_strcmp(buff, "LHV"))
       {
         path2 = cs_xpath_init_path();
@@ -730,7 +728,7 @@ _get_Y1Y2_coefficient_type(const int icha)
 {
   char *path;
   char *buff = NULL;
-  int ichoice;
+  int ichoice = 0;
 
   path = cs_xpath_init_path();
   cs_xpath_add_elements(&path, 2,"thermophysical_models", "solid_fuels");
@@ -739,9 +737,7 @@ _get_Y1Y2_coefficient_type(const int icha)
                         "stoichiometric_coefficient");
   cs_xpath_add_attribute(&path,"type");
   buff = cs_gui_get_attribute_value(path);
-  if (buff == NULL) {
-    ichoice = 0;
-  } else {
+  if (buff != NULL) {
     if (cs_gui_strcmp(buff, "automatic_CHONS"))
       ichoice = 0;
     else if (cs_gui_strcmp(buff, "user_define"))
@@ -1306,7 +1302,7 @@ _get_oxydant_type(void) /*ici un char*/
 {
   char *path;
   char *buff = NULL;
-  int   ichoice;
+  int   ichoice = 0;
 
   path = cs_xpath_init_path();
   cs_xpath_add_elements(&path,3,
@@ -1316,9 +1312,7 @@ _get_oxydant_type(void) /*ici un char*/
   cs_xpath_add_element(&path,"oxidant_type");
   cs_xpath_add_function_text(&path);
   buff = cs_gui_get_text_value(path);
-  if (buff == NULL) {
-    ichoice = 0;
-  } else {
+  if (buff != NULL) {
     if (cs_gui_strcmp(buff, "volumic_percent"))
       ichoice = 0;
     else if (cs_gui_strcmp(buff, "molar"))
@@ -1736,14 +1730,6 @@ void CS_PROCF (uippmo, UIPPMO)(int *const ippmod,
         ippmod[*icompf - 1] = 0;
         *ieos = 1;
       }
-      else if (cs_gui_strcmp(vars->model_value, "variable_gamma'")){
-        ippmod[*icompf - 1] = 0;
-        *ieos = 2;
-      }
-      else if (cs_gui_strcmp(vars->model_value, "van_der_waals")){
-        ippmod[*icompf - 1] = 0;
-        *ieos = 3;
-      }
       else
         bft_error(__FILE__, __LINE__, 0,
             _("Invalid compressible model: %s.\n"),
@@ -2153,7 +2139,7 @@ void CS_PROCF (uisofu, UISOFU) (const int    *const ippmod,
                                 double       *const och,
                                 double       *const nch,
                                 double       *const sch,
-                                double       *const ipci,
+                                int          *const ipci,
                                 double       *const pcich,
                                 double       *const cp2ch,
                                 double       *const rho0ch,
@@ -2230,7 +2216,7 @@ void CS_PROCF (uisofu, UISOFU) (const int    *const ippmod,
     cs_gui_load_file("dp_FCP.xml");
 
   /* ---- Nb de charbons */
-  *ncharb = cs_gui_get_tag_number("/solid_fuels/solid_fuel", 1);
+  *ncharb = cs_gui_get_tag_count("/solid_fuels/solid_fuel", 1);
   if (*ncharb > *ncharm)
     bft_error(__FILE__, __LINE__, 0,
               _("Coal number is limited to %i\n"
@@ -2465,7 +2451,7 @@ void CS_PROCF (uisofu, UISOFU) (const int    *const ippmod,
   /* --> Lecture caracteristiques Oxydants */
 
   /* ---- Nb d'oxydants */
-  *noxyd = cs_gui_get_tag_number("/oxidants/oxidant", 1);
+  *noxyd = cs_gui_get_tag_count("/oxidants/oxidant", 1);
   if (*noxyd < 1 || *noxyd > 3 ) {
     bft_error(__FILE__, __LINE__, 0,
         _("Oxidant number must be between 1 and 3.\n"
@@ -2750,7 +2736,7 @@ cs_gui_get_activ_thermophysical_model(void)
     isactiv = 1;
     return isactiv;
   } else {
-    vars->model = NULL;
+    BFT_FREE(vars->model);
     vars->model_value = NULL;
   }
 
