@@ -204,7 +204,7 @@ void CS_PROCF (uisofu, UISOFU) (const int    *const ippmod,
                                       double *const och,
                                       double *const nch,
                                       double *const sch,
-                                      double *const ipci,
+                                      int    *const ipci,
                                       double *const pcich,
                                       double *const cp2ch,
                                       double *const rho0ch,
