@@ -317,6 +317,23 @@ module lagran
 
   !> \}
 
+  !> \defgroup precipitation_model Precipitation model
+
+  !> \addtogroup precipitation_model
+  !> \{
+
+  !> - 0: no precipitation/dissolution model
+  !> - 1: precipitation/dissolution model
+  integer, save ::         ipreci
+  !> number of particle classes
+  integer, save ::         nbrclas
+
+  !> diameter of particles formed by precipitation
+   double precision, save :: dprec
+  !> density of particles formed by precipitation
+   double precision, save :: rho_preci
+
+  !> \}
   !=======================
 
   !> \defgroup clogging_model Clogging model
@@ -379,6 +396,19 @@ module lagran
 
   !=============================================================================
 
+  !> \defgroup precipitation/dissolution
+
+  !> \addtogroup precipitation_dissolution
+  !> \{
+
+  integer, allocatable, dimension(:)            :: nbprec
+  double precision, allocatable, dimension(:)   :: solub
+  double precision, allocatable, dimension(:,:) :: mp_diss
+
+  !> \}
+
+  !=============================================================================
+
   !> \defgroup particles_pointer Particles pointers
   !> for array \ref eptp
 
@@ -410,7 +440,7 @@ module lagran
   integer, save ::  jmp
   !> pointer to particle diameter for pointer \ref eptp
   integer, save ::  jdp
-  !> pointer to particle extent for array \ref ettp
+  !> pointer to particle extent for array \ref eptp
   integer, save ::  jdp2
   !> pointer to particle and locally undisturbed fluid flow temperature
   !> (Celsius) for pointer \ref eptp
@@ -1116,6 +1146,26 @@ module lagran
   !> Do not change the default value
   integer, save ::  ilapoi
 
+  !> activation (=1) or not (=0) of the added-mass term.
+  !> \f[ \DP{u_p} = - \dfrac{1}{\rho_p} \grad P + \dfrac{u_s-u_p}{\tau_p}
+  !>       + g
+  !>       +1/2 C_A \dfrac{\rho_f}{\rho_p} \left( \dfrac{Du}{Dt}-\DP{u_p} \right)
+  !> \f]
+  !> and
+  !>  \f[ \rho_f \dfrac{Du}{Dt} \simeq  - \grad P + \rho_f g \f]
+  !> with \f$ C_A = 1\f$. Then
+  !>  \f[ \DP{u_p} = - \dfrac{1}{\rho_p} \dfrac{1+C_A/2}
+  !>                                      {1+C_A/2\dfrac{\rho_f}{\rho_p}} \grad P
+  !>          + \dfrac{u_s-u_p}{\widetilde{\tau}_p}
+  !>          + g
+  !>  \f]
+  !> with
+  !> \f[ \widetilde{\tau_p} = (1 + C_A /2 \dfrac{\rho_f}{\rho_p}) \tau_p \f]
+  !>
+  integer, save ::  iadded_mass
+  !> Added-mass constant (\f$ C_A = 1\f$)
+  double precision, save ::  added_mass_const
+
   !> \}
 
   !=============================================================================
@@ -1817,4 +1867,34 @@ contains
 
   !=============================================================================
 
+  ! Initialize auxiliary arrays
+
+  subroutine init_lagr_arrays
+
+    use mesh
+
+    implicit none
+
+    if (ipreci .eq. 1) then
+      allocate(solub(ncelet))
+      allocate(nbprec(ncelet))
+      allocate(mp_diss(ncelet,nbrclas))
+    endif
+
+    return
+
+  end subroutine init_lagr_arrays
+
+  !=============================================================================
+
+  subroutine finalize_lagr_arrays
+
+    if (allocated(solub)) deallocate(solub)
+    if (allocated(nbprec)) deallocate(nbprec)
+    if (allocated(mp_diss)) deallocate(mp_diss)
+
+  end subroutine finalize_lagr_arrays
+
+  !=============================================================================
+
 end module lagran
