@@ -104,6 +104,7 @@ integer          ifac
 
 double precision visccf, romf
 double precision ustarmoy, surftot, surfb
+double precision dtmp(3)
 
 double precision, allocatable, dimension(:) :: taup
 double precision, allocatable, dimension(:,:) :: tlag, piil
@@ -233,6 +234,7 @@ if (iplar.eq.1) then
 
      ustarmoy = 0.d0
      surftot = 0.d0
+     dtmp(1) = 0.d0
 
     ! boundary faces data
 
@@ -263,12 +265,12 @@ if (iplar.eq.1) then
            romf = cromf(iel)
            visccf = viscl(iel) / romf
 
-           if ( uetbor(ifac).gt.1.d-15) then
+           if (uetbor(ifac).gt.1.d-15) then
 
-              ustarmoy = (surftot * ustarmoy +  surfb * uetbor(ifac))   &
-                       / (surftot + surfb)
-              surftot = surftot +  surfb
+              ustarmoy =  ustarmoy +  surfb * uetbor(ifac)
+              surftot = surftot + surfb
               vislen(ifac) = visccf / uetbor(ifac)
+              dtmp(1) = dtmp(1) + 1.d0
 
            endif
 
@@ -276,9 +278,17 @@ if (iplar.eq.1) then
 
      enddo
 
-!  Average friction velocity display
+     if (irangp .ge. 0) then
+       dtmp(2) = ustarmoy
+       dtmp(3) = surftot
+       call parrsm(3, dtmp)
+       ustarmoy = dtmp(2)
+       surftot = dtmp(3)
+     endif
+     if (dtmp(1).gt.0.d0) ustarmoy = ustarmoy/surftot
 
-     write(nfecra,4100) ustarmoy
+!  Average friction velocity display
+if (irangp .le. 0)   write(nfecra,4100) ustarmoy
 !
   endif
 
@@ -673,7 +683,7 @@ if (nor.eq.1) then
    inbr     , inbrbd   , iflm     , iflmbd   , iang     ,         &
    iangbd   , ivit     , ivitbd   , iencnb   , iencma   ,         &
    iencdi   , iencck   , iencnbbd , iencmabd , iencdibd ,         &
-   iencckbd , inclg    , inclgt   , iclogt   , iclogh   , iscovc, &
+   iencckbd , inclg    , inclgt   , iscovc,                       &
    ihdepm   , ihdepv   , ihsum    , nusbor   , iusb     , vislen, &
    dlgeo    , tprenc   , visref   , enc1     ,                    &
    enc2     , tkelvi)
