@@ -77,6 +77,11 @@ module radiat
   !> - 2 ADF model with 50 intervals of wave length
   integer, save :: imoadf
 
+  !>FSCK model:
+  !> - 0 no FSCK model
+  !> - 1 FSCK model activated
+  integer, save :: imfsck
+
   !--> pointeur dans le macrotableau propce :
 
   !                       ITSRE --> Terme source explicite
@@ -94,7 +99,6 @@ module radiat
                     ilumin
 
   !--> field ids for specific  boundary fields
-  !                       ITPARO --> temperature de paroi
   !                       IQINCI --> densite de flux incident radiatif
   !                       IXLAM  --> conductivite thermique de la paroi
   !                       IEPA   --> epaisseur de la paroi
@@ -104,7 +108,6 @@ module radiat
   !                       IHCONV --> Coef d'echange fluide
   !                       IQINSP --> densite de flux incident radiatif spectral
 
-  integer, save ::  itparo = -1
   integer, save ::  iqinci = -1
   integer, save ::  ixlam  = -1
   integer, save ::  iepa   = -1
@@ -179,8 +182,11 @@ module radiat
   !> Useful if and only if the radiation module is activated}
   integer, save ::           nfreqr
 
-  !--> ADF radiation model
+  !> Spectral radiation models (ADF and FSCK)
+  !> Number of ETRs to solve
   integer, save ::           nwsgg
+  !> Weights of the Gaussian quadrature
+  double precision, dimension(:), allocatable :: wq
 
   !--> Informations sur les zones frontieres
 
