@@ -122,21 +122,22 @@ double precision propce(ncelet,*)
 double precision rcodcl(ndimfb,nvarcl,3)
 
 ! Local variables
+
 integer          iok, ifac, iel, ideb, ivart
 integer          mode, ifvu, ii, izonem, izone
 integer          nrferr(14), icoerr(15)
-integer          ivahg
+integer          ivahg, nlst, icodw
 
 double precision tmin , tmax   , tx
 double precision xmtk
 double precision rvferr(25)
 
-integer, allocatable, dimension(:) :: isothm
+integer, allocatable, dimension(:) :: isothm, lstfac
 
-double precision, allocatable, dimension(:) :: tempk, thwall
+double precision, allocatable, dimension(:) :: tempk, thwall, tparo
 double precision, allocatable, dimension(:) :: text, tint
 double precision, dimension(:), pointer :: bhconv, bfconv
-double precision, dimension(:), pointer :: tparo, bqinci
+double precision, dimension(:), pointer :: b_temp, bqinci
 double precision, dimension(:), pointer :: bxlam, bepa, beps, bfnet
 
 double precision, dimension(:), pointer :: cvara_scalt
@@ -145,17 +146,38 @@ integer    ipacli
 data       ipacli /0/
 save       ipacli
 
+!===============================================================================
+! Interfaces
+!===============================================================================
+
+interface
+
+  subroutine b_t_to_h(nlst, lstfac, t_b, h_b)
+
+    use mesh, only: nfabor
+    implicit none
+
+    integer :: nlst
+    integer, dimension(nlst) :: lstfac
+    double precision, dimension(nfabor), intent(in) :: t_b
+    double precision, dimension(nfabor), intent(out), target :: h_b
+
+  end subroutine b_t_to_h
+
+ end interface
+
 !===============================================================================
 ! 1. Initializations
 !===============================================================================
 
 ! Allocate temporary arrays
-allocate(isothm(nfabor))
+allocate(isothm(nfabor), lstfac(nfabor))
 allocate(tempk(ncelet), thwall(ndimfb))
 allocate(text(nfabor), tint(nfabor))
+allocate(tparo(nfabor))
 
 ! Map field arrays
-call field_get_val_s(itparo, tparo)
+call field_get_val_s(itempb, b_temp)
 call field_get_val_s(iqinci, bqinci)
 call field_get_val_s(ixlam, bxlam)
 call field_get_val_s(iepa, bepa)
@@ -185,6 +207,24 @@ tmax = grand + tkelvi
 
 tx = 0.1d0
 
+! Temperature scale
+
+if (itpscl.eq.2) then
+  xmtk = -tkelvi
+else if (itpscl.eq.1) then
+  xmtk = 0.d0
+endif
+
+! Wall temperature
+
+do ifac = 1, nfabor
+  if (itypfb(ifac).eq.iparoi .or. itypfb(ifac).eq.iparug) then
+    tparo(ifac) = b_temp(ifac) - xmtk
+  else
+    tparo(ifac) = 0.d0
+  endif
+enddo
+
 !---> Default initialization
 do ifac = 1, nfabor
   izfrad(ifac) = -1
@@ -277,8 +317,6 @@ if (ipacli.eq.1 .and. isuird.eq.0) then
 
   ! Tparoi en Kelvin et QINCID en W/m2
   do ifac = 1, nfabor
-    tparo(ifac) = tint(ifac)
-    bqinci(ifac) = stephn*tint(ifac)**4
     if (itypfb(ifac).eq.iparoi.or.itypfb(ifac).eq.iparug) then
       tparo(ifac) = tint(ifac)
       bqinci(ifac) = stephn*tint(ifac)**4
@@ -323,7 +361,7 @@ call cs_user_radiative_transfer_bcs &
   icodcl , izfrad , isothm ,                                     &
   tmin   , tmax   , tx     ,                                     &
   dt     , rcodcl ,                                              &
-  thwall , bfnet ,  bfconv ,                                     &
+  thwall , bfnet ,  bhconv ,                                     &
   bfconv , bxlam , bepa   , beps ,                               &
   text   , tint   )
 
@@ -619,19 +657,24 @@ endif
 ! ICODCL et EPS (quand il est nul)
 
 do ifac = 1, nfabor
+  if (itypfb(ifac).eq.iparug) then
+    icodw = 6
+  else
+    icodw = 5
+  endif
   if (isothm(ifac).eq.itpimp) then
-    icodcl(ifac,ivart) = 5
-    if (ihgas.ge.0) icodcl(ifac,ivahg) = 5
+    icodcl(ifac,ivart) = icodw
+    if (ihgas.ge.0) icodcl(ifac,ivahg) = icodw
   elseif (isothm(ifac).eq.ipgrno) then
-    icodcl(ifac,ivart) = 5
-    if (ihgas.ge.0) icodcl(ifac,ivahg) = 5
+    icodcl(ifac,ivart) = icodw
+    if (ihgas.ge.0) icodcl(ifac,ivahg) = icodw
   elseif (isothm(ifac).eq.iprefl) then
-    icodcl(ifac,ivart) = 5
-    if (ihgas.ge.0) icodcl(ifac,ivahg) = 5
+    icodcl(ifac,ivart) = icodw
+    if (ihgas.ge.0) icodcl(ifac,ivahg) = icodw
     beps(ifac) = 0.d0
   elseif (isothm(ifac).eq.ifgrno) then
-    icodcl(ifac,ivart) = 5
-    if (ihgas.ge.0) icodcl(ifac,ivahg) = 5
+    icodcl(ifac,ivart) = icodw
+    if (ihgas.ge.0) icodcl(ifac,ivahg) = icodw
   elseif (isothm(ifac).eq.ifrefl) then
     icodcl(ifac,ivart) = 3
     if (ihgas.ge.0) icodcl(ifac,ivahg) = 3
@@ -643,12 +686,10 @@ enddo
 ! 4. STOCKAGE DE LA TEMPERATURE (en Kelvin) dans TEMPK(IEL)
 !===============================================================================
 
+call field_get_val_prev_s(ivarfl(isca(iscalt)), cvara_scalt)
+
 if (itherm.eq.1) then
 
-  !---> ON REMPLIT TEMPK
-
-  call field_get_val_prev_s(ivarfl(isca(iscalt)), cvara_scalt)
-
   if (itpscl.eq.2) then
     do iel = 1, ncel
       tempk(iel) = cvara_scalt(iel) + tkelvi
@@ -661,30 +702,7 @@ if (itherm.eq.1) then
 
 elseif (itherm.eq.2) then
 
-  !---> LECTURES DES DONNEES UTILISATEURS (TBORD est un auxiliaire)
-
-  mode = 1
-
-  if (ippmod(iphpar).le.1) then
-
-    call usray4 &
- ( nvar   , nscal  ,                                              &
-   mode   ,                                                       &
-   itypfb ,                                                       &
-   dt     ,                                                       &
-   tparo  , thwall , tempk  )
-      ! Resultat : T en K
-
-  else
-
-    call ppray4 &
- ( mode   ,                                                       &
-   itypfb ,                                                       &
-   propce ,                                                       &
-   tparo  , thwall , tempk  )
-      ! Resultat : T en K
-
-  endif
+  call c_h_to_t(cvara_scalt, tempk) ! Resultat : T en K
 
 endif
 
@@ -707,9 +725,7 @@ if (ideb.eq.1) then
 
   do ifac = 1, nfabor
     if (isothm(ifac).ne.-1) then
-      bfconv(ifac) =                               &
-      bhconv(ifac)*(tempk(ifabor(ifac))-           &
-      tparo(ifac))
+      bfconv(ifac) = bhconv(ifac)*(tempk(ifabor(ifac))-tparo(ifac))
     endif
   enddo
 
@@ -752,12 +768,6 @@ endif
 
 if (itherm.eq.1) then
 
-  if (itpscl.eq.2) then
-    xmtk = -tkelvi
-  else if (itpscl.eq.1) then
-    xmtk = 0.d0
-  endif
-
   do ifac = 1, nfabor
 
     if (isothm(ifac).eq.itpimp .or.                             &
@@ -803,28 +813,15 @@ elseif (itherm.eq.2) then
 
   if (mode.eq.-1) then
 
-    if (ippmod(iphpar).le.1) then
+    nlst = 0
+    do ifac = 1, nfabor
+      if (itypfb(ifac).eq.iparoi .or. itypfb(ifac).eq.iparug) then
+        nlst = nlst+1
+        lstfac(nlst) = ifac
+      endif
+    enddo
 
-      call usray4 &
-    ( nvar   , nscal  ,                                              &
-      mode   ,                                                       &
-      itypfb ,                                                       &
-      dt     ,                                                       &
-      tparo  , bfnet  ,                                              &
-      tempk  )
-      ! HPAROI
-
-    else
-
-      call ppray4 &
-    ( mode   ,                                                       &
-      itypfb ,                                                       &
-      propce ,                                                       &
-      tparo  , bfnet  ,                                              &
-      tempk  )
-      ! HPAROI
-
-    endif
+    call b_t_to_h(nlst, lstfac, tparo, bfnet)
 
   endif
 
@@ -838,26 +835,15 @@ elseif (itherm.eq.2) then
 
   if (mode.eq.-1) then
 
-    if (ippmod(iphpar).le.1) then
+    nlst = 0
+    do ifac = 1, nfabor
+      if (itypfb(ifac).eq.iparoi .or. itypfb(ifac).eq.iparug) then
+        nlst = nlst+1
+        lstfac(nlst) = ifac
+      endif
+    enddo
 
-      call usray4 &
-    ( nvar   , nscal  ,                                              &
-      mode   ,                                                       &
-      itypfb ,                                                       &
-      dt     ,                                                       &
-      text   , thwall , tempk  )
-      ! HEXT
-
-    else
-
-      call ppray4 &
-    ( mode   ,                                                       &
-      itypfb ,                                                       &
-      propce ,                                                       &
-      text   , thwall , tempk  )
-      ! HEXT
-
-    endif
+    call b_t_to_h(nlst, lstfac, text, thwall)
 
   endif
 
@@ -903,10 +889,23 @@ elseif (itherm.eq.2) then
 
 endif
 
+! Update boundary temperature field
+
+do ifac = 1, nfabor
+  if (itypfb(ifac).eq.iparoi .or. itypfb(ifac).eq.iparug) then
+    if (itpscl.eq.2) then
+      b_temp(ifac) = tparo(ifac) - tkelvi
+    else
+      b_temp(ifac) = tparo(ifac)
+    endif
+  endif
+enddo
+
 ! Free memory
-deallocate(isothm)
+deallocate(isothm,lstfac)
 deallocate(tempk,thwall)
 deallocate(text, tint)
+deallocate(tparo)
 
 !--------
 ! Formats
