@@ -114,6 +114,11 @@ imodak = 0
 
 imoadf = 0
 
+!-->  IMFSCK = 0 switch off FSCK model
+!            = 1 switch on FSCK model
+
+imfsck = 0
+
 !-->  INDICATEUR SUITE DE CALCUL (LECTURE DU FICHIER SUITE)
 
 isuird = isuite
@@ -171,6 +176,10 @@ elseif (imoadf.eq.2) then
   nwsgg = 50
 endif
 
+if (imfsck.eq.1) then
+  nwsgg=7
+endif
+
 !===============================================================================
 ! 2. VERIFICATION LA COHERENCE D'UTILISATION DU MODULE DE RAYONNEMENT
 !    AVEC LA THERMIQUE OU LES PHYSIQUES PARTICULIERES (COMBUSTION)
@@ -284,7 +293,7 @@ if (iirayo.gt.0) then
 ! --> NDIREC
 !     Parametre Quadrature Tn
   if (iirayo.eq.1 .and. i_quadrature.eq.6) then
-    if (ndirec.lt.3) then
+    if (ndirec.lt.2) then
       write(nfecra, 4020) ndirec
       iok = iok + 1
     endif
