@@ -20,32 +20,28 @@
 
 !-------------------------------------------------------------------------------
 
-subroutine clpalp &
- ( ncelet , ncel   , nvar   )
-
 !===============================================================================
-! FONCTION :
+! Function :
 ! ----------
+!> \file clpalp.f90
+!> \brief Clipping of alpha in the framwork of the Rij-EBRSM model.
 
-! Clipping of Alpha
+!-------------------------------------------------------------------------------
 
 !-------------------------------------------------------------------------------
 ! Arguments
-!ARGU                             ARGUMENTS
-!__________________.____._____.________________________________________________.
-!    nom           !type!mode !                   role                         !
-!__________________!____!_____!________________________________________________!
-! ncelet           ! e  ! <-- ! nombre d'elements halo compris                 !
-! ncel             ! e  ! <-- ! nombre de cellules                             !
-! nvar             ! e  ! <-- ! nombre de variables                            !
-!__________________!____!_____!________________________________________________!
+!______________________________________________________________________________.
+!  mode           nom           role
+!______________________________________________________________________________!
+!> \param[in]     ncelet        number of extended (real + ghost) cells
+!> \param[in]     ncel          number of cells
+!> \param[in]     alpha_min     minimum acceptable value for alpha
+!______________________________________________________________________________!
 
-!     TYPE : E (ENTIER), R (REEL), A (ALPHANUMERIQUE), T (TABLEAU)
-!            L (LOGIQUE)   .. ET TYPES COMPOSES (EX : TR TABLEAU REEL)
-!     MODE : <-- donnee, --> resultat, <-> Donnee modifiee
-!            --- tableau de travail
 
-!-------------------------------------------------------------------------------
+subroutine clpalp &
+ ( ncelet , ncel  , alpha_min)
+
 !===============================================================================
 
 !===============================================================================
@@ -66,12 +62,13 @@ implicit none
 
 ! Arguments
 
-integer          nvar, ncelet, ncel
+integer          ncelet, ncel
+double precision alpha_min(ncelet)
 
 ! VARIABLES LOCALES
 
 integer          iel
-integer          iclpmn, iclpmx
+integer          iclpmn(1), iclpmx(1)
 double precision vmin(1), vmax(1), var
 
 double precision, dimension(:), pointer :: cvar_al
@@ -94,19 +91,19 @@ enddo
 
 ! ---> Clipping (modif pour eviter les valeurs exactement nulles)
 
-iclpmn = 0
-iclpmx = 0
+iclpmn(1) = 0
+iclpmx(1) = 0
 do iel = 1, ncel
-  if (cvar_al(iel).lt.0.d0) then
-    iclpmn = iclpmn + 1
-    cvar_al(iel) = 0.d0
+  if (cvar_al(iel).lt.alpha_min(iel)) then
+    iclpmn(1) = iclpmn(1) + 1
+    cvar_al(iel) = alpha_min(iel)
   elseif(cvar_al(iel).gt.1.d0) then
-    iclpmx = iclpmx + 1
+    iclpmx(1) = iclpmx(1) + 1
     cvar_al(iel) = 1.d0
   endif
 enddo
 
-call log_iteration_clipping_field(ivarfl(ial), iclpmn, iclpmx, vmin, vmax)
+call log_iteration_clipping_field(ivarfl(ial), iclpmn(1), iclpmx(1), vmin, vmax,iclpmn(1), iclpmx(1))
 
 return
 
