@@ -144,7 +144,15 @@ BEGIN_C_DECLS
         partially coupled version of \f$ k-\varepsilon \f$ (only for iturb=20)
         - 1: true (default)
         - 0: false
-  \var  cs_turb_rans_model_t::irijnu
+  \var  cs_turb_rans_model_t::reinit_turb
+        Advanced re-init for EBRSM and k-omega models
+        - 1: true
+        - 0: false (default)
+  \var  cs_turb_rans_model_t::irijco
+        coupled solving of Rij
+        - 1: true
+        - 0: false (default)
+        \var  cs_turb_rans_model_t::irijnu
         pseudo eddy viscosity in the matrix of momentum equation to partially
         implicit \f$ \divv \left( \rho \tens{R} \right) \f$
         - 1: true
@@ -170,22 +178,21 @@ BEGIN_C_DECLS
         partial implicitation of wall BCs of \f$ \tens{R} \f$
         - 1: true
         - 0: false (default)
-  \var  cs_turb_rans_model_t::almax
+  \var  cs_turb_ref_values_t::almax
         characteristic macroscopic length of the domain, used for the
         initialization of the turbulence and the potential clipping (with
         \ref iclkep=1)
         - Negative value: not initialized (the code then uses the cubic root of
           the domain volume).
 
-        Useful if and only if \ref iturb = 20, 21, 30, 31, 50 or 60
-        (RANS models).
-  \var  cs_turb_rans_model_t::uref
+        Useful mainly for RANS models.
+  \var  cs_turb_ref_values_t:uref
         characteristic flow velocity, used for the initialization of the
         turbulence
         - Negative value: not initialized.
 
-        Useful if and only if \ref iturb= 20, 21, 30, 31, 50 or 60 (RANS model)
-        and the turbulence is not initialized somewhere else (restart file or
+        Useful mainly for RANS models and if
+        the turbulence is not initialized somewhere else (restart file or
         subroutine \ref cs\_user\_initialization).
   \var  cs_turb_rans_model_t::xlomlg
         mixing length for the mixing length model
@@ -224,32 +231,48 @@ BEGIN_C_DECLS
 
 /* main turbulence model structure and associated pointer */
 
-static cs_turb_model_t  _turb_model = {-999, -999, 0};
+static cs_turb_model_t  _turb_model =
+{
+  .iturb  = -999,
+  .itytur = -999,
+  .nvarcl = 0
+};
 
 const cs_turb_model_t  *cs_glob_turb_model = &_turb_model;
 
+/* Reference values for turbulence structure and associated pointer */
+
+static cs_turb_ref_values_t
+_turb_ref_values =
+{
+  .almax      = -999,
+  .uref       =-1e13
+};
+
+const cs_turb_ref_values_t  *cs_glob_turb_ref_values = &_turb_ref_values;
+
 /* RANS turbulence model structure and associated pointer */
 
 static cs_turb_rans_model_t
 _turb_rans_model =
 {
-     0,     /* irccor */
-  -999,     /* itycor */
-     1,     /* idirsm */
-     0,     /* iclkep */
-     0,     /* igrhok */
-     1,     /* igrake */
-     1,     /* igrari */
-  -999,     /* ikecou */
-     0,     /* irijnu */
-     0,     /* irijrb */
-     0,     /* irijec */
-     1,     /* idifre */
-     1,     /* iclsyr */
-     0,     /* iclptr */
-  -999,     /* almax  */
- -1e13,     /* uref   */
- -1e13      /* xlomg  */
+  .irccor     =    0,
+  .itycor     = -999,
+  .idirsm     =    1,
+  .iclkep     =    0,
+  .igrhok     =    0,
+  .igrake     =    1,
+  .igrari     =    1,
+  .ikecou     = -999,
+  .reinit_turb=    0,
+  .irijco     =    0,
+  .irijnu     =    0,
+  .irijrb     =    0,
+  .irijec     =    0,
+  .idifre     =    1,
+  .iclsyr     =    1,
+  .iclptr     =    0,
+  .xlomlg      =-1e13
 };
 
 const cs_turb_rans_model_t  *cs_glob_turb_rans_model = &_turb_rans_model;
@@ -281,7 +304,7 @@ const double cs_turb_xkappa = 0.42;
 const double cs_turb_vdriest = 25.6;
 
 /*!
- * Constant of logarithmic law function:
+ * Constant of logarithmic smooth law function:
  * \f$ \dfrac{1}{\kappa} \ln(y^+) + cstlog \f$
  * (\f$ cstlog = 5.2 \f$).
  *
@@ -291,6 +314,27 @@ const double cs_turb_vdriest = 25.6;
  */
 const double cs_turb_cstlog = 5.2;
 
+/*!
+ * Constant of logarithmic rough law function:
+ * \f$ \dfrac{1}{\kappa} \ln(y/\xi) + cstlog_{rough} \f$
+ * (\f$ cstlog_{rough} = 8.5 \f$).
+ *
+ * Constant of the logarithmic wall function.
+ * Useful if and only if \ref iturb >= 10 (mixing length, \f$k-\varepsilon\f$,
+ * \f$R_{ij}-\varepsilon\f$, LES, v2f or \f$k-\omega\f$).
+ */
+const double cs_turb_cstlog_rough = 8.5;
+
+/*!
+ * Constant \f$ \alpha \f$ for logarithmic law function switching from rough to smooth:
+ * \f$ \dfrac{1}{\kappa} \ln(y u_k/(\nu + \alpha \xi u_k)) + cstlog \f$
+ * (\f$ \alpha = \exp \left( -\kappa (8.5 - 5.2) \right) \f$).
+ *
+ * Useful if and only if \ref iturb >= 10 (mixing length, \f$k-\varepsilon\f$,
+ * \f$R_{ij}-\varepsilon\f$, LES, v2f or \f$k-\omega\f$).
+ */
+double cs_turb_cstlog_alpha;
+
 /*! Werner and Wengle coefficient */
 const double cs_turb_apow = 8.3;
 
@@ -837,6 +881,8 @@ cs_f_turb_rans_model_get_pointers(int     **irccor,
                                   int     **igrake,
                                   int     **igrari,
                                   int     **ikecou,
+                                  int     **reinit_turb,
+                                  int     **irijco,
                                   int     **irijnu,
                                   int     **irijrb,
                                   int     **irijec,
@@ -901,6 +947,8 @@ cs_f_turb_model_get_pointers(int     **iturb,
  *   igrake --> pointer to cs_glob_turb_rans_model->igrake
  *   igrari --> pointer to cs_glob_turb_rans_model->igrari
  *   ikecou --> pointer to cs_glob_turb_rans_model->ikecou
+ *   reinit_turb --> pointer to cs_glob_turb_rans_model->reinit_turb
+ *   irijco --> pointer to cs_glob_turb_rans_model->irijco
  *   irijnu --> pointer to cs_glob_turb_rans_model->irijnu
  *   irijrb --> pointer to cs_glob_turb_rans_model->irijrb
  *   irijec --> pointer to cs_glob_turb_rans_model->irijec
@@ -918,6 +966,8 @@ cs_f_turb_rans_model_get_pointers(int     **irccor,
                                   int     **igrake,
                                   int     **igrari,
                                   int     **ikecou,
+                                  int     **reinit_turb,
+                                  int     **irijco,
                                   int     **irijnu,
                                   int     **irijrb,
                                   int     **irijec,
@@ -933,6 +983,8 @@ cs_f_turb_rans_model_get_pointers(int     **irccor,
   *igrake = &(_turb_rans_model.igrake);
   *igrari = &(_turb_rans_model.igrari);
   *ikecou = &(_turb_rans_model.ikecou);
+  *reinit_turb= &(_turb_rans_model.reinit_turb);
+  *irijco = &(_turb_rans_model.irijco);
   *irijnu = &(_turb_rans_model.irijnu);
   *irijrb = &(_turb_rans_model.irijrb);
   *irijec = &(_turb_rans_model.irijec);
@@ -967,8 +1019,8 @@ cs_f_turb_les_model_get_pointers(int     **idries,
  * enables mapping to Fortran global pointers.
  *
  * parameters:
- *   almax  --> pointer to cs_glob_turb_rans_model->almax
- *   uref   --> pointer to cs_glob_turb_rans_model->uref
+ *   almax  --> pointer to cs_glob_turb_ref_values->almax
+ *   uref   --> pointer to cs_glob_turb_ref_values->uref
  *   xlomlg --> pointer to cs_glob_turb_rans_model->xlomlg
  *----------------------------------------------------------------------------*/
 
@@ -977,8 +1029,8 @@ cs_f_turb_reference_values(double  **almax,
                            double  **uref,
                            double  **xlomlg)
 {
-  *almax  = &(_turb_rans_model.almax);
-  *uref   = &(_turb_rans_model.uref);
+  *almax  = &(_turb_ref_values.almax);
+  *uref   = &(_turb_ref_values.uref);
   *xlomlg = &(_turb_rans_model.xlomlg);
 }
 
@@ -991,6 +1043,9 @@ cs_f_turb_complete_constants(void)
 {
   cs_turb_dpow   = 1/(1.+cs_turb_bpow);
   cs_turb_cmu025 = pow(cs_turb_cmu,0.25);
+  cs_turb_cstlog_alpha = exp(-cs_turb_xkappa
+                             * (cs_turb_cstlog_rough - cs_turb_cstlog));
+
 
   if (   cs_glob_turb_model->iturb == 30
       || cs_glob_turb_model->iturb == 31)
@@ -1021,6 +1076,59 @@ cs_f_turb_complete_constants(void)
  * Public function definitions
  *============================================================================*/
 
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Provide acces to cs_glob_turb_model
+ *
+ * needed to initialize structure with GUI
+ *----------------------------------------------------------------------------*/
+
+cs_turb_model_t *
+cs_get_glob_turb_model(void)
+{
+  return &_turb_model;
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Provide acces to cs_glob_turb_ref_values
+ *
+ * needed to initialize structure with GUI
+ *----------------------------------------------------------------------------*/
+
+cs_turb_ref_values_t *
+cs_get_glob_turb_ref_values(void)
+{
+  return &_turb_ref_values;
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Provide acces to cs_glob_turb_rans_model
+ *
+ * needed to initialize structure with GUI
+ *----------------------------------------------------------------------------*/
+
+cs_turb_rans_model_t *
+cs_get_glob_turb_rans_model(void)
+{
+  return &_turb_rans_model;
+}
+
+/*----------------------------------------------------------------------------*/
+/*!
+ * \brief Provide acces to cs_glob_turb_les_model
+ *
+ * needed to initialize structure with GUI
+ *----------------------------------------------------------------------------*/
+
+cs_turb_les_model_t *
+cs_get_glob_turb_les_model(void)
+{
+  return &_turb_les_model;
+}
+
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
