@@ -74,6 +74,17 @@ typedef struct {
 
 } cs_turb_model_t;
 
+
+/* Reference values for turbulence structure and associated pointer */
+/*------------------------------------------------------------------*/
+
+typedef struct {
+  double        almax;        /* characteristic macroscopic length of the
+                                 domain */
+  double        uref;         /* characteristic flow velocity */
+} cs_turb_ref_values_t;
+
+
 /* rans turbulence model descriptor */
 /*----------------------------------*/
 
@@ -112,6 +123,12 @@ typedef struct {
                                  k-epsilon (only for iturb=20)
                                  - 1: true (default)
                                  - 0: false */
+  int           reinit_turb;  /* Advanced re-init for EBRSM and k-omega models
+                                 - 1: true (default)
+                                 - 0: false */
+  int           irijco;       /* coupled solving of Rij
+                                 - 1: true
+                                 - 0: false (default) */
   int           irijnu;       /* pseudo eddy viscosity in the matrix of momentum
                                  equation to partially implicit div( rho R )
                                  - 1: true
@@ -133,9 +150,6 @@ typedef struct {
   int           iclptr;       /* partial implicitation of wall BCs of R
                                  - 1: true
                                  - 0: false (default) */
-  double        almax;        /* characteristic macroscopic length of the
-                                 domain */
-  double        uref;         /* characteristic flow velocity */
   double        xlomlg;       /* mixing length */
 
 } cs_turb_rans_model_t;
@@ -163,6 +177,10 @@ typedef struct {
 
 extern const cs_turb_model_t         *cs_glob_turb_model;
 
+/* Pointer to reference values for turbulence descriptor structure */
+
+extern const cs_turb_ref_values_t    *cs_glob_turb_ref_values;
+
 /* Pointer to RANS turbulence model descriptor structure */
 
 extern const cs_turb_rans_model_t    *cs_glob_turb_rans_model;
@@ -176,6 +194,8 @@ extern const cs_turb_les_model_t     *cs_glob_turb_les_model;
 extern const double cs_turb_xkappa;
 extern const double cs_turb_vdriest;
 extern const double cs_turb_cstlog;
+extern const double cs_turb_cstlog_rough;
+extern double cs_turb_cstlog_alpha;
 extern const double cs_turb_apow;
 extern const double cs_turb_bpow;
 extern double cs_turb_dpow;
@@ -275,6 +295,43 @@ extern const double cs_turb_cthdfm;
  * Public function prototypes
  *============================================================================*/
 
+/*----------------------------------------------------------------------------
+ * Provide acces to cs_glob_turb_model
+ *
+ * needed to initialize structure with GUI
+ *----------------------------------------------------------------------------*/
+
+cs_turb_model_t *
+cs_get_glob_turb_model(void);
+
+/*----------------------------------------------------------------------------
+ * Provide acces to cs_glob_turb_ref_values
+ *
+ * needed to initialize structure with GUI
+ *----------------------------------------------------------------------------*/
+
+cs_turb_ref_values_t *
+cs_get_glob_turb_ref_values(void);
+
+
+/*----------------------------------------------------------------------------
+ * Provide acces to cs_glob_turb_rans_model
+ *
+ * needed to initialize structure with GUI
+ *----------------------------------------------------------------------------*/
+
+cs_turb_rans_model_t *
+cs_get_glob_turb_rans_model(void);
+
+/*----------------------------------------------------------------------------
+ * Provide acces to cs_glob_turb_les_model
+ *
+ * needed to initialize structure with GUI
+ *----------------------------------------------------------------------------*/
+
+cs_turb_les_model_t *
+cs_get_glob_turb_les_model(void);
+
 /*----------------------------------------------------------------------------*/
 
 END_C_DECLS
