@@ -115,7 +115,7 @@ integer          icetsm(ncesmp), itypsm(ncesmp,nvar)
 
 double precision dt(ncelet)
 double precision produc(6,ncelet)
-double precision gradro(ncelet,3)
+double precision gradro(3,ncelet)
 double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 double precision viscf(nfac), viscb(nfabor)
 double precision tslage(ncelet),tslagi(ncelet)
@@ -301,10 +301,9 @@ if (ncesmp.gt.0) then
 
 !       We increment smbr with -Gamma.var_prev. and rocsdt with Gamma (*theta)
   call catsma &
-  !==========
  ( ncelet , ncel   , ncesmp , iiun   , isto2t , thetv  ,          &
    icetsm , itypsm(:,ivar)  ,                                     &
-   volume , cvara_var       , smacel(:,ivar)   , smacel(:,ipr) ,  &
+   cell_f_vol , cvara_var   , smacel(:,ivar)   , smacel(:,ipr) ,  &
    smbr   ,  rovsdt , w1 )
 
 !       If we extrapolate the source terms we put Gamma Pinj in propce
@@ -327,7 +326,7 @@ endif
 
 do iel=1,ncel
   rovsdt(iel) = rovsdt(iel)                                          &
-              + istat(ivar)*(crom(iel)/dt(iel))*volume(iel)
+              + istat(ivar)*(crom(iel)/dt(iel))*cell_f_vol(iel)
 enddo
 
 
@@ -377,7 +376,7 @@ if (st_prv_id.ge.0) then
     !       In propce:
     !       = rhoPij-C1rho eps/k(   -2/3k dij)-C2rho(Pij-1/3Pkk dij)-2/3rho eps dij
     !       = rho{2/3dij[C2 Pkk/2+(C1-1)eps)]+(1-C2)Pij           }
-    c_st_prv(iel) = c_st_prv(iel) + cromo(iel) * volume(iel)      &
+    c_st_prv(iel) = c_st_prv(iel) + cromo(iel) * cell_f_vol(iel)  &
       *(   deltij*d2s3*                                           &
            (  crij2*trprod                                        &
             +(crij1-1.d0)* cvara_ep(iel)  )                       &
@@ -385,12 +384,12 @@ if (st_prv_id.ge.0) then
     !       In smbr
     !       =       -C1rho eps/k(Rij         )
     !       = rho{                                     -C1eps/kRij}
-    smbr(iel) = smbr(iel) + crom(iel) * volume(iel)               &
+    smbr(iel) = smbr(iel) + crom(iel) * cell_f_vol(iel)               &
       *( -crij1*cvara_ep(iel)/trrij * cvara_var(iel) )
 
     !     Calculation of the implicit part coming from Phil
     !       = C1rho eps/k(1        )
-    rovsdt(iel) = rovsdt(iel) + crom(iel) * volume(iel)           &
+    rovsdt(iel) = rovsdt(iel) + crom(iel) * cell_f_vol(iel)           &
                             *crij1*cvara_ep(iel)/trrij*thetv
 
   enddo
@@ -404,16 +403,16 @@ if (st_prv_id.ge.0) then
 
      !    We remove of cromo
      !       =       -C1rho eps/k(   -1/3Rij dij)
-      c_st_prv(iel) = c_st_prv(iel) - cromo(iel) * volume(iel)    &
+      c_st_prv(iel) = c_st_prv(iel) - cromo(iel) * cell_f_vol(iel)    &
       *(deltij*d1s3*crij1*cvara_ep(iel)/trrij * cvara_var(iel))
       !    We add to smbr (with crom)
       !       =       -C1rho eps/k(   -1/3Rij dij)
       smbr(iel)                 = smbr(iel)                       &
-                          + crom(iel) * volume(iel)               &
+                          + crom(iel) * cell_f_vol(iel)           &
       *(deltij*d1s3*crij1*cvara_ep(iel)/trrij * cvara_var(iel))
       !    We add to rovsdt (woth crom)
       !       =        C1rho eps/k(   -1/3    dij)
-      rovsdt(iel) = rovsdt(iel) + crom(iel) * volume(iel)         &
+      rovsdt(iel) = rovsdt(iel) + crom(iel) * cell_f_vol(iel)         &
       *(deltij*d1s3*crij1*cvara_ep(iel)/trrij                 )
     enddo
 
@@ -431,7 +430,7 @@ else
     !     Calculation of Prod+Phi1+Phi2-Eps
     !       = rhoPij-C1rho eps/k(Rij-2/3k dij)-C2rho(Pij-1/3Pkk dij)-2/3rho eps dij
     !       = rho{2/3dij[C2 Pkk/2+(C1-1)eps)]+(1-C2)Pij-C1eps/kRij}
-    smbr(iel) = smbr(iel) + crom(iel) * volume(iel)               &
+    smbr(iel) = smbr(iel) + crom(iel) * cell_f_vol(iel)           &
       *(   deltij*d2s3*                                           &
            (  crij2*trprod                                        &
             +(crij1-1.d0)* cvara_ep(iel)  )                           &
@@ -440,7 +439,7 @@ else
 
     !     Calculation of the implicit part coming from Phi1
     !       = C1rho eps/k(1-1/3 dij)
-    rovsdt(iel) = rovsdt(iel) + crom(iel) * volume(iel)           &
+    rovsdt(iel) = rovsdt(iel) + crom(iel) * cell_f_vol(iel)           &
          *(1.d0-d1s3*deltij)*crij1*cvara_ep(iel)/trrij
   enddo
 
@@ -503,7 +502,7 @@ if (icorio.eq.1 .or. iturbo.eq.1) then
   ! Coriolis contribution in the Phi1 term: (1-C2/2)Gij
   if (icorio.eq.1) then
     do iel = 1, ncel
-      w7(iel) = crom(iel)*volume(iel)*(1.d0 - 0.5d0*crij2)*w7(iel)
+      w7(iel) = crom(iel)*cell_f_vol(iel)*(1.d0 - 0.5d0*crij2)*w7(iel)
     enddo
   endif
 
@@ -532,7 +531,6 @@ if (irijec.eq.1) then
   enddo
 
   call rijech(isou, produc, w7)
-  !==========
 
   ! If we extrapolate the source terms: propce
   if (st_prv_id.ge.0) then
@@ -560,7 +558,6 @@ if (igrari.eq.1) then
   enddo
 
   call rijthe(nscal, ivar, gradro, w7)
-  !==========
 
   ! If source terms are extrapolated
   if (st_prv_id.ge.0) then
@@ -596,7 +593,6 @@ if (idften(ivar).eq.6) then
   iwarnp = iwarni(ivar)
 
   call vitens &
-  !==========
  ( viscce , iwarnp ,             &
    weighf , weighb ,             &
    viscf  , viscb  )
@@ -611,7 +607,6 @@ else
   enddo
 
   call viscfa                    &
-  !==========
  ( imvisf ,                      &
    w1     ,                      &
    viscf  , viscb  )
@@ -654,7 +649,6 @@ relaxp = relaxv(ivar)
 icvflb = 0
 
 call codits &
-!==========
  ( idtvar , ivar   , iconvp , idiffp , ndircp ,                   &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
    ischcp , isstpp , iescap , imucpp , idftnp , iswdyp ,          &
