@@ -74,6 +74,7 @@ use ppincl
 use mesh
 use field
 use field_operator
+use cs_c_bindings
 
 !===============================================================================
 
@@ -96,8 +97,8 @@ double precision prdv2f(ncelet)
 
 character(len=80) :: chaine
 integer          iel   , ifac  , init  , inc   , iccocg, ivar
-integer          iivar , iiun
-integer          iclip , isqrt
+integer          f_id0 , iiun
+integer          iclip
 integer          nswrgp, imligp
 integer          iconvp, idiffp, ndircp
 integer          nswrsp, ircflp, ischcp, isstpp, iescap
@@ -332,7 +333,6 @@ if (irccor.eq.1) then
   ! Compute the modified Ceps2 coefficient (w1 array not used)
 
   call rotcor(dt, w1, ce2rc)
-  !==========
 
 else
 
@@ -367,18 +367,14 @@ endif
 ! (function of the potential temperature)
 if (igrake.eq.1 .and. ippmod(iatmos).ge.1) then
 
-  call atprke &
-  !==========
- ( nscal  ,                                                       &
-   tinstk ,                                                       &
-   smbrk  , smbre  )
+  call atprke(nscal, tinstk, smbrk, smbre)
 
 ! --- Buoyancy term     G = Beta*g.Grad(scalar)/prdtur/rho
 !     Here is computed  G =-g.grad(rho)/prdtur/rho
 else if (igrake.eq.1) then
 
   ! Allocate a temporary for the gradient calculation
-  allocate(grad(ncelet,3))
+  allocate(grad(3,ncelet))
 
   iccocg = 1
   inc = 1
@@ -394,12 +390,11 @@ else if (igrake.eq.1) then
     viscb(ifac) = 0.d0
   enddo
 
-  iivar = 0
+  f_id0 = -1
 
-  call grdcel &
-  !==========
- ( iivar  , imrgra , inc    , iccocg , nswrgp , imligp ,          &
-   iwarnp , nfecra , epsrgp , climgp , extrap ,                   &
+  call gradient_s                                                 &
+ ( f_id0  , imrgra , inc    , iccocg , nswrgp , imligp ,          &
+   iwarnp , epsrgp , climgp , extrap ,                            &
    cromo  , bromo  , viscb  ,                                     &
    grad   )
 
@@ -420,7 +415,7 @@ else if (igrake.eq.1) then
     xk   = cvara_k(iel)
     ttke = xk / xeps
 
-    gravke = -(grad(iel,1)*gx + grad(iel,2)*gy + grad(iel,3)*gz) &
+    gravke = -(grad(1,iel)*gx + grad(2,iel)*gy + grad(3,iel)*gz) &
            / (rho*prdtur)
 
     ! Implicit Buoyant terms when negativ
@@ -463,11 +458,7 @@ if (iturb.eq.51) then
     w3(iel) = visct/rho/sigmak
   enddo
 
-  call viscfa &
-  !==========
-( imvisf ,        &
-  w3     ,        &
-  viscf  , viscb  )
+  call viscfa(imvisf, w3, viscf, viscb)
 
   ivar = ik
   call field_get_coefa_s(ivarfl(ivar), coefap)
@@ -501,7 +492,6 @@ if (iturb.eq.51) then
   iphydp = 0
 
   call itrgrp &
-  !==========
 ( ivarfl(ivar), init   , inc    , imrgra , iccocg , nswrgp , imligp , iphydp , &
   iwarnp ,                                                                     &
   epsrgp , climgp , extrap ,                                                   &
@@ -525,7 +515,6 @@ if (iturb.eq.51) then
   allocate(w12(ncelet))
 
   call tsepls(w12)
-  !==========
 
   do iel = 1, ncel
 
@@ -560,7 +549,6 @@ endif
 
 !===============================================================================
 ! 8. Finalization of explicit and implicit source terms
-
 !===============================================================================
 
 ! smbre = ceps1 epsilon/k (prod + g ) - rho0 volume epsilon epsilon/k
@@ -715,7 +703,6 @@ do iel = 1, ncel
 enddo
 
 call cs_user_turbulence_source_terms &
-!===================================
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    ivarfl(ik)      ,                                              &
    icepdc , icetsm , itypsm ,                                     &
@@ -723,7 +710,6 @@ call cs_user_turbulence_source_terms &
    w7     , usimpk )
 
 call cs_user_turbulence_source_terms &
-!===================================
  ( nvar   , nscal  , ncepdp , ncesmp ,                            &
    ivarfl(iep)     ,                                              &
    icepdc , icetsm , itypsm ,                                     &
@@ -820,7 +806,6 @@ if (ncesmp.gt.0) then
   ivar = ik
 
   call catsma &
-  !==========
  ( ncelet , ncel   , ncesmp , iiun   ,                            &
    isto2t , thetav(ivar)    ,                                     &
    icetsm , itypsm(:,ivar)  ,                                     &
@@ -830,7 +815,6 @@ if (ncesmp.gt.0) then
   ivar = iep
 
   call catsma &
-  !==========
  ( ncelet , ncel   , ncesmp , iiun   ,                            &
    isto2t , thetav(ivar)    ,                                     &
    icetsm , itypsm(:,ivar)  ,                                     &
@@ -889,15 +873,10 @@ if (ikecou.eq.1) then
   if (idiff(ivar).ge. 1) then
 
     do iel = 1, ncel
-      w4(iel) = viscl(iel)                                        &
-              + idifft(ivar)*cvisct(iel)/sigmak
+      w4(iel) = viscl(iel) + idifft(ivar)*cvisct(iel)/sigmak
     enddo
 
-    call viscfa &
-    !==========
- ( imvisf ,                                                       &
-   w4     ,                                                       &
-   viscf  , viscb  )
+    call viscfa(imvisf, w4, viscf, viscb)
 
   else
 
@@ -932,7 +911,6 @@ if (ikecou.eq.1) then
   icvflb = 0
 
   call bilsca &
-  !==========
  ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
    iwarnp , imucpp , idftnp ,                                     &
@@ -946,8 +924,7 @@ if (ikecou.eq.1) then
    w7     )
 
   if (iwarni(ivar).ge.2) then
-    isqrt = 1
-    call prodsc(ncel,isqrt,smbrk,smbrk,rnorm)
+    rnorm = sqrt(cs_gdot(ncel,smbrk,smbrk))
     write(nfecra,1100) chaine(1:8) ,rnorm
   endif
 
@@ -967,11 +944,7 @@ if (ikecou.eq.1) then
               + idifft(ivar)*cvisct(iel)/sigmae
     enddo
 
-    call viscfa &
-    !==========
- ( imvisf ,                                                       &
-   w4     ,                                                       &
-   viscf  , viscb  )
+    call viscfa(imvisf, w4, viscf, viscb)
 
   else
 
@@ -1006,7 +979,6 @@ if (ikecou.eq.1) then
   icvflb = 0
 
   call bilsca &
-  !==========
  ( idtvar , ivar   , iconvp , idiffp , nswrgp , imligp , ircflp , &
    ischcp , isstpp , inc    , imrgra , iccocg ,                   &
    iwarnp , imucpp , idftnp ,                                     &
@@ -1020,8 +992,7 @@ if (ikecou.eq.1) then
    w8     )
 
   if (iwarni(ivar).ge.2) then
-    isqrt = 1
-    call prodsc(ncel,isqrt,smbre,smbre,rnorm)
+    rnorm = sqrt(cs_gdot(ncel,smbre,smbre))
     write(nfecra,1100) chaine(1:8) ,rnorm
   endif
 
@@ -1133,11 +1104,7 @@ if (idiff(ivar).ge.1) then
     endif
   enddo
 
-  call viscfa &
-  !==========
- ( imvisf ,                                                       &
-   w1     ,                                                       &
-   viscf  , viscb  )
+  call viscfa(imvisf, w1, viscf, viscb)
 
 else
 
@@ -1177,7 +1144,6 @@ thetap = thetav(ivar)
 icvflb = 0
 
 call codits &
-!==========
  ( idtvar , ivar   , iconvp , idiffp , ndircp ,                   &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
    ischcp , isstpp , iescap , imucpp , idftnp , iswdyp ,          &
@@ -1213,11 +1179,7 @@ if (idiff(ivar).ge.1) then
     endif
   enddo
 
-  call viscfa &
-  !==========
- ( imvisf ,                                                       &
-   w1     ,                                                       &
-   viscf  , viscb  )
+  call viscfa(imvisf, w1, viscf, viscb)
 
 else
 
@@ -1257,7 +1219,6 @@ thetap = thetav(ivar)
 icvflb = 0
 
 call codits &
-!==========
  ( idtvar , ivar   , iconvp , idiffp , ndircp ,                   &
    imrgra , nswrsp , nswrgp , imligp , ircflp ,                   &
    ischcp , isstpp , iescap , imucpp , idftnp , iswdyp ,          &
@@ -1279,10 +1240,7 @@ call codits &
 
 iclip = 1
 iwarnp = iwarni(ik)
-call clipke &
-!==========
- ( ncelet , ncel   , nvar   ,                                     &
-   iclip  , iwarnp )
+call clipke(ncelet, ncel, nvar, iclip, iwarnp)
 
 ! Free memory
 deallocate(viscf, viscb)
