@@ -69,7 +69,7 @@ use cstnum
 use cstphy
 use optcal
 use lagran
-use pointe, only: s2kw, divukw, ifapat, dispar
+use pointe, only: s2kw, divukw, dispar
 use parall
 use mesh
 use field
@@ -96,8 +96,8 @@ double precision ckupdc(ncepdp,6), smacel(ncesmp,nvar)
 
 character(len=80) :: chaine
 integer          iel   , ifac  , inc   , iprev,  iccocg, ivar
-integer          ii, f_id , iiun  , ifacpt
-integer          iclipk, iclipw
+integer          ii, f_id , iiun
+integer          iclipk(1), iclipw, iclpkmx(1)
 integer          nswrgp, imligp
 integer          iconvp, idiffp, ndircp
 integer          nswrsp, ircflp, ischcp, isstpp, iescap
@@ -119,6 +119,7 @@ double precision thetp1, thetak, thetaw, thets, thetap, epsrsp
 double precision tuexpk, tuexpw
 double precision cdkw, xarg1, xxf1, xgamma, xbeta, sigma, produc
 double precision var, vrmin(2), vrmax(2)
+double precision utaurf,ut2,ypa,ya,xunorm, limiter, nu0
 
 double precision rvoid(1)
 
@@ -145,6 +146,7 @@ double precision, dimension(:), pointer :: cvar_var
 double precision, dimension(:), pointer :: cpro_pcvto, cpro_pcvlo
 double precision, dimension(:), pointer :: viscl, cvisct
 double precision, dimension(:), pointer :: c_st_k_p, c_st_omg_p
+double precision, dimension(:,:), pointer :: vel
 
 !===============================================================================
 
@@ -164,6 +166,7 @@ allocate(gdkgdw(ncelet))
 allocate(prodk(ncelet), prodw(ncelet))
 
 epz2 = epzero**2
+iclpkmx(1) = 0
 
 call field_get_val_s(iprpfl(ivisct), cvisct)
 call field_get_val_s(iprpfl(iviscl), viscl)
@@ -258,19 +261,9 @@ deallocate(gradk, grado)
 ! 2.2. Compute the weight f1 (stored in xf1)
 !===============================================================================
 
-if (abs(icdpar).eq.2) then
-  do iel = 1, ncel
-    ifacpt = ifapat(iel)
-    w2(iel) = (cdgfbo(1,ifacpt)-xyzcen(1,iel))**2 &
-            + (cdgfbo(2,ifacpt)-xyzcen(2,iel))**2 &
-            + (cdgfbo(3,ifacpt)-xyzcen(3,iel))**2
-    w2(iel) = sqrt(w2(iel))
-  enddo
-else
-  do iel = 1, ncel
-    w2(iel) = max(dispar(iel),epzero)
-  enddo
-endif
+do iel = 1, ncel
+  w2(iel) = max(dispar(iel),epzero)
+enddo
 
 ! En cas d'ordre 2 on utilise les valeurs en n car le terme en (1-f1)*gdkgdw
 ! sera dans PROPCE. Du coup, on aura quand meme certaines "constantes"
@@ -1063,16 +1056,16 @@ do ii = 1, 2
 enddo
 
 ! On clippe simplement k et omega par valeur absolue
-iclipk = 0
+iclipk(1) = 0
 iclipw = 0
 do iel = 1, ncel
   xk = cvar_k(iel)
   xw = cvar_omg(iel)
   if (abs(xk).le.epz2) then
-    iclipk = iclipk + 1
+    iclipk(1) = iclipk(1) + 1
     cvar_k(iel) = max(cvar_k(iel),epz2)
   elseif (xk.le.0.d0) then
-    iclipk = iclipk + 1
+    iclipk(1) = iclipk(1) + 1
     cvar_k(iel) = -xk
   endif
   if (abs(xw).le.epz2) then
@@ -1086,10 +1079,67 @@ enddo
 
 ! ---  Stockage nb de clippings pour listing
 
-call log_iteration_clipping_field(ivarfl(ik), iclipk, 0,    &
-                                  vrmin(1:1), vrmax(1:1))
+call log_iteration_clipping_field(ivarfl(ik), iclipk(1), 0,    &
+                                  vrmin(1:1), vrmax(1:1),iclipk(1), iclpkmx(1))
 call log_iteration_clipping_field(ivarfl(iomg), iclipw, 0,  &
-                                  vrmin(2:2), vrmax(2:2))
+                                  vrmin(2:2), vrmax(2:2),iclipk(1), iclpkmx(1))
+!===============================================================================
+! 16. Advanced reinit
+!===============================================================================
+
+! Automatic reinitialization at the end of the first iteration:
+! wall distance y^+ is computed with -C log(1-alpha), where C=CL*Ceta*L*kappa, then y
+! so we have an idea of the wall distance in complexe geometries.
+! Then U is initialized with a Reichard lay
+! Epsilon by 1/(kappa y), clipped next to the wall at its value for y^+=15
+! k is given by a blending between eps/(2 nu)*y^2 and utau/sqrt(Cmu)
+! The blending function is chosen so that the asymptotic behavior
+! and give the correct pic of k (not the same blending than for the EBRSM
+! because k profile is not the same for k-omega)
+! For omega, far from the wall we take eps/Cmu/k, but next to the wall, omega solution is enforced
+!TODO FIXME: why not just before? Are the BC uncompatible?
+if (ntcabs.eq.1.and.reinit_turb.eq.1) then
+
+  call field_get_val_prev_v(ivarfl(iu), vel)
+
+  utaurf = 0.05d0*uref
+  nu0 = viscl0 / ro0
+
+  do iel = 1, ncel
+    ! Compute the velocity magnitude
+    xunorm = vel(1,iel)**2 + vel(2,iel)**2 + vel(3,iel)**2
+    xunorm = sqrt(xunorm)
+
+    ya = dispar(iel)
+    ypa = ya*utaurf/nu0
+    ! Velocity magnitude is imposed (limitted only), the direction is
+    ! conserved
+    if (xunorm.le.1.d-12*uref) then
+      limiter = 1.d0
+    else
+      limiter = min(utaurf/xunorm*(2.5d0*dlog(1.d0+0.4d0*ypa)            &
+      +7.8d0*(1.d0-dexp(-ypa/11.d0)          &
+      -(ypa/11.d0)*dexp(-0.33d0*ypa))),      &
+      1.d0)
+    endif
+
+    vel(1,iel) = limiter*vel(1,iel)
+    vel(2,iel) = limiter*vel(2,iel)
+    vel(3,iel) = limiter*vel(3,iel)
+
+    ut2 = 0.05d0*uref
+    xeps = utaurf**3*min(1.d0/(xkappa*15.d0*nu0/utaurf), &
+    1.d0/(xkappa*ya))
+    cvar_k(iel) = xeps/2.d0/nu0*ya**2                    &
+    * exp(-ypa/25.d0)**2                        &
+    + ut2**2/sqrt(cmu)*(1.d0-exp(-ypa/25.d0))**2
+
+    cvar_omg(iel) = ut2**3/(xkappa*15.d0*nu0/ut2)/(ut2**2/sqrt(cmu))/cmu
+
+  enddo
+end if
+
+
 
 ! Free memory
 deallocate(viscf, viscb)
