@@ -115,68 +115,13 @@ cs_user_model(void)
 
   if (cs_gui_file_is_loaded())
     return;
-
-  /*--------------------------------------------------------------------------*/
-
-  /* Example: add 2 scalar variables ("species" in the GUI nomenclature).
-   *
-   * Note that at this (very early) stage of the data setup, fields are
-   * not defined yet. Associated fields will be defined later (after
-   * model-defined fields) in the same order as that used here, and
-   * after user-defined variables defined throught the GUI, if used.
-   *
-   * Currently, only 1d (scalar) fields are handled.
-   *
-   * parameters for cs_parameters_add_variable():
-   *   name             <-- name of variable and associated field
-   *   dim              <-- variable dimension
-   */
-
-  if (false) {
-    cs_parameters_add_variable("species_1", 1);
-    cs_parameters_add_variable("tracer", 1);
-  }
-
-  /*--------------------------------------------------------------------------*/
-
-  /* Example: add the variance of a user variable.
-   *
-   * parameters for cs_parameters_add_variable_variance():
-   *   name          <-- name of variance and associated field
-   *   variable_name <-- name of associated variable
-   */
-
-  if (false) {
-    cs_parameters_add_variable_variance("variance_1",
-                                        "species_1");
-  }
-
-  /*--------------------------------------------------------------------------*/
-
-  /* Example: add a user property defined on boundary faces.
-   *
-   * parameters for cs_parameters_add_property():
-   *   name        <-- name of property and associated field
-   *   dim         <-- property dimension
-   *   location_id <-- id of associated mesh location, which must be one of:
-   *                     CS_MESH_LOCATION_CELLS
-   *                     CS_MESH_LOCATION_INTERIOR_FACES
-   *                     CS_MESH_LOCATION_BOUNDARY_FACES
-   *                     CS_MESH_LOCATION_VERTICES
-   */
-
-  if (false) {
-    cs_parameters_add_property("user_b_property_1",
-                               1,
-                               CS_MESH_LOCATION_BOUNDARY_FACES);
-  }
 }
 
 /*----------------------------------------------------------------------------*/
 /*!
  * \brief Define or modify general numerical and physical user parameters.
  *
- * At the calling point of this function, most model-related most varibles
+ * At the calling point of this function, most model-related most variables
  * and other fields have been defined, so specific settings related to those
  * fields may be set here.
  */
@@ -185,6 +130,7 @@ cs_user_model(void)
 void
 cs_user_parameters(void)
 {
+
 }
 
 /*----------------------------------------------------------------------------*/
