@@ -239,7 +239,7 @@ endif
 !                     1 (transported particle velocity)
 !                     2 (limit drop particle velocity)
 if (.false.) then
-  i_coal_drift = 1
+  i_comb_drift = 1
 endif
 
 
@@ -270,6 +270,19 @@ if (ixmlpu.eq.0) then
 
 endif
 
+! --- eos: equation of state for compressible flows
+! ========
+
+!        if = 1    ideal gas with constant gamma
+!        if = 2    stiffened gas
+!        if = 3    ideal gas mix
+
+if (ixmlpu.eq.0.and.ippmod(icompf).ge.0) then
+
+  ieos = 1
+
+endif
+
 ! --- eljou: Joule effect
 ! ==========
 
@@ -496,6 +509,7 @@ subroutine usipph &
 !===============================================================================
 
 use entsor, only: nfecra ! No other module should appear here
+use optcal, only: irijco ! No other module should appear here
 
 !===============================================================================
 
@@ -592,6 +606,14 @@ if (ixmlpu.eq.0) then
 
 endif
 
+
+! Coupled solver for Rij components (when iturb=30, 31 or 32)
+if (.false.) then
+
+  irijco = 0
+
+endif
+
 ! --- Thermal model
 !      0: none
 !      1: temperature
@@ -705,8 +727,8 @@ integer nmodpp
 ! Local variables
 
 logical       ilved, inoprv
-integer       ii, jj, kscmin, kscmax, keydri
-integer       f_id, idim1, itycat, ityloc, iscdri, iscal, ifcvsl
+integer       ii, jj, kscmin, kscmax, keydri, kbfid
+integer       f_id, idim1, itycat, ityloc, iscdri, iscal, ifcvsl, b_f_id
 
 !===============================================================================
 
@@ -972,6 +994,18 @@ if (.false.) then
 
 endif
 
+! --- Advanced re-initialization for EBRSM or k-omega models
+
+!     - 0: switch off (default)
+!     - 1: switch on
+
+if (.false.) then
+
+  reinit_turb = 1
+
+endif
+
+
 ! --- Turbulent diffusion model for second moment closure (iturb = 3x)
 !      0: scalar diffusivity (Shir model)
 !      1: tensorial diffusivity (Daly and Harlow model, default model)
@@ -984,6 +1018,14 @@ if (.false.) then
 
 endif
 
+! --- Advanced choice of Wall function
+
+if (.false.) then
+
+  iwallf = 5
+
+endif
+
 ! Physical constants (cstphy)
 ! ===========================
 
@@ -1269,7 +1311,11 @@ endif
 if (.false.) then
 
   ! For thermal scalar
-  if (iscalt.gt.0) call field_set_key_int(ivarfl(isca(iscalt)), kivisl, ifcvsl)
+  if (ippmod(icompf).ge.0) then
+    call field_set_key_int(ivarfl(isca(itempk)), kivisl, ifcvsl)
+  else if (iscalt.gt.0) then
+    call field_set_key_int(ivarfl(isca(iscalt)), kivisl, ifcvsl)
+  endif
 
   do iscal = 1, nscaus
     if (iscavr(iscal).le.0) then
@@ -1320,7 +1366,6 @@ if (.false.) then
   almax = 0.5
 endif
 
-
 ! --- Scalar with a drift (key work "drift_scalar_model">0) or without drift
 !       ((key work "drift_scalar_model"=0, default option) for each USER scalar.
 !       - to specify that a scalar have a drift and need the drift computation:
@@ -1371,8 +1416,8 @@ endif
 ! =============================
 
 ! Example: enforce existence of 'yplus', 'tplus' and 'tstar' fields, so that
-!          yplus, a boundary temperature or Nusselt number may be computed using
-!          the post_boundary_temperature or post_boundary_nusselt subroutines.
+!          yplus may be saved, or a local Nusselt number may be computed using
+!          the post_boundary_nusselt subroutine.
 !          When postprocessing of these quantities is activated, those fields
 !          are present, but if we need to compute them in the
 !          cs_user_extra_operations user subroutine without postprocessing them,
@@ -1406,7 +1451,7 @@ if (.false.) then
   call field_get_id_try('tstar', f_id)
   if (f_id.lt.0) then
     call field_create('tstar', itycat, ityloc, idim1, ilved, inoprv, f_id)
-    ! tplus postreated and in the log
+    ! tstar postreated and in the log
     call field_set_key_int(f_id, keyvis, 1)
     call field_set_key_int(f_id, keylog, 1)
   endif
@@ -2031,12 +2076,33 @@ if (.false.) then
   iimlum = 0
 endif
 
-! Compute the absorption coefficient through Modak (if 1), or do not use
+! Compute the absorption coefficient through Modak (if 1 or 2), or do not use
 ! Modak (if 0)
 ! Useful ONLY when gas or coal combustion is activated
+! imodak = 1: ADF model with 8 wave length intervals
+! imodak = 2: ADF model with 50 wave length intervals
 
 if (.false.) then
-  imodak = 0
+  imodak = 2
+endif
+
+! Compute the absorption coefficient via ADF model
+! Useful ONLY when coal combustion is activated
+! imoadf = 0 switch off the ADF model
+!        = 1 switch on the ADF model (with 8 bands ADF08)
+!        = 2 switch on the ADF model (with 50 bands ADF50)
+
+if (.false.) then
+  imoadf = 1
+endif
+
+! Compute the absorption coefficient through FSCK model (if 1)
+! Useful ONLY when coal combustion is activated
+! imfsck = 1: activated
+! imfsck = 0: not activated
+
+if (.false.) then
+  imfsck = 1
 endif
 
 !===============================================================================
@@ -2059,12 +2125,8 @@ subroutine uscfx1
 !    User subroutine.
 
 !    Initialize non standard options for the compressible flow scheme such
-!    what kind of equation of state must be used.
-
-!    In addition to options set in the user subroutine 'uscfx2' (or in
-!    the GUI): this subroutine allows to set switches to indicate if the
-!    volumetric viscosity and the conductivity are constants, their
-!    values being given in the subroutine 'uscfx2'.
+!    as the variability of the thermal conductivity and the volume viscosity.
+!    Their values can be given in the subroutine 'uscfx2'.
 
 !-------------------------------------------------------------------------------
 ! Arguments
@@ -2142,27 +2204,21 @@ endif
 ! TEST_TO_REMOVE_FOR_USE_OF_SUBROUTINE_END
 
 !===============================================================================
-! 1. Scheme options
+! 1. Properties options
 !===============================================================================
 
 if (iihmpr.eq.0) then   !  Remove test to set values here when also using GUI.
 
-! Equation of state choice
-! --> ieos = 1: Perfect gas with constant Gamma
-! --> ieos = 2: Perfect gas with variable Gamma (please fill-in the source file
-!               cfther.f90 in this case, otherwise it won't work!)
-  ieos = 1
-
-! --> Molecular thermal conductivity
-!       constant  : ifcvsl = -1
-!       variable  : ifcvsl = 0
+  ! --> Molecular thermal conductivity
+  !       constant  : ifcvsl = -1
+  !       variable  : ifcvsl = 0
 
   ifcvsl = -1
   call field_set_key_int(ivarfl(isca(itempk)), kivisl, ifcvsl)
 
-! --> Volumetric molecular viscosity
-!       iviscv = 0 : uniform  in space and constant in time
-!              = 1 : variable in space and time
+  ! --> Volumetric molecular viscosity
+  !       iviscv = 0 : uniform  in space and constant in time
+  !              = 1 : variable in space and time
 
   iviscv = 0
 
@@ -2305,14 +2361,14 @@ if (iihmpr.eq.0) then   !  Remove test to set values here when also using GUI.
 ! --> Molar mass of the gas (kg/mol)
 
 !       For example with dry air, xmasml is around 28.8d-3 kg/mol
-  if (ieos.eq.1) then
-    xmasmr = 0.028966
-  endif
+
+  xmasmr = 0.028966
 
 ! --> Hydrostatic equilibrium
 
 !       Specify if the hydrostatic equilibrium must be accounted for
 !         (yes = 1 , no = 0)
+
   icfgrp = 1
 
 endif
@@ -2725,5 +2781,3 @@ end subroutine user_darcy_ini1
 
 
 !===============================================================================
-
-
