@@ -113,6 +113,7 @@ use pointe
 use numvar
 use optcal
 use cstphy
+use cstnum
 use entsor
 use parall
 use period
@@ -121,6 +122,8 @@ use ppthch
 use ppincl
 use field
 use mesh
+use lagran
+use cs_c_bindings
 
 !===============================================================================
 
@@ -137,7 +140,7 @@ double precision dt(ncelet)
 ! Local variables
 
 integer          ivart, iel, ifac
-integer          ith, iscal, ii, ifcvsl
+integer          iscal, ifcvsl
 double precision vara, varb, varc, varam, varbm, varcm, vardm
 double precision                   varal, varbl, varcl, vardl
 double precision                   varac, varbc
@@ -190,7 +193,7 @@ if (1.eq.1) return
 !    Below, we define the same density law
 !    Values of this property must be defined at cell centers
 !      (and optionally, at boundary faces).
-!  ===================================================================
+!===============================================================================
 
 !    The test on .false. allows deactivating instructions (which are defined
 !       only as a starting example)
@@ -299,7 +302,7 @@ endif ! --- Test on .false.
 !  =========
 !    Below, we define the same viscosity law
 !    Values of this property must be defined at cell centers
-!  ===================================================================
+!===============================================================================
 
 !    The test on .false. allows deactivating instructions (which are defined
 !       only as a starting example)
@@ -350,7 +353,7 @@ endif ! --- Test on .false.
 !  =========
 !    Below, we define the same viscosity law
 !    Values of this property must be defined at cell centers
-!  ===================================================================
+!===============================================================================
 
 !    The test on .false. allows deactivating instructions (which are defined
 !       only as a starting example)
@@ -408,7 +411,7 @@ endif ! --- Test on .false.
 !  =========
 !  Below, we define the same lambda/Cp ratio law (or lambda law if temperature is used)
 !  Values of this property must be defined at cell centers
-!  ====================================================================================
+!===============================================================================
 
 !    The test on .false. allows deactivating instructions (which are defined
 !       only as a starting example)
@@ -528,35 +531,25 @@ endif ! --- Test on .false.
 !    Below, we define the same diffusivity law for all scalars (except the
 !      ones excluded above).
 !    Values of this property must be defined at cell centers
-!  ===================================================================
+!===============================================================================
 
 !    The test on .false. allows deactivating instructions (which are defined
 !       only as a starting example)
 
 if (.false.) then
 
-  do ii = 1, nscaus ! Loop on scalars
-
-    ! --- Number of user scalar 'ii' in the lsit of scalars
-    iscal = ii
-
-    ! --- If it is a thermal variable, it has already been handled above
-    ith = 0
-    if (iscal.eq.iscalt) ith = 1
+  do iscal = 1, nscaus ! Loop on scalars
 
     ! --- If the variable is a fluctuation, its diffusivity is the same
     !       as that of the scalar to which it is attached:
     !       there is nothing to do here, we move on to the next variable
     !       without setting cpro_vscalt(iel).
 
-    ! We only handle here non-thermal variables which are not fluctuations
-    if (ith.eq.0.and.iscavr(iscal).le.0) then
-
-      ! Position of variables, coefficients
-      ! -----------------------------------
+    ! We only handle here variables which are not fluctuations
+    if (iscavr(iscal).le.0) then
 
       ! --- Number of the thermal variable
-      !       To use user scalar 2 instead, write 'ivart = isca(2)'
+      !     To use user scalar 2 instead, write 'ivart = isca(2)'
 
       if (iscalt.gt.0) then
         ivart = isca(iscalt)
@@ -583,7 +576,7 @@ if (.false.) then
       endif
 
       ! --- Coefficients of laws chosen by the user
-      !       Values given here are fictitious
+      !     Values given here are fictitious
 
       varal = -3.3283d-7
       varbl =  3.6021d-5
@@ -601,13 +594,104 @@ if (.false.) then
         cpro_vscalt(iel) = (xvart*(xvart*(varal*xvart+varbl)+varcl)+vardl)
       enddo
 
-    endif ! --- Tests on 'ith' and 'iscavr'
+    endif ! --- Tests on 'iscavr'
 
   enddo ! --- Loop on scalars
 endif ! --- Test on .false.
 
+!===============================================================================
+!  Example 6: Diffusivity as a function of temperature for user scalars
+!  =========
+!    Excluding:
+!      - temperature, enthalpy (handled above)
+!      - fluctuation variances (property equal to that of the associated scalar)
+!
+!    Below, we define the same diffusivity law for all scalars (except the
+!      ones excluded above).
+!    Values of this property must be defined at cell centers
+!===============================================================================
+
+!    The test on .false. allows deactivating instructions (which are defined
+!       only as a starting example)
+
+if (.false.) then
+
+  call field_get_val_s(iprpfl(iviscl), cpro_viscl)
+  call field_get_val_s(icrom, cpro_rom)
+
+  do iscal = 1, nscaus ! Loop on scalars
+
+    ! --- If the variable is a fluctuation, its diffusivity is the same
+    !       as that of the scalar to which it is attached:
+    !       there is nothing to do here, we move on to the next variable
+    !       without setting cpro_vscalt(iel).
+
+    ! We only handle here variables which are not fluctuations
+    if (iscavr(iscal).le.0) then
+
+      ! --- Number of the thermal variable
+      !     To use user scalar 2 instead, write 'ivart = isca(2)'
+
+      if (iscalt.gt.0) then
+        ivart = isca(iscalt)
+        call field_get_val_s(ivarfl(ivart), cvar_scalt)
+      else
+        write(nfecra,9010) iscalt
+        call csexit (1)
+      endif
+
+      ! --- Scalar's Lambda
+
+      call field_get_key_int(ivarfl(isca(iscal)), kivisl, ifcvsl)
+      if (ifcvsl.ge.0) then
+        call field_get_val_s(ifcvsl, cpro_vscalt)
+      else
+        cpro_vscalt => NULL()
+      endif
+
+      ! --- Stop if Lambda is not variable
+
+      if (ifcvsl.lt.0) then
+        write(nfecra,1010) iscal
+        call csexit (1)
+      endif
+
+      ! Stokes-Einstein equation
+
+      varal =  1.38d-23 ! Boltzmann constant
+      varbl =  0.3d-9   ! Diameter of soluble ions
+
+      do iel = 1, ncel
+        xvart = cvar_scalt(iel)
+        cpro_vscalt(iel) = (cpro_rom(iel) * varal * xvart)       &
+                           /(3.d0 * pi * cpro_viscl(iel) * varbl)
+      enddo
+
+    endif ! --- Tests on 'iscavr'
+
+  enddo ! --- Loop on scalars
+endif ! --- Test on .false.
 
 !===============================================================================
+!  Example 7: Solubility as a function of temperature for user scalars
+!  =========
+!
+!    Excluding:
+!      - temperature, enthalpy (handled above)
+!      - fluctuation variances (property equal to that of the associated scalar)
+!===============================================================================
+
+!    The test on .false. allows deactivating instructions (which are defined
+!       only as a starting example)
+
+if (.false.) then
+  if (ipreci == 1) then
+    do iel = 1, ncel
+      solub(iel) = -0.0088d0 *  cvar_scalt(iel) + 3.8839d0 ! ppb (ug/L)
+      solub(iel) = solub(iel)*1.d-9 * cpro_rom(iel) ! kg/m3
+   enddo
+  endif
+endif
 
 !--------
 ! Formats
@@ -860,6 +944,7 @@ use ppincl
 use elincl
 use field
 use mesh
+use cs_c_bindings
 
 !===============================================================================
 
@@ -877,7 +962,6 @@ double precision dt(ncelet)
 ! Local variables
 
 integer          iel, ifcvsl
-integer          mode
 
 double precision tp
 double precision xkr   , xbr
@@ -982,31 +1066,16 @@ if (ippmod(ieljou).ge.1) then
 !                                scalar_diffusivity_id est >= 0 pour
 !                                les scalaires iscalt, ipotr, ipoti
 
-
-
 !       Calcul de la temperature a partir de l'enthalpie
 !       ------------------------------------------------
 
 !       Ceci depend largement des choix utilisateur en
 !         matiere de loi H-T (T en Kelvin)
 
-!       On demande de fournir cette loi dans le sous programme usthht
-!          (users/usthht.f90)
-!           usthht fournit en particulier un exemple d'interpolation
-!            a partir d'une tabulation utilisateur
-!           usthht en mode T->H sera utilise pour l'initialisation
-!            de l'enthalpie dans useliv.
-
-!       mode = 1 : h => ivarfl(isca(ihm)) -> t => iprpfl(itemp)
-  mode = 1
-
   call field_get_val_s(ivarfl(isca(iscalt)), cvar_scalt)
   call field_get_val_s(iprpfl(itemp), cpro_temp)
 
-  do iel = 1, ncel
-    call usthht (mode,cvar_scalt(iel),cpro_temp(iel))
-  enddo
-
+  call c_h_to_t(cvar_scalt, cpro_temp)
 
 !       Masse volumique au centre des cellules
 !       --------------------------------------
