@@ -260,145 +260,6 @@ endif
 end subroutine usray3
 
 
-!===============================================================================
-
-
-subroutine usray4 &
-!================
-
- ( nvar   , nscal  ,                                              &
-   mode   ,                                                       &
-   itypfb ,                                                       &
-   dt     ,                                                       &
-   tparop , hparop , tempk  )
-
-!===============================================================================
-! Purpose:
-! --------
-
-! User subroutine for input of radiative transfer parameters:
-
-!   Temperature <--> enthalpy convertion
-!   Usefull if the thermal scalar is an enthalpy.
-
-!   PRECAUTIONS: ENTHALPY MUST BE CONVERTED IN KELVIN TEMPERATURE
-
-!   Warning: it is forbidden to modify MODE in this subroutine
-
-!-------------------------------------------------------------------------------
-! Arguments
-!__________________.____._____.________________________________________________.
-! name             !type!mode ! role                                           !
-!__________________!____!_____!________________________________________________!
-! nvar             ! i  ! <-- ! total number of variables                      !
-! nscal            ! i  ! <-- ! total number of scalars                        !
-! mode             ! i  ! <-- ! convertion mode                                !
-!                  !    !     ! mode = 1 enthaly -> temperature                !
-!                  !    !     ! mode =-1 temperature -> enthaly                !
-! itypfb           ! ia ! <-- ! boundary face types                            !
-! dt(ncelet)       ! ra ! <-- ! time step (per cell)                           !
-! tparop(nfabor)   ! i  ! <-- ! temperature in kelvin for wall boundary faces  !
-! hparop(nfabor)   ! i  ! --> ! enthalpy for wall boundary faces               !
-! tempk(ncelet)    ! i  ! --> ! temperature in kelvin                          !
-!__________________!____!_____!________________________________________________!
-
-!     Type: i (integer), r (real), s (string), a (array), l (logical),
-!           and composite types (ex: ra real array)
-!     mode: <-- input, --> output, <-> modifies data, --- work array
-!===============================================================================
-
-!===============================================================================
-! Module files
-!===============================================================================
-
-use paramx
-use numvar
-use entsor
-use optcal
-use cstphy
-use cstnum
-use parall
-use period
-use ppppar
-use ppthch
-use cpincl
-use ppincl
-use radiat
-use mesh
-use field
-
-!===============================================================================
-
-implicit none
-
-! Arguments
-
-integer          nvar   , nscal
-
-integer          mode
-
-integer          itypfb(nfabor)
-
-double precision dt(ncelet)
-
-double precision tempk(ncelet)
-double precision tparop(nfabor), hparop(nfabor)
-
-! Local variables
-
-integer          iel , ifac
-
-double precision, dimension(:), pointer :: cvara_scal
-
-!===============================================================================
-!  1.1 - Tempearature in Kelvin for cells
-!===============================================================================
-
-!---> enthalpy -> temperature convertion (MODE =  1)
-!     -----------------------------------------------
-
-
-if (mode.eq.1) then
-
-  call field_get_val_prev_s(ivarfl(isca(iscalt)), cvara_scal)
-
-  do iel = 1,ncel
-    call usthht(mode,cvara_scal(iel),tempk(iel))
-  enddo
-
-endif
-
-
-!===============================================================================
-!  1.2 - Enthalpy for wall boundary faces
-!===============================================================================
-
-!---> Temperature -> enthalpy (MODE = -1)
-!     -----------------------------------
-
-
-if (mode.eq.-1) then
-
-  do ifac = 1,nfabor
-
-    if (itypfb(ifac).eq.iparoi .or.                               &
-        itypfb(ifac).eq.iparug )then
-
-      call usthht(mode,hparop(ifac),tparop(ifac))
-
-    endif
-
-  enddo
-
-endif
-
-!----
-! End
-!----
-
-return
-end subroutine usray4
-
 !===============================================================================
 
 subroutine usray5 &
@@ -418,7 +279,7 @@ subroutine usray5 &
 
 ! Compute the net radiation flux:
 
-!      The density of net radiation flux must calculated
+!      The density of net radiation flux must be calculated
 !        consistently with the boundary conditions of the intensity.
 !      The density of net flux is the balance between the radiative
 !      emiting part of a boudary face (and not the reflecting one)
