@@ -118,6 +118,7 @@ use ppthch
 use ppincl
 use field
 use mesh
+use cs_cf_bindings
 
 !===============================================================================
 
@@ -143,7 +144,7 @@ double precision xvart
 
 double precision, dimension(:), pointer :: cpro_viscl, cpro_viscv
 double precision, dimension(:), pointer :: cpro_vtmpk, cpro_vscal
-double precision, dimension(:), pointer :: cpro_cp, cpro_cv
+double precision, dimension(:), pointer :: cpro_cp, cpro_cv, mix_mol_mas
 double precision, dimension(:), pointer :: cvar_scalt
 !< [loc_var_dec]
 
@@ -270,13 +271,6 @@ enddo
 !    of the temperature. All variables are evaluated at the cell centers.
 !===============================================================================
 
-! Warning:
-! =======
-! do not discard the call to the subroutine 'usthht' at the end of this
-! example: its purpose is to calculate the isochoric specific heat.
-! Indeed, this variable needs to be computed from the isobaric specific heat
-! using the thermodynamics laws.
-
 !     To refer to the user-defined scalar number 2 instead, for example, use
 !     ivart = isca(2)
 
@@ -288,7 +282,7 @@ call field_get_val_s(ivarfl(ivart), cvar_scalt)
 
 if (icp.gt.0) call field_get_val_s(iprpfl(icp), cpro_cp)
 
-! --- Stop if the iobaric or iochoric specific heat (cpro_cp or cpro_cv) has not
+! --- Stop if the isobaric or isochoric specific heat (cpro_cp or cpro_cv) has not
 !     been defined as variable
 
 if (icp.le.0) then
@@ -321,9 +315,10 @@ enddo
 ! --- The isochoric specific heat is deduced from the isobaric specific heat
 
 call field_get_val_s(iprpfl(icv), cpro_cv)
-call cf_thermo_cv(cpro_cp, cpro_cv, ncel)
-!< [example_3]
+call field_get_val_s(iprpfl(igmxml), mix_mol_mas)
+call cs_cf_thermo_cv(cpro_cp, mix_mol_mas, cpro_cv, ncel)
 
+!< [example_3]
 
 !===============================================================================
 ! Ex. 4: molecular thermal conductivity varying with temperature
