@@ -197,8 +197,8 @@ call field_get_val_s(icrom, cpro_rom)
 !  MMT = 100.d0 [kg/m2/s2] (momentum production by volume and time unit)
 !
 !which yields:
-!     crvimp(1, 1, iel) = volume(iel)* A = - volume(iel)*(rho*CKP )
-!     crvexp(1, iel) = volume(iel)* B = volume(iel)*(XMMT)
+!     crvimp(1, 1, iel) = cell_f_vol(iel)* A = - cell_f_vol(iel)*(rho*CKP )
+!     crvexp(1, iel) = cell_f_vol(iel)* B = cell_f_vol(iel)*(XMMT)
 
 ! ----------------------------------------------
 
@@ -207,11 +207,11 @@ ckp  = 10.d0
 qdm  = 100.d0
 
 do iel = 1, ncel
-  crvimp(1, 1, iel) = - volume(iel)*cpro_rom(iel)*ckp
+  crvimp(1, 1, iel) = - cell_f_vol(iel)*cpro_rom(iel)*ckp
 enddo
 
 do iel = 1, ncel
-  crvexp(1, iel) = volume(iel)*qdm
+  crvexp(1, iel) = cell_f_vol(iel)*qdm
 enddo
 
 !< [remaining_1]
@@ -289,7 +289,7 @@ end subroutine ustsnv
 ! WARNING: If scalar is the temperature, the resulting equation
 !          solved by the code is:
 !
-!  rho*Cp*volume*dT/dt + .... = crvimp*T + crvexp
+!  rho*Cp*cell_f_vol*dT/dt + .... = crvimp*T + crvexp
 !
 !
 ! Note that crvexp and crvimp are defined after the Finite Volume integration
@@ -308,7 +308,7 @@ end subroutine ustsnv
 !   where f(n) is the value of f at time tn, the beginning of the time step.
 !
 ! This yields :
-!   crvexp = volume*F(f(n))
+!   crvexp = cell_f_vol*F(f(n))
 !   crvimp = 0
 !
 ! However, if the source term is potentially steep, this fully explicit
@@ -318,8 +318,8 @@ end subroutine ustsnv
 !   df/dt = .... + dF/df*f(n+1) - dF/df*f(n) + F(f(n))
 !
 ! This yields:
-!   crvexp = volume*( F(f(n)) - dF/df*f(n) )
-!   crvimp = volume*dF/df
+!   crvexp = cell_f_vol*( F(f(n)) - dF/df*f(n) )
+!   crvimp = cell_f_vol*dF/df
 
 !-------------------------------------------------------------------------------
 ! Arguments
@@ -466,8 +466,8 @@ endif
 !     prodf  = 100.d0 [ [f]/s ] (production of f by unit of time)
 
 !which yields
-!     crvimp(iel) = volume(iel)* A = - volume(iel)*rho/tauf
-!     crvexp(iel) = volume(iel)* B =   volume(iel)*rho*prodf
+!     crvimp(iel) = cell_f_vol(iel)* A = - cell_f_vol(iel)*rho/tauf
+!     crvexp(iel) = cell_f_vol(iel)* B =   cell_f_vol(iel)*rho*prodf
 
 !===============================================================================
 
@@ -481,11 +481,11 @@ if (iscal.eq.2) then
    prodf = 100.d0
 
    do iel = 1, ncel
-      crvimp(iel) = - volume(iel)*cpro_rom(iel)/tauf
+      crvimp(iel) = - cell_f_vol(iel)*cpro_rom(iel)/tauf
    enddo
 
    do iel = 1, ncel
-      crvexp(iel) =   volume(iel)*cpro_rom(iel)*prodf
+      crvexp(iel) =   cell_f_vol(iel)*cpro_rom(iel)*prodf
    enddo
 
 endif
@@ -502,7 +502,7 @@ endif
 
 ! This yields
 !     crvimp(iel) = 0
-!     crvexp(iel) = volume(iel)* Pwatt/voltf
+!     crvexp(iel) = cell_f_vol(iel)* Pwatt/voltf
 
 !===============================================================================
 
@@ -514,8 +514,7 @@ endif
 ! by Cp because Cp is put outside the diffusion term and multiplied
 ! in the temperature equation as follows:
 !
-!  rho*Cp*volume*dT/dt + .... =  volume(iel)* Pwatt/voltf
-!
+!  rho*Cp*cell_f_vol*dT/dt + .... =  cell_f_vol(iel)* Pwatt/voltf
 
 pwatt = 100.d0
 
@@ -528,7 +527,7 @@ call getcel('x > 0.0 and x < 1.2 and y > 3.1 and '//               &
 
 do ilelt = 1, nlelt
   iel = lstelt(ilelt)
-  voltf = voltf + volume(iel)
+  voltf = voltf + cell_f_vol(iel)
 enddo
 
 if (irangp.ge.0) then
@@ -542,7 +541,7 @@ do ilelt = 1, nlelt
 ! No implicit source term
   crvimp(iel) = 0.d0
 ! Explicit source term
-  crvexp(iel) = volume(iel)*pwatt/voltf
+  crvexp(iel) = cell_f_vol(iel)*pwatt/voltf
 enddo
 !< [ex_3_apply]
 
@@ -735,8 +734,8 @@ endif
 !    (Source term on the TKE 'k' here)
 
 !      Source term for cvar_var:
-!         rho volume d(cvar_var)/dt       = ...
-!                        ... - rho*volume*ff - rho*volume*cvar_var/tau
+!         rho cell_f_vol d(cvar_var)/dt       = ...
+!                        ... - rho*cell_f_vol*ff - rho*cell_f_vol*cvar_var/tau
 
 !      With ff=3.d0 and tau = 4.d0
 
@@ -761,13 +760,13 @@ if (.false.) then
 
     ! --- Explicit source terms
     do iel = 1, ncel
-      crvexp(iel) = -cpro_rom(iel)*volume(iel)*ff
+      crvexp(iel) = -cpro_rom(iel)*cell_f_vol(iel)*ff
     enddo
 
     ! --- Implicit source terms
     !        crvimp is already initialized to 0, no need to set it here
     do iel = 1, ncel
-      crvimp(iel) = -cpro_rom(iel)*volume(iel)/tau
+      crvimp(iel) = -cpro_rom(iel)*cell_f_vol(iel)/tau
     enddo
 
   endif
